/*========================== begin_copyright_notice ============================

Copyright (C) 2023 Intel Corporation

SPDX-License-Identifier: MIT

============================= end_copyright_notice ===========================*/

//     File Name:  md_metric_sets_PVC_GT2.cpp
//
//     Abstract:   C++ automated generated file that defines Metric Sets
//                 for each Concurrent Group

#include "md_metric_sets_PVC_GT2.h"
#include <algorithm>

#if MD_INCLUDE_PVC_GT2_METRICS

namespace MetricsDiscoveryInternal::MetricSets_PVC_GT2_PipelineStatistics
{
    CPipelineStatsMetricSet::CPipelineStatsMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CPipelineStatsMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "", 0, 0, 0x80000206, 0, 0, "", 0, "Intel_Raw_Pipeline_Statistics_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "IAVertices", "Input vertices",
                          "The total number of vertices that entered the 3D Pipeline.",
                          "3D Pipe/Input Assembler", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_IA * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "vertices", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "IAPrimitives", "Input primitives",
                          "The total number of rendering primitives assembled and put into the input assembly stage of the 3D Pipeline.",
                          "3D Pipe/Input Assembler", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_IA * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "triangles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsInvocations", "VS per vertex invocations",
                          "The total number of times a vertex shader was invoked. 3D rendering invokes the vertex shader once per vertex.",
                          "3D Pipe/Vertex Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_VS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsInvocations", "HS invocations",
                          "The total number of times a hull shader was invoked.",
                          "3D Pipe/Hull Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_HS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,hull|control,HS|TCS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsInvocations", "DS invocations",
                          "The total number of times a domain shader was invoked.",
                          "3D Pipe/Domain Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_DS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,domain|evaluation,DS|TES", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsInvocations", "GS per triangle invocations",
                          "The total number of times a geometry shader was invoked per triangle.",
                          "3D Pipe/Geometry Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_GS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x18" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsPrimitives", "Post-GS primitives",
                          "The total number of primitives that flowed through from GS to the clipper if GS was enabled.",
                          "3D Pipe/Geometry Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_GS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "triangles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x20" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ClipperInvocations", "Clipper invocations",
                          "The total number of primitives sent to the Clipper.",
                          "3D Pipe/Clipper", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_CL * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "triangles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x28" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ClipperPrimitives", "Clipper primitives",
                          "The total number of primitives that flowed out of the Clipper.",
                          "3D Pipe/Clipper", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_CL * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "triangles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsInvocations", "PS invocations",
                          "The total number of times a pixel shader was invoked. 3D rendering invokes a pixel shader once per pixel or subsample.",
                          "3D Pipe/Pixel Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_PS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS,pixel|fragment", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x38" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsInvocations", "CS invocations",
                          "The total number of times a compute shader was invoked.",
                          "3D Pipe/Compute Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_CS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CpsInvocations", "CPS invocations",
                          "The total number of times a coarse shader was invoked.",
                          "3D Pipe/Compute Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_CS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
        }

        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
} // namespace MetricsDiscoveryInternal::MetricSets_PVC_GT2_PipelineStatistics

namespace MetricsDiscoveryInternal::MetricSets_PVC_GT2_OA
{
    void AddInformationSet( CConcurrentGroup* concurrentGroup )
    {
        CInformation* information = nullptr;
        information               = concurrentGroup->AddInformation( "QueryBeginTime", "Query Begin Time", "The measurement begin time.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM | API_TYPE_MEDIA, INFORMATION_TYPE_TIMESTAMP, "ns", nullptr, 0 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" );
            information->SetDeltaReportReadEquation( "qw@0x1c0" );
            information->SetOverflowFunction( "NS_TIME" );
        }

        information = concurrentGroup->AddInformation( "CoreFrequencyMHz", "GPU Core Frequency", "The last GPU core (unslice) frequency in the measurement.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM, INFORMATION_TYPE_VALUE, "MHz", nullptr, 1 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 0x1ff AND 16666 UMUL 1000 UDIV" );
            information->SetDeltaReportReadEquation( "qw@0x218 1000000 UDIV" );
        }

        information = concurrentGroup->AddInformation( "XveSliceFrequencyMHz", "XVE Slice Frequency", "The last GPU Execution Unit slice frequency in the measurement.", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_VALUE, "MHz", nullptr, 2 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 25 >> dw@0x0 9 >> 0x3 AND OR 16666 UMUL 1000 UDIV" );
        }

        information = concurrentGroup->AddInformation( "ReportReason", "Report Reason", "The reason of the report.", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_REPORT_REASON, nullptr, nullptr, 3 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "0x40 dw@0x0 19 >> 0x3f AND 0x0 == UMUL dw@0x0 19 >> 0x3f AND OR" );
        }

        information = concurrentGroup->AddInformation( "ContextIdValid", "Context ID Valid", "When set indicates render context is valid", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_FLAG, nullptr, nullptr, 4 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 16 >> 0x1 AND" );
        }

        information = concurrentGroup->AddInformation( "ContextId", "Context ID", "The context tag in which report has been taken.", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_CONTEXT_ID_TAG, nullptr, nullptr, 5 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x08 0xffbfffff AND dw@0x0 16 >> 0x1 AND UMUL" );
        }

        information = concurrentGroup->AddInformation( "CoreFrequencyChanged", "GPU Core Frequency Changed", "The flag indicating that GPU core frequency has changed.", "Exception", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 6 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x214" );
        }

        information = concurrentGroup->AddInformation( "QuerySplitOccurred", "Query Split Occurred", "The flag indicating that query has been split during execution on the GPU.", "Exception", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 7 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x210" );
        }

        information = concurrentGroup->AddInformation( "ReportId", "Query report id", "Query report identification number.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_VALUE, nullptr, nullptr, 8 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x220" );
        }

        information = concurrentGroup->AddInformation( "ReportsCount", "Query reports count", "The number of available query reports.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_VALUE, nullptr, nullptr, 9 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x224" );
        }

        information = concurrentGroup->AddInformation( "OverrunOccured", "Query Overrun Occurred", "The flag indicating that Oa buffer has been overran.", "Exception", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 10 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1dc" );
        }

        information = concurrentGroup->AddInformation( "SampleSequence", "Sample sequence", "Number identifying report sequence.", "Report Meta Data", API_TYPE_BBSTREAM, INFORMATION_TYPE_VALUE, nullptr, nullptr, 11 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 0x7f AND" );
        }

        information = concurrentGroup->AddInformation( "SamplePhase", "Sample phase", "Buffer execution phase.", "Report Meta Data", API_TYPE_BBSTREAM, INFORMATION_TYPE_SAMPLE_PHASE, nullptr, nullptr, 12 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 7 >> 0x01 AND" );
        }

        information = concurrentGroup->AddInformation( "GpuNode", "Gpu node", "GPU node buffer was sent to.", "Report Meta Data", API_TYPE_BBSTREAM, INFORMATION_TYPE_GPU_NODE, nullptr, nullptr, 13 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 8 >> 0x07 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryTimer", "Mid Query Timer", "The flag indicating that timer report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 14 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x01 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryProgramming", "Mid Query Programming", "The flag indicating that counter programming report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 15 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x02 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryMarker", "Mid Query Marker", "The flag indicating that query marker report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 16 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x04 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryCtxSwitch", "Mid Query Context Switch", "The flag indicating that context switch report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 17 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x08 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryC6", "Mid Query C6", "The flag indicating that C6 report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 18 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x10 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryFreqChange", "Mid Query Freq Change", "The flag indicating that frequency change report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 19 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x20 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryMmioTrigger", "Mid Query Mmio Trigger", "The flag indicating that mmio trigger report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 20 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x40 AND" );
        }

        information = concurrentGroup->AddInformation( "StreamMarker", "Stream marker", "Stream marker value.", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_VALUE, nullptr, nullptr, 21 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x08 dw@0x0 19 >> 0x8 AND 0x0 == UMUL" );
        }

        information = concurrentGroup->AddInformation( "ReportError", "Query report error", "An error in the query execution, the received report should be ignored.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 22 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x13 AND" );
        }

        information = concurrentGroup->AddInformation( "ReportLost", "Query report lost", "Begin or end query report has not been triggered due to hw limitations.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 23 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x01 AND" );
        }

        information = concurrentGroup->AddInformation( "ReportInconsistent", "Query report inconsistent", "The contextId inconsistency in the Oa buffer within the query window.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 24 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x02 AND" );
        }

        information = concurrentGroup->AddInformation( "ReportCtxSwitchLost", "Query report context switch lost", "Oa buffer has not been browsed to find context switch reports to filter out unfamiliar contexts from the query report.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 25 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x08 AND" );
        }

        information = concurrentGroup->AddInformation( "ReportWithoutWorkload", "Query report missing workload", "Missing workload between query begin and query end.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 26 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x10 AND" );
        }
    }

    CComputeBasicMetricSet::CComputeBasicMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CComputeBasicMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_BYTE_READ", "L3 BYTE READ",
                          "Number of bytes read from L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "4096 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_BYTE_WRITE", "L3 BYTE WRITE",
                          "Number of bytes written to L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD dw@0xcc UADD dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD qw@0x158 UADD qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "4096 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_COMPUTE_THREAD_COUNT", "XVE COMPUTE THREAD COUNT",
                          "Number of compute shader hardware threads dispatched",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ATOMIC_ACCESS_COUNT", "XVE ATOMIC ACCESS COUNT",
                          "Number of shader atomic memory accesses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x120" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BARRIER_MESSAGE_COUNT", "XVE BARRIER MESSAGE COUNT",
                          "Number of shader barrier messages",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x9c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x128" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL", "XVE INST EXECUTED ALU0 ALL",
                          "Number of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL", "XVE INST EXECUTED ALU1 ALL",
                          "Number of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_ALL", "XVE INST EXECUTED XMX ALL",
                          "Number of execution slots taken by instructions executed on XMX pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL", "XVE INST EXECUTED SEND ALL",
                          "Number of instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_CONTROL_ALL", "XVE INST EXECUTED CONTROL ALL",
                          "Number of instructions executed on Jump Pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_ALU1_ACTIVE", "XVE PIPE ALU0 AND ALU1 ACTIVE",
                          "Percentage of time in which ALU0 and ALU1 pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_XMX_ACTIVE", "XVE_PIPE_ALU0_AND_XMX_ACTIVE",
                          "Percentage of time in which ALU0 and XMX pipes are both actively executing a Gen ISA instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL_UTILIZATION", "XVE INST EXECUTED ALU0 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL_UTILIZATION", "XVE INST EXECUTED ALU1 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL_UTILIZATION", "XVE INST EXECUTED SEND ALL UTILIZATION",
                          "Percentage of time taken by instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 23 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_CONTROL_ALL_UTILIZATION", "XVE INST EXECUTED CONTROL ALL UTILIZATION",
                          "Percentage of time taken by instructions executed on Jump pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 24 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_ALL_UTILIZATION", "XVE INST EXECUTED XMX ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on XMX pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 25 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06617000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06002000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08007005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06082005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08087000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a610005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1261000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00200010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02200010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02000010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00280002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02280002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e08000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06487000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06827000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08480140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10480340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1082000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066d7140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e6d0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06697000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c690340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140a5e5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340a5e5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01410a0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f410a0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f504444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0c4c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f19010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f19010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f24444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f42020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cb0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d31002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf4040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c11000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c11000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x285000a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500a08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x305000a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32501400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2250060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26501405, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f501010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f01010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f21010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec2020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef2020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f72020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc1010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf1010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c01010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d61010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cb0101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00009001, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x0000a003, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x01002001, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CGpuOffloadMetricSet::CGpuOffloadMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CGpuOffloadMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HOST_TO_GPUMEM_BYTE_READ", "HOST TO GPUMEM BYTE READ",
                          "Number of bytes read by host from GPU local (HBM) memory (downstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "64 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HOST_TO_GPUMEM_BYTE_WRITE", "HOST TO GPUMEM BYTE WRITE",
                          "Number of bytes written by host to GPU local (HBM) memory (downstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "64 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SYSMEM_BYTE_READ", "SYSMEM BYTE READ",
                          "Number of system memory bytes read (upstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "64 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SYSMEM_BYTE_WRITE", "SYSMEM BYTE WRITE",
                          "Number of system memory bytes written (upstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "64 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_DATA_BYTE_RECEIVE", "STACK TO STACK DATA BYTE RECEIVE",
                          "Number of data bytes received (incoming write read return)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 dw@0xd4 dw@0xd0 UADD dw@0xcc UADD dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 qw@0x168 qw@0x160 UADD qw@0x158 UADD qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_DATA_BYTE_TRANSMIT", "STACK TO STACK DATA BYTE TRANSMIT",
                          "Number of data bytes sent (outgoing write read return)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD dw@0xdc UADD dw@0xd8 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD qw@0x178 UADD qw@0x170 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_COMPUTE_THREAD_COUNT", "XVE COMPUTE THREAD COUNT",
                          "Number of compute shader hardware threads dispatched",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14307be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04306000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0030000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e300342, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10300920, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02300000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x245000a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2650140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d45414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16d40014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405a95, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x334000a9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f410002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030455aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0106f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f400a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d20e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d32002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d30012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d40140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d400c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd40440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed407d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d45414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16d40014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5001c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f001c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f201c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d001c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d15015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d201c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad40411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemProfileMetricSet::CMemProfileMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemProfileMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SCALEUP_DATA_BYTE_RECEIVE", "SCALEUP DATA BYTE RECEIVE",
                          "Number of data bytes received (incoming write read return to GPU)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 dw@0xf4 dw@0xf8 UADD dw@0xfc UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 qw@0x1a8 qw@0x1b0 UADD qw@0x1b8 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SCALEUP_DATA_BYTE_TRANSMIT", "SCALEUP DATA BYTE TRANSMIT",
                          "Number of data bytes sent (outgoing write read return from GPU)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 dw@0xe8 dw@0xec UADD dw@0xf0 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 qw@0x190 qw@0x198 UADD qw@0x1a0 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_COMPUTE_THREAD_COUNT", "XVE COMPUTE THREAD COUNT",
                          "Number of compute shader hardware threads dispatched",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d45014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16d40015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d15550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d2fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed40617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10d400d9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d40144, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataportProfileMetricSet::CDataportProfileMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataportProfileMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DATAPORT_BYTE_READ", "DATAPORT BYTE READ ",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $XeCoreTotalCount $GpuCoreClocks UMUL UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DATAPORT_BYTE_WRITE", "DATAPORT BYTE WRITE ",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "32 dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD dw@0xcc UADD dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "32 qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD qw@0x158 UADD qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "32 $XeCoreTotalCount $GpuCoreClocks UMUL UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_COMPUTE_THREAD_COUNT", "XVE COMPUTE THREAD COUNT",
                          "Number of compute shader hardware threads dispatched",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30843, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30043, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1ProfileReadsMetricSet_XeCore0::CL1ProfileReadsMetricSet_XeCore0( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1ProfileReadsMetricSet_XeCore0::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ", "LOAD STORE CACHE BYTE READ",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 $XeCoreTotalCount UMUL dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 $XeCoreTotalCount UMUL qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "512 $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SLM_BYTE_READ", "SLM BYTE READ",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 $XeCoreTotalCount UMUL dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 $XeCoreTotalCount UMUL qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "512 $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_COMPUTE_THREAD_COUNT", "XVE COMPUTE THREAD COUNT",
                          "Number of compute shader hardware threads dispatched",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x007f0000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000fe7f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc00, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc04, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc08, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc0c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc10, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc14, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc18, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc1c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc20, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc24, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc28, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc2c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc30, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc34, 0x0000fdfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1ProfileReadsMetricSet_XeCore4::CL1ProfileReadsMetricSet_XeCore4( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1ProfileReadsMetricSet_XeCore4::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ", "LOAD STORE CACHE BYTE READ",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 $XeCoreTotalCount UMUL dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD UMUL $GtSlice0XeCore4 $GtSlice1XeCore4 UADD $GtSlice2XeCore4 UADD $GtSlice3XeCore4 UADD $GtSlice4XeCore4 UADD $GtSlice5XeCore4 UADD $GtSlice6XeCore4 UADD $GtSlice7XeCore4 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 $XeCoreTotalCount UMUL qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD UMUL $GtSlice0XeCore4 $GtSlice1XeCore4 UADD $GtSlice2XeCore4 UADD $GtSlice3XeCore4 UADD $GtSlice4XeCore4 UADD $GtSlice5XeCore4 UADD $GtSlice6XeCore4 UADD $GtSlice7XeCore4 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "512 $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SLM_BYTE_READ", "SLM BYTE READ",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 $XeCoreTotalCount UMUL dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB UMUL $GtSlice0XeCore4 $GtSlice1XeCore4 UADD $GtSlice2XeCore4 UADD $GtSlice3XeCore4 UADD $GtSlice4XeCore4 UADD $GtSlice5XeCore4 UADD $GtSlice6XeCore4 UADD $GtSlice7XeCore4 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 $XeCoreTotalCount UMUL qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB UMUL $GtSlice0XeCore4 $GtSlice1XeCore4 UADD $GtSlice2XeCore4 UADD $GtSlice3XeCore4 UADD $GtSlice4XeCore4 UADD $GtSlice5XeCore4 UADD $GtSlice6XeCore4 UADD $GtSlice7XeCore4 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "512 $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_COMPUTE_THREAD_COUNT", "XVE COMPUTE THREAD COUNT",
                          "Number of compute shader hardware threads dispatched",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x007f0000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000fe7f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc00, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc04, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc08, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc0c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc10, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc14, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc18, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc1c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc20, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc24, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc28, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc2c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc30, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc34, 0x0000fdfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1ProfileSlmBankConflictsMetricSet_XeCore0::CL1ProfileSlmBankConflictsMetricSet_XeCore0( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1ProfileSlmBankConflictsMetricSet_XeCore0::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT", "SLM BANK CONFLICT COUNT",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD UADD dw@0xdc 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD UADD dw@0xcc 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD UADD UMUL $XeCoreTotalCount UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD UADD qw@0x178 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD UADD qw@0x158 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD UADD UMUL $XeCoreTotalCount UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_COMPUTE_THREAD_COUNT", "XVE COMPUTE THREAD COUNT",
                          "Number of compute shader hardware threads dispatched",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1ProfileSlmBankConflictsMetricSet_XeCore4::CL1ProfileSlmBankConflictsMetricSet_XeCore4( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1ProfileSlmBankConflictsMetricSet_XeCore4::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT", "SLM BANK CONFLICT COUNT",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD UADD dw@0xdc 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD UADD dw@0xcc 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD UADD UMUL $XeCoreTotalCount UMUL $GtSlice0XeCore4 $GtSlice1XeCore4 UADD $GtSlice2XeCore4 UADD $GtSlice3XeCore4 UADD $GtSlice4XeCore4 UADD $GtSlice5XeCore4 UADD $GtSlice6XeCore4 UADD $GtSlice7XeCore4 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD UADD qw@0x178 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD UADD qw@0x158 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD UADD UMUL $XeCoreTotalCount UMUL $GtSlice0XeCore4 $GtSlice1XeCore4 UADD $GtSlice2XeCore4 UADD $GtSlice3XeCore4 UADD $GtSlice4XeCore4 UADD $GtSlice5XeCore4 UADD $GtSlice6XeCore4 UADD $GtSlice7XeCore4 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_COMPUTE_THREAD_COUNT", "XVE COMPUTE THREAD COUNT",
                          "Number of compute shader hardware threads dispatched",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e4007e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e54201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe5001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30408, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1ProfileWritesMetricSet_XeCore0::CL1ProfileWritesMetricSet_XeCore0( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1ProfileWritesMetricSet_XeCore0::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE", "LOAD STORE CACHE BYTE WRITE",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 $XeCoreTotalCount UMUL dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 $XeCoreTotalCount UMUL qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "256 $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SLM_BYTE_WRITE", "SLM BYTE WRITE",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 $XeCoreTotalCount UMUL dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 $XeCoreTotalCount UMUL qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "256 $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_COMPUTE_THREAD_COUNT", "XVE COMPUTE THREAD COUNT",
                          "Number of compute shader hardware threads dispatched",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x007f0000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000fe7f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc00, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc04, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc08, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc0c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc10, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc14, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc18, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc1c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc20, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc24, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc28, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc2c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc30, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc34, 0x0000fdfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1ProfileWritesMetricSet_XeCore4::CL1ProfileWritesMetricSet_XeCore4( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1ProfileWritesMetricSet_XeCore4::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE", "LOAD STORE CACHE BYTE WRITE",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 $XeCoreTotalCount UMUL dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD UMUL $GtSlice0XeCore4 $GtSlice1XeCore4 UADD $GtSlice2XeCore4 UADD $GtSlice3XeCore4 UADD $GtSlice4XeCore4 UADD $GtSlice5XeCore4 UADD $GtSlice6XeCore4 UADD $GtSlice7XeCore4 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 $XeCoreTotalCount UMUL qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD UMUL $GtSlice0XeCore4 $GtSlice1XeCore4 UADD $GtSlice2XeCore4 UADD $GtSlice3XeCore4 UADD $GtSlice4XeCore4 UADD $GtSlice5XeCore4 UADD $GtSlice6XeCore4 UADD $GtSlice7XeCore4 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "256 $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SLM_BYTE_WRITE", "SLM BYTE WRITE",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 $XeCoreTotalCount UMUL dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB UMUL $GtSlice0XeCore4 $GtSlice1XeCore4 UADD $GtSlice2XeCore4 UADD $GtSlice3XeCore4 UADD $GtSlice4XeCore4 UADD $GtSlice5XeCore4 UADD $GtSlice6XeCore4 UADD $GtSlice7XeCore4 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 $XeCoreTotalCount UMUL qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB UMUL $GtSlice0XeCore4 $GtSlice1XeCore4 UADD $GtSlice2XeCore4 UADD $GtSlice3XeCore4 UADD $GtSlice4XeCore4 UADD $GtSlice5XeCore4 UADD $GtSlice6XeCore4 UADD $GtSlice7XeCore4 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "256 $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1024 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_COMPUTE_THREAD_COUNT", "XVE COMPUTE THREAD COUNT",
                          "Number of compute shader hardware threads dispatched",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x007f0000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000fe7f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc00, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc04, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc08, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc0c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc10, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc14, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc18, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc1c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc20, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc24, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc28, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc2c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc30, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc34, 0x0000fdfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTestOaMetricSet::CTestOaMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTestOaMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter0", "TestCounter0",
                          "HW test counter 0. Factor: 0.0",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter1", "TestCounter1",
                          "HW test counter 1. Factor: 1.0",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter2", "TestCounter2",
                          "HW test counter 2. Factor: 1.0",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter3", "TestCounter3",
                          "HW test counter 3. Factor: 0.5",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter4", "TestCounter4",
                          "HW test counter 4. Factor: 0.3333",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter5", "TestCounter5",
                          "HW test counter 5. Factor: 0.3333",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter6", "TestCounter6",
                          "HW test counter 6. Factor: 0.16666",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter7", "TestCounter7",
                          "HW test counter 7. Factor: 0.6666",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter8", "TestCounter8",
                          "HW test counter 8. Should be equal to 1 in IOStream or in OAG query mode",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3b410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33400001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07410006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f410cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000007, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00100002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00100002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00100082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x001000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00100001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ffe7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport1MetricSet::CDataport1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE0", "DATAPORT BYTE READ XECORE0",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE1", "DATAPORT BYTE READ XECORE1",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE2", "DATAPORT BYTE READ XECORE2",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE3", "DATAPORT BYTE READ XECORE3",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE4", "DATAPORT BYTE READ XECORE4",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE5", "DATAPORT BYTE READ XECORE5",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE6", "DATAPORT BYTE READ XECORE6",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE7", "DATAPORT BYTE READ XECORE7",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE0", "DATAPORT BYTE WRITE XECORE0",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE1", "DATAPORT BYTE WRITE XECORE1",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE2", "DATAPORT BYTE WRITE XECORE2",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE3", "DATAPORT BYTE WRITE XECORE3",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE4", "DATAPORT BYTE WRITE XECORE4",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE5", "DATAPORT BYTE WRITE XECORE5",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE6", "DATAPORT BYTE WRITE XECORE6",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE7", "DATAPORT BYTE WRITE XECORE7",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport2MetricSet::CDataport2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE8", "DATAPORT BYTE READ XECORE8",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE9", "DATAPORT BYTE READ XECORE9",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE10", "DATAPORT BYTE READ XECORE10",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE11", "DATAPORT BYTE READ XECORE11",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE12", "DATAPORT BYTE READ XECORE12",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE13", "DATAPORT BYTE READ XECORE13",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE14", "DATAPORT BYTE READ XECORE14",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE15", "DATAPORT BYTE READ XECORE15",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE8", "DATAPORT BYTE WRITE XECORE8",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE9", "DATAPORT BYTE WRITE XECORE9",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE10", "DATAPORT BYTE WRITE XECORE10",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE11", "DATAPORT BYTE WRITE XECORE11",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE12", "DATAPORT BYTE WRITE XECORE12",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE13", "DATAPORT BYTE WRITE XECORE13",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE14", "DATAPORT BYTE WRITE XECORE14",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE15", "DATAPORT BYTE WRITE XECORE15",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport3MetricSet::CDataport3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE16", "DATAPORT BYTE READ XECORE16",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE17", "DATAPORT BYTE READ XECORE17",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE18", "DATAPORT BYTE READ XECORE18",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE19", "DATAPORT BYTE READ XECORE19",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE20", "DATAPORT BYTE READ XECORE20",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE21", "DATAPORT BYTE READ XECORE21",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE22", "DATAPORT BYTE READ XECORE22",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE23", "DATAPORT BYTE READ XECORE23",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE16", "DATAPORT BYTE WRITE XECORE16",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE17", "DATAPORT BYTE WRITE XECORE17",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE18", "DATAPORT BYTE WRITE XECORE18",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE19", "DATAPORT BYTE WRITE XECORE19",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE20", "DATAPORT BYTE WRITE XECORE20",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE21", "DATAPORT BYTE WRITE XECORE21",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE22", "DATAPORT BYTE WRITE XECORE22",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE23", "DATAPORT BYTE WRITE XECORE23",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport4MetricSet::CDataport4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE24", "DATAPORT BYTE READ XECORE24",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE25", "DATAPORT BYTE READ XECORE25",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE26", "DATAPORT BYTE READ XECORE26",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE27", "DATAPORT BYTE READ XECORE27",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE28", "DATAPORT BYTE READ XECORE28",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE29", "DATAPORT BYTE READ XECORE29",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE30", "DATAPORT BYTE READ XECORE30",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE31", "DATAPORT BYTE READ XECORE31",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE24", "DATAPORT BYTE WRITE XECORE24",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE25", "DATAPORT BYTE WRITE XECORE25",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE26", "DATAPORT BYTE WRITE XECORE26",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE27", "DATAPORT BYTE WRITE XECORE27",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE28", "DATAPORT BYTE WRITE XECORE28",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE29", "DATAPORT BYTE WRITE XECORE29",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE30", "DATAPORT BYTE WRITE XECORE30",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE31", "DATAPORT BYTE WRITE XECORE31",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport5MetricSet::CDataport5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE32", "DATAPORT BYTE READ XECORE32",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE33", "DATAPORT BYTE READ XECORE33",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE34", "DATAPORT BYTE READ XECORE34",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE35", "DATAPORT BYTE READ XECORE35",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE36", "DATAPORT BYTE READ XECORE36",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE37", "DATAPORT BYTE READ XECORE37",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE38", "DATAPORT BYTE READ XECORE38",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE39", "DATAPORT BYTE READ XECORE39",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE32", "DATAPORT BYTE WRITE XECORE32",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE33", "DATAPORT BYTE WRITE XECORE33",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE34", "DATAPORT BYTE WRITE XECORE34",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE35", "DATAPORT BYTE WRITE XECORE35",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE36", "DATAPORT BYTE WRITE XECORE36",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE37", "DATAPORT BYTE WRITE XECORE37",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE38", "DATAPORT BYTE WRITE XECORE38",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE39", "DATAPORT BYTE WRITE XECORE39",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport6MetricSet::CDataport6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE40", "DATAPORT BYTE READ XECORE40",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE41", "DATAPORT BYTE READ XECORE41",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE42", "DATAPORT BYTE READ XECORE42",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE43", "DATAPORT BYTE READ XECORE43",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE44", "DATAPORT BYTE READ XECORE44",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE45", "DATAPORT BYTE READ XECORE45",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE46", "DATAPORT BYTE READ XECORE46",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE47", "DATAPORT BYTE READ XECORE47",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE40", "DATAPORT BYTE WRITE XECORE40",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE41", "DATAPORT BYTE WRITE XECORE41",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE42", "DATAPORT BYTE WRITE XECORE42",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE43", "DATAPORT BYTE WRITE XECORE43",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE44", "DATAPORT BYTE WRITE XECORE44",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE45", "DATAPORT BYTE WRITE XECORE45",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE46", "DATAPORT BYTE WRITE XECORE46",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE47", "DATAPORT BYTE WRITE XECORE47",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport7MetricSet::CDataport7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE48", "DATAPORT BYTE READ XECORE48",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE49", "DATAPORT BYTE READ XECORE49",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE50", "DATAPORT BYTE READ XECORE50",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE51", "DATAPORT BYTE READ XECORE51",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE52", "DATAPORT BYTE READ XECORE52",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE53", "DATAPORT BYTE READ XECORE53",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE54", "DATAPORT BYTE READ XECORE54",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE55", "DATAPORT BYTE READ XECORE55",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE48", "DATAPORT BYTE WRITE XECORE48",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE49", "DATAPORT BYTE WRITE XECORE49",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE50", "DATAPORT BYTE WRITE XECORE50",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE51", "DATAPORT BYTE WRITE XECORE51",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE52", "DATAPORT BYTE WRITE XECORE52",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE53", "DATAPORT BYTE WRITE XECORE53",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE54", "DATAPORT BYTE WRITE XECORE54",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE55", "DATAPORT BYTE WRITE XECORE55",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport8MetricSet::CDataport8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE56", "DATAPORT BYTE READ XECORE56",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE57", "DATAPORT BYTE READ XECORE57",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE58", "DATAPORT BYTE READ XECORE58",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE59", "DATAPORT BYTE READ XECORE59",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE60", "DATAPORT BYTE READ XECORE60",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE61", "DATAPORT BYTE READ XECORE61",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE62", "DATAPORT BYTE READ XECORE62",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE63", "DATAPORT BYTE READ XECORE63",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE56", "DATAPORT BYTE WRITE XECORE56",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE57", "DATAPORT BYTE WRITE XECORE57",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE58", "DATAPORT BYTE WRITE XECORE58",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE59", "DATAPORT BYTE WRITE XECORE59",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE60", "DATAPORT BYTE WRITE XECORE60",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE61", "DATAPORT BYTE WRITE XECORE61",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE62", "DATAPORT BYTE WRITE XECORE62",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE63", "DATAPORT BYTE WRITE XECORE63",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 32 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3303a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3b03a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330780, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport9MetricSet::CDataport9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE0", "DATAPORT INPUT AVAILABLE XECORE0",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE1", "DATAPORT INPUT AVAILABLE XECORE1",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE2", "DATAPORT INPUT AVAILABLE XECORE2",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE3", "DATAPORT INPUT AVAILABLE XECORE3",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE4", "DATAPORT INPUT AVAILABLE XECORE4",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE5", "DATAPORT INPUT AVAILABLE XECORE5",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE6", "DATAPORT INPUT AVAILABLE XECORE6",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE7", "DATAPORT INPUT AVAILABLE XECORE7",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE0", "DATAPORT OUTPUT READY XECORE0",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE1", "DATAPORT OUTPUT READY XECORE1",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE2", "DATAPORT OUTPUT READY XECORE2",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE3", "DATAPORT OUTPUT READY XECORE3",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE4", "DATAPORT OUTPUT READY XECORE4",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE5", "DATAPORT OUTPUT READY XECORE5",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE6", "DATAPORT OUTPUT READY XECORE6",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE7", "DATAPORT OUTPUT READY XECORE7",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport10MetricSet::CDataport10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE8", "DATAPORT INPUT AVAILABLE XECORE8",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE9", "DATAPORT INPUT AVAILABLE XECORE9",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE10", "DATAPORT INPUT AVAILABLE XECORE10",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE11", "DATAPORT INPUT AVAILABLE XECORE11",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE12", "DATAPORT INPUT AVAILABLE XECORE12",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE13", "DATAPORT INPUT AVAILABLE XECORE13",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE14", "DATAPORT INPUT AVAILABLE XECORE14",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE15", "DATAPORT INPUT AVAILABLE XECORE15",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE8", "DATAPORT OUTPUT READY XECORE8",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE9", "DATAPORT OUTPUT READY XECORE9",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE10", "DATAPORT OUTPUT READY XECORE10",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE11", "DATAPORT OUTPUT READY XECORE11",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE12", "DATAPORT OUTPUT READY XECORE12",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE13", "DATAPORT OUTPUT READY XECORE13",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE14", "DATAPORT OUTPUT READY XECORE14",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE15", "DATAPORT OUTPUT READY XECORE15",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport11MetricSet::CDataport11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE16", "DATAPORT INPUT AVAILABLE XECORE16",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE17", "DATAPORT INPUT AVAILABLE XECORE17",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE18", "DATAPORT INPUT AVAILABLE XECORE18",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE19", "DATAPORT INPUT AVAILABLE XECORE19",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE20", "DATAPORT INPUT AVAILABLE XECORE20",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE21", "DATAPORT INPUT AVAILABLE XECORE21",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE22", "DATAPORT INPUT AVAILABLE XECORE22",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE23", "DATAPORT INPUT AVAILABLE XECORE23",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE16", "DATAPORT OUTPUT READY XECORE16",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE17", "DATAPORT OUTPUT READY XECORE17",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE18", "DATAPORT OUTPUT READY XECORE18",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE19", "DATAPORT OUTPUT READY XECORE19",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE20", "DATAPORT OUTPUT READY XECORE20",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE21", "DATAPORT OUTPUT READY XECORE21",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE22", "DATAPORT OUTPUT READY XECORE22",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE23", "DATAPORT OUTPUT READY XECORE23",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport12MetricSet::CDataport12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE24", "DATAPORT INPUT AVAILABLE XECORE24",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE25", "DATAPORT INPUT AVAILABLE XECORE25",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE26", "DATAPORT INPUT AVAILABLE XECORE26",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE27", "DATAPORT INPUT AVAILABLE XECORE27",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE28", "DATAPORT INPUT AVAILABLE XECORE28",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE29", "DATAPORT INPUT AVAILABLE XECORE29",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE30", "DATAPORT INPUT AVAILABLE XECORE30",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE31", "DATAPORT INPUT AVAILABLE XECORE31",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE24", "DATAPORT OUTPUT READY XECORE24",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE25", "DATAPORT OUTPUT READY XECORE25",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE26", "DATAPORT OUTPUT READY XECORE26",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE27", "DATAPORT OUTPUT READY XECORE27",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE28", "DATAPORT OUTPUT READY XECORE28",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE29", "DATAPORT OUTPUT READY XECORE29",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE30", "DATAPORT OUTPUT READY XECORE30",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE31", "DATAPORT OUTPUT READY XECORE31",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport13MetricSet::CDataport13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE32", "DATAPORT INPUT AVAILABLE XECORE32",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE33", "DATAPORT INPUT AVAILABLE XECORE33",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE34", "DATAPORT INPUT AVAILABLE XECORE34",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE35", "DATAPORT INPUT AVAILABLE XECORE35",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE36", "DATAPORT INPUT AVAILABLE XECORE36",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE37", "DATAPORT INPUT AVAILABLE XECORE37",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE38", "DATAPORT INPUT AVAILABLE XECORE38",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE39", "DATAPORT INPUT AVAILABLE XECORE39",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE32", "DATAPORT OUTPUT READY XECORE32",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE33", "DATAPORT OUTPUT READY XECORE33",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE34", "DATAPORT OUTPUT READY XECORE34",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE35", "DATAPORT OUTPUT READY XECORE35",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE36", "DATAPORT OUTPUT READY XECORE36",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE37", "DATAPORT OUTPUT READY XECORE37",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE38", "DATAPORT OUTPUT READY XECORE38",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE39", "DATAPORT OUTPUT READY XECORE39",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport14MetricSet::CDataport14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE40", "DATAPORT INPUT AVAILABLE XECORE40",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE41", "DATAPORT INPUT AVAILABLE XECORE41",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE42", "DATAPORT INPUT AVAILABLE XECORE42",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE43", "DATAPORT INPUT AVAILABLE XECORE43",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE44", "DATAPORT INPUT AVAILABLE XECORE44",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE45", "DATAPORT INPUT AVAILABLE XECORE45",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE46", "DATAPORT INPUT AVAILABLE XECORE46",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE47", "DATAPORT INPUT AVAILABLE XECORE47",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE40", "DATAPORT OUTPUT READY XECORE40",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE41", "DATAPORT OUTPUT READY XECORE41",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE42", "DATAPORT OUTPUT READY XECORE42",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE43", "DATAPORT OUTPUT READY XECORE43",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE44", "DATAPORT OUTPUT READY XECORE44",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE45", "DATAPORT OUTPUT READY XECORE45",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE46", "DATAPORT OUTPUT READY XECORE46",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE47", "DATAPORT OUTPUT READY XECORE47",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport15MetricSet::CDataport15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE48", "DATAPORT INPUT AVAILABLE XECORE48",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE49", "DATAPORT INPUT AVAILABLE XECORE49",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE50", "DATAPORT INPUT AVAILABLE XECORE50",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE51", "DATAPORT INPUT AVAILABLE XECORE51",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE52", "DATAPORT INPUT AVAILABLE XECORE52",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE53", "DATAPORT INPUT AVAILABLE XECORE53",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE54", "DATAPORT INPUT AVAILABLE XECORE54",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE55", "DATAPORT INPUT AVAILABLE XECORE55",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE48", "DATAPORT OUTPUT READY XECORE48",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE49", "DATAPORT OUTPUT READY XECORE49",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE50", "DATAPORT OUTPUT READY XECORE50",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE51", "DATAPORT OUTPUT READY XECORE51",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE52", "DATAPORT OUTPUT READY XECORE52",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE53", "DATAPORT OUTPUT READY XECORE53",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE54", "DATAPORT OUTPUT READY XECORE54",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE55", "DATAPORT OUTPUT READY XECORE55",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport16MetricSet::CDataport16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE56", "DATAPORT INPUT AVAILABLE XECORE56",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE57", "DATAPORT INPUT AVAILABLE XECORE57",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE58", "DATAPORT INPUT AVAILABLE XECORE58",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE59", "DATAPORT INPUT AVAILABLE XECORE59",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE60", "DATAPORT INPUT AVAILABLE XECORE60",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE61", "DATAPORT INPUT AVAILABLE XECORE61",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE62", "DATAPORT INPUT AVAILABLE XECORE62",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE63", "DATAPORT INPUT AVAILABLE XECORE63",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE56", "DATAPORT OUTPUT READY XECORE56",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE57", "DATAPORT OUTPUT READY XECORE57",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE58", "DATAPORT OUTPUT READY XECORE58",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE59", "DATAPORT OUTPUT READY XECORE59",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE60", "DATAPORT OUTPUT READY XECORE60",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE61", "DATAPORT OUTPUT READY XECORE61",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE62", "DATAPORT OUTPUT READY XECORE62",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE63", "DATAPORT OUTPUT READY XECORE63",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport17MetricSet::CDataport17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE0", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE0",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE1", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE1",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE2", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE2",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE3", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE3",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE4", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE4",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE5", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE5",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE6", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE6",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE7", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE7",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE0", "XVE DATAPORT FENCE MESSAGE COUNT XECORE0",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE1", "XVE DATAPORT FENCE MESSAGE COUNT XECORE1",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE2", "XVE DATAPORT FENCE MESSAGE COUNT XECORE2",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE3", "XVE DATAPORT FENCE MESSAGE COUNT XECORE3",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE4", "XVE DATAPORT FENCE MESSAGE COUNT XECORE4",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE5", "XVE DATAPORT FENCE MESSAGE COUNT XECORE5",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE6", "XVE DATAPORT FENCE MESSAGE COUNT XECORE6",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE7", "XVE DATAPORT FENCE MESSAGE COUNT XECORE7",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20130011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x201b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20230011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x202b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20330011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x203b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport18MetricSet::CDataport18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE8", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE8",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE9", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE9",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE10", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE10",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE11", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE11",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE12", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE12",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE13", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE13",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE14", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE14",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE15", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE15",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE8", "XVE DATAPORT FENCE MESSAGE COUNT XECORE8",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE9", "XVE DATAPORT FENCE MESSAGE COUNT XECORE9",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE10", "XVE DATAPORT FENCE MESSAGE COUNT XECORE10",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE11", "XVE DATAPORT FENCE MESSAGE COUNT XECORE11",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE12", "XVE DATAPORT FENCE MESSAGE COUNT XECORE12",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE13", "XVE DATAPORT FENCE MESSAGE COUNT XECORE13",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE14", "XVE DATAPORT FENCE MESSAGE COUNT XECORE14",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE15", "XVE DATAPORT FENCE MESSAGE COUNT XECORE15",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21030011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21130011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x211b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21230011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x212b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21330011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x213b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport19MetricSet::CDataport19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE16", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE16",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE17", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE17",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE18", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE18",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE19", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE19",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE20", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE20",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE21", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE21",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE22", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE22",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE23", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE23",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE16", "XVE DATAPORT FENCE MESSAGE COUNT XECORE16",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE17", "XVE DATAPORT FENCE MESSAGE COUNT XECORE17",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE18", "XVE DATAPORT FENCE MESSAGE COUNT XECORE18",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE19", "XVE DATAPORT FENCE MESSAGE COUNT XECORE19",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE20", "XVE DATAPORT FENCE MESSAGE COUNT XECORE20",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE21", "XVE DATAPORT FENCE MESSAGE COUNT XECORE21",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE22", "XVE DATAPORT FENCE MESSAGE COUNT XECORE22",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE23", "XVE DATAPORT FENCE MESSAGE COUNT XECORE23",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20130011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x201b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20230011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x202b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20330011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x203b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport20MetricSet::CDataport20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE24", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE24",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE25", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE25",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE26", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE26",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE27", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE27",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE28", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE28",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE29", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE29",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE30", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE30",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE31", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE31",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE24", "XVE DATAPORT FENCE MESSAGE COUNT XECORE24",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE25", "XVE DATAPORT FENCE MESSAGE COUNT XECORE25",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE26", "XVE DATAPORT FENCE MESSAGE COUNT XECORE26",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE27", "XVE DATAPORT FENCE MESSAGE COUNT XECORE27",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE28", "XVE DATAPORT FENCE MESSAGE COUNT XECORE28",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE29", "XVE DATAPORT FENCE MESSAGE COUNT XECORE29",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE30", "XVE DATAPORT FENCE MESSAGE COUNT XECORE30",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE31", "XVE DATAPORT FENCE MESSAGE COUNT XECORE31",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21030011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21130011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x211b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21230011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x212b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21330011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x213b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport21MetricSet::CDataport21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE32", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE32",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE33", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE33",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE34", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE34",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE35", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE35",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE36", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE36",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE37", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE37",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE38", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE38",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE39", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE39",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE32", "XVE DATAPORT FENCE MESSAGE COUNT XECORE32",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE33", "XVE DATAPORT FENCE MESSAGE COUNT XECORE33",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE34", "XVE DATAPORT FENCE MESSAGE COUNT XECORE34",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE35", "XVE DATAPORT FENCE MESSAGE COUNT XECORE35",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE36", "XVE DATAPORT FENCE MESSAGE COUNT XECORE36",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE37", "XVE DATAPORT FENCE MESSAGE COUNT XECORE37",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE38", "XVE DATAPORT FENCE MESSAGE COUNT XECORE38",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE39", "XVE DATAPORT FENCE MESSAGE COUNT XECORE39",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20130011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x201b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20230011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x202b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20330011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x203b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport22MetricSet::CDataport22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE40", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE40",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE41", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE41",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE42", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE42",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE43", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE43",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE44", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE44",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE45", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE45",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE46", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE46",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE47", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE47",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE40", "XVE DATAPORT FENCE MESSAGE COUNT XECORE40",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE41", "XVE DATAPORT FENCE MESSAGE COUNT XECORE41",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE42", "XVE DATAPORT FENCE MESSAGE COUNT XECORE42",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE43", "XVE DATAPORT FENCE MESSAGE COUNT XECORE43",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE44", "XVE DATAPORT FENCE MESSAGE COUNT XECORE44",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE45", "XVE DATAPORT FENCE MESSAGE COUNT XECORE45",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE46", "XVE DATAPORT FENCE MESSAGE COUNT XECORE46",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE47", "XVE DATAPORT FENCE MESSAGE COUNT XECORE47",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21030011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21130011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x211b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21230011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x212b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21330011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x213b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport23MetricSet::CDataport23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE48", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE48",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE49", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE49",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE50", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE50",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE51", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE51",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE52", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE52",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE53", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE53",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE54", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE54",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE55", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE55",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE48", "XVE DATAPORT FENCE MESSAGE COUNT XECORE48",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE49", "XVE DATAPORT FENCE MESSAGE COUNT XECORE49",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE50", "XVE DATAPORT FENCE MESSAGE COUNT XECORE50",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE51", "XVE DATAPORT FENCE MESSAGE COUNT XECORE51",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE52", "XVE DATAPORT FENCE MESSAGE COUNT XECORE52",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE53", "XVE DATAPORT FENCE MESSAGE COUNT XECORE53",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE54", "XVE DATAPORT FENCE MESSAGE COUNT XECORE54",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE55", "XVE DATAPORT FENCE MESSAGE COUNT XECORE55",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20130011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x201b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20230011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x202b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20330011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x203b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport24MetricSet::CDataport24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE56", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE56",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE57", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE57",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE58", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE58",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE59", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE59",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE60", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE60",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE61", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE61",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE62", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE62",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE63", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE63",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE56", "XVE DATAPORT FENCE MESSAGE COUNT XECORE56",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE57", "XVE DATAPORT FENCE MESSAGE COUNT XECORE57",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE58", "XVE DATAPORT FENCE MESSAGE COUNT XECORE58",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE59", "XVE DATAPORT FENCE MESSAGE COUNT XECORE59",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE60", "XVE DATAPORT FENCE MESSAGE COUNT XECORE60",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE61", "XVE DATAPORT FENCE MESSAGE COUNT XECORE61",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE62", "XVE DATAPORT FENCE MESSAGE COUNT XECORE62",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE63", "XVE DATAPORT FENCE MESSAGE COUNT XECORE63",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21030011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21130011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x211b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21230011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x212b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21330011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x213b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport25MetricSet::CDataport25MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport25MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE0", "XVE DATAPORT READ MESSAGE COUNT XECORE0",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE1", "XVE DATAPORT READ MESSAGE COUNT XECORE1",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE2", "XVE DATAPORT READ MESSAGE COUNT XECORE2",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE3", "XVE DATAPORT READ MESSAGE COUNT XECORE3",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE4", "XVE DATAPORT READ MESSAGE COUNT XECORE4",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE5", "XVE DATAPORT READ MESSAGE COUNT XECORE5",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE6", "XVE DATAPORT READ MESSAGE COUNT XECORE6",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE7", "XVE DATAPORT READ MESSAGE COUNT XECORE7",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE0", "XVE DATAPORT WRITE MESSAGE COUNT XECORE0",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE1", "XVE DATAPORT WRITE MESSAGE COUNT XECORE1",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE2", "XVE DATAPORT WRITE MESSAGE COUNT XECORE2",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE3", "XVE DATAPORT WRITE MESSAGE COUNT XECORE3",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE4", "XVE DATAPORT WRITE MESSAGE COUNT XECORE4",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE5", "XVE DATAPORT WRITE MESSAGE COUNT XECORE5",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE6", "XVE DATAPORT WRITE MESSAGE COUNT XECORE6",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE7", "XVE DATAPORT WRITE MESSAGE COUNT XECORE7",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport26MetricSet::CDataport26MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport26MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE8", "XVE DATAPORT READ MESSAGE COUNT XECORE8",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE9", "XVE DATAPORT READ MESSAGE COUNT XECORE9",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE10", "XVE DATAPORT READ MESSAGE COUNT XECORE10",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE11", "XVE DATAPORT READ MESSAGE COUNT XECORE11",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE12", "XVE DATAPORT READ MESSAGE COUNT XECORE12",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE13", "XVE DATAPORT READ MESSAGE COUNT XECORE13",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE14", "XVE DATAPORT READ MESSAGE COUNT XECORE14",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE15", "XVE DATAPORT READ MESSAGE COUNT XECORE15",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE8", "XVE DATAPORT WRITE MESSAGE COUNT XECORE8",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE9", "XVE DATAPORT WRITE MESSAGE COUNT XECORE9",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE10", "XVE DATAPORT WRITE MESSAGE COUNT XECORE10",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE11", "XVE DATAPORT WRITE MESSAGE COUNT XECORE11",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE12", "XVE DATAPORT WRITE MESSAGE COUNT XECORE12",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE13", "XVE DATAPORT WRITE MESSAGE COUNT XECORE13",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE14", "XVE DATAPORT WRITE MESSAGE COUNT XECORE14",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE15", "XVE DATAPORT WRITE MESSAGE COUNT XECORE15",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport27MetricSet::CDataport27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE16", "XVE DATAPORT READ MESSAGE COUNT XECORE16",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE17", "XVE DATAPORT READ MESSAGE COUNT XECORE17",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE18", "XVE DATAPORT READ MESSAGE COUNT XECORE18",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE19", "XVE DATAPORT READ MESSAGE COUNT XECORE19",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE20", "XVE DATAPORT READ MESSAGE COUNT XECORE20",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE21", "XVE DATAPORT READ MESSAGE COUNT XECORE21",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE22", "XVE DATAPORT READ MESSAGE COUNT XECORE22",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE23", "XVE DATAPORT READ MESSAGE COUNT XECORE23",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE16", "XVE DATAPORT WRITE MESSAGE COUNT XECORE16",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE17", "XVE DATAPORT WRITE MESSAGE COUNT XECORE17",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE18", "XVE DATAPORT WRITE MESSAGE COUNT XECORE18",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE19", "XVE DATAPORT WRITE MESSAGE COUNT XECORE19",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE20", "XVE DATAPORT WRITE MESSAGE COUNT XECORE20",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE21", "XVE DATAPORT WRITE MESSAGE COUNT XECORE21",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE22", "XVE DATAPORT WRITE MESSAGE COUNT XECORE22",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE23", "XVE DATAPORT WRITE MESSAGE COUNT XECORE23",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport28MetricSet::CDataport28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE24", "XVE DATAPORT READ MESSAGE COUNT XECORE24",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE25", "XVE DATAPORT READ MESSAGE COUNT XECORE25",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE26", "XVE DATAPORT READ MESSAGE COUNT XECORE26",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE27", "XVE DATAPORT READ MESSAGE COUNT XECORE27",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE28", "XVE DATAPORT READ MESSAGE COUNT XECORE28",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE29", "XVE DATAPORT READ MESSAGE COUNT XECORE29",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE30", "XVE DATAPORT READ MESSAGE COUNT XECORE30",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE31", "XVE DATAPORT READ MESSAGE COUNT XECORE31",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE24", "XVE DATAPORT WRITE MESSAGE COUNT XECORE24",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE25", "XVE DATAPORT WRITE MESSAGE COUNT XECORE25",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE26", "XVE DATAPORT WRITE MESSAGE COUNT XECORE26",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE27", "XVE DATAPORT WRITE MESSAGE COUNT XECORE27",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE28", "XVE DATAPORT WRITE MESSAGE COUNT XECORE28",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE29", "XVE DATAPORT WRITE MESSAGE COUNT XECORE29",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE30", "XVE DATAPORT WRITE MESSAGE COUNT XECORE30",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE31", "XVE DATAPORT WRITE MESSAGE COUNT XECORE31",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport29MetricSet::CDataport29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE32", "XVE DATAPORT READ MESSAGE COUNT XECORE32",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE33", "XVE DATAPORT READ MESSAGE COUNT XECORE33",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE34", "XVE DATAPORT READ MESSAGE COUNT XECORE34",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE35", "XVE DATAPORT READ MESSAGE COUNT XECORE35",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE36", "XVE DATAPORT READ MESSAGE COUNT XECORE36",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE37", "XVE DATAPORT READ MESSAGE COUNT XECORE37",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE38", "XVE DATAPORT READ MESSAGE COUNT XECORE38",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE39", "XVE DATAPORT READ MESSAGE COUNT XECORE39",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE32", "XVE DATAPORT WRITE MESSAGE COUNT XECORE32",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE33", "XVE DATAPORT WRITE MESSAGE COUNT XECORE33",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE34", "XVE DATAPORT WRITE MESSAGE COUNT XECORE34",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE35", "XVE DATAPORT WRITE MESSAGE COUNT XECORE35",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE36", "XVE DATAPORT WRITE MESSAGE COUNT XECORE36",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE37", "XVE DATAPORT WRITE MESSAGE COUNT XECORE37",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE38", "XVE DATAPORT WRITE MESSAGE COUNT XECORE38",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE39", "XVE DATAPORT WRITE MESSAGE COUNT XECORE39",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport30MetricSet::CDataport30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE40", "XVE DATAPORT READ MESSAGE COUNT XECORE40",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE41", "XVE DATAPORT READ MESSAGE COUNT XECORE41",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE42", "XVE DATAPORT READ MESSAGE COUNT XECORE42",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE43", "XVE DATAPORT READ MESSAGE COUNT XECORE43",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE44", "XVE DATAPORT READ MESSAGE COUNT XECORE44",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE45", "XVE DATAPORT READ MESSAGE COUNT XECORE45",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE46", "XVE DATAPORT READ MESSAGE COUNT XECORE46",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE47", "XVE DATAPORT READ MESSAGE COUNT XECORE47",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE40", "XVE DATAPORT WRITE MESSAGE COUNT XECORE40",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE41", "XVE DATAPORT WRITE MESSAGE COUNT XECORE41",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE42", "XVE DATAPORT WRITE MESSAGE COUNT XECORE42",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE43", "XVE DATAPORT WRITE MESSAGE COUNT XECORE43",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE44", "XVE DATAPORT WRITE MESSAGE COUNT XECORE44",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE45", "XVE DATAPORT WRITE MESSAGE COUNT XECORE45",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE46", "XVE DATAPORT WRITE MESSAGE COUNT XECORE46",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE47", "XVE DATAPORT WRITE MESSAGE COUNT XECORE47",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport31MetricSet::CDataport31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE48", "XVE DATAPORT READ MESSAGE COUNT XECORE48",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE49", "XVE DATAPORT READ MESSAGE COUNT XECORE49",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE50", "XVE DATAPORT READ MESSAGE COUNT XECORE50",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE51", "XVE DATAPORT READ MESSAGE COUNT XECORE51",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE52", "XVE DATAPORT READ MESSAGE COUNT XECORE52",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE53", "XVE DATAPORT READ MESSAGE COUNT XECORE53",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE54", "XVE DATAPORT READ MESSAGE COUNT XECORE54",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE55", "XVE DATAPORT READ MESSAGE COUNT XECORE55",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE48", "XVE DATAPORT WRITE MESSAGE COUNT XECORE48",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE49", "XVE DATAPORT WRITE MESSAGE COUNT XECORE49",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE50", "XVE DATAPORT WRITE MESSAGE COUNT XECORE50",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE51", "XVE DATAPORT WRITE MESSAGE COUNT XECORE51",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE52", "XVE DATAPORT WRITE MESSAGE COUNT XECORE52",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE53", "XVE DATAPORT WRITE MESSAGE COUNT XECORE53",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE54", "XVE DATAPORT WRITE MESSAGE COUNT XECORE54",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE55", "XVE DATAPORT WRITE MESSAGE COUNT XECORE55",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport32MetricSet::CDataport32MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport32MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE56", "XVE DATAPORT READ MESSAGE COUNT XECORE56",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE57", "XVE DATAPORT READ MESSAGE COUNT XECORE57",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE58", "XVE DATAPORT READ MESSAGE COUNT XECORE58",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE59", "XVE DATAPORT READ MESSAGE COUNT XECORE59",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE60", "XVE DATAPORT READ MESSAGE COUNT XECORE60",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE61", "XVE DATAPORT READ MESSAGE COUNT XECORE61",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE62", "XVE DATAPORT READ MESSAGE COUNT XECORE62",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE63", "XVE DATAPORT READ MESSAGE COUNT XECORE63",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE56", "XVE DATAPORT WRITE MESSAGE COUNT XECORE56",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE57", "XVE DATAPORT WRITE MESSAGE COUNT XECORE57",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE58", "XVE DATAPORT WRITE MESSAGE COUNT XECORE58",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE59", "XVE DATAPORT WRITE MESSAGE COUNT XECORE59",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE60", "XVE DATAPORT WRITE MESSAGE COUNT XECORE60",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE61", "XVE DATAPORT WRITE MESSAGE COUNT XECORE61",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE62", "XVE DATAPORT WRITE MESSAGE COUNT XECORE62",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE63", "XVE DATAPORT WRITE MESSAGE COUNT XECORE63",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c314db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport33MetricSet::CDataport33MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport33MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE0", "XVE DATAPORT REGISTER REQUEST COUNT XECORE0",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE1", "XVE DATAPORT REGISTER REQUEST COUNT XECORE1",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE2", "XVE DATAPORT REGISTER REQUEST COUNT XECORE2",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec 2 dw@0xe8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 2 qw@0x190 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE3", "XVE DATAPORT REGISTER REQUEST COUNT XECORE3",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 2 dw@0xe0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 2 qw@0x180 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE4", "XVE DATAPORT REGISTER REQUEST COUNT XECORE4",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc 2 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 2 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE5", "XVE DATAPORT REGISTER REQUEST COUNT XECORE5",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 2 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 2 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE6", "XVE DATAPORT REGISTER REQUEST COUNT XECORE6",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc 2 dw@0xc8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 2 qw@0x150 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE7", "XVE DATAPORT REGISTER REQUEST COUNT XECORE7",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 2 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 2 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a13000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a23000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a2b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a33000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a3b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c2b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport34MetricSet::CDataport34MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport34MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE8", "XVE DATAPORT REGISTER REQUEST COUNT XECORE8",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE9", "XVE DATAPORT REGISTER REQUEST COUNT XECORE9",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE10", "XVE DATAPORT REGISTER REQUEST COUNT XECORE10",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec 2 dw@0xe8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 2 qw@0x190 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE11", "XVE DATAPORT REGISTER REQUEST COUNT XECORE11",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 2 dw@0xe0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 2 qw@0x180 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE12", "XVE DATAPORT REGISTER REQUEST COUNT XECORE12",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc 2 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 2 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE13", "XVE DATAPORT REGISTER REQUEST COUNT XECORE13",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 2 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 2 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE14", "XVE DATAPORT REGISTER REQUEST COUNT XECORE14",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc 2 dw@0xc8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 2 qw@0x150 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE15", "XVE DATAPORT REGISTER REQUEST COUNT XECORE15",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 2 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 2 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b03000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b13000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b1b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b23000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b2b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b33000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b3b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport35MetricSet::CDataport35MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport35MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE16", "XVE DATAPORT REGISTER REQUEST COUNT XECORE16",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE17", "XVE DATAPORT REGISTER REQUEST COUNT XECORE17",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE18", "XVE DATAPORT REGISTER REQUEST COUNT XECORE18",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec 2 dw@0xe8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 2 qw@0x190 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE19", "XVE DATAPORT REGISTER REQUEST COUNT XECORE19",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 2 dw@0xe0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 2 qw@0x180 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE20", "XVE DATAPORT REGISTER REQUEST COUNT XECORE20",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc 2 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 2 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE21", "XVE DATAPORT REGISTER REQUEST COUNT XECORE21",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 2 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 2 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE22", "XVE DATAPORT REGISTER REQUEST COUNT XECORE22",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc 2 dw@0xc8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 2 qw@0x150 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE23", "XVE DATAPORT REGISTER REQUEST COUNT XECORE23",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 2 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 2 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a13000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a23000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a2b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a33000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a3b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c2b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport36MetricSet::CDataport36MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport36MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE24", "XVE DATAPORT REGISTER REQUEST COUNT XECORE24",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE25", "XVE DATAPORT REGISTER REQUEST COUNT XECORE25",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE26", "XVE DATAPORT REGISTER REQUEST COUNT XECORE26",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec 2 dw@0xe8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 2 qw@0x190 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE27", "XVE DATAPORT REGISTER REQUEST COUNT XECORE27",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 2 dw@0xe0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 2 qw@0x180 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE28", "XVE DATAPORT REGISTER REQUEST COUNT XECORE28",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc 2 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 2 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE29", "XVE DATAPORT REGISTER REQUEST COUNT XECORE29",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 2 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 2 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE30", "XVE DATAPORT REGISTER REQUEST COUNT XECORE30",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc 2 dw@0xc8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 2 qw@0x150 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE31", "XVE DATAPORT REGISTER REQUEST COUNT XECORE31",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 2 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 2 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b03000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b13000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b1b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b23000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b2b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b33000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b3b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport37MetricSet::CDataport37MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport37MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE32", "XVE DATAPORT REGISTER REQUEST COUNT XECORE32",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE33", "XVE DATAPORT REGISTER REQUEST COUNT XECORE33",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE34", "XVE DATAPORT REGISTER REQUEST COUNT XECORE34",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec 2 dw@0xe8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 2 qw@0x190 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE35", "XVE DATAPORT REGISTER REQUEST COUNT XECORE35",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 2 dw@0xe0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 2 qw@0x180 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE36", "XVE DATAPORT REGISTER REQUEST COUNT XECORE36",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc 2 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 2 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE37", "XVE DATAPORT REGISTER REQUEST COUNT XECORE37",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 2 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 2 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE38", "XVE DATAPORT REGISTER REQUEST COUNT XECORE38",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc 2 dw@0xc8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 2 qw@0x150 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE39", "XVE DATAPORT REGISTER REQUEST COUNT XECORE39",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 2 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 2 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a13000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a23000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a2b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a33000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a3b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c2b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport38MetricSet::CDataport38MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport38MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE40", "XVE DATAPORT REGISTER REQUEST COUNT XECORE40",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE41", "XVE DATAPORT REGISTER REQUEST COUNT XECORE41",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE42", "XVE DATAPORT REGISTER REQUEST COUNT XECORE42",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec 2 dw@0xe8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 2 qw@0x190 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE43", "XVE DATAPORT REGISTER REQUEST COUNT XECORE43",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 2 dw@0xe0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 2 qw@0x180 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE44", "XVE DATAPORT REGISTER REQUEST COUNT XECORE44",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc 2 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 2 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE45", "XVE DATAPORT REGISTER REQUEST COUNT XECORE45",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 2 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 2 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE46", "XVE DATAPORT REGISTER REQUEST COUNT XECORE46",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc 2 dw@0xc8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 2 qw@0x150 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE47", "XVE DATAPORT REGISTER REQUEST COUNT XECORE47",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 2 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 2 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b03000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b13000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b1b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b23000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b2b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b33000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b3b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport39MetricSet::CDataport39MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport39MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE48", "XVE DATAPORT REGISTER REQUEST COUNT XECORE48",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE49", "XVE DATAPORT REGISTER REQUEST COUNT XECORE49",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE50", "XVE DATAPORT REGISTER REQUEST COUNT XECORE50",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec 2 dw@0xe8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 2 qw@0x190 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE51", "XVE DATAPORT REGISTER REQUEST COUNT XECORE51",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 2 dw@0xe0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 2 qw@0x180 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE52", "XVE DATAPORT REGISTER REQUEST COUNT XECORE52",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc 2 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 2 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE53", "XVE DATAPORT REGISTER REQUEST COUNT XECORE53",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 2 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 2 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE54", "XVE DATAPORT REGISTER REQUEST COUNT XECORE54",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc 2 dw@0xc8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 2 qw@0x150 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE55", "XVE DATAPORT REGISTER REQUEST COUNT XECORE55",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 2 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 2 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a13000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x181b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a23000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x182b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a2b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a33000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x183b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a3b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c2b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport40MetricSet::CDataport40MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport40MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE56", "XVE DATAPORT REGISTER REQUEST COUNT XECORE56",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE57", "XVE DATAPORT REGISTER REQUEST COUNT XECORE57",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE58", "XVE DATAPORT REGISTER REQUEST COUNT XECORE58",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec 2 dw@0xe8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 2 qw@0x190 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE59", "XVE DATAPORT REGISTER REQUEST COUNT XECORE59",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 2 dw@0xe0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 2 qw@0x180 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE60", "XVE DATAPORT REGISTER REQUEST COUNT XECORE60",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc 2 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 2 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE61", "XVE DATAPORT REGISTER REQUEST COUNT XECORE61",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 2 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 2 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE62", "XVE DATAPORT REGISTER REQUEST COUNT XECORE62",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc 2 dw@0xc8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 2 qw@0x150 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE63", "XVE DATAPORT REGISTER REQUEST COUNT XECORE63",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 2 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 2 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19033800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b03000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19133800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b13000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x191b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b1b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19233800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b23000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x192b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b2b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19333800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b33000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x193b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b3b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport41MetricSet::CDataport41MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport41MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE0", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE0",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE1", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE1",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE2", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE2",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE3", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE3",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE4", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE4",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE5", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE5",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE6", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE6",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE7", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE7",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE8", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE8",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE9", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE9",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE10", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE10",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE11", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE11",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE12", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE12",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE13", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE13",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE14", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE14",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE15", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE15",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport42MetricSet::CDataport42MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport42MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE16", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE16",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE17", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE17",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE18", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE18",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE19", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE19",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE20", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE20",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE21", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE21",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE22", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE22",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE23", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE23",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE24", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE24",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE25", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE25",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE26", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE26",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE27", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE27",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE28", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE28",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE29", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE29",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE30", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE30",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE31", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE31",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport43MetricSet::CDataport43MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport43MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE32", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE32",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE33", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE33",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE34", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE34",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE35", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE35",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE36", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE36",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE37", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE37",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE38", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE38",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE39", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE39",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE40", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE40",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE41", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE41",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE42", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE42",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE43", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE43",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE44", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE44",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE45", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE45",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE46", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE46",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE47", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE47",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataport44MetricSet::CDataport44MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataport44MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE48", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE48",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE49", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE49",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE50", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE50",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE51", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE51",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE52", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE52",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE53", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE53",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE54", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE54",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE55", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE55",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE56", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE56",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE57", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE57",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE58", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE58",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE59", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE59",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE60", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE60",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE61", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE61",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE62", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE62",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE63", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE63",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f037580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b7016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f137000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f237000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f337000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CFrontEnd1MetricSet::CFrontEnd1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CFrontEnd1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS0", "COMMAND PARSER COMPUTE ENGINE BUSY CCS0",
                          "Percentage of time in which there is a context loaded and active on the compute queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS1", "COMMAND PARSER COMPUTE ENGINE BUSY CCS1",
                          "Percentage of time in which there is a context loaded and active on the compute queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS2", "COMMAND PARSER COMPUTE ENGINE BUSY CCS2",
                          "Percentage of time in which there is a context loaded and active on the compute queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS3", "COMMAND PARSER COMPUTE ENGINE BUSY CCS3",
                          "Percentage of time in which there is a context loaded and active on the compute queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_BUSY", "COMMAND PARSER COMPUTE ENGINE BUSY",
                          "Percentage of time in which there is a context loaded and active on the compute queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS0 $COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS1 FADD $COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS2 FADD $COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS3 FADD 4 FDIV $GpuCoreClocks FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COPY_ENGINE_BUSY", "COMMAND PARSER COPY ENGINE BUSY",
                          "Percentage of time in which there is a context loaded and active on the copy queue.",
                          "CopyEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENGINE_BUSY_VDBOXSLIM0", "COMMAND PARSER VIDEO ENGINE BUSY VDBOXSLIM0",
                          "Percentage of time in which there is a context loaded and active on the media queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENGINE_BUSY_VDBOXSLIM1", "COMMAND PARSER VIDEO ENGINE BUSY VDBOXSLIM1",
                          "Percentage of time in which there is a context loaded and active on the media queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENGINE_BUSY_VDBOXFULL0", "COMMAND PARSER VIDEO ENGINE BUSY VDBOXFULL0",
                          "Percentage of time in which there is a context loaded and active on the media queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COPY_ENGINE_BUSY_L3NODE0", "COMMAND PARSER COPY ENGINE BUSY L3NODE0",
                          "Percentage of time in which there is a context loaded and active on the copy queue.",
                          "CopyEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COPY_ENGINE_BUSY_L3NODE1", "COMMAND PARSER COPY ENGINE BUSY L3NODE1",
                          "Percentage of time in which there is a context loaded and active on the copy queue.",
                          "CopyEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COPY_ENGINE_BUSY_L3NODE2", "COMMAND PARSER COPY ENGINE BUSY L3NODE2",
                          "Percentage of time in which there is a context loaded and active on the copy queue.",
                          "CopyEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COPY_ENGINE_BUSY_L3NODE3", "COMMAND PARSER COPY ENGINE BUSY L3NODE3",
                          "Percentage of time in which there is a context loaded and active on the copy queue.",
                          "CopyEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COPY_ENGINE_BUSY_L3NODE4", "COMMAND PARSER COPY ENGINE BUSY L3NODE4",
                          "Percentage of time in which there is a context loaded and active on the copy queue.",
                          "CopyEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COPY_ENGINE_BUSY_L3NODE5", "COMMAND PARSER COPY ENGINE BUSY L3NODE5",
                          "Percentage of time in which there is a context loaded and active on the copy queue.",
                          "CopyEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COPY_ENGINE_BUSY_L3NODE6", "COMMAND PARSER COPY ENGINE BUSY L3NODE6",
                          "Percentage of time in which there is a context loaded and active on the copy queue.",
                          "CopyEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COPY_ENGINE_BUSY_L3NODE7", "COMMAND PARSER COPY ENGINE BUSY L3NODE7",
                          "Percentage of time in which there is a context loaded and active on the copy queue.",
                          "CopyEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17407c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21407c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b417c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23417c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b417c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x43287c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x43207c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f57c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d57c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x45307c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03400504, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11400100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15400500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140a5f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03411409, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05410020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13410900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15410114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01410a0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f410005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05280022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15280014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03280000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01280000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01250200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05200022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13200500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03200000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01200000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035545, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aa9a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f000c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f200c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f49000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d14000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d20080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad50100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03110006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031e0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03100005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07300022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15300014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05300000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03300000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f57c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d57c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d50100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f57c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d57c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d50100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f57c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d57c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d50100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2250160c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x245000b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2650180b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CFrontEnd2MetricSet::CFrontEnd2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CFrontEnd2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS0", "COMMAND PARSER COMPUTE ENGINE DISPATCH KERNEL COUNT CCS0",
                          "Number of compute walker commands parsed on the compute engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS1", "COMMAND PARSER COMPUTE ENGINE DISPATCH KERNEL COUNT CCS1",
                          "Number of compute walker commands parsed on the compute engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS2", "COMMAND PARSER COMPUTE ENGINE DISPATCH KERNEL COUNT CCS2",
                          "Number of compute walker commands parsed on the compute engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS3", "COMMAND PARSER COMPUTE ENGINE DISPATCH KERNEL COUNT CCS3",
                          "Number of compute walker commands parsed on the compute engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_FLUSH_COUNT", "COMMAND PARSER FLUSH COUNT",
                          "Number of stalling flushes at the top of the pipe",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2540001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d40001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f41001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2741001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f41001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03400900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05400009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11400900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15400400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0341240d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x054100a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13410800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15410010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050f800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache1MetricSet::CL1Cache1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE0", "LOAD STORE CACHE INPUT AVAILABLE XECORE0",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE0", "LOAD STORE CACHE OUTPUT READY XECORE0",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache2MetricSet::CL1Cache2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE1", "LOAD STORE CACHE INPUT AVAILABLE XECORE1",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE1", "LOAD STORE CACHE OUTPUT READY XECORE1",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1acc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ccc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22cc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ccd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ecd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22cd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24cd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04cc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08cc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0acc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ccc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10cc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12cc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14cc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04cd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06cd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08cd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0acd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ecd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10cd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12cd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache3MetricSet::CL1Cache3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE2", "LOAD STORE CACHE INPUT AVAILABLE XECORE2",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE2", "LOAD STORE CACHE OUTPUT READY XECORE2",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ad40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cd40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20d40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cd50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ed50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10d40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10d5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache4MetricSet::CL1Cache4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE3", "LOAD STORE CACHE INPUT AVAILABLE XECORE3",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE3", "LOAD STORE CACHE OUTPUT READY XECORE3",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1adc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cdc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20dc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22dc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cdd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1edd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22dd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24dd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04dc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08dc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0adc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cdc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10dc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12dc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14dc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04dd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06dd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08dd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0add0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0edd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10dd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12dd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00def0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache5MetricSet::CL1Cache5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE4", "LOAD STORE CACHE INPUT AVAILABLE XECORE4",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE4", "LOAD STORE CACHE OUTPUT READY XECORE4",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache6MetricSet::CL1Cache6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE5", "LOAD STORE CACHE INPUT AVAILABLE XECORE5",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE5", "LOAD STORE CACHE OUTPUT READY XECORE5",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aec0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cec0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20ec0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22ec0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ced0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1eed0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22ed0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24ed0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ec4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04ec00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aec0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ec0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12ec076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ec000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04ed4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06ed60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ed0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aed0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0eed0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ed076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12ed000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache7MetricSet::CL1Cache7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE6", "LOAD STORE CACHE INPUT AVAILABLE XECORE6",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE6", "LOAD STORE CACHE OUTPUT READY XECORE6",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1af40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cf40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20f40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cf50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ef50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10f40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12f4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ef50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10f5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12f5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache8MetricSet::CL1Cache8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE7", "LOAD STORE CACHE INPUT AVAILABLE XECORE7",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE7", "LOAD STORE CACHE OUTPUT READY XECORE7",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1afc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cfc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20fc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22fc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cfd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1efd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22fd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24fd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08fc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0afc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cfc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10fc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12fc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14fc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06fd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08fd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0afd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0efd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10fd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12fd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache9MetricSet::CL1Cache9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE8", "LOAD STORE CACHE INPUT AVAILABLE XECORE8",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE8", "LOAD STORE CACHE OUTPUT READY XECORE8",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache10MetricSet::CL1Cache10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE9", "LOAD STORE CACHE INPUT AVAILABLE XECORE9",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE9", "LOAD STORE CACHE OUTPUT READY XECORE9",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bcc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dcc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23cc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dcd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fcd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23cd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25cd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05cc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09cc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bcc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dcc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11cc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13cc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15cc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05cd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07cd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09cd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bcd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fcd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11cd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13cd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache11MetricSet::CL1Cache11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE10", "LOAD STORE CACHE INPUT AVAILABLE XECORE10",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE10", "LOAD STORE CACHE OUTPUT READY XECORE10",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bd40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dd40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21d40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23d40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dd50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fd50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23d50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25d50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11d40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13d4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15d4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07d560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fd50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11d5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13d5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache12MetricSet::CL1Cache12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE11", "LOAD STORE CACHE INPUT AVAILABLE XECORE11",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE11", "LOAD STORE CACHE OUTPUT READY XECORE11",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bdc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ddc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21dc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23dc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ddd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fdd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23dd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25dd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05dc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09dc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bdc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ddc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11dc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13dc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15dc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05dd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07dd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09dd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bdd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fdd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11dd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13dd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01def0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache13MetricSet::CL1Cache13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE12", "LOAD STORE CACHE INPUT AVAILABLE XECORE12",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE12", "LOAD STORE CACHE OUTPUT READY XECORE12",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache14MetricSet::CL1Cache14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE13", "LOAD STORE CACHE INPUT AVAILABLE XECORE13",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE13", "LOAD STORE CACHE OUTPUT READY XECORE13",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bec0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dec0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21ec0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23ec0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ded0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fed0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23ed0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25ed0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ec4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05ec00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bec0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ec0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13ec076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ec000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05ed4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07ed60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ed0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bed0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fed0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ed076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13ed000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01eef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache15MetricSet::CL1Cache15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE14", "LOAD STORE CACHE INPUT AVAILABLE XECORE14",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE14", "LOAD STORE CACHE OUTPUT READY XECORE14",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bf40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1df40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21f40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23f40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1df50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ff50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23f50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25f50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11f40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13f4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15f4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ff50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11f5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13f5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache16MetricSet::CL1Cache16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE15", "LOAD STORE CACHE INPUT AVAILABLE XECORE15",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE15", "LOAD STORE CACHE OUTPUT READY XECORE15",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bfc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dfc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21fc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23fc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dfd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ffd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23fd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25fd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09fc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bfc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dfc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11fc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13fc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15fc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07fd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09fd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bfd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ffd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11fd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13fd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache17MetricSet::CL1Cache17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE16", "LOAD STORE CACHE INPUT AVAILABLE XECORE16",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE16", "LOAD STORE CACHE OUTPUT READY XECORE16",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache18MetricSet::CL1Cache18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE17", "LOAD STORE CACHE INPUT AVAILABLE XECORE17",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE17", "LOAD STORE CACHE OUTPUT READY XECORE17",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1acc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ccc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22cc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ccd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ecd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22cd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24cd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04cc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08cc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0acc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ccc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10cc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12cc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14cc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04cd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06cd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08cd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0acd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ecd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10cd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12cd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache19MetricSet::CL1Cache19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE18", "LOAD STORE CACHE INPUT AVAILABLE XECORE18",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE18", "LOAD STORE CACHE OUTPUT READY XECORE18",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ad40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cd40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20d40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cd50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ed50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10d40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10d5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache20MetricSet::CL1Cache20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE19", "LOAD STORE CACHE INPUT AVAILABLE XECORE19",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE19", "LOAD STORE CACHE OUTPUT READY XECORE19",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1adc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cdc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20dc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22dc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cdd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1edd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22dd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24dd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04dc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08dc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0adc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cdc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10dc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12dc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14dc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04dd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06dd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08dd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0add0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0edd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10dd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12dd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00def0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache21MetricSet::CL1Cache21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE20", "LOAD STORE CACHE INPUT AVAILABLE XECORE20",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE20", "LOAD STORE CACHE OUTPUT READY XECORE20",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache22MetricSet::CL1Cache22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE21", "LOAD STORE CACHE INPUT AVAILABLE XECORE21",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE21", "LOAD STORE CACHE OUTPUT READY XECORE21",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aec0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cec0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20ec0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22ec0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ced0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1eed0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22ed0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24ed0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ec4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04ec00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aec0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ec0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12ec076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ec000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04ed4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06ed60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ed0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aed0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0eed0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ed076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12ed000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache23MetricSet::CL1Cache23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE22", "LOAD STORE CACHE INPUT AVAILABLE XECORE22",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE22", "LOAD STORE CACHE OUTPUT READY XECORE22",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1af40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cf40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20f40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cf50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ef50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10f40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12f4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ef50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10f5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12f5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache24MetricSet::CL1Cache24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE23", "LOAD STORE CACHE INPUT AVAILABLE XECORE23",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE23", "LOAD STORE CACHE OUTPUT READY XECORE23",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1afc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cfc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20fc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22fc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cfd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1efd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22fd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24fd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08fc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0afc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cfc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10fc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12fc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14fc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06fd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08fd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0afd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0efd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10fd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12fd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache25MetricSet::CL1Cache25MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache25MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE24", "LOAD STORE CACHE INPUT AVAILABLE XECORE24",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE24", "LOAD STORE CACHE OUTPUT READY XECORE24",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache26MetricSet::CL1Cache26MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache26MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE25", "LOAD STORE CACHE INPUT AVAILABLE XECORE25",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE25", "LOAD STORE CACHE OUTPUT READY XECORE25",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bcc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dcc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23cc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dcd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fcd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23cd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25cd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05cc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09cc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bcc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dcc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11cc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13cc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15cc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05cd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07cd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09cd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bcd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fcd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11cd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13cd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache27MetricSet::CL1Cache27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE26", "LOAD STORE CACHE INPUT AVAILABLE XECORE26",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE26", "LOAD STORE CACHE OUTPUT READY XECORE26",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bd40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dd40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21d40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23d40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dd50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fd50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23d50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25d50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11d40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13d4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15d4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07d560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fd50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11d5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13d5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache28MetricSet::CL1Cache28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE27", "LOAD STORE CACHE INPUT AVAILABLE XECORE27",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE27", "LOAD STORE CACHE OUTPUT READY XECORE27",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bdc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ddc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21dc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23dc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ddd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fdd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23dd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25dd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05dc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09dc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bdc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ddc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11dc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13dc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15dc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05dd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07dd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09dd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bdd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fdd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11dd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13dd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01def0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache29MetricSet::CL1Cache29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE28", "LOAD STORE CACHE INPUT AVAILABLE XECORE28",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE28", "LOAD STORE CACHE OUTPUT READY XECORE28",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache30MetricSet::CL1Cache30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE29", "LOAD STORE CACHE INPUT AVAILABLE XECORE29",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE29", "LOAD STORE CACHE OUTPUT READY XECORE29",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bec0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dec0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21ec0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23ec0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ded0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fed0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23ed0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25ed0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ec4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05ec00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bec0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ec0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13ec076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ec000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05ed4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07ed60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ed0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bed0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fed0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ed076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13ed000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01eef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache31MetricSet::CL1Cache31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE30", "LOAD STORE CACHE INPUT AVAILABLE XECORE30",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE30", "LOAD STORE CACHE OUTPUT READY XECORE30",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bf40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1df40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21f40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23f40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1df50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ff50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23f50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25f50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11f40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13f4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15f4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ff50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11f5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13f5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache32MetricSet::CL1Cache32MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache32MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE31", "LOAD STORE CACHE INPUT AVAILABLE XECORE31",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE31", "LOAD STORE CACHE OUTPUT READY XECORE31",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bfc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dfc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21fc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23fc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dfd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ffd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23fd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25fd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09fc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bfc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dfc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11fc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13fc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15fc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07fd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09fd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bfd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ffd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11fd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13fd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache33MetricSet::CL1Cache33MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache33MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE32", "LOAD STORE CACHE INPUT AVAILABLE XECORE32",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE32", "LOAD STORE CACHE OUTPUT READY XECORE32",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache34MetricSet::CL1Cache34MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache34MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE33", "LOAD STORE CACHE INPUT AVAILABLE XECORE33",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE33", "LOAD STORE CACHE OUTPUT READY XECORE33",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1acc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ccc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22cc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ccd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ecd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22cd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24cd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04cc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08cc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0acc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ccc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10cc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12cc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14cc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04cd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06cd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08cd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0acd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ecd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10cd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12cd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache35MetricSet::CL1Cache35MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache35MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE34", "LOAD STORE CACHE INPUT AVAILABLE XECORE34",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE34", "LOAD STORE CACHE OUTPUT READY XECORE34",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ad40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cd40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20d40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cd50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ed50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10d40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10d5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache36MetricSet::CL1Cache36MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache36MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE35", "LOAD STORE CACHE INPUT AVAILABLE XECORE35",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE35", "LOAD STORE CACHE OUTPUT READY XECORE35",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1adc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cdc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20dc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22dc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cdd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1edd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22dd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24dd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04dc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08dc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0adc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cdc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10dc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12dc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14dc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04dd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06dd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08dd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0add0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0edd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10dd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12dd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00def0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache37MetricSet::CL1Cache37MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache37MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE36", "LOAD STORE CACHE INPUT AVAILABLE XECORE36",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE36", "LOAD STORE CACHE OUTPUT READY XECORE36",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache38MetricSet::CL1Cache38MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache38MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE37", "LOAD STORE CACHE INPUT AVAILABLE XECORE37",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE37", "LOAD STORE CACHE OUTPUT READY XECORE37",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aec0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cec0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20ec0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22ec0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ced0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1eed0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22ed0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24ed0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ec4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04ec00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aec0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ec0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12ec076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ec000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04ed4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06ed60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ed0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aed0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0eed0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ed076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12ed000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache39MetricSet::CL1Cache39MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache39MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE38", "LOAD STORE CACHE INPUT AVAILABLE XECORE38",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE38", "LOAD STORE CACHE OUTPUT READY XECORE38",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1af40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cf40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20f40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cf50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ef50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10f40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12f4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ef50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10f5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12f5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache40MetricSet::CL1Cache40MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache40MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE39", "LOAD STORE CACHE INPUT AVAILABLE XECORE39",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE39", "LOAD STORE CACHE OUTPUT READY XECORE39",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1afc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cfc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20fc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22fc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cfd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1efd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22fd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24fd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08fc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0afc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cfc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10fc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12fc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14fc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06fd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08fd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0afd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0efd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10fd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12fd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache41MetricSet::CL1Cache41MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache41MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE40", "LOAD STORE CACHE INPUT AVAILABLE XECORE40",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE40", "LOAD STORE CACHE OUTPUT READY XECORE40",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache42MetricSet::CL1Cache42MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache42MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE41", "LOAD STORE CACHE INPUT AVAILABLE XECORE41",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE41", "LOAD STORE CACHE OUTPUT READY XECORE41",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bcc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dcc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23cc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dcd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fcd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23cd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25cd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05cc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09cc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bcc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dcc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11cc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13cc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15cc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05cd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07cd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09cd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bcd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fcd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11cd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13cd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache43MetricSet::CL1Cache43MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache43MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE42", "LOAD STORE CACHE INPUT AVAILABLE XECORE42",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE42", "LOAD STORE CACHE OUTPUT READY XECORE42",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bd40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dd40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21d40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23d40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dd50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fd50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23d50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25d50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11d40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13d4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15d4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07d560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fd50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11d5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13d5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache44MetricSet::CL1Cache44MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache44MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE43", "LOAD STORE CACHE INPUT AVAILABLE XECORE43",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE43", "LOAD STORE CACHE OUTPUT READY XECORE43",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bdc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ddc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21dc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23dc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ddd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fdd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23dd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25dd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05dc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09dc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bdc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ddc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11dc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13dc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15dc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05dd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07dd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09dd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bdd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fdd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11dd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13dd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01def0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache45MetricSet::CL1Cache45MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache45MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE44", "LOAD STORE CACHE INPUT AVAILABLE XECORE44",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE44", "LOAD STORE CACHE OUTPUT READY XECORE44",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache46MetricSet::CL1Cache46MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache46MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE45", "LOAD STORE CACHE INPUT AVAILABLE XECORE45",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE45", "LOAD STORE CACHE OUTPUT READY XECORE45",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bec0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dec0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21ec0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23ec0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ded0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fed0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23ed0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25ed0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ec4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05ec00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bec0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ec0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13ec076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ec000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05ed4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07ed60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ed0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bed0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fed0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ed076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13ed000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01eef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache47MetricSet::CL1Cache47MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache47MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE46", "LOAD STORE CACHE INPUT AVAILABLE XECORE46",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE46", "LOAD STORE CACHE OUTPUT READY XECORE46",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bf40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1df40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21f40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23f40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1df50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ff50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23f50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25f50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11f40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13f4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15f4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ff50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11f5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13f5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache48MetricSet::CL1Cache48MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache48MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE47", "LOAD STORE CACHE INPUT AVAILABLE XECORE47",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE47", "LOAD STORE CACHE OUTPUT READY XECORE47",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bfc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dfc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21fc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23fc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dfd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ffd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23fd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25fd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09fc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bfc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dfc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11fc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13fc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15fc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07fd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09fd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bfd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ffd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11fd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13fd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache49MetricSet::CL1Cache49MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache49MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE48", "LOAD STORE CACHE INPUT AVAILABLE XECORE48",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE48", "LOAD STORE CACHE OUTPUT READY XECORE48",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache50MetricSet::CL1Cache50MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache50MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE49", "LOAD STORE CACHE INPUT AVAILABLE XECORE49",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE49", "LOAD STORE CACHE OUTPUT READY XECORE49",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1acc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ccc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22cc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ccd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ecd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22cd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24cd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04cc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08cc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0acc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ccc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10cc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12cc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14cc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04cd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06cd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08cd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0acd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ecd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10cd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12cd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache51MetricSet::CL1Cache51MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache51MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE50", "LOAD STORE CACHE INPUT AVAILABLE XECORE50",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE50", "LOAD STORE CACHE OUTPUT READY XECORE50",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ad40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cd40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20d40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cd50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ed50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10d40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10d5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache52MetricSet::CL1Cache52MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache52MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE51", "LOAD STORE CACHE INPUT AVAILABLE XECORE51",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE51", "LOAD STORE CACHE OUTPUT READY XECORE51",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1adc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cdc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20dc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22dc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cdd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1edd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22dd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24dd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04dc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08dc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0adc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cdc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10dc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12dc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14dc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04dd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06dd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08dd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0add0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0edd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10dd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12dd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00def0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache53MetricSet::CL1Cache53MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache53MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE52", "LOAD STORE CACHE INPUT AVAILABLE XECORE52",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE52", "LOAD STORE CACHE OUTPUT READY XECORE52",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache54MetricSet::CL1Cache54MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache54MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE53", "LOAD STORE CACHE INPUT AVAILABLE XECORE53",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE53", "LOAD STORE CACHE OUTPUT READY XECORE53",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aec0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cec0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20ec0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22ec0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ced0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1eed0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22ed0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24ed0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ec4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04ec00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aec0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ec0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12ec076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ec000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04ed4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06ed60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ed0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aed0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0eed0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ed076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12ed000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache55MetricSet::CL1Cache55MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache55MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE54", "LOAD STORE CACHE INPUT AVAILABLE XECORE54",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE54", "LOAD STORE CACHE OUTPUT READY XECORE54",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1af40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cf40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20f40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cf50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ef50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10f40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12f4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ef50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10f5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12f5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache56MetricSet::CL1Cache56MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache56MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE55", "LOAD STORE CACHE INPUT AVAILABLE XECORE55",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE55", "LOAD STORE CACHE OUTPUT READY XECORE55",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1afc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cfc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20fc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22fc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cfd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1efd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22fd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24fd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08fc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0afc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cfc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10fc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12fc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14fc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06fd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08fd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0afd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0efd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10fd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12fd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache57MetricSet::CL1Cache57MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache57MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE56", "LOAD STORE CACHE INPUT AVAILABLE XECORE56",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE56", "LOAD STORE CACHE OUTPUT READY XECORE56",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27c44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache58MetricSet::CL1Cache58MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache58MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE57", "LOAD STORE CACHE INPUT AVAILABLE XECORE57",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE57", "LOAD STORE CACHE OUTPUT READY XECORE57",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bcc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dcc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23cc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27cc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dcd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fcd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23cd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25cd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29cd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05cc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09cc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bcc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dcc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11cc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13cc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15cc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05cd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07cd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09cd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bcd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fcd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11cd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13cd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache59MetricSet::CL1Cache59MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache59MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE58", "LOAD STORE CACHE INPUT AVAILABLE XECORE58",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE58", "LOAD STORE CACHE OUTPUT READY XECORE58",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bd40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dd40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21d40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23d40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27d44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dd50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fd50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23d50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25d50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29d54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11d40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13d4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15d4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07d560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fd50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11d5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13d5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache60MetricSet::CL1Cache60MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache60MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE59", "LOAD STORE CACHE INPUT AVAILABLE XECORE59",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE59", "LOAD STORE CACHE OUTPUT READY XECORE59",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bdc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ddc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21dc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23dc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27dc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ddd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fdd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23dd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25dd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29dd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05dc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09dc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bdc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ddc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11dc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13dc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15dc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05dd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07dd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09dd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bdd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fdd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11dd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13dd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01def0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache61MetricSet::CL1Cache61MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache61MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE60", "LOAD STORE CACHE INPUT AVAILABLE XECORE60",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE60", "LOAD STORE CACHE OUTPUT READY XECORE60",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27e44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache62MetricSet::CL1Cache62MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache62MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE61", "LOAD STORE CACHE INPUT AVAILABLE XECORE61",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE61", "LOAD STORE CACHE OUTPUT READY XECORE61",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bec0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dec0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21ec0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23ec0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27ec4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ded0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fed0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23ed0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25ed0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29ed4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ec4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05ec00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bec0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ec0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13ec076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ec000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05ed4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07ed60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ed0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bed0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fed0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ed076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13ed000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01eef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache63MetricSet::CL1Cache63MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache63MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE62", "LOAD STORE CACHE INPUT AVAILABLE XECORE62",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE62", "LOAD STORE CACHE OUTPUT READY XECORE62",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bf40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1df40260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21f40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23f40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27f44c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1df50800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ff50260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23f50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25f50013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29f54c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f44514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f400a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11f40f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13f4076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15f4000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f54514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f560a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f50420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ff50f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11f5076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13f5000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache64MetricSet::CL1Cache64MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache64MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE63", "LOAD STORE CACHE INPUT AVAILABLE XECORE63",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD dw@0xec FADD dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD qw@0x198 FADD qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE63", "LOAD STORE CACHE OUTPUT READY XECORE63",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD dw@0xcc FADD dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD qw@0x158 FADD qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 8 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bfc0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dfc0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21fc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23fc0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27fc4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dfd0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ffd0260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23fd0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25fd0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29fd4c02, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fc4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fc00a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09fc0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bfc0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dfc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11fc0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13fc076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15fc000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fd4514, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07fd60a2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09fd0420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bfd0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ffd0f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11fd076d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13fd000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fef0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache65MetricSet::CL1Cache65MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache65MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE0", "LOAD STORE CACHE L3 READ XECORE0",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE1", "LOAD STORE CACHE L3 READ XECORE1",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE2", "LOAD STORE CACHE L3 READ XECORE2",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE3", "LOAD STORE CACHE L3 READ XECORE3",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE4", "LOAD STORE CACHE L3 READ XECORE4",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE5", "LOAD STORE CACHE L3 READ XECORE5",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE6", "LOAD STORE CACHE L3 READ XECORE6",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE7", "LOAD STORE CACHE L3 READ XECORE7",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ce0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cde0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ee0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fe0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache66MetricSet::CL1Cache66MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache66MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE8", "LOAD STORE CACHE L3 READ XECORE8",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE9", "LOAD STORE CACHE L3 READ XECORE9",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE10", "LOAD STORE CACHE L3 READ XECORE10",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE11", "LOAD STORE CACHE L3 READ XECORE11",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE12", "LOAD STORE CACHE L3 READ XECORE12",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE13", "LOAD STORE CACHE L3 READ XECORE13",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE14", "LOAD STORE CACHE L3 READ XECORE14",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE15", "LOAD STORE CACHE L3 READ XECORE15",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ce0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fd60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dde0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ee0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fe0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache67MetricSet::CL1Cache67MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache67MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE16", "LOAD STORE CACHE L3 READ XECORE16",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE17", "LOAD STORE CACHE L3 READ XECORE17",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE18", "LOAD STORE CACHE L3 READ XECORE18",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE19", "LOAD STORE CACHE L3 READ XECORE19",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE20", "LOAD STORE CACHE L3 READ XECORE20",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE21", "LOAD STORE CACHE L3 READ XECORE21",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE22", "LOAD STORE CACHE L3 READ XECORE22",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE23", "LOAD STORE CACHE L3 READ XECORE23",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ce0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cde0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ee0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fe0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache68MetricSet::CL1Cache68MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache68MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE24", "LOAD STORE CACHE L3 READ XECORE24",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE25", "LOAD STORE CACHE L3 READ XECORE25",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE26", "LOAD STORE CACHE L3 READ XECORE26",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE27", "LOAD STORE CACHE L3 READ XECORE27",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE28", "LOAD STORE CACHE L3 READ XECORE28",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE29", "LOAD STORE CACHE L3 READ XECORE29",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE30", "LOAD STORE CACHE L3 READ XECORE30",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE31", "LOAD STORE CACHE L3 READ XECORE31",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ce0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fd60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dde0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ee0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fe0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache69MetricSet::CL1Cache69MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache69MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE32", "LOAD STORE CACHE L3 READ XECORE32",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE33", "LOAD STORE CACHE L3 READ XECORE33",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE34", "LOAD STORE CACHE L3 READ XECORE34",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE35", "LOAD STORE CACHE L3 READ XECORE35",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE36", "LOAD STORE CACHE L3 READ XECORE36",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE37", "LOAD STORE CACHE L3 READ XECORE37",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE38", "LOAD STORE CACHE L3 READ XECORE38",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE39", "LOAD STORE CACHE L3 READ XECORE39",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ce0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cde0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ee0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fe0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache70MetricSet::CL1Cache70MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache70MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE40", "LOAD STORE CACHE L3 READ XECORE40",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE41", "LOAD STORE CACHE L3 READ XECORE41",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE42", "LOAD STORE CACHE L3 READ XECORE42",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE43", "LOAD STORE CACHE L3 READ XECORE43",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE44", "LOAD STORE CACHE L3 READ XECORE44",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE45", "LOAD STORE CACHE L3 READ XECORE45",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE46", "LOAD STORE CACHE L3 READ XECORE46",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE47", "LOAD STORE CACHE L3 READ XECORE47",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ce0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fd60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dde0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ee0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fe0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache71MetricSet::CL1Cache71MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache71MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE48", "LOAD STORE CACHE L3 READ XECORE48",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE49", "LOAD STORE CACHE L3 READ XECORE49",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE50", "LOAD STORE CACHE L3 READ XECORE50",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE51", "LOAD STORE CACHE L3 READ XECORE51",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE52", "LOAD STORE CACHE L3 READ XECORE52",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE53", "LOAD STORE CACHE L3 READ XECORE53",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE54", "LOAD STORE CACHE L3 READ XECORE54",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE55", "LOAD STORE CACHE L3 READ XECORE55",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ce0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cde0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ee0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fe0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache72MetricSet::CL1Cache72MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache72MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE56", "LOAD STORE CACHE L3 READ XECORE56",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE57", "LOAD STORE CACHE L3 READ XECORE57",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE58", "LOAD STORE CACHE L3 READ XECORE58",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE59", "LOAD STORE CACHE L3 READ XECORE59",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE60", "LOAD STORE CACHE L3 READ XECORE60",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE61", "LOAD STORE CACHE L3 READ XECORE61",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE62", "LOAD STORE CACHE L3 READ XECORE62",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE63", "LOAD STORE CACHE L3 READ XECORE63",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ce0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fd60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dde0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ee0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f60925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fe0925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache73MetricSet::CL1Cache73MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache73MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE0", "LOAD STORE CACHE L3 WRITE XECORE0",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE1", "LOAD STORE CACHE L3 WRITE XECORE1",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE2", "LOAD STORE CACHE L3 WRITE XECORE2",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE3", "LOAD STORE CACHE L3 WRITE XECORE3",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE4", "LOAD STORE CACHE L3 WRITE XECORE4",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE5", "LOAD STORE CACHE L3 WRITE XECORE5",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE6", "LOAD STORE CACHE L3 WRITE XECORE6",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE7", "LOAD STORE CACHE L3 WRITE XECORE7",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ce09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cde09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ee09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fe09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache74MetricSet::CL1Cache74MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache74MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE8", "LOAD STORE CACHE L3 WRITE XECORE8",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE9", "LOAD STORE CACHE L3 WRITE XECORE9",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE10", "LOAD STORE CACHE L3 WRITE XECORE10",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE11", "LOAD STORE CACHE L3 WRITE XECORE11",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE12", "LOAD STORE CACHE L3 WRITE XECORE12",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE13", "LOAD STORE CACHE L3 WRITE XECORE13",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE14", "LOAD STORE CACHE L3 WRITE XECORE14",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE15", "LOAD STORE CACHE L3 WRITE XECORE15",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ce09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fd609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dde09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ee09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fe09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache75MetricSet::CL1Cache75MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache75MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE16", "LOAD STORE CACHE L3 WRITE XECORE16",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE17", "LOAD STORE CACHE L3 WRITE XECORE17",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE18", "LOAD STORE CACHE L3 WRITE XECORE18",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE19", "LOAD STORE CACHE L3 WRITE XECORE19",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE20", "LOAD STORE CACHE L3 WRITE XECORE20",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE21", "LOAD STORE CACHE L3 WRITE XECORE21",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE22", "LOAD STORE CACHE L3 WRITE XECORE22",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE23", "LOAD STORE CACHE L3 WRITE XECORE23",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ce09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cde09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ee09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fe09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache76MetricSet::CL1Cache76MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache76MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE24", "LOAD STORE CACHE L3 WRITE XECORE24",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE25", "LOAD STORE CACHE L3 WRITE XECORE25",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE26", "LOAD STORE CACHE L3 WRITE XECORE26",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE27", "LOAD STORE CACHE L3 WRITE XECORE27",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE28", "LOAD STORE CACHE L3 WRITE XECORE28",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE29", "LOAD STORE CACHE L3 WRITE XECORE29",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE30", "LOAD STORE CACHE L3 WRITE XECORE30",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE31", "LOAD STORE CACHE L3 WRITE XECORE31",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ce09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fd609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dde09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ee09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fe09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache77MetricSet::CL1Cache77MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache77MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE32", "LOAD STORE CACHE L3 WRITE XECORE32",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE33", "LOAD STORE CACHE L3 WRITE XECORE33",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE34", "LOAD STORE CACHE L3 WRITE XECORE34",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE35", "LOAD STORE CACHE L3 WRITE XECORE35",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE36", "LOAD STORE CACHE L3 WRITE XECORE36",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE37", "LOAD STORE CACHE L3 WRITE XECORE37",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE38", "LOAD STORE CACHE L3 WRITE XECORE38",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE39", "LOAD STORE CACHE L3 WRITE XECORE39",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ce09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cde09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ee09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fe09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache78MetricSet::CL1Cache78MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache78MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE40", "LOAD STORE CACHE L3 WRITE XECORE40",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE41", "LOAD STORE CACHE L3 WRITE XECORE41",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE42", "LOAD STORE CACHE L3 WRITE XECORE42",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE43", "LOAD STORE CACHE L3 WRITE XECORE43",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE44", "LOAD STORE CACHE L3 WRITE XECORE44",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE45", "LOAD STORE CACHE L3 WRITE XECORE45",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE46", "LOAD STORE CACHE L3 WRITE XECORE46",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE47", "LOAD STORE CACHE L3 WRITE XECORE47",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ce09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fd609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dde09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ee09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fe09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache79MetricSet::CL1Cache79MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache79MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE48", "LOAD STORE CACHE L3 WRITE XECORE48",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE49", "LOAD STORE CACHE L3 WRITE XECORE49",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE50", "LOAD STORE CACHE L3 WRITE XECORE50",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE51", "LOAD STORE CACHE L3 WRITE XECORE51",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE52", "LOAD STORE CACHE L3 WRITE XECORE52",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE53", "LOAD STORE CACHE L3 WRITE XECORE53",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE54", "LOAD STORE CACHE L3 WRITE XECORE54",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE55", "LOAD STORE CACHE L3 WRITE XECORE55",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10ce09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cde09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08ee09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04fe09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache80MetricSet::CL1Cache80MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache80MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE56", "LOAD STORE CACHE L3 WRITE XECORE56",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE57", "LOAD STORE CACHE L3 WRITE XECORE57",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE58", "LOAD STORE CACHE L3 WRITE XECORE58",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE59", "LOAD STORE CACHE L3 WRITE XECORE59",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE60", "LOAD STORE CACHE L3 WRITE XECORE60",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE61", "LOAD STORE CACHE L3 WRITE XECORE61",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE62", "LOAD STORE CACHE L3 WRITE XECORE62",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE63", "LOAD STORE CACHE L3 WRITE XECORE63",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ce1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15d61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15de1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15ee1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15f61f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15fe1f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ce0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11ce09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fd609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03de0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dde09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ee0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09ee09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f609a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fe0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05fe09a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache81MetricSet::CL1Cache81MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache81MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE0", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE0",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD dw@0xd0 UADD dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD qw@0x160 UADD qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4269a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40ed3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c405c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c409d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40de8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5269a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c500d3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec501c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c505c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c509d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50de8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c50038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c600ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache82MetricSet::CL1Cache82MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache82MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE0", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE0",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD dw@0xd0 UADD dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD qw@0x160 UADD qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c42082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c40500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40910, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40d20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c52082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50910, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50d20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c50030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c600ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache83MetricSet::CL1Cache83MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache83MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE0", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE0",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD dw@0xd0 UADD dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD qw@0x160 UADD qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c43c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc401e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c43c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c53c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec501e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c5000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c53c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c44104, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c40585, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40995, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40da5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c54104, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50585, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50995, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50da5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c50035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c600ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache84MetricSet::CL1Cache84MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache84MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE0", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE0",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD dw@0xd0 UADD dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD qw@0x160 UADD qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c42082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40610, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c404c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c408d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40ce0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c52082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec500c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c504c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c508d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50ce0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c50030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c600ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache85MetricSet::CL1Cache85MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache85MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE0", "XVE SLM FENCE MESSAGE COUNT XECORE0",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD dw@0xd0 UADD dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD qw@0x160 UADD qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4269a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40ed3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c405c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c409d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40de8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5269a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c500d3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec501c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c505c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c509d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50de8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c50038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c600ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache86MetricSet::CL1Cache86MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache86MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE0", "XVE SLM READ MESSAGE COUNT XECORE0",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD dw@0xd0 UADD dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD qw@0x160 UADD qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c42082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c40500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40910, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40d20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c52082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50910, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50d20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c50030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c600ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache87MetricSet::CL1Cache87MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache87MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE0", "XVE SLM WRITE MESSAGE COUNT XECORE0",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD dw@0xd0 UADD dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD qw@0x160 UADD qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c42082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40610, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c404c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c408d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40ce0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c52082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec500c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c504c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c508d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50ce0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c50030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c600ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache88MetricSet::CL1Cache88MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache88MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE0", "LOAD STORE CACHE HIT XECORE0",
                          "Number of Load Store Cache hits",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD dw@0xd0 UADD dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD qw@0x160 UADD qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10800240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12802409, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14800120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810261, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12812409, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0082ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00800108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02800301, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04800509, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06800911, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08800021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810301, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810509, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810911, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c5ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c5aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache89MetricSet::CL1Cache89MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache89MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE0", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE0",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD dw@0xd0 UADD dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD qw@0x160 UADD qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c48e80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac4023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec46800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c44740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c58ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c56800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c54740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40a41, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c4054f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c4095f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40d6f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc4003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50041, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c5054f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c5095f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50d6f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c600ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache90MetricSet::CL1Cache90MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache90MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE0", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE0",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD dw@0xd0 UADD dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD qw@0x160 UADD qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c48e80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac4023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec46800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c44740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c58ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c56800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c54740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40a41, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c4054f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c4095f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40d6f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc4003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50041, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c5054f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c5095f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50d6f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c600ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache91MetricSet::CL1Cache91MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache91MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE0", "SLM ACCESS COUNT XECORE0",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE0", "LOAD_STORE_CACHE_ACCESS XECORE0",
                          "Number of Load Store Cache accesses",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD dw@0xcc UADD dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD qw@0x158 UADD qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108004cd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12804c13, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14800260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108104c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12814c13, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c50100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c50080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00800002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c800940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e800155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c81000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac405a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c56c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c505a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c5ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c600f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache92MetricSet::CL1Cache92MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache92MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE0", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE0",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE0", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE0",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD dw@0xcc UADD dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD qw@0x158 UADD qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10800088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12800802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14800040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00800002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c800800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e800010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c42082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40461, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c52082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c56210, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50461, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c5ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c600f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache93MetricSet::CL1Cache93MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache93MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE0", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE0",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108000cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12800c03, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14800060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810c03, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00800002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8009c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8001d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088109c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8101d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c81000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c5ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache94MetricSet::CL1Cache94MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache94MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK0_XECORE0", "LOAD STORE CACHE BYTE READ BANK0 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK0_XECORE0", "SLM BYTE READ BANK0 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache95MetricSet::CL1Cache95MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache95MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK1_XECORE0", "LOAD STORE CACHE BYTE READ BANK1 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK1_XECORE0", "SLM BYTE READ BANK1 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40064, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c42c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c40411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache96MetricSet::CL1Cache96MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache96MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK2_XECORE0", "LOAD STORE CACHE BYTE READ BANK2 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK2_XECORE0", "SLM BYTE READ BANK2 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c44c01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c408a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c40821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4002f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache97MetricSet::CL1Cache97MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache97MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK3_XECORE0", "LOAD STORE CACHE BYTE READ BANK3 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK3_XECORE0", "SLM BYTE READ BANK3 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c40c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c46c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40d35, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40cb3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c40c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache98MetricSet::CL1Cache98MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache98MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK4_XECORE0", "LOAD STORE CACHE BYTE READ BANK4 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK4_XECORE0", "SLM BYTE READ BANK4 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c5190f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache99MetricSet::CL1Cache99MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache99MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK5_XECORE0", "LOAD STORE CACHE BYTE READ BANK5 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK5_XECORE0", "SLM BYTE READ BANK5 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50064, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c52c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache100MetricSet::CL1Cache100MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache100MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK6_XECORE0", "LOAD STORE CACHE BYTE READ BANK6 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK6_XECORE0", "SLM BYTE READ BANK6 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c54c01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c5002f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache101MetricSet::CL1Cache101MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache101MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK7_XECORE0", "LOAD STORE CACHE BYTE READ BANK7 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK7_XECORE0", "SLM BYTE READ BANK7 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c50c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c56c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50d35, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50cb3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c5003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache102MetricSet::CL1Cache102MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache102MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK0_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK0 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK0_XECORE0", "SLM BYTE WRITE BANK0 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c41908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec4034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache103MetricSet::CL1Cache103MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache103MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK1_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK1 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK1_XECORE0", "SLM BYTE WRITE BANK1 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40064, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c42c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec4075e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c406dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c4065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c40018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache104MetricSet::CL1Cache104MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache104MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK2_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK2 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK2_XECORE0", "SLM BYTE WRITE BANK2 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c44c01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40b6e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40aec, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c40a6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c40028, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache105MetricSet::CL1Cache105MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache105MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK3_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK3 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK3_XECORE0", "SLM BYTE WRITE BANK3 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c40c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c46c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40f7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40efc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c40e7a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache106MetricSet::CL1Cache106MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache106MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK4_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK4 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK4_XECORE0", "SLM BYTE WRITE BANK4 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c51908, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c5034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c502cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c5024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache107MetricSet::CL1Cache107MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache107MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK5_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK5 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK5_XECORE0", "SLM BYTE WRITE BANK5 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50064, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c52c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c5075e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c506dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c5065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c50018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache108MetricSet::CL1Cache108MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache108MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK6_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK6 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK6_XECORE0", "SLM BYTE WRITE BANK6 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c54c01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50b6e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50aec, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50a6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c50028, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache109MetricSet::CL1Cache109MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache109MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK7_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK7 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK7_XECORE0", "SLM BYTE WRITE BANK7 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fe01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c50c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c56c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50f7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50efc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50e7a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c50038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x0000200a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbfe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000100a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdfe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache110MetricSet::CL1Cache110MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache110MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_BANK0_XECORE0", "XVE SLM ATOMIC MESSAGE COUNT BANK0 XECORE0",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_BANK1_XECORE0", "XVE SLM ATOMIC MESSAGE COUNT BANK1 XECORE0",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_BANK2_XECORE0", "XVE SLM ATOMIC MESSAGE COUNT BANK2 XECORE0",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_BANK3_XECORE0", "XVE SLM ATOMIC MESSAGE COUNT BANK3 XECORE0",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_BANK0_XECORE0", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT BANK0 XECORE0",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_BANK1_XECORE0", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT BANK1 XECORE0",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_BANK2_XECORE0", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT BANK2 XECORE0",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_BANK3_XECORE0", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT BANK3 XECORE0",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x334000aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4269a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c406d3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c40202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac408d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc40a22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec40cb3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c00055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c3001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache111MetricSet::CL1Cache111MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache111MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_BANK4_XECORE0", "XVE SLM ATOMIC MESSAGE COUNT BANK4 XECORE0",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_BANK5_XECORE0", "XVE SLM ATOMIC MESSAGE COUNT BANK5 XECORE0",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_BANK6_XECORE0", "XVE SLM ATOMIC MESSAGE COUNT BANK6 XECORE0",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_BANK7_XECORE0", "XVE SLM ATOMIC MESSAGE COUNT BANK7 XECORE0",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_BANK4_XECORE0", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT BANK4 XECORE0",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_BANK5_XECORE0", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT BANK5 XECORE0",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_BANK6_XECORE0", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT BANK6 XECORE0",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_BANK7_XECORE0", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT BANK7 XECORE0",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x334000aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5269a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c506d3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc508d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50a22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50cb3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c00055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c3001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache112MetricSet::CL1Cache112MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache112MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_BANK0_XECORE0", "SLM BANK CONFLICT COUNT BANK0 XECORE0",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_BANK1_XECORE0", "SLM BANK CONFLICT COUNT BANK1 XECORE0",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_BANK2_XECORE0", "SLM BANK CONFLICT COUNT BANK2 XECORE0",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_BANK3_XECORE0", "SLM BANK CONFLICT COUNT BANK3 XECORE0",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c4298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac400a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec41800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c40005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c414c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c46241, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c40ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c4087e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc4046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec407d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c4005e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1Cache113MetricSet::CL1Cache113MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1Cache113MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_BANK4_XECORE0", "SLM BANK CONFLICT COUNT BANK4 XECORE0",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_BANK5_XECORE0", "SLM BANK CONFLICT COUNT BANK5 XECORE0",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_BANK6_XECORE0", "SLM BANK CONFLICT COUNT BANK6 XECORE0",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_BANK7_XECORE0", "SLM BANK CONFLICT COUNT BANK7 XECORE0",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c5298e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc500a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c51800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26c514c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c50208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c56241, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac5087e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50be0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec5046e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c507d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c5005e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c503c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache1MetricSet::CL3Cache1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK0", "ICACHE L3 HIT L3BANK0",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK1", "ICACHE L3 HIT L3BANK1",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK2", "ICACHE L3 HIT L3BANK2",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK3", "ICACHE L3 HIT L3BANK3",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK4", "ICACHE L3 HIT L3BANK4",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK5", "ICACHE L3 HIT L3BANK5",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK6", "ICACHE L3 HIT L3BANK6",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK7", "ICACHE L3 HIT L3BANK7",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK0", "ICACHE L3 READ L3BANK0",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK1", "ICACHE L3 READ L3BANK1",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK2", "ICACHE L3 READ L3BANK2",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK3", "ICACHE L3 READ L3BANK3",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK4", "ICACHE L3 READ L3BANK4",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK5", "ICACHE L3 READ L3BANK5",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK6", "ICACHE L3 READ L3BANK6",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK7", "ICACHE L3 READ L3BANK7",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x224c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22480004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x226d0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22690004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044001c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22400004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22440004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12480036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02690400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08690007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10690036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8a0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e0036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c400d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02440400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c440036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a7a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3248a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f3144a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache2MetricSet::CL3Cache2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK8", "ICACHE L3 HIT L3BANK8",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK9", "ICACHE L3 HIT L3BANK9",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK10", "ICACHE L3 HIT L3BANK10",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK11", "ICACHE L3 HIT L3BANK11",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK12", "ICACHE L3 HIT L3BANK12",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK13", "ICACHE L3 HIT L3BANK13",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK14", "ICACHE L3 HIT L3BANK14",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK15", "ICACHE L3 HIT L3BANK15",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK8", "ICACHE L3 READ L3BANK8",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK9", "ICACHE L3 READ L3BANK9",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK10", "ICACHE L3 READ L3BANK10",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK11", "ICACHE L3 READ L3BANK11",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK12", "ICACHE L3 READ L3BANK12",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK13", "ICACHE L3 READ L3BANK13",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK14", "ICACHE L3 READ L3BANK14",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK15", "ICACHE L3 READ L3BANK15",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22610004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22650004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22820004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22860004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a6101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02650400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a650007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12650036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10860036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x224c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22480004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x226d0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22690004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4c0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e480036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02690400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c690036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f4100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c02020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500205, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache3MetricSet::CL3Cache3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK16", "ICACHE L3 HIT L3BANK16",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK17", "ICACHE L3 HIT L3BANK17",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK18", "ICACHE L3 HIT L3BANK18",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK19", "ICACHE L3 HIT L3BANK19",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK20", "ICACHE L3 HIT L3BANK20",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK21", "ICACHE L3 HIT L3BANK21",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK22", "ICACHE L3 HIT L3BANK22",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK23", "ICACHE L3 HIT L3BANK23",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK16", "ICACHE L3 READ L3BANK16",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK17", "ICACHE L3 READ L3BANK17",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK18", "ICACHE L3 READ L3BANK18",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK19", "ICACHE L3 READ L3BANK19",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK20", "ICACHE L3 READ L3BANK20",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK21", "ICACHE L3 READ L3BANK21",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK22", "ICACHE L3 READ L3BANK22",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK23", "ICACHE L3 READ L3BANK23",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22400004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22440004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22610004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22650004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22820004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22860004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8a01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8e0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e0036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x084001c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10400d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02440400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08440007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10440036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e610d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02650400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06650007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e650036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c820d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c860036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3028a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d72020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache4MetricSet::CL3Cache4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK24", "ICACHE L3 HIT L3BANK24",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK25", "ICACHE L3 HIT L3BANK25",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK26", "ICACHE L3 HIT L3BANK26",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK27", "ICACHE L3 HIT L3BANK27",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK28", "ICACHE L3 HIT L3BANK28",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK29", "ICACHE L3 HIT L3BANK29",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK30", "ICACHE L3 HIT L3BANK30",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK31", "ICACHE L3 HIT L3BANK31",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK24", "ICACHE L3 READ L3BANK24",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK25", "ICACHE L3 READ L3BANK25",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK26", "ICACHE L3 READ L3BANK26",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK27", "ICACHE L3 READ L3BANK27",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK28", "ICACHE L3 READ L3BANK28",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK29", "ICACHE L3 READ L3BANK29",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK30", "ICACHE L3 READ L3BANK30",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK31", "ICACHE L3 READ L3BANK31",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x224c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22480004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x226d0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22690004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044001c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22400004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22440004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12480036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02690400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08690007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10690036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8a0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e0036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c400d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02440400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c440036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a7a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3248a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f3144a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache5MetricSet::CL3Cache5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK32", "ICACHE L3 HIT L3BANK32",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK33", "ICACHE L3 HIT L3BANK33",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK34", "ICACHE L3 HIT L3BANK34",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK35", "ICACHE L3 HIT L3BANK35",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK36", "ICACHE L3 HIT L3BANK36",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK37", "ICACHE L3 HIT L3BANK37",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK38", "ICACHE L3 HIT L3BANK38",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK39", "ICACHE L3 HIT L3BANK39",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK32", "ICACHE L3 READ L3BANK32",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK33", "ICACHE L3 READ L3BANK33",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK34", "ICACHE L3 READ L3BANK34",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK35", "ICACHE L3 READ L3BANK35",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK36", "ICACHE L3 READ L3BANK36",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK37", "ICACHE L3 READ L3BANK37",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK38", "ICACHE L3 READ L3BANK38",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK39", "ICACHE L3 READ L3BANK39",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22610004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22650004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22820004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22860004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a6101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02650400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a650007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12650036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10860036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x224c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22480004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x226d0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22690004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4c0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e480036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02690400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c690036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f4100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500205, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c02020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache6MetricSet::CL3Cache6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK40", "ICACHE L3 HIT L3BANK40",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK41", "ICACHE L3 HIT L3BANK41",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK42", "ICACHE L3 HIT L3BANK42",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK43", "ICACHE L3 HIT L3BANK43",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK44", "ICACHE L3 HIT L3BANK44",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK45", "ICACHE L3 HIT L3BANK45",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK46", "ICACHE L3 HIT L3BANK46",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK47", "ICACHE L3 HIT L3BANK47",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK40", "ICACHE L3 READ L3BANK40",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK41", "ICACHE L3 READ L3BANK41",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK42", "ICACHE L3 READ L3BANK42",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK43", "ICACHE L3 READ L3BANK43",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK44", "ICACHE L3 READ L3BANK44",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK45", "ICACHE L3 READ L3BANK45",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK46", "ICACHE L3 READ L3BANK46",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK47", "ICACHE L3 READ L3BANK47",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22400004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22440004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22610004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22650004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22820004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22860004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8a01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8e0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e0036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x084001c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10400d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02440400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08440007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10440036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e610d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02650400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06650007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e650036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c820d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c860036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3028a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d72020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache7MetricSet::CL3Cache7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK48", "ICACHE L3 HIT L3BANK48",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK49", "ICACHE L3 HIT L3BANK49",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK50", "ICACHE L3 HIT L3BANK50",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK51", "ICACHE L3 HIT L3BANK51",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK52", "ICACHE L3 HIT L3BANK52",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK53", "ICACHE L3 HIT L3BANK53",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK54", "ICACHE L3 HIT L3BANK54",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK55", "ICACHE L3 HIT L3BANK55",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK48", "ICACHE L3 READ L3BANK48",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK49", "ICACHE L3 READ L3BANK49",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK50", "ICACHE L3 READ L3BANK50",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK51", "ICACHE L3 READ L3BANK51",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK52", "ICACHE L3 READ L3BANK52",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK53", "ICACHE L3 READ L3BANK53",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK54", "ICACHE L3 READ L3BANK54",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK55", "ICACHE L3 READ L3BANK55",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22000800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22010800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22040800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22050800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22020800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22060800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06070007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00205a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02205a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04000400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0001c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14000d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00004040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04040400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a050007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12050036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0021005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0221005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10020d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e070036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb0f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbf0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache8MetricSet::CL3Cache8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK56", "ICACHE L3 HIT L3BANK56",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK57", "ICACHE L3 HIT L3BANK57",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK58", "ICACHE L3 HIT L3BANK58",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK59", "ICACHE L3 HIT L3BANK59",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK60", "ICACHE L3 HIT L3BANK60",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK61", "ICACHE L3 HIT L3BANK61",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK62", "ICACHE L3 HIT L3BANK62",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK63", "ICACHE L3 HIT L3BANK63",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK56", "ICACHE L3 READ L3BANK56",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK57", "ICACHE L3 READ L3BANK57",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK58", "ICACHE L3 READ L3BANK58",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK59", "ICACHE L3 READ L3BANK59",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK60", "ICACHE L3 READ L3BANK60",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK61", "ICACHE L3 READ L3BANK61",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK62", "ICACHE L3 READ L3BANK62",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK63", "ICACHE L3 READ L3BANK63",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220d0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22090800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220e0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220f0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00285a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02285a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c4040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0d0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140d0036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0801c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00081010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0029005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0229005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080e01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100e0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040f0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080f0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100f0036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0a0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb0f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbf0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache9MetricSet::CL3Cache9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK0", "DATAPORT L3 HIT L3BANK0",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK1", "DATAPORT L3 HIT L3BANK1",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK2", "DATAPORT L3 HIT L3BANK2",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK3", "DATAPORT L3 HIT L3BANK3",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK4", "DATAPORT L3 HIT L3BANK4",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK5", "DATAPORT L3 HIT L3BANK5",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK6", "DATAPORT L3 HIT L3BANK6",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK7", "DATAPORT L3 HIT L3BANK7",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK8", "DATAPORT L3 HIT L3BANK8",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK9", "DATAPORT L3 HIT L3BANK9",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK10", "DATAPORT L3 HIT L3BANK10",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK11", "DATAPORT L3 HIT L3BANK11",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK12", "DATAPORT L3 HIT L3BANK12",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK13", "DATAPORT L3 HIT L3BANK13",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK14", "DATAPORT L3 HIT L3BANK14",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK15", "DATAPORT L3 HIT L3BANK15",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x224c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22480004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x226d0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22690004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22400004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22440004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22610004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22650004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22820004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22860004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12480037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02690400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10690037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8a0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c400dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02440400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c440037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a610dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02650400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a650037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x224c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22480004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x226d0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22690004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02690400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5003f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a7f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f203f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f3144a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc02a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf02a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500c05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache10MetricSet::CL3Cache10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK16", "DATAPORT L3 HIT L3BANK16",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK17", "DATAPORT L3 HIT L3BANK17",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK18", "DATAPORT L3 HIT L3BANK18",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK19", "DATAPORT L3 HIT L3BANK19",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK20", "DATAPORT L3 HIT L3BANK20",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK21", "DATAPORT L3 HIT L3BANK21",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK22", "DATAPORT L3 HIT L3BANK22",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK23", "DATAPORT L3 HIT L3BANK23",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK24", "DATAPORT L3 HIT L3BANK24",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK25", "DATAPORT L3 HIT L3BANK25",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK26", "DATAPORT L3 HIT L3BANK26",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK27", "DATAPORT L3 HIT L3BANK27",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK28", "DATAPORT L3 HIT L3BANK28",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK29", "DATAPORT L3 HIT L3BANK29",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK30", "DATAPORT L3 HIT L3BANK30",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK31", "DATAPORT L3 HIT L3BANK31",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22400004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22440004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22610004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22650004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22820004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22860004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10400dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02440400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10440037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e610dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02650400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e650037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c820dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c860037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x224c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22480004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x226d0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22690004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22400004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22440004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4c0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02690400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08690037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04400dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02440400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500e0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3028a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc2a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf2a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f000a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0058, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0058, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache11MetricSet::CL3Cache11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK32", "DATAPORT L3 HIT L3BANK32",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK33", "DATAPORT L3 HIT L3BANK33",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK34", "DATAPORT L3 HIT L3BANK34",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK35", "DATAPORT L3 HIT L3BANK35",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK36", "DATAPORT L3 HIT L3BANK36",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK37", "DATAPORT L3 HIT L3BANK37",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK38", "DATAPORT L3 HIT L3BANK38",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK39", "DATAPORT L3 HIT L3BANK39",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK40", "DATAPORT L3 HIT L3BANK40",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK41", "DATAPORT L3 HIT L3BANK41",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK42", "DATAPORT L3 HIT L3BANK42",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK43", "DATAPORT L3 HIT L3BANK43",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK44", "DATAPORT L3 HIT L3BANK44",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK45", "DATAPORT L3 HIT L3BANK45",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK46", "DATAPORT L3 HIT L3BANK46",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK47", "DATAPORT L3 HIT L3BANK47",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22610004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22650004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22820004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22860004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02650400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12650037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10860037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x224c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22480004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x226d0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22690004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22400004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22440004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22610004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22650004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22820004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22860004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4c0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e480037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02690400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c690037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8a0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8e0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08400dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02440400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08440037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06610dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02650400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06650037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f4100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32501208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500607, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500604, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c02000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00a7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache12MetricSet::CL3Cache12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK48", "DATAPORT L3 HIT L3BANK48",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK49", "DATAPORT L3 HIT L3BANK49",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK50", "DATAPORT L3 HIT L3BANK50",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK51", "DATAPORT L3 HIT L3BANK51",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK52", "DATAPORT L3 HIT L3BANK52",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK53", "DATAPORT L3 HIT L3BANK53",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK54", "DATAPORT L3 HIT L3BANK54",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK55", "DATAPORT L3 HIT L3BANK55",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK56", "DATAPORT L3 HIT L3BANK56",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK57", "DATAPORT L3 HIT L3BANK57",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK58", "DATAPORT L3 HIT L3BANK58",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK59", "DATAPORT L3 HIT L3BANK59",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK60", "DATAPORT L3 HIT L3BANK60",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK61", "DATAPORT L3 HIT L3BANK61",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK62", "DATAPORT L3 HIT L3BANK62",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK63", "DATAPORT L3 HIT L3BANK63",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22000800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22010800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22040800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22050800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22020800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22060800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220d0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22090800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220e0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220f0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02205a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04000400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14000dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00004000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04040400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12050037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0221005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10020dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e070037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00285a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0d0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0029005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080e0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040f0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080f0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5000f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f9000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f000ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cb00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d000f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache13MetricSet::CL3Cache13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK0", "L3 ATOMIC ACCESS L3BANK0",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK1", "L3 ATOMIC ACCESS L3BANK1",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK2", "L3 ATOMIC ACCESS L3BANK2",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK3", "L3 ATOMIC ACCESS L3BANK3",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK4", "L3 ATOMIC ACCESS L3BANK4",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK5", "L3 ATOMIC ACCESS L3BANK5",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK6", "L3 ATOMIC ACCESS L3BANK6",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK7", "L3 ATOMIC ACCESS L3BANK7",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK8", "L3 ATOMIC ACCESS L3BANK8",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK9", "L3 ATOMIC ACCESS L3BANK9",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK10", "L3 ATOMIC ACCESS L3BANK10",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK11", "L3 ATOMIC ACCESS L3BANK11",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK12", "L3 ATOMIC ACCESS L3BANK12",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK13", "L3 ATOMIC ACCESS L3BANK13",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK14", "L3 ATOMIC ACCESS L3BANK14",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK15", "L3 ATOMIC ACCESS L3BANK15",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12480004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10690004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8a0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c400100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c440004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a610100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a650004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5003f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a7f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f203f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f3144a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc02a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf02a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500c05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache14MetricSet::CL3Cache14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK16", "L3 ATOMIC ACCESS L3BANK16",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK17", "L3 ATOMIC ACCESS L3BANK17",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK18", "L3 ATOMIC ACCESS L3BANK18",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK19", "L3 ATOMIC ACCESS L3BANK19",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK20", "L3 ATOMIC ACCESS L3BANK20",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK21", "L3 ATOMIC ACCESS L3BANK21",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK22", "L3 ATOMIC ACCESS L3BANK22",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK23", "L3 ATOMIC ACCESS L3BANK23",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK24", "L3 ATOMIC ACCESS L3BANK24",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK25", "L3 ATOMIC ACCESS L3BANK25",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK26", "L3 ATOMIC ACCESS L3BANK26",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK27", "L3 ATOMIC ACCESS L3BANK27",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK28", "L3 ATOMIC ACCESS L3BANK28",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK29", "L3 ATOMIC ACCESS L3BANK29",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK30", "L3 ATOMIC ACCESS L3BANK30",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK31", "L3 ATOMIC ACCESS L3BANK31",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10400100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10440004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e610100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e650004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c820100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c860004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08690004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500e0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3028a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc2a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf2a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f000a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0058, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0058, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache15MetricSet::CL3Cache15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK32", "L3 ATOMIC ACCESS L3BANK32",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK33", "L3 ATOMIC ACCESS L3BANK33",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK34", "L3 ATOMIC ACCESS L3BANK34",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK35", "L3 ATOMIC ACCESS L3BANK35",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK36", "L3 ATOMIC ACCESS L3BANK36",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK37", "L3 ATOMIC ACCESS L3BANK37",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK38", "L3 ATOMIC ACCESS L3BANK38",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK39", "L3 ATOMIC ACCESS L3BANK39",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK40", "L3 ATOMIC ACCESS L3BANK40",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK41", "L3 ATOMIC ACCESS L3BANK41",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK42", "L3 ATOMIC ACCESS L3BANK42",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK43", "L3 ATOMIC ACCESS L3BANK43",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK44", "L3 ATOMIC ACCESS L3BANK44",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK45", "L3 ATOMIC ACCESS L3BANK45",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK46", "L3 ATOMIC ACCESS L3BANK46",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK47", "L3 ATOMIC ACCESS L3BANK47",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12650004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10860004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e480004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c690004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8a0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08400100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08440004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06610100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06650004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f4100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32501208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500607, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500604, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c02000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00a7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache16MetricSet::CL3Cache16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK48", "L3 ATOMIC ACCESS L3BANK48",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK49", "L3 ATOMIC ACCESS L3BANK49",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK50", "L3 ATOMIC ACCESS L3BANK50",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK51", "L3 ATOMIC ACCESS L3BANK51",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK52", "L3 ATOMIC ACCESS L3BANK52",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK53", "L3 ATOMIC ACCESS L3BANK53",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK54", "L3 ATOMIC ACCESS L3BANK54",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK55", "L3 ATOMIC ACCESS L3BANK55",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK56", "L3 ATOMIC ACCESS L3BANK56",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK57", "L3 ATOMIC ACCESS L3BANK57",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK58", "L3 ATOMIC ACCESS L3BANK58",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK59", "L3 ATOMIC ACCESS L3BANK59",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK60", "L3 ATOMIC ACCESS L3BANK60",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK61", "L3 ATOMIC ACCESS L3BANK61",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK62", "L3 ATOMIC ACCESS L3BANK62",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK63", "L3 ATOMIC ACCESS L3BANK63",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06002000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06012000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06042000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06052000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06062000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06092000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060f2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a2100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b2004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02205a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14000100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00004000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12050004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0221005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10020100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e070004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00285a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0d0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0029005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080e0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080f0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5000f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f9000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f000ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cb00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d000f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache17MetricSet::CL3Cache17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK0", "L3 HIT L3BANK0",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK1", "L3 HIT L3BANK1",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK2", "L3 HIT L3BANK2",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK3", "L3 HIT L3BANK3",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK4", "L3 HIT L3BANK4",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK5", "L3 HIT L3BANK5",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK6", "L3 HIT L3BANK6",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK7", "L3 HIT L3BANK7",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK0", "L3 MISS L3BANK0",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK1", "L3 MISS L3BANK1",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK2", "L3 MISS L3BANK2",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK3", "L3 MISS L3BANK3",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK4", "L3 MISS L3BANK4",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK5", "L3 MISS L3BANK5",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK6", "L3 MISS L3BANK6",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK7", "L3 MISS L3BANK7",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x224c0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22480003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x226d0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22690003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228a0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228e0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22400003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22440003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4c0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12480031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02690400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08690030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10690031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8a0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e0031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04400c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c400c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02440400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c440031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a7a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3248a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f3144a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache18MetricSet::CL3Cache18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK8", "L3 HIT L3BANK8",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK9", "L3 HIT L3BANK9",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK10", "L3 HIT L3BANK10",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK11", "L3 HIT L3BANK11",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK12", "L3 HIT L3BANK12",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK13", "L3 HIT L3BANK13",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK14", "L3 HIT L3BANK14",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK15", "L3 HIT L3BANK15",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK8", "L3 MISS L3BANK8",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK9", "L3 MISS L3BANK9",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK10", "L3 MISS L3BANK10",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK11", "L3 MISS L3BANK11",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK12", "L3 MISS L3BANK12",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK13", "L3 MISS L3BANK13",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK14", "L3 MISS L3BANK14",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK15", "L3 MISS L3BANK15",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22610003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22650003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22820003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22860003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a610c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02650400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a650030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12650031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10860031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x224c0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22480003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x226d0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22690003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4c0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e480031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02690400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c690031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f4100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c02020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500205, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache19MetricSet::CL3Cache19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK16", "L3 HIT L3BANK16",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK17", "L3 HIT L3BANK17",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK18", "L3 HIT L3BANK18",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK19", "L3 HIT L3BANK19",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK20", "L3 HIT L3BANK20",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK21", "L3 HIT L3BANK21",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK22", "L3 HIT L3BANK22",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK23", "L3 HIT L3BANK23",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK16", "L3 MISS L3BANK16",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK17", "L3 MISS L3BANK17",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK18", "L3 MISS L3BANK18",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK19", "L3 MISS L3BANK19",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK20", "L3 MISS L3BANK20",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK21", "L3 MISS L3BANK21",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK22", "L3 MISS L3BANK22",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK23", "L3 MISS L3BANK23",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228a0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228e0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22400003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22440003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22610003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22650003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22820003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22860003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8a0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8e0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e0031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08400c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10400c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02440400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08440030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10440031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06610c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e610c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02650400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06650030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e650031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c820c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c860031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3028a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d72020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache20MetricSet::CL3Cache20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK24", "L3 HIT L3BANK24",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK25", "L3 HIT L3BANK25",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK26", "L3 HIT L3BANK26",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK27", "L3 HIT L3BANK27",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK28", "L3 HIT L3BANK28",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK29", "L3 HIT L3BANK29",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK30", "L3 HIT L3BANK30",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK31", "L3 HIT L3BANK31",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK24", "L3 MISS L3BANK24",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK25", "L3 MISS L3BANK25",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK26", "L3 MISS L3BANK26",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK27", "L3 MISS L3BANK27",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK28", "L3 MISS L3BANK28",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK29", "L3 MISS L3BANK29",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK30", "L3 MISS L3BANK30",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK31", "L3 MISS L3BANK31",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x224c0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22480003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x226d0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22690003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228a0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228e0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22400003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22440003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4c0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12480031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02690400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08690030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10690031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8a0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e0031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04400c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c400c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02440400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c440031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a7a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3248a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f3144a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache21MetricSet::CL3Cache21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK32", "L3 HIT L3BANK32",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK33", "L3 HIT L3BANK33",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK34", "L3 HIT L3BANK34",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK35", "L3 HIT L3BANK35",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK36", "L3 HIT L3BANK36",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK37", "L3 HIT L3BANK37",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK38", "L3 HIT L3BANK38",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK39", "L3 HIT L3BANK39",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK32", "L3 MISS L3BANK32",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK33", "L3 MISS L3BANK33",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK34", "L3 MISS L3BANK34",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK35", "L3 MISS L3BANK35",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK36", "L3 MISS L3BANK36",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK37", "L3 MISS L3BANK37",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK38", "L3 MISS L3BANK38",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK39", "L3 MISS L3BANK39",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22610003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22650003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22820003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22860003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a610c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02650400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a650030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12650031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10860031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x224c0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22480003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x226d0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22690003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4c0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e480031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02690400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c690031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f4100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500205, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c02020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache22MetricSet::CL3Cache22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK40", "L3 HIT L3BANK40",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK41", "L3 HIT L3BANK41",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK42", "L3 HIT L3BANK42",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK43", "L3 HIT L3BANK43",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK44", "L3 HIT L3BANK44",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK45", "L3 HIT L3BANK45",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK46", "L3 HIT L3BANK46",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK47", "L3 HIT L3BANK47",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK40", "L3 MISS L3BANK40",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK41", "L3 MISS L3BANK41",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK42", "L3 MISS L3BANK42",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK43", "L3 MISS L3BANK43",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK44", "L3 MISS L3BANK44",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK45", "L3 MISS L3BANK45",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK46", "L3 MISS L3BANK46",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK47", "L3 MISS L3BANK47",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228a0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x228e0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22400003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22440003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22610003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22650003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22820003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22860003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8a0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8e0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e0031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08400c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10400c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02440400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08440030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10440031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06610c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e610c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02650400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06650030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e650031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c820c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c860031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3028a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d72020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache23MetricSet::CL3Cache23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK48", "L3 HIT L3BANK48",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK49", "L3 HIT L3BANK49",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK50", "L3 HIT L3BANK50",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK51", "L3 HIT L3BANK51",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK52", "L3 HIT L3BANK52",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK53", "L3 HIT L3BANK53",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK54", "L3 HIT L3BANK54",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK55", "L3 HIT L3BANK55",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK48", "L3 MISS L3BANK48",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK49", "L3 MISS L3BANK49",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK50", "L3 MISS L3BANK50",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK51", "L3 MISS L3BANK51",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK52", "L3 MISS L3BANK52",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK53", "L3 MISS L3BANK53",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK54", "L3 MISS L3BANK54",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK55", "L3 MISS L3BANK55",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22000600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22010600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22040600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22050600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22020600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22060600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22070600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00205a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02205a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04000400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c000c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14000c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00004040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04040400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a040c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a050030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12050031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0021005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0221005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10020c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06070030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e070031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb0f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbf0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache24MetricSet::CL3Cache24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK56", "L3 HIT L3BANK56",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK57", "L3 HIT L3BANK57",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK58", "L3 HIT L3BANK58",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK59", "L3 HIT L3BANK59",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK60", "L3 HIT L3BANK60",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK61", "L3 HIT L3BANK61",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK62", "L3 HIT L3BANK62",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_HIT_L3BANK63", "L3 HIT L3BANK63",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK56", "L3 MISS L3BANK56",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK57", "L3 MISS L3BANK57",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK58", "L3 MISS L3BANK58",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK59", "L3 MISS L3BANK59",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK60", "L3 MISS L3BANK60",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK61", "L3 MISS L3BANK61",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK62", "L3 MISS L3BANK62",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_MISS_L3BANK63", "L3 MISS L3BANK63",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220c0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220d0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22090600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220e0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220f0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220b0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00285a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02285a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c4040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040d0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0d0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140d0031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00081010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0029005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0229005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040e0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080e0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100e0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040f0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080f0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100f0031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0a0c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb0f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbf0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache25MetricSet::CL3Cache25MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache25MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK0", "DATAPORT L3 READ L3BANK0",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK1", "DATAPORT L3 READ L3BANK1",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK2", "DATAPORT L3 READ L3BANK2",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK3", "DATAPORT L3 READ L3BANK3",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK4", "DATAPORT L3 READ L3BANK4",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK5", "DATAPORT L3 READ L3BANK5",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK6", "DATAPORT L3 READ L3BANK6",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK7", "DATAPORT L3 READ L3BANK7",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK0", "DATAPORT L3 WRITE L3BANK0",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK1", "DATAPORT L3 WRITE L3BANK1",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK2", "DATAPORT L3 WRITE L3BANK2",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK3", "DATAPORT L3 WRITE L3BANK3",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK4", "DATAPORT L3 WRITE L3BANK4",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK5", "DATAPORT L3 WRITE L3BANK5",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK6", "DATAPORT L3 WRITE L3BANK6",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK7", "DATAPORT L3 WRITE L3BANK7",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a20c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e2003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044000c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1248000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08690003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1069000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8a03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4003c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c44000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a7a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3248a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f3144a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache26MetricSet::CL3Cache26MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache26MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK8", "DATAPORT L3 READ L3BANK8",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK9", "DATAPORT L3 READ L3BANK9",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK10", "DATAPORT L3 READ L3BANK10",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK11", "DATAPORT L3 READ L3BANK11",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK12", "DATAPORT L3 READ L3BANK12",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK13", "DATAPORT L3 READ L3BANK13",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK14", "DATAPORT L3 READ L3BANK14",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK15", "DATAPORT L3 READ L3BANK15",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK8", "DATAPORT L3 WRITE L3BANK8",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK9", "DATAPORT L3 WRITE L3BANK9",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK10", "DATAPORT L3 WRITE L3BANK10",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK11", "DATAPORT L3 WRITE L3BANK11",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK12", "DATAPORT L3 WRITE L3BANK12",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK13", "DATAPORT L3 WRITE L3BANK13",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK14", "DATAPORT L3 WRITE L3BANK14",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK15", "DATAPORT L3 WRITE L3BANK15",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a6100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x126103c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a650003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1265000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088200c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108203c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1086000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c20c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06482003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4c03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e48000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c69000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f4100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c02020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500205, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache27MetricSet::CL3Cache27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK16", "DATAPORT L3 READ L3BANK16",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK17", "DATAPORT L3 READ L3BANK17",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK18", "DATAPORT L3 READ L3BANK18",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK19", "DATAPORT L3 READ L3BANK19",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK20", "DATAPORT L3 READ L3BANK20",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK21", "DATAPORT L3 READ L3BANK21",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK22", "DATAPORT L3 READ L3BANK22",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK23", "DATAPORT L3 READ L3BANK23",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK16", "DATAPORT L3 WRITE L3BANK16",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK17", "DATAPORT L3 WRITE L3BANK17",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK18", "DATAPORT L3 WRITE L3BANK18",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK19", "DATAPORT L3 WRITE L3BANK19",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK20", "DATAPORT L3 WRITE L3BANK20",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK21", "DATAPORT L3 WRITE L3BANK21",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK22", "DATAPORT L3 WRITE L3BANK22",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK23", "DATAPORT L3 WRITE L3BANK23",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066120c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06652003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048200c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8a00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8e0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x084000c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x104003c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08440003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1044000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e6103c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e65000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8203c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c86000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3028a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d72020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache28MetricSet::CL3Cache28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK24", "DATAPORT L3 READ L3BANK24",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK25", "DATAPORT L3 READ L3BANK25",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK26", "DATAPORT L3 READ L3BANK26",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK27", "DATAPORT L3 READ L3BANK27",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK28", "DATAPORT L3 READ L3BANK28",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK29", "DATAPORT L3 READ L3BANK29",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK30", "DATAPORT L3 READ L3BANK30",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK31", "DATAPORT L3 READ L3BANK31",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK24", "DATAPORT L3 WRITE L3BANK24",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK25", "DATAPORT L3 WRITE L3BANK25",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK26", "DATAPORT L3 WRITE L3BANK26",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK27", "DATAPORT L3 WRITE L3BANK27",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK28", "DATAPORT L3 WRITE L3BANK28",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK29", "DATAPORT L3 WRITE L3BANK29",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK30", "DATAPORT L3 WRITE L3BANK30",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK31", "DATAPORT L3 WRITE L3BANK31",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a20c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e2003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044000c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1248000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08690003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1069000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8a03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4003c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c44000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a7a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3248a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f3144a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache29MetricSet::CL3Cache29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK32", "DATAPORT L3 READ L3BANK32",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK33", "DATAPORT L3 READ L3BANK33",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK34", "DATAPORT L3 READ L3BANK34",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK35", "DATAPORT L3 READ L3BANK35",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK36", "DATAPORT L3 READ L3BANK36",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK37", "DATAPORT L3 READ L3BANK37",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK38", "DATAPORT L3 READ L3BANK38",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK39", "DATAPORT L3 READ L3BANK39",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK32", "DATAPORT L3 WRITE L3BANK32",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK33", "DATAPORT L3 WRITE L3BANK33",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK34", "DATAPORT L3 WRITE L3BANK34",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK35", "DATAPORT L3 WRITE L3BANK35",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK36", "DATAPORT L3 WRITE L3BANK36",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK37", "DATAPORT L3 WRITE L3BANK37",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK38", "DATAPORT L3 WRITE L3BANK38",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK39", "DATAPORT L3 WRITE L3BANK39",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a6100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x126103c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a650003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1265000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088200c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108203c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1086000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c20c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06482003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04690003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4c03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e48000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c69000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f4100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500205, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c02020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache30MetricSet::CL3Cache30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK40", "DATAPORT L3 READ L3BANK40",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK41", "DATAPORT L3 READ L3BANK41",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK42", "DATAPORT L3 READ L3BANK42",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK43", "DATAPORT L3 READ L3BANK43",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK44", "DATAPORT L3 READ L3BANK44",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK45", "DATAPORT L3 READ L3BANK45",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK46", "DATAPORT L3 READ L3BANK46",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK47", "DATAPORT L3 READ L3BANK47",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK40", "DATAPORT L3 WRITE L3BANK40",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK41", "DATAPORT L3 WRITE L3BANK41",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK42", "DATAPORT L3 WRITE L3BANK42",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK43", "DATAPORT L3 WRITE L3BANK43",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK44", "DATAPORT L3 WRITE L3BANK44",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK45", "DATAPORT L3 WRITE L3BANK45",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK46", "DATAPORT L3 WRITE L3BANK46",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK47", "DATAPORT L3 WRITE L3BANK47",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066120c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06652003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048200c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8a00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8e0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x084000c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x104003c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08440003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1044000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e6103c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e65000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8203c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c86000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3028a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d72020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache31MetricSet::CL3Cache31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK48", "DATAPORT L3 READ L3BANK48",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK49", "DATAPORT L3 READ L3BANK49",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK50", "DATAPORT L3 READ L3BANK50",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK51", "DATAPORT L3 READ L3BANK51",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK52", "DATAPORT L3 READ L3BANK52",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK53", "DATAPORT L3 READ L3BANK53",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK54", "DATAPORT L3 READ L3BANK54",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK55", "DATAPORT L3 READ L3BANK55",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK48", "DATAPORT L3 WRITE L3BANK48",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK49", "DATAPORT L3 WRITE L3BANK49",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK50", "DATAPORT L3 WRITE L3BANK50",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK51", "DATAPORT L3 WRITE L3BANK51",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK52", "DATAPORT L3 WRITE L3BANK52",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK53", "DATAPORT L3 WRITE L3BANK53",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK54", "DATAPORT L3 WRITE L3BANK54",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK55", "DATAPORT L3 WRITE L3BANK55",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08002000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08012000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08042000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08052000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080220c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08032003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060600c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08062000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06070003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00205a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02205a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02000010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0000c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140003c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00004040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1401000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120403c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a050003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1205000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0021005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0221005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100203c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0603c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e07000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb0f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbf0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache32MetricSet::CL3Cache32MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache32MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK56", "DATAPORT L3 READ L3BANK56",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK57", "DATAPORT L3 READ L3BANK57",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK58", "DATAPORT L3 READ L3BANK58",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK59", "DATAPORT L3 READ L3BANK59",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK60", "DATAPORT L3 READ L3BANK60",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK61", "DATAPORT L3 READ L3BANK61",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK62", "DATAPORT L3 READ L3BANK62",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK63", "DATAPORT L3 READ L3BANK63",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK56", "DATAPORT L3 WRITE L3BANK56",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK57", "DATAPORT L3 WRITE L3BANK57",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK58", "DATAPORT L3 WRITE L3BANK58",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK59", "DATAPORT L3 WRITE L3BANK59",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK60", "DATAPORT L3 WRITE L3BANK60",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK61", "DATAPORT L3 WRITE L3BANK61",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK62", "DATAPORT L3 WRITE L3BANK62",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK63", "DATAPORT L3 WRITE L3BANK63",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08092000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080e20c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080f2003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00285a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02285a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c4040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0d0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140d000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0800c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120803c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00081010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1209000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0029005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0229005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100e03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020f0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100f000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0a03c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb0f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbf0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache33MetricSet::CL3Cache33MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache33MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK0", "L3 INPUT AVAILABLE L3BANK0",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK1", "L3 INPUT AVAILABLE L3BANK1",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK2", "L3 INPUT AVAILABLE L3BANK2",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK3", "L3 INPUT AVAILABLE L3BANK3",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK4", "L3 INPUT AVAILABLE L3BANK4",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK5", "L3 INPUT AVAILABLE L3BANK5",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK6", "L3 INPUT AVAILABLE L3BANK6",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK7", "L3 INPUT AVAILABLE L3BANK7",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK0", "L3 OUTPUT READY L3BANK0",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK1", "L3 OUTPUT READY L3BANK1",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK2", "L3 OUTPUT READY L3BANK2",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK3", "L3 OUTPUT READY L3BANK3",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK4", "L3 OUTPUT READY L3BANK4",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK5", "L3 OUTPUT READY L3BANK5",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK6", "L3 OUTPUT READY L3BANK6",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK7", "L3 OUTPUT READY L3BANK7",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08690006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10690007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8a01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4001c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c440007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a7a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3248a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f3144a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache34MetricSet::CL3Cache34MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache34MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK8", "L3 INPUT AVAILABLE L3BANK8",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK9", "L3 INPUT AVAILABLE L3BANK9",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK10", "L3 INPUT AVAILABLE L3BANK10",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK11", "L3 INPUT AVAILABLE L3BANK11",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK12", "L3 INPUT AVAILABLE L3BANK12",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK13", "L3 INPUT AVAILABLE L3BANK13",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK14", "L3 INPUT AVAILABLE L3BANK14",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK15", "L3 INPUT AVAILABLE L3BANK15",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK8", "L3 OUTPUT READY L3BANK8",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK9", "L3 OUTPUT READY L3BANK9",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK10", "L3 OUTPUT READY L3BANK10",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK11", "L3 OUTPUT READY L3BANK11",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK12", "L3 OUTPUT READY L3BANK12",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK13", "L3 OUTPUT READY L3BANK13",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK14", "L3 OUTPUT READY L3BANK14",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK15", "L3 OUTPUT READY L3BANK15",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a610180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x126101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a650006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12650007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10860007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c690007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f4100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c02020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500205, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache35MetricSet::CL3Cache35MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache35MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK16", "L3 INPUT AVAILABLE L3BANK16",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK17", "L3 INPUT AVAILABLE L3BANK17",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK18", "L3 INPUT AVAILABLE L3BANK18",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK19", "L3 INPUT AVAILABLE L3BANK19",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK20", "L3 INPUT AVAILABLE L3BANK20",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK21", "L3 INPUT AVAILABLE L3BANK21",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK22", "L3 INPUT AVAILABLE L3BANK22",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK23", "L3 INPUT AVAILABLE L3BANK23",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK16", "L3 OUTPUT READY L3BANK16",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK17", "L3 OUTPUT READY L3BANK17",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK18", "L3 OUTPUT READY L3BANK18",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK19", "L3 OUTPUT READY L3BANK19",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK20", "L3 OUTPUT READY L3BANK20",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK21", "L3 OUTPUT READY L3BANK21",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK22", "L3 OUTPUT READY L3BANK22",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK23", "L3 OUTPUT READY L3BANK23",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8a0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8e0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08400180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x104001c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08440006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10440007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06610180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e6101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06650006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e650007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c860007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3028a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d72020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache36MetricSet::CL3Cache36MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache36MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK24", "L3 INPUT AVAILABLE L3BANK24",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK25", "L3 INPUT AVAILABLE L3BANK25",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK26", "L3 INPUT AVAILABLE L3BANK26",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK27", "L3 INPUT AVAILABLE L3BANK27",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK28", "L3 INPUT AVAILABLE L3BANK28",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK29", "L3 INPUT AVAILABLE L3BANK29",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK30", "L3 INPUT AVAILABLE L3BANK30",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK31", "L3 INPUT AVAILABLE L3BANK31",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK24", "L3 OUTPUT READY L3BANK24",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK25", "L3 OUTPUT READY L3BANK25",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK26", "L3 OUTPUT READY L3BANK26",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK27", "L3 OUTPUT READY L3BANK27",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK28", "L3 OUTPUT READY L3BANK28",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK29", "L3 OUTPUT READY L3BANK29",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK30", "L3 OUTPUT READY L3BANK30",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK31", "L3 OUTPUT READY L3BANK31",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08690006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10690007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8a01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4001c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c440007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a7a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3248a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f3144a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache37MetricSet::CL3Cache37MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache37MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK32", "L3 INPUT AVAILABLE L3BANK32",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK33", "L3 INPUT AVAILABLE L3BANK33",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK34", "L3 INPUT AVAILABLE L3BANK34",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK35", "L3 INPUT AVAILABLE L3BANK35",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK36", "L3 INPUT AVAILABLE L3BANK36",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK37", "L3 INPUT AVAILABLE L3BANK37",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK38", "L3 INPUT AVAILABLE L3BANK38",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK39", "L3 INPUT AVAILABLE L3BANK39",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK32", "L3 OUTPUT READY L3BANK32",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK33", "L3 OUTPUT READY L3BANK33",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK34", "L3 OUTPUT READY L3BANK34",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK35", "L3 OUTPUT READY L3BANK35",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK36", "L3 OUTPUT READY L3BANK36",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK37", "L3 OUTPUT READY L3BANK37",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK38", "L3 OUTPUT READY L3BANK38",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK39", "L3 OUTPUT READY L3BANK39",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a610180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x126101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a650006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12650007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10860007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c690007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f4100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500205, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c02020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache38MetricSet::CL3Cache38MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache38MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK40", "L3 INPUT AVAILABLE L3BANK40",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK41", "L3 INPUT AVAILABLE L3BANK41",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK42", "L3 INPUT AVAILABLE L3BANK42",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK43", "L3 INPUT AVAILABLE L3BANK43",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK44", "L3 INPUT AVAILABLE L3BANK44",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK45", "L3 INPUT AVAILABLE L3BANK45",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK46", "L3 INPUT AVAILABLE L3BANK46",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK47", "L3 INPUT AVAILABLE L3BANK47",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK40", "L3 OUTPUT READY L3BANK40",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK41", "L3 OUTPUT READY L3BANK41",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK42", "L3 OUTPUT READY L3BANK42",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK43", "L3 OUTPUT READY L3BANK43",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK44", "L3 OUTPUT READY L3BANK44",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK45", "L3 OUTPUT READY L3BANK45",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK46", "L3 OUTPUT READY L3BANK46",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK47", "L3 OUTPUT READY L3BANK47",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8a0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8e0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08400180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x104001c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08440006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10440007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06610180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e6101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06650006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e650007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c860007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3028a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d72020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache39MetricSet::CL3Cache39MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache39MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK48", "L3 INPUT AVAILABLE L3BANK48",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK49", "L3 INPUT AVAILABLE L3BANK49",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK50", "L3 INPUT AVAILABLE L3BANK50",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK51", "L3 INPUT AVAILABLE L3BANK51",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK52", "L3 INPUT AVAILABLE L3BANK52",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK53", "L3 INPUT AVAILABLE L3BANK53",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK54", "L3 INPUT AVAILABLE L3BANK54",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK55", "L3 INPUT AVAILABLE L3BANK55",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK48", "L3 OUTPUT READY L3BANK48",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK49", "L3 OUTPUT READY L3BANK49",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK50", "L3 OUTPUT READY L3BANK50",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK51", "L3 OUTPUT READY L3BANK51",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK52", "L3 OUTPUT READY L3BANK52",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK53", "L3 OUTPUT READY L3BANK53",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK54", "L3 OUTPUT READY L3BANK54",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK55", "L3 OUTPUT READY L3BANK55",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06002000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06012000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06042000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06052000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06062180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06072006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00205a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02205a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c000180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140001c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00004040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a040180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a050006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12050007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0021005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0221005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08020180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e070007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb0f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbf0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache40MetricSet::CL3Cache40MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache40MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK56", "L3 INPUT AVAILABLE L3BANK56",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK57", "L3 INPUT AVAILABLE L3BANK57",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK58", "L3 INPUT AVAILABLE L3BANK58",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK59", "L3 INPUT AVAILABLE L3BANK59",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK60", "L3 INPUT AVAILABLE L3BANK60",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK61", "L3 INPUT AVAILABLE L3BANK61",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK62", "L3 INPUT AVAILABLE L3BANK62",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK63", "L3 INPUT AVAILABLE L3BANK63",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK56", "L3 OUTPUT READY L3BANK56",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK57", "L3 OUTPUT READY L3BANK57",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK58", "L3 OUTPUT READY L3BANK58",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK59", "L3 OUTPUT READY L3BANK59",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK60", "L3 OUTPUT READY L3BANK60",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK61", "L3 OUTPUT READY L3BANK61",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK62", "L3 OUTPUT READY L3BANK62",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK63", "L3 OUTPUT READY L3BANK63",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06092000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060f2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a2180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b2006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00285a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02285a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c4040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0d0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140d0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120801c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00081010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0029005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0229005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080e0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100e01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080f0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100f0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0a01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb0f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbf0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache41MetricSet::CL3Cache41MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache41MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK0", "L3 READ L3BANK0",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK1", "L3 READ L3BANK1",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK2", "L3 READ L3BANK2",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK3", "L3 READ L3BANK3",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK4", "L3 READ L3BANK4",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK5", "L3 READ L3BANK5",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK6", "L3 READ L3BANK6",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK7", "L3 READ L3BANK7",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK0", "L3 WRITE L3BANK0",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK1", "L3 WRITE L3BANK1",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK2", "L3 WRITE L3BANK2",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK3", "L3 WRITE L3BANK3",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK4", "L3 WRITE L3BANK4",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK5", "L3 WRITE L3BANK5",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK6", "L3 WRITE L3BANK6",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK7", "L3 WRITE L3BANK7",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06487000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066d7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06697000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a7140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e7005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06407000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06447000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1248000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08690005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1069000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8a0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c400340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c44000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a7a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3248a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f3144a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache42MetricSet::CL3Cache42MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache42MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK8", "L3 READ L3BANK8",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK9", "L3 READ L3BANK9",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK10", "L3 READ L3BANK10",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK11", "L3 READ L3BANK11",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK12", "L3 READ L3BANK12",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK13", "L3 READ L3BANK13",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK14", "L3 READ L3BANK14",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK15", "L3 READ L3BANK15",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK8", "L3 WRITE L3BANK8",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK9", "L3 WRITE L3BANK9",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK10", "L3 WRITE L3BANK10",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK11", "L3 WRITE L3BANK11",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK12", "L3 WRITE L3BANK12",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK13", "L3 WRITE L3BANK13",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK14", "L3 WRITE L3BANK14",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK15", "L3 WRITE L3BANK15",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06617000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06657000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06827000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06867000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a610140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a650005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1265000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1086000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c7140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06487005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066d7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06697000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e48000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c69000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f4100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c02020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500205, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache43MetricSet::CL3Cache43MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache43MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK16", "L3 READ L3BANK16",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK17", "L3 READ L3BANK17",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK18", "L3 READ L3BANK18",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK19", "L3 READ L3BANK19",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK20", "L3 READ L3BANK20",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK21", "L3 READ L3BANK21",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK22", "L3 READ L3BANK22",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK23", "L3 READ L3BANK23",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK16", "L3 WRITE L3BANK16",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK17", "L3 WRITE L3BANK17",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK18", "L3 WRITE L3BANK18",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK19", "L3 WRITE L3BANK19",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK20", "L3 WRITE L3BANK20",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK21", "L3 WRITE L3BANK21",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK22", "L3 WRITE L3BANK22",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK23", "L3 WRITE L3BANK23",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06407000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06447000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06617140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06657005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06827000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06867000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8a0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8e0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08400140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10400340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08440005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1044000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e610340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e65000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c820340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c86000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3028a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d72020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache44MetricSet::CL3Cache44MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache44MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK24", "L3 READ L3BANK24",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK25", "L3 READ L3BANK25",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK26", "L3 READ L3BANK26",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK27", "L3 READ L3BANK27",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK28", "L3 READ L3BANK28",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK29", "L3 READ L3BANK29",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK30", "L3 READ L3BANK30",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK31", "L3 READ L3BANK31",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK24", "L3 WRITE L3BANK24",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK25", "L3 WRITE L3BANK25",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK26", "L3 WRITE L3BANK26",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK27", "L3 WRITE L3BANK27",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK28", "L3 WRITE L3BANK28",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK29", "L3 WRITE L3BANK29",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK30", "L3 WRITE L3BANK30",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK31", "L3 WRITE L3BANK31",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06487000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066d7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06697000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a7140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e7005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06407000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06447000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1248000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08690005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1069000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8a0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c400340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c44000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a7a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18825, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3248a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f3144a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed2280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5858, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e42300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d90101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache45MetricSet::CL3Cache45MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache45MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK32", "L3 READ L3BANK32",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK33", "L3 READ L3BANK33",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK34", "L3 READ L3BANK34",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK35", "L3 READ L3BANK35",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK36", "L3 READ L3BANK36",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK37", "L3 READ L3BANK37",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK38", "L3 READ L3BANK38",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK39", "L3 READ L3BANK39",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK32", "L3 WRITE L3BANK32",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK33", "L3 WRITE L3BANK33",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK34", "L3 WRITE L3BANK34",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK35", "L3 WRITE L3BANK35",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK36", "L3 WRITE L3BANK36",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK37", "L3 WRITE L3BANK37",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK38", "L3 WRITE L3BANK38",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK39", "L3 WRITE L3BANK39",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06617000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06657000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06827000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06867000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a610140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a650005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1265000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1086000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c7140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06487005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066d7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06697000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e48000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c69000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f4100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500205, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d12200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c02020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea008c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10088, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache46MetricSet::CL3Cache46MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache46MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK40", "L3 READ L3BANK40",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK41", "L3 READ L3BANK41",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK42", "L3 READ L3BANK42",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK43", "L3 READ L3BANK43",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK44", "L3 READ L3BANK44",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK45", "L3 READ L3BANK45",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK46", "L3 READ L3BANK46",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK47", "L3 READ L3BANK47",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK40", "L3 WRITE L3BANK40",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK41", "L3 WRITE L3BANK41",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK42", "L3 WRITE L3BANK42",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK43", "L3 WRITE L3BANK43",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK44", "L3 WRITE L3BANK44",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK45", "L3 WRITE L3BANK45",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK46", "L3 WRITE L3BANK46",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK47", "L3 WRITE L3BANK47",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06407000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06447000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06617140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06657005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06827000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06867000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8a0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8e0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08400140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10400340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08440005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1044000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e610340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e65000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c820340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c86000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70112, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca0230, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c80200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d80101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d3028a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0888, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf2a2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10448, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c408c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d72020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache47MetricSet::CL3Cache47MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache47MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK48", "L3 READ L3BANK48",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK49", "L3 READ L3BANK49",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK50", "L3 READ L3BANK50",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK51", "L3 READ L3BANK51",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK52", "L3 READ L3BANK52",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK53", "L3 READ L3BANK53",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK54", "L3 READ L3BANK54",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK55", "L3 READ L3BANK55",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK48", "L3 WRITE L3BANK48",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK49", "L3 WRITE L3BANK49",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK50", "L3 WRITE L3BANK50",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK51", "L3 WRITE L3BANK51",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK52", "L3 WRITE L3BANK52",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK53", "L3 WRITE L3BANK53",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK54", "L3 WRITE L3BANK54",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK55", "L3 WRITE L3BANK55",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06002000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08007000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06012000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08017000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06042000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08047000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06052000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08057000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08027140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08037005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06062140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08067000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06072005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08077000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00205a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02205a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02000010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c000140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14000340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00004040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1401000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a040140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1205000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0021005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0221005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10020340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1003000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e07000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb0f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbf0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache48MetricSet::CL3Cache48MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache48MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK56", "L3 READ L3BANK56",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK57", "L3 READ L3BANK57",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK58", "L3 READ L3BANK58",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK59", "L3 READ L3BANK59",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK60", "L3 READ L3BANK60",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK61", "L3 READ L3BANK61",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK62", "L3 READ L3BANK62",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_READ_L3BANK63", "L3 READ L3BANK63",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK56", "L3 WRITE L3BANK56",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK57", "L3 WRITE L3BANK57",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK58", "L3 WRITE L3BANK58",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK59", "L3 WRITE L3BANK59",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK60", "L3 WRITE L3BANK60",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK61", "L3 WRITE L3BANK61",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK62", "L3 WRITE L3BANK62",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_WRITE_L3BANK63", "L3 WRITE L3BANK63",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080d7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08087000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06092000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08097000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080e7140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060f2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080f7005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a2140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080a7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b2005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00285a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02285a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c4040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0d0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140d000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00081010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1209000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0029005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0229005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100e0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020f0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100f000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0a0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eb0f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbf0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache49MetricSet::CL3Cache49MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache49MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK0", "L3 BUSY L3BANK0",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK1", "L3 BUSY L3BANK1",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK2", "L3 BUSY L3BANK2",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK3", "L3 BUSY L3BANK3",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK0", "L3 STALL L3BANK0",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK1", "L3 STALL L3BANK1",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK2", "L3 STALL L3BANK2",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK3", "L3 STALL L3BANK3",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08480001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12480008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a6d0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c690080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e690001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10690008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eaf02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c03, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e8002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f1a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f31491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f31449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed22a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e423fc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache50MetricSet::CL3Cache50MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache50MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK4", "L3 BUSY L3BANK4",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK5", "L3 BUSY L3BANK5",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK6", "L3 BUSY L3BANK6",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK7", "L3 BUSY L3BANK7",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK4", "L3 STALL L3BANK4",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK5", "L3 STALL L3BANK5",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK6", "L3 STALL L3BANK6",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK7", "L3 STALL L3BANK7",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088e0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a400042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10400200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c440080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e440001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10440008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07ff8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e1002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca02a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c802a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d102a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d32248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d30292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc21c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cda000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf21c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d721c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache51MetricSet::CL3Cache51MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache51MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK8", "L3 BUSY L3BANK8",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK9", "L3 BUSY L3BANK9",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK10", "L3 BUSY L3BANK10",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK11", "L3 BUSY L3BANK11",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK8", "L3 STALL L3BANK8",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK9", "L3 STALL L3BANK9",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK10", "L3 STALL L3BANK10",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK11", "L3 STALL L3BANK11",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06650080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08650001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12650008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a820042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c860080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10860008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c712a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d122a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d3224a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cda02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1a015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c021c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d621c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache52MetricSet::CL3Cache52MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache52MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK12", "L3 BUSY L3BANK12",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK13", "L3 BUSY L3BANK13",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK14", "L3 BUSY L3BANK14",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK15", "L3 BUSY L3BANK15",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK12", "L3 STALL L3BANK12",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK13", "L3 STALL L3BANK13",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK14", "L3 STALL L3BANK14",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK15", "L3 STALL L3BANK15",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08480001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12480008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a6d0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c690080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e690001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10690008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eaf02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c03, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e8002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f1a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f31491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f31449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed22a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e423fc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache53MetricSet::CL3Cache53MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache53MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK16", "L3 BUSY L3BANK16",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK17", "L3 BUSY L3BANK17",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK18", "L3 BUSY L3BANK18",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK19", "L3 BUSY L3BANK19",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK16", "L3 STALL L3BANK16",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK17", "L3 STALL L3BANK17",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK18", "L3 STALL L3BANK18",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK19", "L3 STALL L3BANK19",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088e0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a400042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10400200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c440080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e440001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10440008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07ff8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e1002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca02a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c802a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d102a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d32248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d30292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc21c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cda000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf21c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d721c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache54MetricSet::CL3Cache54MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache54MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK20", "L3 BUSY L3BANK20",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK21", "L3 BUSY L3BANK21",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK22", "L3 BUSY L3BANK22",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK23", "L3 BUSY L3BANK23",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK20", "L3 STALL L3BANK20",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK21", "L3 STALL L3BANK21",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK22", "L3 STALL L3BANK22",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK23", "L3 STALL L3BANK23",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06650080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08650001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12650008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a820042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c860080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10860008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c712a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d122a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d3224a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cda02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1a015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c021c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d621c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache55MetricSet::CL3Cache55MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache55MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK24", "L3 BUSY L3BANK24",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK25", "L3 BUSY L3BANK25",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK26", "L3 BUSY L3BANK26",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK27", "L3 BUSY L3BANK27",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK24", "L3 STALL L3BANK24",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK25", "L3 STALL L3BANK25",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK26", "L3 STALL L3BANK26",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK27", "L3 STALL L3BANK27",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08480001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12480008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a6d0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c690080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e690001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10690008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eaf02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c03, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e8002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f1a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f31491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f31449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed22a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e423fc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache56MetricSet::CL3Cache56MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache56MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK28", "L3 BUSY L3BANK28",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK29", "L3 BUSY L3BANK29",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK30", "L3 BUSY L3BANK30",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK31", "L3 BUSY L3BANK31",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK28", "L3 STALL L3BANK28",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK29", "L3 STALL L3BANK29",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK30", "L3 STALL L3BANK30",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK31", "L3 STALL L3BANK31",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088e0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a400042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10400200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c440080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e440001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10440008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07ff8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e1002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca02a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c802a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d102a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d32248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d30292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc21c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cda000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf21c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d721c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache57MetricSet::CL3Cache57MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache57MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK32", "L3 BUSY L3BANK32",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK33", "L3 BUSY L3BANK33",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK34", "L3 BUSY L3BANK34",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK35", "L3 BUSY L3BANK35",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK32", "L3 STALL L3BANK32",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK33", "L3 STALL L3BANK33",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK34", "L3 STALL L3BANK34",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK35", "L3 STALL L3BANK35",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06650080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08650001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12650008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a820042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c860080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10860008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c712a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d122a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d3224a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cda02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1a015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c021c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d621c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache58MetricSet::CL3Cache58MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache58MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK36", "L3 BUSY L3BANK36",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK37", "L3 BUSY L3BANK37",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK38", "L3 BUSY L3BANK38",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK39", "L3 BUSY L3BANK39",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK36", "L3 STALL L3BANK36",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK37", "L3 STALL L3BANK37",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK38", "L3 STALL L3BANK38",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK39", "L3 STALL L3BANK39",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08480001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12480008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a6d0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c690080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e690001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10690008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e74401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eaf02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea8c03, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f98007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e8002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e88000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0a1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f1a02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f18802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f31292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f31491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f31449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec5e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed22a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef5e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e423fc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f74038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e22000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache59MetricSet::CL3Cache59MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache59MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK40", "L3 BUSY L3BANK40",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK41", "L3 BUSY L3BANK41",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK42", "L3 BUSY L3BANK42",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK43", "L3 BUSY L3BANK43",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK40", "L3 STALL L3BANK40",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK41", "L3 STALL L3BANK41",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK42", "L3 STALL L3BANK42",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK43", "L3 STALL L3BANK43",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088e0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128e0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a400042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10400200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c440080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e440001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10440008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f503fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e72000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f84038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07ff8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f12555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f23fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec8007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef8007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e1002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e18000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e08007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f68007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca02a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d91e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c802a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d01e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d102a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d32248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d30292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc21c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cda000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf21c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d721c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache60MetricSet::CL3Cache60MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache60MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK44", "L3 BUSY L3BANK44",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK45", "L3 BUSY L3BANK45",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK46", "L3 BUSY L3BANK46",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK47", "L3 BUSY L3BANK47",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK44", "L3 STALL L3BANK44",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK45", "L3 STALL L3BANK45",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK46", "L3 STALL L3BANK46",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK47", "L3 STALL L3BANK47",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06650080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08650001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12650008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a820042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c860080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10860008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c712a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca0fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d81e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d05e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d122a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d3224a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cca1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cda02a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd8802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cfa1c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1a015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c14802, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c021c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d621c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache61MetricSet::CL3Cache61MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache61MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK48", "L3 BUSY L3BANK48",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK49", "L3 BUSY L3BANK49",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK50", "L3 BUSY L3BANK50",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK51", "L3 BUSY L3BANK51",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK48", "L3 STALL L3BANK48",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK49", "L3 STALL L3BANK49",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK50", "L3 STALL L3BANK50",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK51", "L3 STALL L3BANK51",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06002042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06012000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06042000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06052000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0020a555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02205aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02000010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00004038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a010001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c040042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e050080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12050008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache62MetricSet::CL3Cache62MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache62MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK52", "L3 BUSY L3BANK52",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK53", "L3 BUSY L3BANK53",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK54", "L3 BUSY L3BANK54",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK55", "L3 BUSY L3BANK55",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK52", "L3 STALL L3BANK52",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK53", "L3 STALL L3BANK53",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK54", "L3 STALL L3BANK54",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK55", "L3 STALL L3BANK55",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06022042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06062000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0021a555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02215aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00024038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c060042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12060200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00061e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e070080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10070001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12070008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eaaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02eaaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f9ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e85555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e85555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ebffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache63MetricSet::CL3Cache63MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache63MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK56", "L3 BUSY L3BANK56",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK57", "L3 BUSY L3BANK57",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK58", "L3 BUSY L3BANK58",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK59", "L3 BUSY L3BANK59",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK56", "L3 STALL L3BANK56",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK57", "L3 STALL L3BANK57",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK58", "L3 STALL L3BANK58",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK59", "L3 STALL L3BANK59",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c2042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080d0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06092000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0028a555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02285aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c4038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0d0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140d0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00081e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c85555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cbffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache64MetricSet::CL3Cache64MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache64MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK60", "L3 BUSY L3BANK60",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK61", "L3 BUSY L3BANK61",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK62", "L3 BUSY L3BANK62",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_BUSY_L3BANK63", "L3 BUSY L3BANK63",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK60", "L3 STALL L3BANK60",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK61", "L3 STALL L3BANK61",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK62", "L3 STALL L3BANK62",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_STALL_L3BANK63", "L3 STALL L3BANK63",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060e2042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060f2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080f0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0029a555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02295aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140e0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e4038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020f0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0f0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140f0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0a0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eaaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02eaaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f9ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e85555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e85555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ebffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache65MetricSet::CL3Cache65MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache65MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK0", "L3_SUPERQ_FULL _L3BANK0",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK1", "L3_SUPERQ_FULL _L3BANK1",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK2", "L3_SUPERQ_FULL _L3BANK2",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK3", "L3_SUPERQ_FULL _L3BANK3",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK4", "L3_SUPERQ_FULL _L3BANK4",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK5", "L3_SUPERQ_FULL _L3BANK5",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK6", "L3_SUPERQ_FULL _L3BANK6",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK7", "L3_SUPERQ_FULL _L3BANK7",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c21c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064801c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a6901c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8a01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x104001c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124401c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea0f0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e8000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fc33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3124a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec03cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eda0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef03cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e15050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e1000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f7000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e200a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caa000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c8a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d73000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache66MetricSet::CL3Cache66MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache66MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK8", "L3_SUPERQ_FULL _L3BANK8",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK9", "L3_SUPERQ_FULL _L3BANK9",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK10", "L3_SUPERQ_FULL _L3BANK10",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK11", "L3_SUPERQ_FULL _L3BANK11",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK12", "L3_SUPERQ_FULL _L3BANK12",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK13", "L3_SUPERQ_FULL _L3BANK13",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK14", "L3_SUPERQ_FULL _L3BANK14",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK15", "L3_SUPERQ_FULL _L3BANK15",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046121c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066501c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088201c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8601c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4c01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4801c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x126901c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5000ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f000ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7a050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c600c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d800c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d000cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d31489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30091, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea0f0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e8000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f03300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f31489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eccc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02eda0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00efcc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e15050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e4f0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e200a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache67MetricSet::CL3Cache67MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache67MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK16", "L3_SUPERQ_FULL _L3BANK16",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK17", "L3_SUPERQ_FULL _L3BANK17",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK18", "L3_SUPERQ_FULL _L3BANK18",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK19", "L3_SUPERQ_FULL _L3BANK19",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK20", "L3_SUPERQ_FULL _L3BANK20",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK21", "L3_SUPERQ_FULL _L3BANK21",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK22", "L3_SUPERQ_FULL _L3BANK22",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK23", "L3_SUPERQ_FULL _L3BANK23",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a21c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x084001c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4401c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6101c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e6501c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108201c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128601c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500203, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f8000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e1000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7a050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caa000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c8a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d8c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0ccc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31291, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc3330, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf3330, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c03000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d63000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache68MetricSet::CL3Cache68MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache68MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK24", "L3_SUPERQ_FULL _L3BANK24",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK25", "L3_SUPERQ_FULL _L3BANK25",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK26", "L3_SUPERQ_FULL _L3BANK26",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK27", "L3_SUPERQ_FULL _L3BANK27",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK28", "L3_SUPERQ_FULL _L3BANK28",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK29", "L3_SUPERQ_FULL _L3BANK29",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK30", "L3_SUPERQ_FULL _L3BANK30",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK31", "L3_SUPERQ_FULL _L3BANK31",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c21c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064801c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086d01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a6901c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8a01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8e01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x104001c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x124401c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ea0f0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e8000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f80c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fc33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f155a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f3124a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec03cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eda0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef03cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e15050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e1000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f7000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e200a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02caa000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d9c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c8a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d73000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache69MetricSet::CL3Cache69MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache69MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK32", "L3_SUPERQ_FULL _L3BANK32",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK33", "L3_SUPERQ_FULL _L3BANK33",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK34", "L3_SUPERQ_FULL _L3BANK34",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK35", "L3_SUPERQ_FULL _L3BANK35",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK36", "L3_SUPERQ_FULL _L3BANK36",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK37", "L3_SUPERQ_FULL _L3BANK37",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK38", "L3_SUPERQ_FULL _L3BANK38",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK39", "L3_SUPERQ_FULL _L3BANK39",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046121c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066501c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088201c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8601c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x044c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04482000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x046d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04692000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x004c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4c01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4801c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x006d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x106d01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00690000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x126901c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5000ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f000ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7a050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ca00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c600c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d800c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d000cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d31489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30091, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ea0f0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e8000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f03300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f31489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eccc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02eda0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00efcc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e15050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e4f0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f70c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e200a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache70MetricSet::CL3Cache70MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache70MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK40", "L3_SUPERQ_FULL _L3BANK40",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK41", "L3_SUPERQ_FULL _L3BANK41",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK42", "L3_SUPERQ_FULL _L3BANK42",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK43", "L3_SUPERQ_FULL _L3BANK43",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK44", "L3_SUPERQ_FULL _L3BANK44",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK45", "L3_SUPERQ_FULL _L3BANK45",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK46", "L3_SUPERQ_FULL _L3BANK46",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK47", "L3_SUPERQ_FULL _L3BANK47",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048a21c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04402000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04442000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04612000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04652000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04822000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04862000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068e01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x084001c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00440000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4401c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6101c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00650000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e6501c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108201c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128601c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500203, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f8000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f155a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e1000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e00003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7a050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caa000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ca00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c8a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d8c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0ccc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d1a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d31291, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc3330, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf3330, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d70030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c03000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d63000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache71MetricSet::CL3Cache71MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache71MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK48", "L3_SUPERQ_FULL _L3BANK48",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK49", "L3_SUPERQ_FULL _L3BANK49",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK50", "L3_SUPERQ_FULL _L3BANK50",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK51", "L3_SUPERQ_FULL _L3BANK51",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK52", "L3_SUPERQ_FULL _L3BANK52",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK53", "L3_SUPERQ_FULL _L3BANK53",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK54", "L3_SUPERQ_FULL _L3BANK54",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK55", "L3_SUPERQ_FULL _L3BANK55",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060021c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06012000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06042000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06052000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06062000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0020aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080101c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0401c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0501c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0221aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0201c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100301c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120601c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0006c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140701c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5000ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02eaaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f9ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e85555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ebff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cb00ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d000ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3Cache72MetricSet::CL3Cache72MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3Cache72MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK56", "L3_SUPERQ_FULL _L3BANK56",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK57", "L3_SUPERQ_FULL _L3BANK57",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK58", "L3_SUPERQ_FULL _L3BANK58",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK59", "L3_SUPERQ_FULL _L3BANK59",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK60", "L3_SUPERQ_FULL _L3BANK60",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK61", "L3_SUPERQ_FULL _L3BANK61",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK62", "L3_SUPERQ_FULL _L3BANK62",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "1";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK63", "L3_SUPERQ_FULL _L3BANK63",
                          "Percentage of time when all slots in L3 request queue are waiting for data return / response",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c21c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060d2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06092000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060e2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060f2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0028aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080d01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0801c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0901c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0229aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0e01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100f01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120a01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ac000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b01c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500e06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5000ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02eaaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f9ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e85555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ebff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00caaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c85555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cb00ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d000ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00010002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00040002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory1MetricSet::CMemory1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI0", "GPU MEMORY 32B TRANSACTION READ SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xfc UMUL dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1b8 UMUL qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI1", "GPU MEMORY 32B TRANSACTION READ SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xf4 UMUL dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1a8 UMUL qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI2", "GPU MEMORY 32B TRANSACTION READ SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xec UMUL dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x198 UMUL qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI3", "GPU MEMORY 32B TRANSACTION READ SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xe4 UMUL dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x188 UMUL qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI0", "GPU MEMORY 64B TRANSACTION READ SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xdc UMUL dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x178 UMUL qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI1", "GPU MEMORY 64B TRANSACTION READ SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xd4 UMUL dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x168 UMUL qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI2", "GPU MEMORY 64B TRANSACTION READ SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xcc UMUL dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x158 UMUL qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI3", "GPU MEMORY 64B TRANSACTION READ SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xc4 UMUL dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x148 UMUL qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14000251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14020251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0010a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a10a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001100a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1100a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00000010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a000207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12000185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10010185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06020207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e020185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010555aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030555aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0106f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory2MetricSet::CMemory2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI4", "GPU MEMORY 32B TRANSACTION READ SQIDI4",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xfc UMUL dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1b8 UMUL qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI5", "GPU MEMORY 32B TRANSACTION READ SQIDI5",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xf4 UMUL dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1a8 UMUL qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI6", "GPU MEMORY 32B TRANSACTION READ SQIDI6",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xec UMUL dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x198 UMUL qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI7", "GPU MEMORY 32B TRANSACTION READ SQIDI7",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xe4 UMUL dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x188 UMUL qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI4", "GPU MEMORY 64B TRANSACTION READ SQIDI4",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xdc UMUL dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x178 UMUL qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI5", "GPU MEMORY 64B TRANSACTION READ SQIDI5",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xd4 UMUL dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x168 UMUL qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI6", "GPU MEMORY 64B TRANSACTION READ SQIDI6",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xcc UMUL dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x158 UMUL qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI7", "GPU MEMORY 64B TRANSACTION READ SQIDI7",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xc4 UMUL dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x148 UMUL qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14040251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14050251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14060251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14070251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0012a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a12a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001300a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1300a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a040207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c070185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011e55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031e55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0110aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0310aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory3MetricSet::CMemory3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI8", "GPU MEMORY 32B TRANSACTION READ SQIDI8",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xfc UMUL dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1b8 UMUL qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI9", "GPU MEMORY 32B TRANSACTION READ SQIDI9",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xf4 UMUL dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1a8 UMUL qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI10", "GPU MEMORY 32B TRANSACTION READ SQIDI10",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xec UMUL dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x198 UMUL qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI11", "GPU MEMORY 32B TRANSACTION READ SQIDI11",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xe4 UMUL dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x188 UMUL qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI8", "GPU MEMORY 64B TRANSACTION READ SQIDI8",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xdc UMUL dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x178 UMUL qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI9", "GPU MEMORY 64B TRANSACTION READ SQIDI9",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xd4 UMUL dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x168 UMUL qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI10", "GPU MEMORY 64B TRANSACTION READ SQIDI10",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xcc UMUL dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x158 UMUL qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI11", "GPU MEMORY 64B TRANSACTION READ SQIDI11",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xc4 UMUL dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x148 UMUL qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0014a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a14a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001500a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1500a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0a0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0100f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory4MetricSet::CMemory4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI12", "GPU MEMORY 32B TRANSACTION READ SQIDI12",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xfc UMUL dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1b8 UMUL qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI13", "GPU MEMORY 32B TRANSACTION READ SQIDI13",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xf4 UMUL dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1a8 UMUL qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI14", "GPU MEMORY 32B TRANSACTION READ SQIDI14",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xec UMUL dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x198 UMUL qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI15", "GPU MEMORY 32B TRANSACTION READ SQIDI15",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xe4 UMUL dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x188 UMUL qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI12", "GPU MEMORY 64B TRANSACTION READ SQIDI12",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xdc UMUL dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x178 UMUL qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI13", "GPU MEMORY 64B TRANSACTION READ SQIDI13",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xd4 UMUL dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x168 UMUL qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI14", "GPU MEMORY 64B TRANSACTION READ SQIDI14",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xcc UMUL dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x158 UMUL qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI15", "GPU MEMORY 64B TRANSACTION READ SQIDI15",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xc4 UMUL dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x148 UMUL qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140d0251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140e0251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140f0251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0016a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a16a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080d0207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100d0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060e0207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0e0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040f0207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0f0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01195500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03195500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011caaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031caaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory5MetricSet::CMemory5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI0", "GPU MEMORY 32B TRANSACTION WRITE SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xfc UMUL dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1b8 UMUL qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI1", "GPU MEMORY 32B TRANSACTION WRITE SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xf4 UMUL dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1a8 UMUL qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI2", "GPU MEMORY 32B TRANSACTION WRITE SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xec UMUL dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x198 UMUL qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI3", "GPU MEMORY 32B TRANSACTION WRITE SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xe4 UMUL dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x188 UMUL qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI0", "GPU MEMORY 64B TRANSACTION WRITE SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xdc UMUL dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x178 UMUL qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI1", "GPU MEMORY 64B TRANSACTION WRITE SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xd4 UMUL dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x168 UMUL qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI2", "GPU MEMORY 64B TRANSACTION WRITE SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xcc UMUL dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x158 UMUL qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI3", "GPU MEMORY 64B TRANSACTION WRITE SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xc4 UMUL dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x148 UMUL qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14000013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14020013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0010a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a10a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001100a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1100a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0000c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12000040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080100c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10010040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060200c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040300c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010555aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030555aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0106f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory6MetricSet::CMemory6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI4", "GPU MEMORY 32B TRANSACTION WRITE SQIDI4",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xfc UMUL dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1b8 UMUL qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI5", "GPU MEMORY 32B TRANSACTION WRITE SQIDI5",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xf4 UMUL dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1a8 UMUL qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI6", "GPU MEMORY 32B TRANSACTION WRITE SQIDI6",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xec UMUL dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x198 UMUL qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI7", "GPU MEMORY 32B TRANSACTION WRITE SQIDI7",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xe4 UMUL dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x188 UMUL qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI4", "GPU MEMORY 64B TRANSACTION WRITE SQIDI4",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xdc UMUL dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x178 UMUL qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI5", "GPU MEMORY 64B TRANSACTION WRITE SQIDI5",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xd4 UMUL dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x168 UMUL qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI6", "GPU MEMORY 64B TRANSACTION WRITE SQIDI6",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xcc UMUL dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x158 UMUL qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI7", "GPU MEMORY 64B TRANSACTION WRITE SQIDI7",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xc4 UMUL dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x148 UMUL qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14040013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14050013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14060013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14070013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0012a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a12a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001300a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1300a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0400c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060600c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040700c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c070040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011e55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031e55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0110aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0310aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory7MetricSet::CMemory7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI8", "GPU MEMORY 32B TRANSACTION WRITE SQIDI8",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xfc UMUL dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1b8 UMUL qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI9", "GPU MEMORY 32B TRANSACTION WRITE SQIDI9",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xf4 UMUL dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1a8 UMUL qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI10", "GPU MEMORY 32B TRANSACTION WRITE SQIDI10",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xec UMUL dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x198 UMUL qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI11", "GPU MEMORY 32B TRANSACTION WRITE SQIDI11",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xe4 UMUL dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x188 UMUL qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI8", "GPU MEMORY 64B TRANSACTION WRITE SQIDI8",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xdc UMUL dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x178 UMUL qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI9", "GPU MEMORY 64B TRANSACTION WRITE SQIDI9",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xd4 UMUL dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x168 UMUL qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI10", "GPU MEMORY 64B TRANSACTION WRITE SQIDI10",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xcc UMUL dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x158 UMUL qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI11", "GPU MEMORY 64B TRANSACTION WRITE SQIDI11",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xc4 UMUL dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x148 UMUL qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0014a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a14a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001500a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1500a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a00c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0a0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b00c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0800c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080900c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0100f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f0f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory8MetricSet::CMemory8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI12", "GPU MEMORY 32B TRANSACTION WRITE SQIDI12",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xfc UMUL dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1b8 UMUL qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI13", "GPU MEMORY 32B TRANSACTION WRITE SQIDI13",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xf4 UMUL dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1a8 UMUL qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI14", "GPU MEMORY 32B TRANSACTION WRITE SQIDI14",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xec UMUL dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x198 UMUL qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI15", "GPU MEMORY 32B TRANSACTION WRITE SQIDI15",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xe4 UMUL dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x188 UMUL qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI12", "GPU MEMORY 64B TRANSACTION WRITE SQIDI12",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xdc UMUL dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x178 UMUL qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI13", "GPU MEMORY 64B TRANSACTION WRITE SQIDI13",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xd4 UMUL dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x168 UMUL qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI14", "GPU MEMORY 64B TRANSACTION WRITE SQIDI14",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xcc UMUL dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x158 UMUL qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI15", "GPU MEMORY 64B TRANSACTION WRITE SQIDI15",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xc4 UMUL dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x148 UMUL qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140d0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140e0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140f0013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0016a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a16a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c00c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080d00c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100d0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060e00c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0e0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040f00c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0f0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01195500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03195500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011caaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031caaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory9MetricSet::CMemory9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI0", "GPU MEMORY BYTE READ SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI1", "GPU MEMORY BYTE READ SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI2", "GPU MEMORY BYTE READ SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI3", "GPU MEMORY BYTE READ SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI4", "GPU MEMORY BYTE READ SQIDI4",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI5", "GPU MEMORY BYTE READ SQIDI5",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI6", "GPU MEMORY BYTE READ SQIDI6",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI7", "GPU MEMORY BYTE READ SQIDI7",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI8", "GPU MEMORY BYTE READ SQIDI8",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI9", "GPU MEMORY BYTE READ SQIDI9",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI10", "GPU MEMORY BYTE READ SQIDI10",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI11", "GPU MEMORY BYTE READ SQIDI11",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI12", "GPU MEMORY BYTE READ SQIDI12",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI13", "GPU MEMORY BYTE READ SQIDI13",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI14", "GPU MEMORY BYTE READ SQIDI14",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI15", "GPU MEMORY BYTE READ SQIDI15",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c00000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c01000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c02000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c08000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c09000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0d000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0e000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0f000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c04000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c06000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c07000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a109000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a110900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00149000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00150900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12000580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12010016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080a0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10020580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a120090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a130009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00160090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00170009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060d0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040e0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040f0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e050016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c060580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c070016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33400055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01410055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f410055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010000c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01025a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030455aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03055a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0106c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011c00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031e005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031000a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory10MetricSet::CMemory10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI0", "GPU MEMORY BYTE WRITE SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI1", "GPU MEMORY BYTE WRITE SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI2", "GPU MEMORY BYTE WRITE SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI3", "GPU MEMORY BYTE WRITE SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI4", "GPU MEMORY BYTE WRITE SQIDI4",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI5", "GPU MEMORY BYTE WRITE SQIDI5",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI6", "GPU MEMORY BYTE WRITE SQIDI6",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI7", "GPU MEMORY BYTE WRITE SQIDI7",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI8", "GPU MEMORY BYTE WRITE SQIDI8",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI9", "GPU MEMORY BYTE WRITE SQIDI9",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI10", "GPU MEMORY BYTE WRITE SQIDI10",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI11", "GPU MEMORY BYTE WRITE SQIDI11",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI12", "GPU MEMORY BYTE WRITE SQIDI12",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI13", "GPU MEMORY BYTE WRITE SQIDI13",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI14", "GPU MEMORY BYTE WRITE SQIDI14",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI15", "GPU MEMORY BYTE WRITE SQIDI15",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c00000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c01000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c02000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c08000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c09000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0d000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0e000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0f000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c04000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c06000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c07000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a109000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a110900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00149000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00150900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12000540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12010015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080a0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10020540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a120090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a130009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00160090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00170009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060d0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040e0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040f0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e050015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c060540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c070015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33400055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01410055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f410055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010000c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01025a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030455aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03055a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0106c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011c00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031e005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031000a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory11MetricSet::CMemory11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI0", "GPU MEMORY READ SQIDI0",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI1", "GPU MEMORY READ SQIDI1",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI2", "GPU MEMORY READ SQIDI2",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI3", "GPU MEMORY READ SQIDI3",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c000011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c010011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c020011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04000453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06000412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a010412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c020453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e020412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0305aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010600ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory12MetricSet::CMemory12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI4", "GPU MEMORY READ SQIDI4",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI5", "GPU MEMORY READ SQIDI5",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI6", "GPU MEMORY READ SQIDI6",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI7", "GPU MEMORY READ SQIDI7",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c040011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c060011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c070011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1355aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04040453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06040412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a050412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c060453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10070453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12070412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011e5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031eaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0110aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory13MetricSet::CMemory13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI8", "GPU MEMORY READ SQIDI8",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI9", "GPU MEMORY READ SQIDI9",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI10", "GPU MEMORY READ SQIDI10",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI11", "GPU MEMORY READ SQIDI11",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c090011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001455aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1555aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0a0453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0a0412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010000ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0302aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory14MetricSet::CMemory14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI12", "GPU MEMORY READ SQIDI12",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI13", "GPU MEMORY READ SQIDI13",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI14", "GPU MEMORY READ SQIDI14",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI15", "GPU MEMORY READ SQIDI15",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0c0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0d0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0e0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0f0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001655aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080d0453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0d0412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0e0453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0e0412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100f0453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120f0412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011caaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031caaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory15MetricSet::CMemory15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI0", "GPU MEMORY WRITE SQIDI0",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI1", "GPU MEMORY WRITE SQIDI1",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI2", "GPU MEMORY WRITE SQIDI2",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI3", "GPU MEMORY WRITE SQIDI3",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c000011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c010011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c020011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04000412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06000453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a010453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c020412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e020453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0305aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010600ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory16MetricSet::CMemory16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI4", "GPU MEMORY WRITE SQIDI4",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI5", "GPU MEMORY WRITE SQIDI5",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI6", "GPU MEMORY WRITE SQIDI6",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI7", "GPU MEMORY WRITE SQIDI7",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c040011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c060011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c070011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1355aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04040412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06040453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a050453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c060412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10070412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12070453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011e5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031eaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0110aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory17MetricSet::CMemory17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI8", "GPU MEMORY WRITE SQIDI8",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI9", "GPU MEMORY WRITE SQIDI9",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI10", "GPU MEMORY WRITE SQIDI10",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI11", "GPU MEMORY WRITE SQIDI11",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0b0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c090011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001455aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1555aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0a0412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0a0453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010000ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0302aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory18MetricSet::CMemory18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI12", "GPU MEMORY WRITE SQIDI12",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI13", "GPU MEMORY WRITE SQIDI13",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI14", "GPU MEMORY WRITE SQIDI14",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI15", "GPU MEMORY WRITE SQIDI15",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0c0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0d0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0e0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0f0011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001655aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080d0412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0d0453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0e0412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0e0453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100f0412, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120f0453, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011caaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031caaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory19MetricSet::CMemory19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI0", "GPU MEMORY ACTIVE SQIDI0",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI1", "GPU MEMORY ACTIVE SQIDI1",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI2", "GPU MEMORY ACTIVE SQIDI2",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI3", "GPU MEMORY ACTIVE SQIDI3",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI4", "GPU MEMORY ACTIVE SQIDI4",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI5", "GPU MEMORY ACTIVE SQIDI5",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI6", "GPU MEMORY ACTIVE SQIDI6",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI7", "GPU MEMORY ACTIVE SQIDI7",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI0", "GPU MEMORY REQUEST QUEUE FULL SQIDI0",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI1", "GPU MEMORY REQUEST QUEUE FULL SQIDI1",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI2", "GPU MEMORY REQUEST QUEUE FULL SQIDI2",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI3", "GPU MEMORY REQUEST QUEUE FULL SQIDI3",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI4", "GPU MEMORY REQUEST QUEUE FULL SQIDI4",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI5", "GPU MEMORY REQUEST QUEUE FULL SQIDI5",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI6", "GPU MEMORY REQUEST QUEUE FULL SQIDI6",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI7", "GPU MEMORY REQUEST QUEUE FULL SQIDI7",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14003400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c00000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14013400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c01000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14023400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c02000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14043400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c04000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14053400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14063400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c06000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14073400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c07000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00100006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a109000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a110900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04000017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12000080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040105c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12010002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06020017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10020080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060305c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00120600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a120090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00136000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a130009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08040017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080505c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a060017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c060080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0705c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33400055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01415500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f410055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030455aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010500a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03055a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0106c003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011ea500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031e005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01100a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031000a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory20MetricSet::CMemory20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI8", "GPU MEMORY ACTIVE SQIDI8",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI9", "GPU MEMORY ACTIVE SQIDI9",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI10", "GPU MEMORY ACTIVE SQIDI10",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI11", "GPU MEMORY ACTIVE SQIDI11",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI12", "GPU MEMORY ACTIVE SQIDI12",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI13", "GPU MEMORY ACTIVE SQIDI13",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI14", "GPU MEMORY ACTIVE SQIDI14",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI15", "GPU MEMORY ACTIVE SQIDI15",
                          "Percentage of time when device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI8", "GPU MEMORY REQUEST QUEUE FULL SQIDI8",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI9", "GPU MEMORY REQUEST QUEUE FULL SQIDI9",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI10", "GPU MEMORY REQUEST QUEUE FULL SQIDI10",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI11", "GPU MEMORY REQUEST QUEUE FULL SQIDI11",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI12", "GPU MEMORY REQUEST QUEUE FULL SQIDI12",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI13", "GPU MEMORY REQUEST QUEUE FULL SQIDI13",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI14", "GPU MEMORY REQUEST QUEUE FULL SQIDI14",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI15", "GPU MEMORY REQUEST QUEUE FULL SQIDI15",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14083400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c08000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14093400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c09000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140d3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0d000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140e3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0e000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140f3400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0f000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00140006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a149000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00150060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a150900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100a0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b05c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040905c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00160600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a160090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00176000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a170009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080d05c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0d0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0e0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0e0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0f05c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0f0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33400055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01415500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f410055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0100c003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101c003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03025a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010355aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011ba500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011caa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031c00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory21MetricSet::CMemory21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "TLB_MISS_L3NODE0", "TLB MISS L3NODE0",
                          "Number of misses from all TLBs and all engines",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "TLB_MISS_L3NODE1", "TLB MISS L3NODE1",
                          "Number of misses from all TLBs and all engines",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "TLB_MISS_L3NODE2", "TLB MISS L3NODE2",
                          "Number of misses from all TLBs and all engines",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "TLB_MISS_L3NODE3", "TLB MISS L3NODE3",
                          "Number of misses from all TLBs and all engines",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1af33c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cf30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18ef3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aef0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ad33c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cd30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18cf3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1acf0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f30680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ef30015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10f3001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32488, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ef0680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cef0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0eef06c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06ef0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d30680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d30015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d3001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cf0680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10cf0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12cf06c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06cf0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1af33c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cf30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18ef3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aef0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ad33c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cd30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18cf3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1acf0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5000f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f000f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f30680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f30150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f3001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ef0680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04ef5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06ef06c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d30680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad30015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd3001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30041, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cf0680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08cf0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0acf06c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06cf0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500407, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory22MetricSet::CMemory22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "TLB_MISS_L3NODE4", "TLB MISS L3NODE4",
                          "Number of misses from all TLBs and all engines",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "TLB_MISS_L3NODE5", "TLB MISS L3NODE5",
                          "Number of misses from all TLBs and all engines",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "TLB_MISS_L3NODE6", "TLB MISS L3NODE6",
                          "Number of misses from all TLBs and all engines",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "TLB_MISS_L3NODE7", "TLB MISS L3NODE7",
                          "Number of misses from all TLBs and all engines",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1af33c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cf30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18ef3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aef0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ad33c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cd30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18cf3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1acf0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f30680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ef30015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10f3001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32488, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ef0680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cef0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0eef06c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06ef0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d30680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d30015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d3001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cf0680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10cf0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12cf06c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06cf0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1af33c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cf30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18ef3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aef0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ad33c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cd30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18cf3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1acf0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5000f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f000f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f30680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f30150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f3001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ef0680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04ef5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06ef06c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ef0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d30680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad30015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd3001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30041, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cf0680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08cf0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0acf06c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06cf0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cf0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500407, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory23MetricSet::CMemory23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HOST_TO_GPUMEM_TRANSACTION_READ", "HOST TO GPUMEM TRANSACTION READ",
                          "Number of host reads to GPU local (HBM) memory (downstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HOST_TO_GPUMEM_TRANSACTION_WRITE", "HOST TO GPUMEM TRANSACTION WRITE",
                          "Number of host writes to GPU local (HBM) memory (downstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SYSMEM_TRANSACTION_READ", "SYSMEM TRANSACTION READ",
                          "Number of system memory reads (upstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SYSMEM_TRANSACTION_WRITE", "SYSMEM TRANSACTION WRITE",
                          "Number of system memory writes (upstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_DATA_BYTE_RECEIVE_L3NODE0", "STACK TO STACK DATA BYTE RECEIVE L3NODE0",
                          "Number of data bytes received (incoming write read return)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 dw@0xec dw@0xe8 UADD dw@0xe4 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 qw@0x198 qw@0x190 UADD qw@0x188 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_DATA_BYTE_TRANSMIT_L3NODE0", "STACK TO STACK DATA BYTE TRANSMIT L3NODE0",
                          "Number of data bytes sent (outgoing write read return)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 dw@0xe0 dw@0xdc UADD dw@0xd8 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 qw@0x180 qw@0x178 UADD qw@0x170 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_DATA_BYTE_RECEIVE_L3NODE2", "STACK TO STACK DATA BYTE RECEIVE L3NODE2",
                          "Number of data bytes received (incoming write read return)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 dw@0xd4 dw@0xd0 UADD dw@0xcc UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 qw@0x168 qw@0x160 UADD qw@0x158 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_DATA_BYTE_TRANSMIT_L3NODE2", "STACK TO STACK DATA BYTE TRANSMIT L3NODE2",
                          "Number of data bytes sent (outgoing write read return)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 dw@0xc8 dw@0xc4 UADD dw@0xc0 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 qw@0x150 qw@0x148 UADD qw@0x140 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_DATA_BYTE_RECEIVE", "STACK TO STACK DATA BYTE RECEIVE",
                          "Number of data bytes received (incoming write read return)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xd4 UADD dw@0xd0 UADD dw@0xcc UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x168 UADD qw@0x160 UADD qw@0x158 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_DATA_BYTE_TRANSMIT", "STACK TO STACK DATA BYTE TRANSMIT",
                          "Number of data bytes sent (outgoing write read return)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 dw@0xe0 dw@0xdc UADD dw@0xd8 UADD dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 qw@0x180 qw@0x178 UADD qw@0x170 UADD qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14307fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04306000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0030000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e300824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10300285, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02300000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22501401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x245000a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2650140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d45414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16d40014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140a555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x334000aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01410aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030455aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0106f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f500fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f20fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f30012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d20fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d30012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad40411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd4015f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed400c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d45414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16d40014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d2003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d40411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d4015f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d400c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory24MetricSet::CMemory24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_INCOMING_READ_REQUEST_L3NODE0", "STACK TO STACK INCOMING READ REQUEST L3NODE0",
                          "Number of incoming read requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_INCOMING_WRITE_REQUEST_L3NODE0", "STACK TO STACK INCOMING WRITE REQUEST L3NODE0",
                          "Number of incoming write requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0 dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0 qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_INCOMING_READ_REQUEST_L3NODE2", "STACK TO STACK INCOMING READ REQUEST L3NODE2",
                          "Number of incoming read requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_INCOMING_WRITE_REQUEST_L3NODE2", "STACK TO STACK INCOMING WRITE REQUEST L3NODE2",
                          "Number of incoming write requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SCALEUP_OUTGOING_ATOMIC_REQUEST", "SCALEUP OUTGOING ATOMIC REQUEST",
                          "Number of outgoing atomics requests over scaleup fabric from GPU",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d40293, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aafc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d15550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d2fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed40187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10d40285, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d40209, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d40293, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5003f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f003f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f203f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d003f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d203f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d40187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad40285, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd40209, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d45000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16d40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d2000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d4079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory25MetricSet::CMemory25MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory25MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_INCOMING_ATOMIC_REQUEST_L3NODE0", "STACK TO STACK INCOMING ATOMIC REQUEST L3NODE0",
                          "Number of incoming atomics requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_OUTGOING_ATOMIC_REQUEST_L3NODE0", "STACK TO STACK OUTGOING ATOMIC REQUEST L3NODE0",
                          "Number of outgoing atomics requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0 dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0 qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_INCOMING_ATOMIC_REQUEST_L3NODE2", "STACK TO STACK INCOMING ATOMIC REQUEST L3NODE2",
                          "Number of incoming atomics requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_OUTGOING_ATOMIC_REQUEST_L3NODE2", "STACK TO STACK OUTGOING ATOMIC REQUEST L3NODE2",
                          "Number of outgoing atomics requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_INCOMING_ATOMIC_REQUEST", "STACK TO STACK INCOMING ATOMIC REQUEST",
                          "Number of incoming atomics requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xe4 UADD dw@0xe0 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x188 UADD qw@0x180 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_OUTGOING_ATOMIC_REQUEST", "STACK TO STACK OUTGOING ATOMIC REQUEST",
                          "Number of outgoing atomics requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0 dw@0xec UADD dw@0xe8 UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0 qw@0x198 UADD qw@0x190 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SCALEUP_OUTGOING_READ_REQUEST", "SCALEUP OUTGOING READ REQUEST",
                          "Number of outgoing read requests over scaleup fabric from GPU",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d45013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16d40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aafc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d15550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d2fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed407d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10d4011e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d45013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16d40013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5003f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f003f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f203f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d003f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d203f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d407d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad4011e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d45000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d2000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d40580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d40515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory26MetricSet::CMemory26MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory26MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_OUTGOING_READ_REQUEST_L3NODE0", "STACK TO STACK OUTGOING READ REQUEST L3NODE0",
                          "Number of outgoing read requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_OUTGOING_WRITE_REQUEST_L3NODE0", "STACK TO STACK OUTGOING WRITE REQUEST L3NODE0",
                          "Number of outgoing write requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0 dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0 qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_OUTGOING_READ_REQUEST_L3NODE2", "STACK TO STACK OUTGOING READ REQUEST L3NODE2",
                          "Number of outgoing read requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_OUTGOING_WRITE_REQUEST_L3NODE2", "STACK TO STACK OUTGOING WRITE REQUEST L3NODE2",
                          "Number of outgoing write requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_OUTGOING_READ_REQUEST", "STACK TO STACK OUTGOING READ REQUEST",
                          "Number of outgoing read requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xe4 UADD dw@0xe0 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x188 UADD qw@0x180 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "STACK_TO_STACK_OUTGOING_WRITE_REQUEST", "STACK TO STACK OUTGOING WRITE REQUEST",
                          "Number of outgoing write requests over stack to stack interface",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0 dw@0xec UADD dw@0xe8 UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0 qw@0x198 UADD qw@0x190 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SCALEUP_OUTGOING_WRITE_REQUEST", "SCALEUP OUTGOING WRITE REQUEST",
                          "Number of outgoing write requests over scaleup fabric from GPU",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d45000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aafc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d15550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d2fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed40493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10d40591, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d40515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d45000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5003f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f003f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f203f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d003f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d203f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d40493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad40591, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd40515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d45000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d2000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d30490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d404c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d40452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory27MetricSet::CMemory27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SCALEUP_DATA_BYTE_RECEIVE", "SCALEUP DATA BYTE RECEIVE",
                          "Number of data bytes received (incoming write read return to GPU)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 dw@0xfc dw@0xf8 UADD dw@0xf4 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SCALEUP_DATA_BYTE_TRANSMIT", "SCALEUP DATA BYTE TRANSMIT",
                          "Number of data bytes sent (outgoing write read return from GPU)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 dw@0xf0 dw@0xec UADD dw@0xe8 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 qw@0x1a0 qw@0x198 UADD qw@0x190 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SCALEUP_INCOMING_ATOMIC_REQUEST", "SCALEUP INCOMING ATOMIC REQUEST",
                          "Number of incoming atomics requests over scaleup fabric to GPU",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SCALEUP_INCOMING_READ_REQUEST", "SCALEUP INCOMING READ REQUEST",
                          "Number of incoming read requests over scaleup fabric to GPU",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SCALEUP_INCOMING_WRITE_REQUEST", "SCALEUP INCOMING WRITE REQUEST",
                          "Number of incoming write requests over scaleup fabric to GPU",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14d45693, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16d40014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d0fffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d15554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d2fffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d40146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d4024a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad40108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd40083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ed40411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10d4035f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12d402cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050fffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory28MetricSet::CMemory28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_INPUT_COMPR0", "COMPRESSOR INPUT COMPR0",
                          "Number of uncompressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_INPUT_COMPR1", "COMPRESSOR INPUT COMPR1",
                          "Number of uncompressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_INPUT_COMPR2", "COMPRESSOR INPUT COMPR2",
                          "Number of uncompressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_INPUT_COMPR3", "COMPRESSOR INPUT COMPR3",
                          "Number of uncompressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_INPUT_COMPR4", "COMPRESSOR INPUT COMPR4",
                          "Number of uncompressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_INPUT_COMPR5", "COMPRESSOR INPUT COMPR5",
                          "Number of uncompressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_INPUT_COMPR6", "COMPRESSOR INPUT COMPR6",
                          "Number of uncompressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_INPUT_COMPR7", "COMPRESSOR INPUT COMPR7",
                          "Number of uncompressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_OUTPUT_COMPR0", "COMPRESSOR OUTPUT COMPR0",
                          "Number of compressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_OUTPUT_COMPR1", "COMPRESSOR OUTPUT COMPR1",
                          "Number of compressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_OUTPUT_COMPR2", "COMPRESSOR OUTPUT COMPR2",
                          "Number of compressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_OUTPUT_COMPR3", "COMPRESSOR OUTPUT COMPR3",
                          "Number of compressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_OUTPUT_COMPR4", "COMPRESSOR OUTPUT COMPR4",
                          "Number of compressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_OUTPUT_COMPR5", "COMPRESSOR OUTPUT COMPR5",
                          "Number of compressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_OUTPUT_COMPR6", "COMPRESSOR OUTPUT COMPR6",
                          "Number of compressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_OUTPUT_COMPR7", "COMPRESSOR OUTPUT COMPR7",
                          "Number of compressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_INPUT", "COMPRESSOR INPUT",
                          "Number of uncompressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$COMPRESSOR_INPUT_COMPR0 $$COMPRESSOR_INPUT_COMPR1 UADD $$COMPRESSOR_INPUT_COMPR2 UADD $$COMPRESSOR_INPUT_COMPR3 UADD $$COMPRESSOR_INPUT_COMPR4 UADD $$COMPRESSOR_INPUT_COMPR5 UADD $$COMPRESSOR_INPUT_COMPR6 UADD $$COMPRESSOR_INPUT_COMPR7 UADD" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMPRESSOR_OUTPUT", "COMPRESSOR OUTPUT",
                          "Number of compressed 128B",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$COMPRESSOR_OUTPUT_COMPR0 $$COMPRESSOR_OUTPUT_COMPR1 UADD $$COMPRESSOR_OUTPUT_COMPR2 UADD $$COMPRESSOR_OUTPUT_COMPR3 UADD $$COMPRESSOR_OUTPUT_COMPR4 UADD $$COMPRESSOR_OUTPUT_COMPR5 UADD $$COMPRESSOR_OUTPUT_COMPR6 UADD $$COMPRESSOR_OUTPUT_COMPR7 UADD" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14140000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14150000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14120000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14160000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14170000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02100002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a100010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08110400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02140002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06140010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e140003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00140000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a140000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02150002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04150400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1500c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00150000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a150000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02120002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08120010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10120003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00120000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a120000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02160002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04160010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c160003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00160000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a160000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02170402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1700c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00170000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a170000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500605, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33400505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01410505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f410505, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01078000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03078000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01000808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010305a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030305a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01045aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03045aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01068080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011c050a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031c050a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011e0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031e0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01100800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03100800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory29MetricSet::CMemory29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI0", "GPU_MEMORY_L3_READ_SQIDI0",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI1", "GPU_MEMORY_L3_READ_SQIDI1",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI2", "GPU_MEMORY_L3_READ_SQIDI2",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI3", "GPU_MEMORY_L3_READ_SQIDI3",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI4", "GPU_MEMORY_L3_READ_SQIDI4",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI5", "GPU_MEMORY_L3_READ_SQIDI5",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI6", "GPU_MEMORY_L3_READ_SQIDI6",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI7", "GPU_MEMORY_L3_READ_SQIDI7",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14001c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14011c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14021c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14041c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14051c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14061c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14071c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a10a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1100a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12000187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10010187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e020187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0012a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001300a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a040187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500605, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030555aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0106f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011e55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0110aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory30MetricSet::CMemory30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI8", "GPU_MEMORY_L3_READ_SQIDI8",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI9", "GPU_MEMORY_L3_READ_SQIDI9",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI10", "GPU_MEMORY_L3_READ_SQIDI10",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI11", "GPU_MEMORY_L3_READ_SQIDI11",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI12", "GPU_MEMORY_L3_READ_SQIDI12",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI13", "GPU_MEMORY_L3_READ_SQIDI13",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI14", "GPU_MEMORY_L3_READ_SQIDI14",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI15", "GPU_MEMORY_L3_READ_SQIDI15",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a1c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b1c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14081c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14091c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c1c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140d1c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140e1c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140f1c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a14a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a1500a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0a0187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0016a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080d0187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060e0187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040f0187, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01415555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0100f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01195500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011caaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CMemory31MetricSet::CMemory31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CMemory31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI0", "GPU_MEMORY_L3_WRITE_SQIDI0",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI1", "GPU_MEMORY_L3_WRITE_SQIDI1",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI2", "GPU_MEMORY_L3_WRITE_SQIDI2",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI3", "GPU_MEMORY_L3_WRITE_SQIDI3",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI4", "GPU_MEMORY_L3_WRITE_SQIDI4",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI5", "GPU_MEMORY_L3_WRITE_SQIDI5",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI6", "GPU_MEMORY_L3_WRITE_SQIDI6",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI7", "GPU_MEMORY_L3_WRITE_SQIDI7",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI8", "GPU_MEMORY_L3_WRITE_SQIDI8",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI9", "GPU_MEMORY_L3_WRITE_SQIDI9",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI10", "GPU_MEMORY_L3_WRITE_SQIDI10",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI11", "GPU_MEMORY_L3_WRITE_SQIDI11",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI12", "GPU_MEMORY_L3_WRITE_SQIDI12",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI13", "GPU_MEMORY_L3_WRITE_SQIDI13",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI14", "GPU_MEMORY_L3_WRITE_SQIDI14",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI15", "GPU_MEMORY_L3_WRITE_SQIDI15",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a109000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a110900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00149000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00150900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a120090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a130009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00160090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00170009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000d0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040d0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000e0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040e0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000f0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040f0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33400055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01410055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f410055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010000c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01025a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030455aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03055a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0106c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011c00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031e005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031000a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing1MetricSet::CRayTracing1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE0", "RT INSTANCE NODE RAY COUNT XECORE0",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE0", "RT INTERNAL NODE RAY COUNT XECORE0",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE0", "RT PROCEDURAL NODE RAY COUNT XECORE0",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE0", "RT QUAD LEAF RAY COUNT XECORE0",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE0", "RT TRAVERSAL STEP RAY COUNT XECORE0",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE0", "RT INPUT MESSAGE RAY COUNT XECORE0",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE0", "RT MESSAGE STALL COUNT XECORE0",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a017fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06016e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a010dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e01057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1201065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing2MetricSet::CRayTracing2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE1", "RT INSTANCE NODE RAY COUNT XECORE1",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE1", "RT INTERNAL NODE RAY COUNT XECORE1",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE1", "RT PROCEDURAL NODE RAY COUNT XECORE1",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE1", "RT QUAD LEAF RAY COUNT XECORE1",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE1", "RT TRAVERSAL STEP RAY COUNT XECORE1",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE1", "RT INPUT MESSAGE RAY COUNT XECORE1",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE1", "RT MESSAGE STALL COUNT XECORE1",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06096e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e09057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1209065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing3MetricSet::CRayTracing3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE2", "RT INSTANCE NODE RAY COUNT XECORE2",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE2", "RT INTERNAL NODE RAY COUNT XECORE2",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE2", "RT PROCEDURAL NODE RAY COUNT XECORE2",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE2", "RT QUAD LEAF RAY COUNT XECORE2",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE2", "RT TRAVERSAL STEP RAY COUNT XECORE2",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE2", "RT INPUT MESSAGE RAY COUNT XECORE2",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE2", "RT MESSAGE STALL COUNT XECORE2",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a117fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06116e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08110d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a110dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c110cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e11057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1211065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing4MetricSet::CRayTracing4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE3", "RT INSTANCE NODE RAY COUNT XECORE3",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE3", "RT INTERNAL NODE RAY COUNT XECORE3",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE3", "RT PROCEDURAL NODE RAY COUNT XECORE3",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE3", "RT QUAD LEAF RAY COUNT XECORE3",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE3", "RT TRAVERSAL STEP RAY COUNT XECORE3",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE3", "RT INPUT MESSAGE RAY COUNT XECORE3",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE3", "RT MESSAGE STALL COUNT XECORE3",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a197fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06196e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08190d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a190dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c190cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e19057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1219065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14190e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16190030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing5MetricSet::CRayTracing5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE4", "RT INSTANCE NODE RAY COUNT XECORE4",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE4", "RT INTERNAL NODE RAY COUNT XECORE4",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE4", "RT PROCEDURAL NODE RAY COUNT XECORE4",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE4", "RT QUAD LEAF RAY COUNT XECORE4",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE4", "RT TRAVERSAL STEP RAY COUNT XECORE4",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE4", "RT INPUT MESSAGE RAY COUNT XECORE4",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE4", "RT MESSAGE STALL COUNT XECORE4",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a217fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06216e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08210d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a210dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e21057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1221065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14210e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing6MetricSet::CRayTracing6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE5", "RT INSTANCE NODE RAY COUNT XECORE5",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE5", "RT INTERNAL NODE RAY COUNT XECORE5",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE5", "RT PROCEDURAL NODE RAY COUNT XECORE5",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE5", "RT QUAD LEAF RAY COUNT XECORE5",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE5", "RT TRAVERSAL STEP RAY COUNT XECORE5",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE5", "RT INPUT MESSAGE RAY COUNT XECORE5",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE5", "RT MESSAGE STALL COUNT XECORE5",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a297fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06296e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08290d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a290dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c290cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e29057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1229065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14290e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16290030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing7MetricSet::CRayTracing7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE6", "RT INSTANCE NODE RAY COUNT XECORE6",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE6", "RT INTERNAL NODE RAY COUNT XECORE6",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE6", "RT PROCEDURAL NODE RAY COUNT XECORE6",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE6", "RT QUAD LEAF RAY COUNT XECORE6",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE6", "RT TRAVERSAL STEP RAY COUNT XECORE6",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE6", "RT INPUT MESSAGE RAY COUNT XECORE6",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE6", "RT MESSAGE STALL COUNT XECORE6",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a317fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06316e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08310d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a310dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c310cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e31057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1231065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14310e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing8MetricSet::CRayTracing8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE7", "RT INSTANCE NODE RAY COUNT XECORE7",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE7", "RT INTERNAL NODE RAY COUNT XECORE7",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE7", "RT PROCEDURAL NODE RAY COUNT XECORE7",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE7", "RT QUAD LEAF RAY COUNT XECORE7",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE7", "RT TRAVERSAL STEP RAY COUNT XECORE7",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE7", "RT INPUT MESSAGE RAY COUNT XECORE7",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE7", "RT MESSAGE STALL COUNT XECORE7",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a397fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06396e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08390d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a390dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c390cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e39057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1239065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14390e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16390030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing9MetricSet::CRayTracing9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE8", "RT INSTANCE NODE RAY COUNT XECORE8",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE8", "RT INTERNAL NODE RAY COUNT XECORE8",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE8", "RT PROCEDURAL NODE RAY COUNT XECORE8",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE8", "RT QUAD LEAF RAY COUNT XECORE8",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE8", "RT TRAVERSAL STEP RAY COUNT XECORE8",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE8", "RT INPUT MESSAGE RAY COUNT XECORE8",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE8", "RT MESSAGE STALL COUNT XECORE8",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b017fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07016e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09010d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b010dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d010cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f01057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1301065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15010e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing10MetricSet::CRayTracing10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE9", "RT INSTANCE NODE RAY COUNT XECORE9",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE9", "RT INTERNAL NODE RAY COUNT XECORE9",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE9", "RT PROCEDURAL NODE RAY COUNT XECORE9",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE9", "RT QUAD LEAF RAY COUNT XECORE9",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE9", "RT TRAVERSAL STEP RAY COUNT XECORE9",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE9", "RT INPUT MESSAGE RAY COUNT XECORE9",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE9", "RT MESSAGE STALL COUNT XECORE9",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07096e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f09057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1309065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing11MetricSet::CRayTracing11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE10", "RT INSTANCE NODE RAY COUNT XECORE10",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE10", "RT INTERNAL NODE RAY COUNT XECORE10",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE10", "RT PROCEDURAL NODE RAY COUNT XECORE10",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE10", "RT QUAD LEAF RAY COUNT XECORE10",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE10", "RT TRAVERSAL STEP RAY COUNT XECORE10",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE10", "RT INPUT MESSAGE RAY COUNT XECORE10",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE10", "RT MESSAGE STALL COUNT XECORE10",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b117fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07116e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09110d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b110dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f11057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1311065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15110e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing12MetricSet::CRayTracing12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE11", "RT INSTANCE NODE RAY COUNT XECORE11",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE11", "RT INTERNAL NODE RAY COUNT XECORE11",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE11", "RT PROCEDURAL NODE RAY COUNT XECORE11",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE11", "RT QUAD LEAF RAY COUNT XECORE11",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE11", "RT TRAVERSAL STEP RAY COUNT XECORE11",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE11", "RT INPUT MESSAGE RAY COUNT XECORE11",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE11", "RT MESSAGE STALL COUNT XECORE11",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b197fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07196e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09190d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d190cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f19057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1319065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15190e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17190030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing13MetricSet::CRayTracing13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE12", "RT INSTANCE NODE RAY COUNT XECORE12",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE12", "RT INTERNAL NODE RAY COUNT XECORE12",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE12", "RT PROCEDURAL NODE RAY COUNT XECORE12",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE12", "RT QUAD LEAF RAY COUNT XECORE12",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE12", "RT TRAVERSAL STEP RAY COUNT XECORE12",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE12", "RT INPUT MESSAGE RAY COUNT XECORE12",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE12", "RT MESSAGE STALL COUNT XECORE12",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b217fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07216e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09210d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d210cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f21057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1321065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15210e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing14MetricSet::CRayTracing14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE13", "RT INSTANCE NODE RAY COUNT XECORE13",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE13", "RT INTERNAL NODE RAY COUNT XECORE13",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE13", "RT PROCEDURAL NODE RAY COUNT XECORE13",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE13", "RT QUAD LEAF RAY COUNT XECORE13",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE13", "RT TRAVERSAL STEP RAY COUNT XECORE13",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE13", "RT INPUT MESSAGE RAY COUNT XECORE13",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE13", "RT MESSAGE STALL COUNT XECORE13",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b297fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07296e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b290dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d290cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f29057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1329065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15290e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17290030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing15MetricSet::CRayTracing15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE14", "RT INSTANCE NODE RAY COUNT XECORE14",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE14", "RT INTERNAL NODE RAY COUNT XECORE14",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE14", "RT PROCEDURAL NODE RAY COUNT XECORE14",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE14", "RT QUAD LEAF RAY COUNT XECORE14",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE14", "RT TRAVERSAL STEP RAY COUNT XECORE14",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE14", "RT INPUT MESSAGE RAY COUNT XECORE14",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE14", "RT MESSAGE STALL COUNT XECORE14",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b317fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07316e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b310dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d310cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f31057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1331065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15310e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing16MetricSet::CRayTracing16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE15", "RT INSTANCE NODE RAY COUNT XECORE15",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE15", "RT INTERNAL NODE RAY COUNT XECORE15",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE15", "RT PROCEDURAL NODE RAY COUNT XECORE15",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE15", "RT QUAD LEAF RAY COUNT XECORE15",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE15", "RT TRAVERSAL STEP RAY COUNT XECORE15",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE15", "RT INPUT MESSAGE RAY COUNT XECORE15",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE15", "RT MESSAGE STALL COUNT XECORE15",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b397fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09390d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b390dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d390cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f39057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1339065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15390e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17390030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing17MetricSet::CRayTracing17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE16", "RT INSTANCE NODE RAY COUNT XECORE16",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE16", "RT INTERNAL NODE RAY COUNT XECORE16",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE16", "RT PROCEDURAL NODE RAY COUNT XECORE16",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE16", "RT QUAD LEAF RAY COUNT XECORE16",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE16", "RT TRAVERSAL STEP RAY COUNT XECORE16",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE16", "RT INPUT MESSAGE RAY COUNT XECORE16",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE16", "RT MESSAGE STALL COUNT XECORE16",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a017fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06016e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a010dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e01057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1201065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing18MetricSet::CRayTracing18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE17", "RT INSTANCE NODE RAY COUNT XECORE17",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE17", "RT INTERNAL NODE RAY COUNT XECORE17",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE17", "RT PROCEDURAL NODE RAY COUNT XECORE17",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE17", "RT QUAD LEAF RAY COUNT XECORE17",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE17", "RT TRAVERSAL STEP RAY COUNT XECORE17",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE17", "RT INPUT MESSAGE RAY COUNT XECORE17",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE17", "RT MESSAGE STALL COUNT XECORE17",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06096e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e09057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1209065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing19MetricSet::CRayTracing19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE18", "RT INSTANCE NODE RAY COUNT XECORE18",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE18", "RT INTERNAL NODE RAY COUNT XECORE18",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE18", "RT PROCEDURAL NODE RAY COUNT XECORE18",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE18", "RT QUAD LEAF RAY COUNT XECORE18",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE18", "RT TRAVERSAL STEP RAY COUNT XECORE18",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE18", "RT INPUT MESSAGE RAY COUNT XECORE18",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE18", "RT MESSAGE STALL COUNT XECORE18",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a117fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06116e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08110d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a110dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c110cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e11057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1211065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing20MetricSet::CRayTracing20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE19", "RT INSTANCE NODE RAY COUNT XECORE19",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE19", "RT INTERNAL NODE RAY COUNT XECORE19",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE19", "RT PROCEDURAL NODE RAY COUNT XECORE19",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE19", "RT QUAD LEAF RAY COUNT XECORE19",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE19", "RT TRAVERSAL STEP RAY COUNT XECORE19",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE19", "RT INPUT MESSAGE RAY COUNT XECORE19",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE19", "RT MESSAGE STALL COUNT XECORE19",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a197fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06196e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08190d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a190dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c190cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e19057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1219065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14190e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16190030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing21MetricSet::CRayTracing21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE20", "RT INSTANCE NODE RAY COUNT XECORE20",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE20", "RT INTERNAL NODE RAY COUNT XECORE20",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE20", "RT PROCEDURAL NODE RAY COUNT XECORE20",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE20", "RT QUAD LEAF RAY COUNT XECORE20",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE20", "RT TRAVERSAL STEP RAY COUNT XECORE20",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE20", "RT INPUT MESSAGE RAY COUNT XECORE20",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE20", "RT MESSAGE STALL COUNT XECORE20",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a217fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06216e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08210d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a210dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e21057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1221065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14210e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing22MetricSet::CRayTracing22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE21", "RT INSTANCE NODE RAY COUNT XECORE21",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE21", "RT INTERNAL NODE RAY COUNT XECORE21",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE21", "RT PROCEDURAL NODE RAY COUNT XECORE21",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE21", "RT QUAD LEAF RAY COUNT XECORE21",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE21", "RT TRAVERSAL STEP RAY COUNT XECORE21",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE21", "RT INPUT MESSAGE RAY COUNT XECORE21",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE21", "RT MESSAGE STALL COUNT XECORE21",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a297fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06296e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08290d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a290dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c290cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e29057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1229065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14290e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16290030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing23MetricSet::CRayTracing23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE22", "RT INSTANCE NODE RAY COUNT XECORE22",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE22", "RT INTERNAL NODE RAY COUNT XECORE22",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE22", "RT PROCEDURAL NODE RAY COUNT XECORE22",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE22", "RT QUAD LEAF RAY COUNT XECORE22",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE22", "RT TRAVERSAL STEP RAY COUNT XECORE22",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE22", "RT INPUT MESSAGE RAY COUNT XECORE22",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE22", "RT MESSAGE STALL COUNT XECORE22",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a317fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06316e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08310d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a310dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c310cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e31057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1231065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14310e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing24MetricSet::CRayTracing24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE23", "RT INSTANCE NODE RAY COUNT XECORE23",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE23", "RT INTERNAL NODE RAY COUNT XECORE23",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE23", "RT PROCEDURAL NODE RAY COUNT XECORE23",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE23", "RT QUAD LEAF RAY COUNT XECORE23",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE23", "RT TRAVERSAL STEP RAY COUNT XECORE23",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE23", "RT INPUT MESSAGE RAY COUNT XECORE23",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE23", "RT MESSAGE STALL COUNT XECORE23",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a397fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06396e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08390d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a390dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c390cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e39057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1239065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14390e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16390030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing25MetricSet::CRayTracing25MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing25MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE24", "RT INSTANCE NODE RAY COUNT XECORE24",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE24", "RT INTERNAL NODE RAY COUNT XECORE24",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE24", "RT PROCEDURAL NODE RAY COUNT XECORE24",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE24", "RT QUAD LEAF RAY COUNT XECORE24",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE24", "RT TRAVERSAL STEP RAY COUNT XECORE24",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE24", "RT INPUT MESSAGE RAY COUNT XECORE24",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE24", "RT MESSAGE STALL COUNT XECORE24",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b017fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07016e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09010d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b010dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d010cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f01057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1301065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15010e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing26MetricSet::CRayTracing26MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing26MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE25", "RT INSTANCE NODE RAY COUNT XECORE25",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE25", "RT INTERNAL NODE RAY COUNT XECORE25",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE25", "RT PROCEDURAL NODE RAY COUNT XECORE25",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE25", "RT QUAD LEAF RAY COUNT XECORE25",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE25", "RT TRAVERSAL STEP RAY COUNT XECORE25",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE25", "RT INPUT MESSAGE RAY COUNT XECORE25",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE25", "RT MESSAGE STALL COUNT XECORE25",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07096e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f09057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1309065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing27MetricSet::CRayTracing27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE26", "RT INSTANCE NODE RAY COUNT XECORE26",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE26", "RT INTERNAL NODE RAY COUNT XECORE26",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE26", "RT PROCEDURAL NODE RAY COUNT XECORE26",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE26", "RT QUAD LEAF RAY COUNT XECORE26",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE26", "RT TRAVERSAL STEP RAY COUNT XECORE26",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE26", "RT INPUT MESSAGE RAY COUNT XECORE26",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE26", "RT MESSAGE STALL COUNT XECORE26",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b117fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07116e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09110d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b110dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f11057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1311065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15110e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing28MetricSet::CRayTracing28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE27", "RT INSTANCE NODE RAY COUNT XECORE27",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE27", "RT INTERNAL NODE RAY COUNT XECORE27",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE27", "RT PROCEDURAL NODE RAY COUNT XECORE27",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE27", "RT QUAD LEAF RAY COUNT XECORE27",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE27", "RT TRAVERSAL STEP RAY COUNT XECORE27",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE27", "RT INPUT MESSAGE RAY COUNT XECORE27",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE27", "RT MESSAGE STALL COUNT XECORE27",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b197fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07196e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09190d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d190cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f19057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1319065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15190e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17190030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing29MetricSet::CRayTracing29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE28", "RT INSTANCE NODE RAY COUNT XECORE28",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE28", "RT INTERNAL NODE RAY COUNT XECORE28",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE28", "RT PROCEDURAL NODE RAY COUNT XECORE28",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE28", "RT QUAD LEAF RAY COUNT XECORE28",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE28", "RT TRAVERSAL STEP RAY COUNT XECORE28",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE28", "RT INPUT MESSAGE RAY COUNT XECORE28",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE28", "RT MESSAGE STALL COUNT XECORE28",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b217fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07216e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09210d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d210cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f21057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1321065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15210e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing30MetricSet::CRayTracing30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE29", "RT INSTANCE NODE RAY COUNT XECORE29",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE29", "RT INTERNAL NODE RAY COUNT XECORE29",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE29", "RT PROCEDURAL NODE RAY COUNT XECORE29",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE29", "RT QUAD LEAF RAY COUNT XECORE29",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE29", "RT TRAVERSAL STEP RAY COUNT XECORE29",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE29", "RT INPUT MESSAGE RAY COUNT XECORE29",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE29", "RT MESSAGE STALL COUNT XECORE29",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b297fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07296e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b290dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d290cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f29057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1329065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15290e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17290030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing31MetricSet::CRayTracing31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE30", "RT INSTANCE NODE RAY COUNT XECORE30",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE30", "RT INTERNAL NODE RAY COUNT XECORE30",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE30", "RT PROCEDURAL NODE RAY COUNT XECORE30",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE30", "RT QUAD LEAF RAY COUNT XECORE30",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE30", "RT TRAVERSAL STEP RAY COUNT XECORE30",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE30", "RT INPUT MESSAGE RAY COUNT XECORE30",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE30", "RT MESSAGE STALL COUNT XECORE30",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b317fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07316e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b310dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d310cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f31057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1331065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15310e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing32MetricSet::CRayTracing32MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing32MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE31", "RT INSTANCE NODE RAY COUNT XECORE31",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE31", "RT INTERNAL NODE RAY COUNT XECORE31",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE31", "RT PROCEDURAL NODE RAY COUNT XECORE31",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE31", "RT QUAD LEAF RAY COUNT XECORE31",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE31", "RT TRAVERSAL STEP RAY COUNT XECORE31",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE31", "RT INPUT MESSAGE RAY COUNT XECORE31",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE31", "RT MESSAGE STALL COUNT XECORE31",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b397fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09390d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b390dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d390cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f39057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1339065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15390e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17390030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing33MetricSet::CRayTracing33MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing33MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE32", "RT INSTANCE NODE RAY COUNT XECORE32",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE32", "RT INTERNAL NODE RAY COUNT XECORE32",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE32", "RT PROCEDURAL NODE RAY COUNT XECORE32",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE32", "RT QUAD LEAF RAY COUNT XECORE32",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE32", "RT TRAVERSAL STEP RAY COUNT XECORE32",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE32", "RT INPUT MESSAGE RAY COUNT XECORE32",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE32", "RT MESSAGE STALL COUNT XECORE32",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a017fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06016e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a010dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e01057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1201065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing34MetricSet::CRayTracing34MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing34MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE33", "RT INSTANCE NODE RAY COUNT XECORE33",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE33", "RT INTERNAL NODE RAY COUNT XECORE33",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE33", "RT PROCEDURAL NODE RAY COUNT XECORE33",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE33", "RT QUAD LEAF RAY COUNT XECORE33",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE33", "RT TRAVERSAL STEP RAY COUNT XECORE33",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE33", "RT INPUT MESSAGE RAY COUNT XECORE33",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE33", "RT MESSAGE STALL COUNT XECORE33",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06096e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e09057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1209065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing35MetricSet::CRayTracing35MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing35MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE34", "RT INSTANCE NODE RAY COUNT XECORE34",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE34", "RT INTERNAL NODE RAY COUNT XECORE34",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE34", "RT PROCEDURAL NODE RAY COUNT XECORE34",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE34", "RT QUAD LEAF RAY COUNT XECORE34",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE34", "RT TRAVERSAL STEP RAY COUNT XECORE34",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE34", "RT INPUT MESSAGE RAY COUNT XECORE34",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE34", "RT MESSAGE STALL COUNT XECORE34",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a117fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06116e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08110d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a110dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c110cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e11057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1211065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing36MetricSet::CRayTracing36MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing36MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE35", "RT INSTANCE NODE RAY COUNT XECORE35",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE35", "RT INTERNAL NODE RAY COUNT XECORE35",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE35", "RT PROCEDURAL NODE RAY COUNT XECORE35",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE35", "RT QUAD LEAF RAY COUNT XECORE35",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE35", "RT TRAVERSAL STEP RAY COUNT XECORE35",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE35", "RT INPUT MESSAGE RAY COUNT XECORE35",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE35", "RT MESSAGE STALL COUNT XECORE35",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a197fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06196e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08190d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a190dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c190cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e19057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1219065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14190e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16190030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing37MetricSet::CRayTracing37MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing37MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE36", "RT INSTANCE NODE RAY COUNT XECORE36",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE36", "RT INTERNAL NODE RAY COUNT XECORE36",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE36", "RT PROCEDURAL NODE RAY COUNT XECORE36",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE36", "RT QUAD LEAF RAY COUNT XECORE36",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE36", "RT TRAVERSAL STEP RAY COUNT XECORE36",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE36", "RT INPUT MESSAGE RAY COUNT XECORE36",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE36", "RT MESSAGE STALL COUNT XECORE36",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a217fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06216e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08210d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a210dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e21057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1221065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14210e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing38MetricSet::CRayTracing38MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing38MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE37", "RT INSTANCE NODE RAY COUNT XECORE37",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE37", "RT INTERNAL NODE RAY COUNT XECORE37",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE37", "RT PROCEDURAL NODE RAY COUNT XECORE37",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE37", "RT QUAD LEAF RAY COUNT XECORE37",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE37", "RT TRAVERSAL STEP RAY COUNT XECORE37",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE37", "RT INPUT MESSAGE RAY COUNT XECORE37",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE37", "RT MESSAGE STALL COUNT XECORE37",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a297fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06296e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08290d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a290dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c290cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e29057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1229065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14290e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16290030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing39MetricSet::CRayTracing39MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing39MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE38", "RT INSTANCE NODE RAY COUNT XECORE38",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE38", "RT INTERNAL NODE RAY COUNT XECORE38",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE38", "RT PROCEDURAL NODE RAY COUNT XECORE38",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE38", "RT QUAD LEAF RAY COUNT XECORE38",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE38", "RT TRAVERSAL STEP RAY COUNT XECORE38",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE38", "RT INPUT MESSAGE RAY COUNT XECORE38",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE38", "RT MESSAGE STALL COUNT XECORE38",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a317fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06316e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08310d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a310dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c310cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e31057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1231065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14310e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing40MetricSet::CRayTracing40MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing40MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE39", "RT INSTANCE NODE RAY COUNT XECORE39",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE39", "RT INTERNAL NODE RAY COUNT XECORE39",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE39", "RT PROCEDURAL NODE RAY COUNT XECORE39",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE39", "RT QUAD LEAF RAY COUNT XECORE39",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE39", "RT TRAVERSAL STEP RAY COUNT XECORE39",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE39", "RT INPUT MESSAGE RAY COUNT XECORE39",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE39", "RT MESSAGE STALL COUNT XECORE39",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a397fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06396e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08390d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a390dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c390cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e39057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1239065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14390e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16390030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing41MetricSet::CRayTracing41MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing41MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE40", "RT INSTANCE NODE RAY COUNT XECORE40",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE40", "RT INTERNAL NODE RAY COUNT XECORE40",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE40", "RT PROCEDURAL NODE RAY COUNT XECORE40",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE40", "RT QUAD LEAF RAY COUNT XECORE40",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE40", "RT TRAVERSAL STEP RAY COUNT XECORE40",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE40", "RT INPUT MESSAGE RAY COUNT XECORE40",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE40", "RT MESSAGE STALL COUNT XECORE40",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b017fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07016e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09010d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b010dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d010cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f01057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1301065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15010e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing42MetricSet::CRayTracing42MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing42MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE41", "RT INSTANCE NODE RAY COUNT XECORE41",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE41", "RT INTERNAL NODE RAY COUNT XECORE41",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE41", "RT PROCEDURAL NODE RAY COUNT XECORE41",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE41", "RT QUAD LEAF RAY COUNT XECORE41",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE41", "RT TRAVERSAL STEP RAY COUNT XECORE41",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE41", "RT INPUT MESSAGE RAY COUNT XECORE41",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE41", "RT MESSAGE STALL COUNT XECORE41",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07096e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f09057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1309065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing43MetricSet::CRayTracing43MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing43MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE42", "RT INSTANCE NODE RAY COUNT XECORE42",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE42", "RT INTERNAL NODE RAY COUNT XECORE42",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE42", "RT PROCEDURAL NODE RAY COUNT XECORE42",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE42", "RT QUAD LEAF RAY COUNT XECORE42",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE42", "RT TRAVERSAL STEP RAY COUNT XECORE42",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE42", "RT INPUT MESSAGE RAY COUNT XECORE42",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE42", "RT MESSAGE STALL COUNT XECORE42",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b117fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07116e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09110d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b110dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f11057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1311065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15110e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing44MetricSet::CRayTracing44MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing44MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE43", "RT INSTANCE NODE RAY COUNT XECORE43",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE43", "RT INTERNAL NODE RAY COUNT XECORE43",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE43", "RT PROCEDURAL NODE RAY COUNT XECORE43",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE43", "RT QUAD LEAF RAY COUNT XECORE43",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE43", "RT TRAVERSAL STEP RAY COUNT XECORE43",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE43", "RT INPUT MESSAGE RAY COUNT XECORE43",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE43", "RT MESSAGE STALL COUNT XECORE43",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b197fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07196e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09190d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d190cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f19057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1319065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15190e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17190030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing45MetricSet::CRayTracing45MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing45MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE44", "RT INSTANCE NODE RAY COUNT XECORE44",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE44", "RT INTERNAL NODE RAY COUNT XECORE44",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE44", "RT PROCEDURAL NODE RAY COUNT XECORE44",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE44", "RT QUAD LEAF RAY COUNT XECORE44",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE44", "RT TRAVERSAL STEP RAY COUNT XECORE44",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE44", "RT INPUT MESSAGE RAY COUNT XECORE44",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE44", "RT MESSAGE STALL COUNT XECORE44",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b217fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07216e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09210d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d210cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f21057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1321065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15210e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing46MetricSet::CRayTracing46MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing46MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE45", "RT INSTANCE NODE RAY COUNT XECORE45",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE45", "RT INTERNAL NODE RAY COUNT XECORE45",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE45", "RT PROCEDURAL NODE RAY COUNT XECORE45",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE45", "RT QUAD LEAF RAY COUNT XECORE45",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE45", "RT TRAVERSAL STEP RAY COUNT XECORE45",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE45", "RT INPUT MESSAGE RAY COUNT XECORE45",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE45", "RT MESSAGE STALL COUNT XECORE45",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b297fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07296e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b290dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d290cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f29057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1329065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15290e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17290030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing47MetricSet::CRayTracing47MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing47MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE46", "RT INSTANCE NODE RAY COUNT XECORE46",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE46", "RT INTERNAL NODE RAY COUNT XECORE46",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE46", "RT PROCEDURAL NODE RAY COUNT XECORE46",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE46", "RT QUAD LEAF RAY COUNT XECORE46",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE46", "RT TRAVERSAL STEP RAY COUNT XECORE46",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE46", "RT INPUT MESSAGE RAY COUNT XECORE46",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE46", "RT MESSAGE STALL COUNT XECORE46",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b317fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07316e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b310dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d310cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f31057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1331065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15310e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing48MetricSet::CRayTracing48MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing48MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE47", "RT INSTANCE NODE RAY COUNT XECORE47",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE47", "RT INTERNAL NODE RAY COUNT XECORE47",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE47", "RT PROCEDURAL NODE RAY COUNT XECORE47",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE47", "RT QUAD LEAF RAY COUNT XECORE47",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE47", "RT TRAVERSAL STEP RAY COUNT XECORE47",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE47", "RT INPUT MESSAGE RAY COUNT XECORE47",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE47", "RT MESSAGE STALL COUNT XECORE47",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b397fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09390d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b390dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d390cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f39057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1339065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15390e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17390030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing49MetricSet::CRayTracing49MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing49MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE48", "RT INSTANCE NODE RAY COUNT XECORE48",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE48", "RT INTERNAL NODE RAY COUNT XECORE48",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE48", "RT PROCEDURAL NODE RAY COUNT XECORE48",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE48", "RT QUAD LEAF RAY COUNT XECORE48",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE48", "RT TRAVERSAL STEP RAY COUNT XECORE48",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE48", "RT INPUT MESSAGE RAY COUNT XECORE48",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE48", "RT MESSAGE STALL COUNT XECORE48",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a017fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06016e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a010dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e01057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1201065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing50MetricSet::CRayTracing50MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing50MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE49", "RT INSTANCE NODE RAY COUNT XECORE49",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE49", "RT INTERNAL NODE RAY COUNT XECORE49",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE49", "RT PROCEDURAL NODE RAY COUNT XECORE49",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE49", "RT QUAD LEAF RAY COUNT XECORE49",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE49", "RT TRAVERSAL STEP RAY COUNT XECORE49",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE49", "RT INPUT MESSAGE RAY COUNT XECORE49",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE49", "RT MESSAGE STALL COUNT XECORE49",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06096e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e09057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1209065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing51MetricSet::CRayTracing51MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing51MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE50", "RT INSTANCE NODE RAY COUNT XECORE50",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE50", "RT INTERNAL NODE RAY COUNT XECORE50",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE50", "RT PROCEDURAL NODE RAY COUNT XECORE50",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE50", "RT QUAD LEAF RAY COUNT XECORE50",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE50", "RT TRAVERSAL STEP RAY COUNT XECORE50",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE50", "RT INPUT MESSAGE RAY COUNT XECORE50",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE50", "RT MESSAGE STALL COUNT XECORE50",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a117fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06116e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08110d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a110dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c110cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e11057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1211065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing52MetricSet::CRayTracing52MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing52MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE51", "RT INSTANCE NODE RAY COUNT XECORE51",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE51", "RT INTERNAL NODE RAY COUNT XECORE51",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE51", "RT PROCEDURAL NODE RAY COUNT XECORE51",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE51", "RT QUAD LEAF RAY COUNT XECORE51",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE51", "RT TRAVERSAL STEP RAY COUNT XECORE51",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE51", "RT INPUT MESSAGE RAY COUNT XECORE51",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE51", "RT MESSAGE STALL COUNT XECORE51",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a197fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e1972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06196e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08190d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a190dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c190cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e19057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1219065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14190e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16190030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing53MetricSet::CRayTracing53MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing53MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE52", "RT INSTANCE NODE RAY COUNT XECORE52",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE52", "RT INTERNAL NODE RAY COUNT XECORE52",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE52", "RT PROCEDURAL NODE RAY COUNT XECORE52",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE52", "RT QUAD LEAF RAY COUNT XECORE52",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE52", "RT TRAVERSAL STEP RAY COUNT XECORE52",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE52", "RT INPUT MESSAGE RAY COUNT XECORE52",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE52", "RT MESSAGE STALL COUNT XECORE52",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a217fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06216e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08210d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a210dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e21057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1221065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14210e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing54MetricSet::CRayTracing54MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing54MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE53", "RT INSTANCE NODE RAY COUNT XECORE53",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE53", "RT INTERNAL NODE RAY COUNT XECORE53",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE53", "RT PROCEDURAL NODE RAY COUNT XECORE53",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE53", "RT QUAD LEAF RAY COUNT XECORE53",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE53", "RT TRAVERSAL STEP RAY COUNT XECORE53",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE53", "RT INPUT MESSAGE RAY COUNT XECORE53",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE53", "RT MESSAGE STALL COUNT XECORE53",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a297fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e2972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06296e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08290d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a290dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c290cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e29057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1229065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14290e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16290030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing55MetricSet::CRayTracing55MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing55MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE54", "RT INSTANCE NODE RAY COUNT XECORE54",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE54", "RT INTERNAL NODE RAY COUNT XECORE54",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE54", "RT PROCEDURAL NODE RAY COUNT XECORE54",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE54", "RT QUAD LEAF RAY COUNT XECORE54",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE54", "RT TRAVERSAL STEP RAY COUNT XECORE54",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE54", "RT INPUT MESSAGE RAY COUNT XECORE54",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE54", "RT MESSAGE STALL COUNT XECORE54",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a317fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06316e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08310d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a310dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c310cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e31057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1231065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14310e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing56MetricSet::CRayTracing56MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing56MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE55", "RT INSTANCE NODE RAY COUNT XECORE55",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE55", "RT INTERNAL NODE RAY COUNT XECORE55",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE55", "RT PROCEDURAL NODE RAY COUNT XECORE55",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE55", "RT QUAD LEAF RAY COUNT XECORE55",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE55", "RT TRAVERSAL STEP RAY COUNT XECORE55",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE55", "RT INPUT MESSAGE RAY COUNT XECORE55",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE55", "RT MESSAGE STALL COUNT XECORE55",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a397fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e3972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06396e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08390d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a390dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c390cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e39057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1239065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14390e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16390030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing57MetricSet::CRayTracing57MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing57MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE56", "RT INSTANCE NODE RAY COUNT XECORE56",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE56", "RT INTERNAL NODE RAY COUNT XECORE56",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE56", "RT PROCEDURAL NODE RAY COUNT XECORE56",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE56", "RT QUAD LEAF RAY COUNT XECORE56",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE56", "RT TRAVERSAL STEP RAY COUNT XECORE56",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE56", "RT INPUT MESSAGE RAY COUNT XECORE56",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE56", "RT MESSAGE STALL COUNT XECORE56",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b017fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07016e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09010d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b010dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d010cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f01057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1301065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15010e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing58MetricSet::CRayTracing58MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing58MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE57", "RT INSTANCE NODE RAY COUNT XECORE57",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE57", "RT INTERNAL NODE RAY COUNT XECORE57",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE57", "RT PROCEDURAL NODE RAY COUNT XECORE57",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE57", "RT QUAD LEAF RAY COUNT XECORE57",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE57", "RT TRAVERSAL STEP RAY COUNT XECORE57",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE57", "RT INPUT MESSAGE RAY COUNT XECORE57",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE57", "RT MESSAGE STALL COUNT XECORE57",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07096e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f09057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1309065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing59MetricSet::CRayTracing59MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing59MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE58", "RT INSTANCE NODE RAY COUNT XECORE58",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE58", "RT INTERNAL NODE RAY COUNT XECORE58",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE58", "RT PROCEDURAL NODE RAY COUNT XECORE58",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE58", "RT QUAD LEAF RAY COUNT XECORE58",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE58", "RT TRAVERSAL STEP RAY COUNT XECORE58",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE58", "RT INPUT MESSAGE RAY COUNT XECORE58",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE58", "RT MESSAGE STALL COUNT XECORE58",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b117fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07116e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09110d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b110dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f11057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1311065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15110e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing60MetricSet::CRayTracing60MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing60MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE59", "RT INSTANCE NODE RAY COUNT XECORE59",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE59", "RT INTERNAL NODE RAY COUNT XECORE59",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE59", "RT PROCEDURAL NODE RAY COUNT XECORE59",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE59", "RT QUAD LEAF RAY COUNT XECORE59",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE59", "RT TRAVERSAL STEP RAY COUNT XECORE59",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE59", "RT INPUT MESSAGE RAY COUNT XECORE59",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE59", "RT MESSAGE STALL COUNT XECORE59",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b197fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f1972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07196e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09190d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d190cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f19057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1319065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15190e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17190030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing61MetricSet::CRayTracing61MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing61MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE60", "RT INSTANCE NODE RAY COUNT XECORE60",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE60", "RT INTERNAL NODE RAY COUNT XECORE60",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE60", "RT PROCEDURAL NODE RAY COUNT XECORE60",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE60", "RT QUAD LEAF RAY COUNT XECORE60",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE60", "RT TRAVERSAL STEP RAY COUNT XECORE60",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE60", "RT INPUT MESSAGE RAY COUNT XECORE60",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE60", "RT MESSAGE STALL COUNT XECORE60",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b217fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07216e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09210d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d210cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f21057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1321065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15210e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing62MetricSet::CRayTracing62MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing62MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE61", "RT INSTANCE NODE RAY COUNT XECORE61",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE61", "RT INTERNAL NODE RAY COUNT XECORE61",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE61", "RT PROCEDURAL NODE RAY COUNT XECORE61",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE61", "RT QUAD LEAF RAY COUNT XECORE61",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE61", "RT TRAVERSAL STEP RAY COUNT XECORE61",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE61", "RT INPUT MESSAGE RAY COUNT XECORE61",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE61", "RT MESSAGE STALL COUNT XECORE61",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b297fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f2972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07296e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b290dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d290cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f29057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1329065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15290e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17290030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing63MetricSet::CRayTracing63MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing63MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE62", "RT INSTANCE NODE RAY COUNT XECORE62",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE62", "RT INTERNAL NODE RAY COUNT XECORE62",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE62", "RT PROCEDURAL NODE RAY COUNT XECORE62",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE62", "RT QUAD LEAF RAY COUNT XECORE62",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE62", "RT TRAVERSAL STEP RAY COUNT XECORE62",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE62", "RT INPUT MESSAGE RAY COUNT XECORE62",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE62", "RT MESSAGE STALL COUNT XECORE62",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b317fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3172e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07316e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b310dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d310cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f31057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113106dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1331065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15310e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing64MetricSet::CRayTracing64MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing64MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE63", "RT INSTANCE NODE RAY COUNT XECORE63",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE63", "RT INTERNAL NODE RAY COUNT XECORE63",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE63", "RT PROCEDURAL NODE RAY COUNT XECORE63",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE63", "RT QUAD LEAF RAY COUNT XECORE63",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE63", "RT TRAVERSAL STEP RAY COUNT XECORE63",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE63", "RT INPUT MESSAGE RAY COUNT XECORE63",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 2 dw@0xf0 UMUL UADD 4 dw@0xec UMUL UADD 8 dw@0xe8 UMUL UADD 16 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 2 qw@0x1a0 UMUL UADD 4 qw@0x198 UMUL UADD 8 qw@0x190 UMUL UADD 16 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE63", "RT MESSAGE STALL COUNT XECORE63",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b397fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f3972e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396e40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09390d7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b390dbd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d390cfe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f39057b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113906dc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1339065a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15390e18, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17390030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00040022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x00007ffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00020042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000bff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00040202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x00007fbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000bf7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing65MetricSet::CRayTracing65MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing65MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE0", "RT TRAVERSAL INPUT RAY COUNT XECORE0",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE1", "RT TRAVERSAL INPUT RAY COUNT XECORE1",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE2", "RT TRAVERSAL INPUT RAY COUNT XECORE2",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE3", "RT TRAVERSAL INPUT RAY COUNT XECORE3",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE4", "RT TRAVERSAL INPUT RAY COUNT XECORE4",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE5", "RT TRAVERSAL INPUT RAY COUNT XECORE5",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE6", "RT TRAVERSAL INPUT RAY COUNT XECORE6",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE7", "RT TRAVERSAL INPUT RAY COUNT XECORE7",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06016000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a110c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e190031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e210c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12290031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12310c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f63000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14390c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16390031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fcc000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fec000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c000a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1a5ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c200a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c3225b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing66MetricSet::CRayTracing66MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing66MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE8", "RT TRAVERSAL INPUT RAY COUNT XECORE8",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE9", "RT TRAVERSAL INPUT RAY COUNT XECORE9",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE10", "RT TRAVERSAL INPUT RAY COUNT XECORE10",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE11", "RT TRAVERSAL INPUT RAY COUNT XECORE11",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE12", "RT TRAVERSAL INPUT RAY COUNT XECORE12",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE13", "RT TRAVERSAL INPUT RAY COUNT XECORE13",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE14", "RT TRAVERSAL INPUT RAY COUNT XECORE14",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE15", "RT TRAVERSAL INPUT RAY COUNT XECORE15",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07016000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b110c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f190031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f210c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13290031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13310c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f63000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15390c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17390031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fcc000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fec000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c000a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1a5ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c200a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c3225b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing67MetricSet::CRayTracing67MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing67MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE16", "RT TRAVERSAL INPUT RAY COUNT XECORE16",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE17", "RT TRAVERSAL INPUT RAY COUNT XECORE17",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE18", "RT TRAVERSAL INPUT RAY COUNT XECORE18",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE19", "RT TRAVERSAL INPUT RAY COUNT XECORE19",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE20", "RT TRAVERSAL INPUT RAY COUNT XECORE20",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE21", "RT TRAVERSAL INPUT RAY COUNT XECORE21",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE22", "RT TRAVERSAL INPUT RAY COUNT XECORE22",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE23", "RT TRAVERSAL INPUT RAY COUNT XECORE23",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06016000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a110c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e190031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e210c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12290031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12310c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f63000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14390c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16390031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fcc000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fec000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c000a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1a5ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c200a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c3225b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing68MetricSet::CRayTracing68MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing68MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE24", "RT TRAVERSAL INPUT RAY COUNT XECORE24",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE25", "RT TRAVERSAL INPUT RAY COUNT XECORE25",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE26", "RT TRAVERSAL INPUT RAY COUNT XECORE26",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE27", "RT TRAVERSAL INPUT RAY COUNT XECORE27",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE28", "RT TRAVERSAL INPUT RAY COUNT XECORE28",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE29", "RT TRAVERSAL INPUT RAY COUNT XECORE29",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE30", "RT TRAVERSAL INPUT RAY COUNT XECORE30",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE31", "RT TRAVERSAL INPUT RAY COUNT XECORE31",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07016000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b110c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f190031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f210c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13290031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13310c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f63000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15390c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17390031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fcc000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fec000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c000a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1a5ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c200a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c3225b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing69MetricSet::CRayTracing69MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing69MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE32", "RT TRAVERSAL INPUT RAY COUNT XECORE32",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE33", "RT TRAVERSAL INPUT RAY COUNT XECORE33",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE34", "RT TRAVERSAL INPUT RAY COUNT XECORE34",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE35", "RT TRAVERSAL INPUT RAY COUNT XECORE35",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE36", "RT TRAVERSAL INPUT RAY COUNT XECORE36",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE37", "RT TRAVERSAL INPUT RAY COUNT XECORE37",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE38", "RT TRAVERSAL INPUT RAY COUNT XECORE38",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE39", "RT TRAVERSAL INPUT RAY COUNT XECORE39",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06016000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a110c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e190031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e210c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12290031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12310c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f63000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14390c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16390031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fcc000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fec000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c000a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1a5ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c200a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c3225b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing70MetricSet::CRayTracing70MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing70MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE40", "RT TRAVERSAL INPUT RAY COUNT XECORE40",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE41", "RT TRAVERSAL INPUT RAY COUNT XECORE41",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE42", "RT TRAVERSAL INPUT RAY COUNT XECORE42",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE43", "RT TRAVERSAL INPUT RAY COUNT XECORE43",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE44", "RT TRAVERSAL INPUT RAY COUNT XECORE44",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE45", "RT TRAVERSAL INPUT RAY COUNT XECORE45",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE46", "RT TRAVERSAL INPUT RAY COUNT XECORE46",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE47", "RT TRAVERSAL INPUT RAY COUNT XECORE47",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07016000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b110c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f190031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f210c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13290031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13310c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f63000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15390c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17390031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fcc000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fec000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c000a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1a5ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c200a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c3225b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing71MetricSet::CRayTracing71MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing71MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE48", "RT TRAVERSAL INPUT RAY COUNT XECORE48",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE49", "RT TRAVERSAL INPUT RAY COUNT XECORE49",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE50", "RT TRAVERSAL INPUT RAY COUNT XECORE50",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE51", "RT TRAVERSAL INPUT RAY COUNT XECORE51",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE52", "RT TRAVERSAL INPUT RAY COUNT XECORE52",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE53", "RT TRAVERSAL INPUT RAY COUNT XECORE53",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE54", "RT TRAVERSAL INPUT RAY COUNT XECORE54",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE55", "RT TRAVERSAL INPUT RAY COUNT XECORE55",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06016000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a110c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e190031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e210c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12290031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12310c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f63000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14390c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16390031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fcc000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fec000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c000a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1a5ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c200a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c3225b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing72MetricSet::CRayTracing72MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing72MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE56", "RT TRAVERSAL INPUT RAY COUNT XECORE56",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE57", "RT TRAVERSAL INPUT RAY COUNT XECORE57",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE58", "RT TRAVERSAL INPUT RAY COUNT XECORE58",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE59", "RT TRAVERSAL INPUT RAY COUNT XECORE59",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE60", "RT TRAVERSAL INPUT RAY COUNT XECORE60",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE61", "RT TRAVERSAL INPUT RAY COUNT XECORE61",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE62", "RT TRAVERSAL INPUT RAY COUNT XECORE62",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE63", "RT TRAVERSAL INPUT RAY COUNT XECORE63",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500602, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07016000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b110c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f190031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f210c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13290031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b00f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13310c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f50500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f63000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15390c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17390031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bf000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fcc000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fec000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c000a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1a5ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c200a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c3225b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing73MetricSet::CRayTracing73MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing73MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE0", "RT TRAVERSAL OUTPUT RAY COUNT XECORE0",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE1", "RT TRAVERSAL OUTPUT RAY COUNT XECORE1",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE2", "RT TRAVERSAL OUTPUT RAY COUNT XECORE2",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE3", "RT TRAVERSAL OUTPUT RAY COUNT XECORE3",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE4", "RT TRAVERSAL OUTPUT RAY COUNT XECORE4",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE5", "RT TRAVERSAL OUTPUT RAY COUNT XECORE5",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE6", "RT TRAVERSAL OUTPUT RAY COUNT XECORE6",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE7", "RT TRAVERSAL OUTPUT RAY COUNT XECORE7",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE8", "RT TRAVERSAL OUTPUT RAY COUNT XECORE8",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE9", "RT TRAVERSAL OUTPUT RAY COUNT XECORE9",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE10", "RT TRAVERSAL OUTPUT RAY COUNT XECORE10",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE11", "RT TRAVERSAL OUTPUT RAY COUNT XECORE11",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE12", "RT TRAVERSAL OUTPUT RAY COUNT XECORE12",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE13", "RT TRAVERSAL OUTPUT RAY COUNT XECORE13",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE14", "RT TRAVERSAL OUTPUT RAY COUNT XECORE14",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE15", "RT TRAVERSAL OUTPUT RAY COUNT XECORE15",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12190d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12210036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10310036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e390d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing74MetricSet::CRayTracing74MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing74MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE16", "RT TRAVERSAL OUTPUT RAY COUNT XECORE16",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE17", "RT TRAVERSAL OUTPUT RAY COUNT XECORE17",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE18", "RT TRAVERSAL OUTPUT RAY COUNT XECORE18",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE19", "RT TRAVERSAL OUTPUT RAY COUNT XECORE19",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE20", "RT TRAVERSAL OUTPUT RAY COUNT XECORE20",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE21", "RT TRAVERSAL OUTPUT RAY COUNT XECORE21",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE22", "RT TRAVERSAL OUTPUT RAY COUNT XECORE22",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE23", "RT TRAVERSAL OUTPUT RAY COUNT XECORE23",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE24", "RT TRAVERSAL OUTPUT RAY COUNT XECORE24",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE25", "RT TRAVERSAL OUTPUT RAY COUNT XECORE25",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE26", "RT TRAVERSAL OUTPUT RAY COUNT XECORE26",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE27", "RT TRAVERSAL OUTPUT RAY COUNT XECORE27",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE28", "RT TRAVERSAL OUTPUT RAY COUNT XECORE28",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE29", "RT TRAVERSAL OUTPUT RAY COUNT XECORE29",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE30", "RT TRAVERSAL OUTPUT RAY COUNT XECORE30",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE31", "RT TRAVERSAL OUTPUT RAY COUNT XECORE31",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12190d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12210036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10310036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e390d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing75MetricSet::CRayTracing75MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing75MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE32", "RT TRAVERSAL OUTPUT RAY COUNT XECORE32",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE33", "RT TRAVERSAL OUTPUT RAY COUNT XECORE33",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE34", "RT TRAVERSAL OUTPUT RAY COUNT XECORE34",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE35", "RT TRAVERSAL OUTPUT RAY COUNT XECORE35",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE36", "RT TRAVERSAL OUTPUT RAY COUNT XECORE36",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE37", "RT TRAVERSAL OUTPUT RAY COUNT XECORE37",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE38", "RT TRAVERSAL OUTPUT RAY COUNT XECORE38",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE39", "RT TRAVERSAL OUTPUT RAY COUNT XECORE39",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE40", "RT TRAVERSAL OUTPUT RAY COUNT XECORE40",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE41", "RT TRAVERSAL OUTPUT RAY COUNT XECORE41",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE42", "RT TRAVERSAL OUTPUT RAY COUNT XECORE42",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE43", "RT TRAVERSAL OUTPUT RAY COUNT XECORE43",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE44", "RT TRAVERSAL OUTPUT RAY COUNT XECORE44",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE45", "RT TRAVERSAL OUTPUT RAY COUNT XECORE45",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE46", "RT TRAVERSAL OUTPUT RAY COUNT XECORE46",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE47", "RT TRAVERSAL OUTPUT RAY COUNT XECORE47",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12190d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12210036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10310036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e390d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing76MetricSet::CRayTracing76MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing76MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE48", "RT TRAVERSAL OUTPUT RAY COUNT XECORE48",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE49", "RT TRAVERSAL OUTPUT RAY COUNT XECORE49",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE50", "RT TRAVERSAL OUTPUT RAY COUNT XECORE50",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE51", "RT TRAVERSAL OUTPUT RAY COUNT XECORE51",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE52", "RT TRAVERSAL OUTPUT RAY COUNT XECORE52",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE53", "RT TRAVERSAL OUTPUT RAY COUNT XECORE53",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE54", "RT TRAVERSAL OUTPUT RAY COUNT XECORE54",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE55", "RT TRAVERSAL OUTPUT RAY COUNT XECORE55",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE56", "RT TRAVERSAL OUTPUT RAY COUNT XECORE56",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE57", "RT TRAVERSAL OUTPUT RAY COUNT XECORE57",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE58", "RT TRAVERSAL OUTPUT RAY COUNT XECORE58",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE59", "RT TRAVERSAL OUTPUT RAY COUNT XECORE59",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE60", "RT TRAVERSAL OUTPUT RAY COUNT XECORE60",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE61", "RT TRAVERSAL OUTPUT RAY COUNT XECORE61",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE62", "RT TRAVERSAL OUTPUT RAY COUNT XECORE62",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE63", "RT TRAVERSAL OUTPUT RAY COUNT XECORE63",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12190d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12210036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10310036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e390d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing77MetricSet::CRayTracing77MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing77MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE0", "RT BVH CACHE MISS XECORE0",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE1", "RT BVH CACHE MISS XECORE1",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE2", "RT BVH CACHE MISS XECORE2",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE3", "RT BVH CACHE MISS XECORE3",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE4", "RT BVH CACHE MISS XECORE4",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE5", "RT BVH CACHE MISS XECORE5",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE6", "RT BVH CACHE MISS XECORE6",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE7", "RT BVH CACHE MISS XECORE7",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18012400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18092400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18112400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18192400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18212400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18292400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18312400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18392400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10110580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12110018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e190580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10190018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e210018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e600c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a290580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c290018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08310580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a310018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06392c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08390018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing78MetricSet::CRayTracing78MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing78MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE8", "RT BVH CACHE MISS XECORE8",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE9", "RT BVH CACHE MISS XECORE9",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE10", "RT BVH CACHE MISS XECORE10",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE11", "RT BVH CACHE MISS XECORE11",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE12", "RT BVH CACHE MISS XECORE12",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE13", "RT BVH CACHE MISS XECORE13",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE14", "RT BVH CACHE MISS XECORE14",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE15", "RT BVH CACHE MISS XECORE15",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19012400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19092400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19112400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19192400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19212400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19292400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19312400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19392400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15010580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13090580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11110580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13110018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f190580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11190018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d210580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f210018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e600c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b290580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d290018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b310018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07392c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09390018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing79MetricSet::CRayTracing79MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing79MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE16", "RT BVH CACHE MISS XECORE16",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE17", "RT BVH CACHE MISS XECORE17",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE18", "RT BVH CACHE MISS XECORE18",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE19", "RT BVH CACHE MISS XECORE19",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE20", "RT BVH CACHE MISS XECORE20",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE21", "RT BVH CACHE MISS XECORE21",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE22", "RT BVH CACHE MISS XECORE22",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE23", "RT BVH CACHE MISS XECORE23",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18012400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18092400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18112400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18192400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18212400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18292400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18312400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18392400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10110580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12110018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e190580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10190018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e210018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e600c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a290580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c290018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08310580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a310018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06392c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08390018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing80MetricSet::CRayTracing80MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing80MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE24", "RT BVH CACHE MISS XECORE24",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE25", "RT BVH CACHE MISS XECORE25",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE26", "RT BVH CACHE MISS XECORE26",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE27", "RT BVH CACHE MISS XECORE27",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE28", "RT BVH CACHE MISS XECORE28",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE29", "RT BVH CACHE MISS XECORE29",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE30", "RT BVH CACHE MISS XECORE30",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE31", "RT BVH CACHE MISS XECORE31",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19012400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19092400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19112400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19192400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19212400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19292400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19312400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19392400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15010580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13090580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11110580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13110018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f190580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11190018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d210580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f210018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e600c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b290580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d290018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b310018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07392c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09390018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing81MetricSet::CRayTracing81MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing81MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE32", "RT BVH CACHE MISS XECORE32",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE33", "RT BVH CACHE MISS XECORE33",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE34", "RT BVH CACHE MISS XECORE34",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE35", "RT BVH CACHE MISS XECORE35",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE36", "RT BVH CACHE MISS XECORE36",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE37", "RT BVH CACHE MISS XECORE37",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE38", "RT BVH CACHE MISS XECORE38",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE39", "RT BVH CACHE MISS XECORE39",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18012400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18092400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18112400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18192400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18212400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18292400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18312400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18392400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10110580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12110018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e190580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10190018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e210018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e600c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a290580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c290018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08310580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a310018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06392c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08390018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing82MetricSet::CRayTracing82MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing82MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE40", "RT BVH CACHE MISS XECORE40",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE41", "RT BVH CACHE MISS XECORE41",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE42", "RT BVH CACHE MISS XECORE42",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE43", "RT BVH CACHE MISS XECORE43",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE44", "RT BVH CACHE MISS XECORE44",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE45", "RT BVH CACHE MISS XECORE45",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE46", "RT BVH CACHE MISS XECORE46",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE47", "RT BVH CACHE MISS XECORE47",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19012400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19092400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19112400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19192400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19212400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19292400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19312400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19392400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15010580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13090580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11110580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13110018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f190580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11190018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d210580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f210018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e600c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b290580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d290018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b310018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07392c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09390018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing83MetricSet::CRayTracing83MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing83MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE48", "RT BVH CACHE MISS XECORE48",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE49", "RT BVH CACHE MISS XECORE49",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE50", "RT BVH CACHE MISS XECORE50",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE51", "RT BVH CACHE MISS XECORE51",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE52", "RT BVH CACHE MISS XECORE52",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE53", "RT BVH CACHE MISS XECORE53",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE54", "RT BVH CACHE MISS XECORE54",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE55", "RT BVH CACHE MISS XECORE55",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18012400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18092400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18112400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18192400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18212400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18292400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18312400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18392400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10110580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12110018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d60c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e190580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10190018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e210018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e600c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a290580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c290018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08310580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a310018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06392c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08390018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing84MetricSet::CRayTracing84MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing84MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE56", "RT BVH CACHE MISS XECORE56",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE57", "RT BVH CACHE MISS XECORE57",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE58", "RT BVH CACHE MISS XECORE58",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE59", "RT BVH CACHE MISS XECORE59",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE60", "RT BVH CACHE MISS XECORE60",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE61", "RT BVH CACHE MISS XECORE61",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE62", "RT BVH CACHE MISS XECORE62",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE63", "RT BVH CACHE MISS XECORE63",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19012400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19092400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19112400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19192400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19212400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19292400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19312400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19392400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15010580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13090580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11110580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13110018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f190580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11190018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d210580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f210018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e600c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b290580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d290018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b310018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07392c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09390018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ff5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing85MetricSet::CRayTracing85MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing85MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE0", "RT QUAD TEST RAY COUNT XECORE0",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE1", "RT QUAD TEST RAY COUNT XECORE1",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE2", "RT QUAD TEST RAY COUNT XECORE2",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE3", "RT QUAD TEST RAY COUNT XECORE3",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE4", "RT QUAD TEST RAY COUNT XECORE4",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE5", "RT QUAD TEST RAY COUNT XECORE5",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE6", "RT QUAD TEST RAY COUNT XECORE6",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE7", "RT QUAD TEST RAY COUNT XECORE7",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE8", "RT QUAD TEST RAY COUNT XECORE8",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE9", "RT QUAD TEST RAY COUNT XECORE9",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE10", "RT QUAD TEST RAY COUNT XECORE10",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE11", "RT QUAD TEST RAY COUNT XECORE11",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE12", "RT QUAD TEST RAY COUNT XECORE12",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE13", "RT QUAD TEST RAY COUNT XECORE13",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE14", "RT QUAD TEST RAY COUNT XECORE14",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE15", "RT QUAD TEST RAY COUNT XECORE15",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e390c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing86MetricSet::CRayTracing86MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing86MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE16", "RT QUAD TEST RAY COUNT XECORE16",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE17", "RT QUAD TEST RAY COUNT XECORE17",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE18", "RT QUAD TEST RAY COUNT XECORE18",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE19", "RT QUAD TEST RAY COUNT XECORE19",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE20", "RT QUAD TEST RAY COUNT XECORE20",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE21", "RT QUAD TEST RAY COUNT XECORE21",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE22", "RT QUAD TEST RAY COUNT XECORE22",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE23", "RT QUAD TEST RAY COUNT XECORE23",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE24", "RT QUAD TEST RAY COUNT XECORE24",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE25", "RT QUAD TEST RAY COUNT XECORE25",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE26", "RT QUAD TEST RAY COUNT XECORE26",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE27", "RT QUAD TEST RAY COUNT XECORE27",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE28", "RT QUAD TEST RAY COUNT XECORE28",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE29", "RT QUAD TEST RAY COUNT XECORE29",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE30", "RT QUAD TEST RAY COUNT XECORE30",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE31", "RT QUAD TEST RAY COUNT XECORE31",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e390c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing87MetricSet::CRayTracing87MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing87MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE32", "RT QUAD TEST RAY COUNT XECORE32",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE33", "RT QUAD TEST RAY COUNT XECORE33",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE34", "RT QUAD TEST RAY COUNT XECORE34",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE35", "RT QUAD TEST RAY COUNT XECORE35",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE36", "RT QUAD TEST RAY COUNT XECORE36",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE37", "RT QUAD TEST RAY COUNT XECORE37",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE38", "RT QUAD TEST RAY COUNT XECORE38",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE39", "RT QUAD TEST RAY COUNT XECORE39",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE40", "RT QUAD TEST RAY COUNT XECORE40",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE41", "RT QUAD TEST RAY COUNT XECORE41",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE42", "RT QUAD TEST RAY COUNT XECORE42",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE43", "RT QUAD TEST RAY COUNT XECORE43",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE44", "RT QUAD TEST RAY COUNT XECORE44",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE45", "RT QUAD TEST RAY COUNT XECORE45",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE46", "RT QUAD TEST RAY COUNT XECORE46",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE47", "RT QUAD TEST RAY COUNT XECORE47",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e390c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing88MetricSet::CRayTracing88MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing88MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE48", "RT QUAD TEST RAY COUNT XECORE48",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE49", "RT QUAD TEST RAY COUNT XECORE49",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE50", "RT QUAD TEST RAY COUNT XECORE50",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE51", "RT QUAD TEST RAY COUNT XECORE51",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE52", "RT QUAD TEST RAY COUNT XECORE52",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE53", "RT QUAD TEST RAY COUNT XECORE53",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE54", "RT QUAD TEST RAY COUNT XECORE54",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE55", "RT QUAD TEST RAY COUNT XECORE55",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE56", "RT QUAD TEST RAY COUNT XECORE56",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE57", "RT QUAD TEST RAY COUNT XECORE57",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE58", "RT QUAD TEST RAY COUNT XECORE58",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE59", "RT QUAD TEST RAY COUNT XECORE59",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE60", "RT QUAD TEST RAY COUNT XECORE60",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE61", "RT QUAD TEST RAY COUNT XECORE61",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE62", "RT QUAD TEST RAY COUNT XECORE62",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE63", "RT QUAD TEST RAY COUNT XECORE63",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e390c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing89MetricSet::CRayTracing89MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing89MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE0", "RT TRANSFORM RAY COUNT XECORE0",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE1", "RT TRANSFORM RAY COUNT XECORE1",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE2", "RT TRANSFORM RAY COUNT XECORE2",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE3", "RT TRANSFORM RAY COUNT XECORE3",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE4", "RT TRANSFORM RAY COUNT XECORE4",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE5", "RT TRANSFORM RAY COUNT XECORE5",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE6", "RT TRANSFORM RAY COUNT XECORE6",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE7", "RT TRANSFORM RAY COUNT XECORE7",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE8", "RT TRANSFORM RAY COUNT XECORE8",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE9", "RT TRANSFORM RAY COUNT XECORE9",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE10", "RT TRANSFORM RAY COUNT XECORE10",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE11", "RT TRANSFORM RAY COUNT XECORE11",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE12", "RT TRANSFORM RAY COUNT XECORE12",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE13", "RT TRANSFORM RAY COUNT XECORE13",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE14", "RT TRANSFORM RAY COUNT XECORE14",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE15", "RT TRANSFORM RAY COUNT XECORE15",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12190c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e390c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing90MetricSet::CRayTracing90MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing90MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE16", "RT TRANSFORM RAY COUNT XECORE16",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE17", "RT TRANSFORM RAY COUNT XECORE17",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE18", "RT TRANSFORM RAY COUNT XECORE18",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE19", "RT TRANSFORM RAY COUNT XECORE19",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE20", "RT TRANSFORM RAY COUNT XECORE20",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE21", "RT TRANSFORM RAY COUNT XECORE21",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE22", "RT TRANSFORM RAY COUNT XECORE22",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE23", "RT TRANSFORM RAY COUNT XECORE23",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE24", "RT TRANSFORM RAY COUNT XECORE24",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE25", "RT TRANSFORM RAY COUNT XECORE25",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE26", "RT TRANSFORM RAY COUNT XECORE26",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE27", "RT TRANSFORM RAY COUNT XECORE27",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE28", "RT TRANSFORM RAY COUNT XECORE28",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE29", "RT TRANSFORM RAY COUNT XECORE29",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE30", "RT TRANSFORM RAY COUNT XECORE30",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE31", "RT TRANSFORM RAY COUNT XECORE31",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12190c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e390c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing91MetricSet::CRayTracing91MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing91MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE32", "RT TRANSFORM RAY COUNT XECORE32",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE33", "RT TRANSFORM RAY COUNT XECORE33",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE34", "RT TRANSFORM RAY COUNT XECORE34",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE35", "RT TRANSFORM RAY COUNT XECORE35",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE36", "RT TRANSFORM RAY COUNT XECORE36",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE37", "RT TRANSFORM RAY COUNT XECORE37",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE38", "RT TRANSFORM RAY COUNT XECORE38",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE39", "RT TRANSFORM RAY COUNT XECORE39",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE40", "RT TRANSFORM RAY COUNT XECORE40",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE41", "RT TRANSFORM RAY COUNT XECORE41",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE42", "RT TRANSFORM RAY COUNT XECORE42",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE43", "RT TRANSFORM RAY COUNT XECORE43",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE44", "RT TRANSFORM RAY COUNT XECORE44",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE45", "RT TRANSFORM RAY COUNT XECORE45",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE46", "RT TRANSFORM RAY COUNT XECORE46",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE47", "RT TRANSFORM RAY COUNT XECORE47",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12190c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e390c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRayTracing92MetricSet::CRayTracing92MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRayTracing92MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE48", "RT TRANSFORM RAY COUNT XECORE48",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE49", "RT TRANSFORM RAY COUNT XECORE49",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE50", "RT TRANSFORM RAY COUNT XECORE50",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE51", "RT TRANSFORM RAY COUNT XECORE51",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE52", "RT TRANSFORM RAY COUNT XECORE52",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE53", "RT TRANSFORM RAY COUNT XECORE53",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE54", "RT TRANSFORM RAY COUNT XECORE54",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE55", "RT TRANSFORM RAY COUNT XECORE55",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE56", "RT TRANSFORM RAY COUNT XECORE56",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE57", "RT TRANSFORM RAY COUNT XECORE57",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE58", "RT TRANSFORM RAY COUNT XECORE58",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE59", "RT TRANSFORM RAY COUNT XECORE59",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE60", "RT TRANSFORM RAY COUNT XECORE60",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE61", "RT TRANSFORM RAY COUNT XECORE61",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE62", "RT TRANSFORM RAY COUNT XECORE62",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE63", "RT TRANSFORM RAY COUNT XECORE63",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12190c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e390c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f010120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f090120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f110120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f190120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f210120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f290120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f310120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f390120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b190c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b210031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09310031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07396200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher1MetricSet::CThreadDispatcher1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE0", "ASYNC GPGPU THREAD EXIT COUNT XECORE0",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE1", "ASYNC GPGPU THREAD EXIT COUNT XECORE1",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE63", "THREADGROUP DISPATCH RESOURCE STALL XECORE63",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher2MetricSet::CThreadDispatcher2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE2", "ASYNC GPGPU THREAD EXIT COUNT XECORE2",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE3", "ASYNC GPGPU THREAD EXIT COUNT XECORE3",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE0", "THREADGROUP DISPATCH RESOURCE STALL XECORE0",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a030cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x161b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher3MetricSet::CThreadDispatcher3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE4", "ASYNC GPGPU THREAD EXIT COUNT XECORE4",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE5", "ASYNC GPGPU THREAD EXIT COUNT XECORE5",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE1", "THREADGROUP DISPATCH RESOURCE STALL XECORE1",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x142b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x162b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c000aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher4MetricSet::CThreadDispatcher4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE6", "ASYNC GPGPU THREAD EXIT COUNT XECORE6",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE7", "ASYNC GPGPU THREAD EXIT COUNT XECORE7",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE2", "THREADGROUP DISPATCH RESOURCE STALL XECORE2",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a130cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c330c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x123b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x143b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x163b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c316db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher5MetricSet::CThreadDispatcher5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE8", "ASYNC GPGPU THREAD EXIT COUNT XECORE8",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE9", "ASYNC GPGPU THREAD EXIT COUNT XECORE9",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE3", "THREADGROUP DISPATCH RESOURCE STALL XECORE3",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher6MetricSet::CThreadDispatcher6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE10", "ASYNC GPGPU THREAD EXIT COUNT XECORE10",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE11", "ASYNC GPGPU THREAD EXIT COUNT XECORE11",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE4", "THREADGROUP DISPATCH RESOURCE STALL XECORE4",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x171b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher7MetricSet::CThreadDispatcher7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE12", "ASYNC GPGPU THREAD EXIT COUNT XECORE12",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE13", "ASYNC GPGPU THREAD EXIT COUNT XECORE13",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE5", "THREADGROUP DISPATCH RESOURCE STALL XECORE5",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x152b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x172b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher8MetricSet::CThreadDispatcher8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE14", "ASYNC GPGPU THREAD EXIT COUNT XECORE14",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE15", "ASYNC GPGPU THREAD EXIT COUNT XECORE15",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE6", "THREADGROUP DISPATCH RESOURCE STALL XECORE6",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a330cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d330c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x133b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x153b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x173b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher9MetricSet::CThreadDispatcher9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE16", "ASYNC GPGPU THREAD EXIT COUNT XECORE16",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE17", "ASYNC GPGPU THREAD EXIT COUNT XECORE17",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE7", "THREADGROUP DISPATCH RESOURCE STALL XECORE7",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher10MetricSet::CThreadDispatcher10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE18", "ASYNC GPGPU THREAD EXIT COUNT XECORE18",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE19", "ASYNC GPGPU THREAD EXIT COUNT XECORE19",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE8", "THREADGROUP DISPATCH RESOURCE STALL XECORE8",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b030cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c00055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x161b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher11MetricSet::CThreadDispatcher11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE20", "ASYNC GPGPU THREAD EXIT COUNT XECORE20",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE21", "ASYNC GPGPU THREAD EXIT COUNT XECORE21",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE9", "THREADGROUP DISPATCH RESOURCE STALL XECORE9",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c000aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x142b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x162b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher12MetricSet::CThreadDispatcher12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE22", "ASYNC GPGPU THREAD EXIT COUNT XECORE22",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE23", "ASYNC GPGPU THREAD EXIT COUNT XECORE23",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE10", "THREADGROUP DISPATCH RESOURCE STALL XECORE10",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b130cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c330c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x123b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x143b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x163b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher13MetricSet::CThreadDispatcher13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE24", "ASYNC GPGPU THREAD EXIT COUNT XECORE24",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE25", "ASYNC GPGPU THREAD EXIT COUNT XECORE25",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE11", "THREADGROUP DISPATCH RESOURCE STALL XECORE11",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b1b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher14MetricSet::CThreadDispatcher14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE26", "ASYNC GPGPU THREAD EXIT COUNT XECORE26",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE27", "ASYNC GPGPU THREAD EXIT COUNT XECORE27",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE12", "THREADGROUP DISPATCH RESOURCE STALL XECORE12",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x171b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher15MetricSet::CThreadDispatcher15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE28", "ASYNC GPGPU THREAD EXIT COUNT XECORE28",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE29", "ASYNC GPGPU THREAD EXIT COUNT XECORE29",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE13", "THREADGROUP DISPATCH RESOURCE STALL XECORE13",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x152b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x172b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher16MetricSet::CThreadDispatcher16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE30", "ASYNC GPGPU THREAD EXIT COUNT XECORE30",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE31", "ASYNC GPGPU THREAD EXIT COUNT XECORE31",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE14", "THREADGROUP DISPATCH RESOURCE STALL XECORE14",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b330cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d330c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x133b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x153b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x173b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher17MetricSet::CThreadDispatcher17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE32", "ASYNC GPGPU THREAD EXIT COUNT XECORE32",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE33", "ASYNC GPGPU THREAD EXIT COUNT XECORE33",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE15", "THREADGROUP DISPATCH RESOURCE STALL XECORE15",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501209, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher18MetricSet::CThreadDispatcher18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE34", "ASYNC GPGPU THREAD EXIT COUNT XECORE34",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE35", "ASYNC GPGPU THREAD EXIT COUNT XECORE35",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE16", "THREADGROUP DISPATCH RESOURCE STALL XECORE16",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a030cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c00055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x161b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher19MetricSet::CThreadDispatcher19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE36", "ASYNC GPGPU THREAD EXIT COUNT XECORE36",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE37", "ASYNC GPGPU THREAD EXIT COUNT XECORE37",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE17", "THREADGROUP DISPATCH RESOURCE STALL XECORE17",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c000aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x142b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x162b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher20MetricSet::CThreadDispatcher20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE38", "ASYNC GPGPU THREAD EXIT COUNT XECORE38",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE39", "ASYNC GPGPU THREAD EXIT COUNT XECORE39",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE18", "THREADGROUP DISPATCH RESOURCE STALL XECORE18",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a130cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c330c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x123b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x143b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x163b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher21MetricSet::CThreadDispatcher21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE40", "ASYNC GPGPU THREAD EXIT COUNT XECORE40",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE41", "ASYNC GPGPU THREAD EXIT COUNT XECORE41",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE19", "THREADGROUP DISPATCH RESOURCE STALL XECORE19",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher22MetricSet::CThreadDispatcher22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE42", "ASYNC GPGPU THREAD EXIT COUNT XECORE42",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE43", "ASYNC GPGPU THREAD EXIT COUNT XECORE43",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE20", "THREADGROUP DISPATCH RESOURCE STALL XECORE20",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x171b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher23MetricSet::CThreadDispatcher23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE44", "ASYNC GPGPU THREAD EXIT COUNT XECORE44",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE45", "ASYNC GPGPU THREAD EXIT COUNT XECORE45",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE21", "THREADGROUP DISPATCH RESOURCE STALL XECORE21",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500e07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500e07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x152b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x172b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher24MetricSet::CThreadDispatcher24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE46", "ASYNC GPGPU THREAD EXIT COUNT XECORE46",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE47", "ASYNC GPGPU THREAD EXIT COUNT XECORE47",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE22", "THREADGROUP DISPATCH RESOURCE STALL XECORE22",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500e07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500e07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500e07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500e07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a330cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d330c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x133b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x153b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x173b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher25MetricSet::CThreadDispatcher25MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher25MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE48", "ASYNC GPGPU THREAD EXIT COUNT XECORE48",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE49", "ASYNC GPGPU THREAD EXIT COUNT XECORE49",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE23", "THREADGROUP DISPATCH RESOURCE STALL XECORE23",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher26MetricSet::CThreadDispatcher26MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher26MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE50", "ASYNC GPGPU THREAD EXIT COUNT XECORE50",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE51", "ASYNC GPGPU THREAD EXIT COUNT XECORE51",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE24", "THREADGROUP DISPATCH RESOURCE STALL XECORE24",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b030cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c00055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x161b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher27MetricSet::CThreadDispatcher27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE52", "ASYNC GPGPU THREAD EXIT COUNT XECORE52",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE53", "ASYNC GPGPU THREAD EXIT COUNT XECORE53",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE25", "THREADGROUP DISPATCH RESOURCE STALL XECORE25",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c000aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x142b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x162b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher28MetricSet::CThreadDispatcher28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE54", "ASYNC GPGPU THREAD EXIT COUNT XECORE54",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE55", "ASYNC GPGPU THREAD EXIT COUNT XECORE55",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE26", "THREADGROUP DISPATCH RESOURCE STALL XECORE26",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b130cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c330c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x123b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x143b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x163b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher29MetricSet::CThreadDispatcher29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE56", "ASYNC GPGPU THREAD EXIT COUNT XECORE56",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE57", "ASYNC GPGPU THREAD EXIT COUNT XECORE57",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE27", "THREADGROUP DISPATCH RESOURCE STALL XECORE27",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b1b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher30MetricSet::CThreadDispatcher30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE58", "ASYNC GPGPU THREAD EXIT COUNT XECORE58",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE59", "ASYNC GPGPU THREAD EXIT COUNT XECORE59",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE28", "THREADGROUP DISPATCH RESOURCE STALL XECORE28",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x171b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher31MetricSet::CThreadDispatcher31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE60", "ASYNC GPGPU THREAD EXIT COUNT XECORE60",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE61", "ASYNC GPGPU THREAD EXIT COUNT XECORE61",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE29", "THREADGROUP DISPATCH RESOURCE STALL XECORE29",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x152b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x172b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher32MetricSet::CThreadDispatcher32MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher32MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE62", "ASYNC GPGPU THREAD EXIT COUNT XECORE62",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE63", "ASYNC GPGPU THREAD EXIT COUNT XECORE63",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE30", "THREADGROUP DISPATCH RESOURCE STALL XECORE30",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b330cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d330c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x133b0c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x153b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x173b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000c02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher33MetricSet::CThreadDispatcher33MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher33MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE31", "THREADGROUP DISPATCH RESOURCE STALL XECORE31",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE32", "THREADGROUP DISPATCH RESOURCE STALL XECORE32",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE33", "THREADGROUP DISPATCH RESOURCE STALL XECORE33",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE34", "THREADGROUP DISPATCH RESOURCE STALL XECORE34",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ff55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16130cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c000aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000401, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00040001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher34MetricSet::CThreadDispatcher34MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher34MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE35", "THREADGROUP DISPATCH RESOURCE STALL XECORE35",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE36", "THREADGROUP DISPATCH RESOURCE STALL XECORE36",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE37", "THREADGROUP DISPATCH RESOURCE STALL XECORE37",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE38", "THREADGROUP DISPATCH RESOURCE STALL XECORE38",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e230cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16330cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c3125b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000401, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00040001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher35MetricSet::CThreadDispatcher35MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher35MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE39", "THREADGROUP DISPATCH RESOURCE STALL XECORE39",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE40", "THREADGROUP DISPATCH RESOURCE STALL XECORE40",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE41", "THREADGROUP DISPATCH RESOURCE STALL XECORE41",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE42", "THREADGROUP DISPATCH RESOURCE STALL XECORE42",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500803, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17130cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c000aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000401, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00040001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher36MetricSet::CThreadDispatcher36MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher36MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE43", "THREADGROUP DISPATCH RESOURCE STALL XECORE43",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE44", "THREADGROUP DISPATCH RESOURCE STALL XECORE44",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE45", "THREADGROUP DISPATCH RESOURCE STALL XECORE45",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE46", "THREADGROUP DISPATCH RESOURCE STALL XECORE46",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b1b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f230cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17330cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c3125b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000401, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00040001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher37MetricSet::CThreadDispatcher37MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher37MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE47", "THREADGROUP DISPATCH RESOURCE STALL XECORE47",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE48", "THREADGROUP DISPATCH RESOURCE STALL XECORE48",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE49", "THREADGROUP DISPATCH RESOURCE STALL XECORE49",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE50", "THREADGROUP DISPATCH RESOURCE STALL XECORE50",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014055ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x285000a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a50140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16130cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c000aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000401, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00040001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher38MetricSet::CThreadDispatcher38MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher38MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE51", "THREADGROUP DISPATCH RESOURCE STALL XECORE51",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE52", "THREADGROUP DISPATCH RESOURCE STALL XECORE52",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE53", "THREADGROUP DISPATCH RESOURCE STALL XECORE53",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE54", "THREADGROUP DISPATCH RESOURCE STALL XECORE54",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e230cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16330cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c3125b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000401, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00040001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher39MetricSet::CThreadDispatcher39MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher39MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE55", "THREADGROUP DISPATCH RESOURCE STALL XECORE55",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE56", "THREADGROUP DISPATCH RESOURCE STALL XECORE56",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE57", "THREADGROUP DISPATCH RESOURCE STALL XECORE57",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE58", "THREADGROUP DISPATCH RESOURCE STALL XECORE58",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500803, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f33492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f400aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17130cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c000aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000401, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00040001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher40MetricSet::CThreadDispatcher40MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher40MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE59", "THREADGROUP DISPATCH RESOURCE STALL XECORE59",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE60", "THREADGROUP DISPATCH RESOURCE STALL XECORE60",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE61", "THREADGROUP DISPATCH RESOURCE STALL XECORE61",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE62", "THREADGROUP DISPATCH RESOURCE STALL XECORE62",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b1b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f230cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15330db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17330cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c100aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c3125b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000401, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00040001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher41MetricSet::CThreadDispatcher41MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher41MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE0", "ASYNC GPGPU THREADGROUP COUNT XECORE0",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE1", "ASYNC GPGPU THREADGROUP COUNT XECORE1",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE2", "ASYNC GPGPU THREADGROUP COUNT XECORE2",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33402aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a030d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c03003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1613003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1155f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher42MetricSet::CThreadDispatcher42MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher42MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE3", "ASYNC GPGPU THREADGROUP COUNT XECORE3",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE4", "ASYNC GPGPU THREADGROUP COUNT XECORE4",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE5", "ASYNC GPGPU THREADGROUP COUNT XECORE5",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33402aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e230d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10230fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x142b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x162b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c102aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c257ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c22aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher43MetricSet::CThreadDispatcher43MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher43MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE6", "ASYNC GPGPU THREADGROUP COUNT XECORE6",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE7", "ASYNC GPGPU THREADGROUP COUNT XECORE7",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE8", "ASYNC GPGPU THREADGROUP COUNT XECORE8",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33402aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5003ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f003ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f203ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a330d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c33003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c3b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15030d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1703003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c01550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c13ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c23ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher44MetricSet::CThreadDispatcher44MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher44MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE9", "ASYNC GPGPU THREADGROUP COUNT XECORE9",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE10", "ASYNC GPGPU THREADGROUP COUNT XECORE10",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE11", "ASYNC GPGPU THREADGROUP COUNT XECORE11",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33402aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f130d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11130fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x171b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c002aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c157ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c12aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher45MetricSet::CThreadDispatcher45MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher45MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE12", "ASYNC GPGPU THREADGROUP COUNT XECORE12",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE13", "ASYNC GPGPU THREADGROUP COUNT XECORE13",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE14", "ASYNC GPGPU THREADGROUP COUNT XECORE14",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33402aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d23003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15330d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1733003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher46MetricSet::CThreadDispatcher46MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher46MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE15", "ASYNC GPGPU THREADGROUP COUNT XECORE15",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE16", "ASYNC GPGPU THREADGROUP COUNT XECORE16",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE17", "ASYNC GPGPU THREADGROUP COUNT XECORE17",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014056aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f412aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x285000a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a50140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c5000a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d3b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c02aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c13fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher47MetricSet::CThreadDispatcher47MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher47MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE18", "ASYNC GPGPU THREADGROUP COUNT XECORE18",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE19", "ASYNC GPGPU THREADGROUP COUNT XECORE19",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE20", "ASYNC GPGPU THREADGROUP COUNT XECORE20",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f412aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a130d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c13003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101b0fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14230d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1623003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2155f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher48MetricSet::CThreadDispatcher48MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher48MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE21", "ASYNC GPGPU THREADGROUP COUNT XECORE21",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE22", "ASYNC GPGPU THREADGROUP COUNT XECORE22",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE23", "ASYNC GPGPU THREADGROUP COUNT XECORE23",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f412aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c2b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c330c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e330d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x123b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x143b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x163b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c202aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher49MetricSet::CThreadDispatcher49MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher49MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE24", "ASYNC GPGPU THREADGROUP COUNT XECORE24",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE25", "ASYNC GPGPU THREADGROUP COUNT XECORE25",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE26", "ASYNC GPGPU THREADGROUP COUNT XECORE26",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f412aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b030d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d03003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1713003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1155f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher50MetricSet::CThreadDispatcher50MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher50MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE27", "ASYNC GPGPU THREADGROUP COUNT XECORE27",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE28", "ASYNC GPGPU THREADGROUP COUNT XECORE28",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE29", "ASYNC GPGPU THREADGROUP COUNT XECORE29",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f412aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b1b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f230d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11230fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x152b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x172b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c102aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c257ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c22aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher51MetricSet::CThreadDispatcher51MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher51MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE30", "ASYNC GPGPU THREADGROUP COUNT XECORE30",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE31", "ASYNC GPGPU THREADGROUP COUNT XECORE31",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE32", "ASYNC GPGPU THREADGROUP COUNT XECORE32",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33403ff5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b330d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d33003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d3b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c01550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c13ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c23ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher52MetricSet::CThreadDispatcher52MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher52MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE33", "ASYNC GPGPU THREADGROUP COUNT XECORE33",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE34", "ASYNC GPGPU THREADGROUP COUNT XECORE34",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE35", "ASYNC GPGPU THREADGROUP COUNT XECORE35",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33403fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e130d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10130fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x161b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c002aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c157ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c12aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher53MetricSet::CThreadDispatcher53MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher53MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE36", "ASYNC GPGPU THREADGROUP COUNT XECORE36",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE37", "ASYNC GPGPU THREADGROUP COUNT XECORE37",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE38", "ASYNC GPGPU THREADGROUP COUNT XECORE38",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33403fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c23003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c2b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102b0fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14330d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1633003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher54MetricSet::CThreadDispatcher54MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher54MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE39", "ASYNC GPGPU THREADGROUP COUNT XECORE39",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE40", "ASYNC GPGPU THREADGROUP COUNT XECORE40",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE41", "ASYNC GPGPU THREADGROUP COUNT XECORE41",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33403fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f402aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c3b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11030fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c02aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c13fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher55MetricSet::CThreadDispatcher55MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher55MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE42", "ASYNC GPGPU THREADGROUP COUNT XECORE42",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE43", "ASYNC GPGPU THREADGROUP COUNT XECORE43",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE44", "ASYNC GPGPU THREADGROUP COUNT XECORE44",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33403fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b130d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d13003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111b0fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15230d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1723003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2155f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher56MetricSet::CThreadDispatcher56MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher56MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE45", "ASYNC GPGPU THREADGROUP COUNT XECORE45",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE46", "ASYNC GPGPU THREADGROUP COUNT XECORE46",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE47", "ASYNC GPGPU THREADGROUP COUNT XECORE47",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33403fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d330c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f330d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x133b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x153b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x173b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c202aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher57MetricSet::CThreadDispatcher57MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher57MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE48", "ASYNC GPGPU THREADGROUP COUNT XECORE48",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE49", "ASYNC GPGPU THREADGROUP COUNT XECORE49",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE50", "ASYNC GPGPU THREADGROUP COUNT XECORE50",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f413fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a030d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c03003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1613003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1155f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher58MetricSet::CThreadDispatcher58MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher58MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE51", "ASYNC GPGPU THREADGROUP COUNT XECORE51",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE52", "ASYNC GPGPU THREADGROUP COUNT XECORE52",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE53", "ASYNC GPGPU THREADGROUP COUNT XECORE53",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f413fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e230d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10230fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x142b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x162b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c102aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c257ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c22aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher59MetricSet::CThreadDispatcher59MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher59MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE54", "ASYNC GPGPU THREADGROUP COUNT XECORE54",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE55", "ASYNC GPGPU THREADGROUP COUNT XECORE55",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE56", "ASYNC GPGPU THREADGROUP COUNT XECORE56",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f413fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5003ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f003ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f203ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a330d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c33003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c3b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15030d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1703003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c01550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c13ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c23ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher60MetricSet::CThreadDispatcher60MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher60MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE57", "ASYNC GPGPU THREADGROUP COUNT XECORE57",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE58", "ASYNC GPGPU THREADGROUP COUNT XECORE58",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE59", "ASYNC GPGPU THREADGROUP COUNT XECORE59",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f413fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f130d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11130fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x171b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c002aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c157ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c12aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher61MetricSet::CThreadDispatcher61MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher61MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE60", "ASYNC GPGPU THREADGROUP COUNT XECORE60",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE61", "ASYNC GPGPU THREADGROUP COUNT XECORE61",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE62", "ASYNC GPGPU THREADGROUP COUNT XECORE62",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f413fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3303aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d23003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15330d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1733003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher62MetricSet::CThreadDispatcher62MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher62MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE63", "ASYNC GPGPU THREADGROUP COUNT XECORE63",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010402aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b03aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d3b003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher63MetricSet::CThreadDispatcher63MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher63MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE0", "GPGPU THREADGROUP COUNT XECORE0",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE1", "GPGPU THREADGROUP COUNT XECORE1",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE2", "GPGPU THREADGROUP COUNT XECORE2",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33402aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a030d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16130039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1155f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher64MetricSet::CThreadDispatcher64MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher64MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE3", "GPGPU THREADGROUP COUNT XECORE3",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE4", "GPGPU THREADGROUP COUNT XECORE4",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE5", "GPGPU THREADGROUP COUNT XECORE5",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33402aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e230d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10230e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x142b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x162b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c102aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c257ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c22aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher65MetricSet::CThreadDispatcher65MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher65MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE6", "GPGPU THREADGROUP COUNT XECORE6",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE7", "GPGPU THREADGROUP COUNT XECORE7",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE8", "GPGPU THREADGROUP COUNT XECORE8",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33402aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5003ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f003ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f203ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a330d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c330039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c3b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15030d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c01550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c13ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c23ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher66MetricSet::CThreadDispatcher66MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher66MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE9", "GPGPU THREADGROUP COUNT XECORE9",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE10", "GPGPU THREADGROUP COUNT XECORE10",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE11", "GPGPU THREADGROUP COUNT XECORE11",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33402aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f130d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11130e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x171b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c002aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c157ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c12aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher67MetricSet::CThreadDispatcher67MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher67MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE12", "GPGPU THREADGROUP COUNT XECORE12",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE13", "GPGPU THREADGROUP COUNT XECORE13",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE14", "GPGPU THREADGROUP COUNT XECORE14",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33402aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15330d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17330039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher68MetricSet::CThreadDispatcher68MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher68MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE15", "GPGPU THREADGROUP COUNT XECORE15",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE16", "GPGPU THREADGROUP COUNT XECORE16",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE17", "GPGPU THREADGROUP COUNT XECORE17",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014056aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f412aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x285000a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a50140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c5000a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d3b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c02aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c13fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher69MetricSet::CThreadDispatcher69MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher69MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE18", "GPGPU THREADGROUP COUNT XECORE18",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE19", "GPGPU THREADGROUP COUNT XECORE19",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE20", "GPGPU THREADGROUP COUNT XECORE20",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f412aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a130d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e1b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101b0e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14230d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16230039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2155f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher70MetricSet::CThreadDispatcher70MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher70MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE21", "GPGPU THREADGROUP COUNT XECORE21",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE22", "GPGPU THREADGROUP COUNT XECORE22",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE23", "GPGPU THREADGROUP COUNT XECORE23",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f412aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c2b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c330c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e330d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x123b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x143b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x163b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c202aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher71MetricSet::CThreadDispatcher71MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher71MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE24", "GPGPU THREADGROUP COUNT XECORE24",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE25", "GPGPU THREADGROUP COUNT XECORE25",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE26", "GPGPU THREADGROUP COUNT XECORE26",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f412aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b030d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17130039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1155f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher72MetricSet::CThreadDispatcher72MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher72MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE27", "GPGPU THREADGROUP COUNT XECORE27",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE28", "GPGPU THREADGROUP COUNT XECORE28",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE29", "GPGPU THREADGROUP COUNT XECORE29",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f412aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b1b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f230d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11230e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x152b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x172b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c102aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c257ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c22aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher73MetricSet::CThreadDispatcher73MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher73MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE30", "GPGPU THREADGROUP COUNT XECORE30",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE31", "GPGPU THREADGROUP COUNT XECORE31",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE32", "GPGPU THREADGROUP COUNT XECORE32",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33403ff5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b330d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d330039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d3b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f3b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c01550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c13ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c23ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher74MetricSet::CThreadDispatcher74MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher74MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE33", "GPGPU THREADGROUP COUNT XECORE33",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE34", "GPGPU THREADGROUP COUNT XECORE34",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE35", "GPGPU THREADGROUP COUNT XECORE35",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33403fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e130d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10130e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x161b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c002aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c157ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c12aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher75MetricSet::CThreadDispatcher75MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher75MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE36", "GPGPU THREADGROUP COUNT XECORE36",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE37", "GPGPU THREADGROUP COUNT XECORE37",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE38", "GPGPU THREADGROUP COUNT XECORE38",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33403fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a230d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c2b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102b0e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14330d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16330039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher76MetricSet::CThreadDispatcher76MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher76MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE39", "GPGPU THREADGROUP COUNT XECORE39",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE40", "GPGPU THREADGROUP COUNT XECORE40",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE41", "GPGPU THREADGROUP COUNT XECORE41",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33403fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f402aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c3b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11030e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c02aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c13fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher77MetricSet::CThreadDispatcher77MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher77MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE42", "GPGPU THREADGROUP COUNT XECORE42",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE43", "GPGPU THREADGROUP COUNT XECORE43",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE44", "GPGPU THREADGROUP COUNT XECORE44",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33403fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b130d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f1b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111b0e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15230d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17230039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2155f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher78MetricSet::CThreadDispatcher78MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher78MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE45", "GPGPU THREADGROUP COUNT XECORE45",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE46", "GPGPU THREADGROUP COUNT XECORE46",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE47", "GPGPU THREADGROUP COUNT XECORE47",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33403fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d330c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f330d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11330e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x133b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x153b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x173b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c202aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher79MetricSet::CThreadDispatcher79MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher79MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE48", "GPGPU THREADGROUP COUNT XECORE48",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE49", "GPGPU THREADGROUP COUNT XECORE49",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE50", "GPGPU THREADGROUP COUNT XECORE50",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f413fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a030d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12130cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16130039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1155f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher80MetricSet::CThreadDispatcher80MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher80MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE51", "GPGPU THREADGROUP COUNT XECORE51",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE52", "GPGPU THREADGROUP COUNT XECORE52",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE53", "GPGPU THREADGROUP COUNT XECORE53",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f413fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f07fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f11555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f27fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f42aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c1b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e230d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10230e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x142b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x162b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c102aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c257ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c22aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher81MetricSet::CThreadDispatcher81MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher81MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE54", "GPGPU THREADGROUP COUNT XECORE54",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE55", "GPGPU THREADGROUP COUNT XECORE55",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE56", "GPGPU THREADGROUP COUNT XECORE56",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f413fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f5003ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f003ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f203ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a330d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c330039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c3b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e3b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07039800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15030d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c01550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c13ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c23ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher82MetricSet::CThreadDispatcher82MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher82MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE57", "GPGPU THREADGROUP COUNT XECORE57",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE58", "GPGPU THREADGROUP COUNT XECORE58",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE59", "GPGPU THREADGROUP COUNT XECORE59",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f413fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07139800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f130d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11130e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x151b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x171b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c002aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c157ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c12aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c23fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher83MetricSet::CThreadDispatcher83MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher83MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE60", "GPGPU THREADGROUP COUNT XECORE60",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE61", "GPGPU THREADGROUP COUNT XECORE61",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE62", "GPGPU THREADGROUP COUNT XECORE62",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33401555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f413fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03031555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03042aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00507fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3303ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07239800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b0c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b0d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0e75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07339800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13330cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15330d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17330039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001702, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0002e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher84MetricSet::CThreadDispatcher84MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher84MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE63", "GPGPU THREADGROUP COUNT XECORE63",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010402aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b03ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b9800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3b0d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d3b0039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher85MetricSet::CThreadDispatcher85MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher85MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE0", "THREAD DISPATCH INPUT AVAILABLE XECORE0",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE1", "THREAD DISPATCH INPUT AVAILABLE XECORE1",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE2", "THREAD DISPATCH INPUT AVAILABLE XECORE2",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE3", "THREAD DISPATCH INPUT AVAILABLE XECORE3",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE4", "THREAD DISPATCH INPUT AVAILABLE XECORE4",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE5", "THREAD DISPATCH INPUT AVAILABLE XECORE5",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE6", "THREAD DISPATCH INPUT AVAILABLE XECORE6",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE7", "THREAD DISPATCH INPUT AVAILABLE XECORE7",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE8", "THREAD DISPATCH INPUT AVAILABLE XECORE8",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE9", "THREAD DISPATCH INPUT AVAILABLE XECORE9",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE10", "THREAD DISPATCH INPUT AVAILABLE XECORE10",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE11", "THREAD DISPATCH INPUT AVAILABLE XECORE11",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE12", "THREAD DISPATCH INPUT AVAILABLE XECORE12",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE13", "THREAD DISPATCH INPUT AVAILABLE XECORE13",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE14", "THREAD DISPATCH INPUT AVAILABLE XECORE14",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE15", "THREAD DISPATCH INPUT AVAILABLE XECORE15",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher86MetricSet::CThreadDispatcher86MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher86MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE16", "THREAD DISPATCH INPUT AVAILABLE XECORE16",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE17", "THREAD DISPATCH INPUT AVAILABLE XECORE17",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE18", "THREAD DISPATCH INPUT AVAILABLE XECORE18",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE19", "THREAD DISPATCH INPUT AVAILABLE XECORE19",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE20", "THREAD DISPATCH INPUT AVAILABLE XECORE20",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE21", "THREAD DISPATCH INPUT AVAILABLE XECORE21",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE22", "THREAD DISPATCH INPUT AVAILABLE XECORE22",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE23", "THREAD DISPATCH INPUT AVAILABLE XECORE23",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE24", "THREAD DISPATCH INPUT AVAILABLE XECORE24",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE25", "THREAD DISPATCH INPUT AVAILABLE XECORE25",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE26", "THREAD DISPATCH INPUT AVAILABLE XECORE26",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE27", "THREAD DISPATCH INPUT AVAILABLE XECORE27",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE28", "THREAD DISPATCH INPUT AVAILABLE XECORE28",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE29", "THREAD DISPATCH INPUT AVAILABLE XECORE29",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE30", "THREAD DISPATCH INPUT AVAILABLE XECORE30",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE31", "THREAD DISPATCH INPUT AVAILABLE XECORE31",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher87MetricSet::CThreadDispatcher87MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher87MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE32", "THREAD DISPATCH INPUT AVAILABLE XECORE32",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE33", "THREAD DISPATCH INPUT AVAILABLE XECORE33",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE34", "THREAD DISPATCH INPUT AVAILABLE XECORE34",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE35", "THREAD DISPATCH INPUT AVAILABLE XECORE35",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE36", "THREAD DISPATCH INPUT AVAILABLE XECORE36",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE37", "THREAD DISPATCH INPUT AVAILABLE XECORE37",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE38", "THREAD DISPATCH INPUT AVAILABLE XECORE38",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE39", "THREAD DISPATCH INPUT AVAILABLE XECORE39",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE40", "THREAD DISPATCH INPUT AVAILABLE XECORE40",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE41", "THREAD DISPATCH INPUT AVAILABLE XECORE41",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE42", "THREAD DISPATCH INPUT AVAILABLE XECORE42",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE43", "THREAD DISPATCH INPUT AVAILABLE XECORE43",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE44", "THREAD DISPATCH INPUT AVAILABLE XECORE44",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE45", "THREAD DISPATCH INPUT AVAILABLE XECORE45",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE46", "THREAD DISPATCH INPUT AVAILABLE XECORE46",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE47", "THREAD DISPATCH INPUT AVAILABLE XECORE47",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher88MetricSet::CThreadDispatcher88MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher88MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE48", "THREAD DISPATCH INPUT AVAILABLE XECORE48",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE49", "THREAD DISPATCH INPUT AVAILABLE XECORE49",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE50", "THREAD DISPATCH INPUT AVAILABLE XECORE50",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE51", "THREAD DISPATCH INPUT AVAILABLE XECORE51",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE52", "THREAD DISPATCH INPUT AVAILABLE XECORE52",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE53", "THREAD DISPATCH INPUT AVAILABLE XECORE53",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE54", "THREAD DISPATCH INPUT AVAILABLE XECORE54",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE55", "THREAD DISPATCH INPUT AVAILABLE XECORE55",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE56", "THREAD DISPATCH INPUT AVAILABLE XECORE56",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE57", "THREAD DISPATCH INPUT AVAILABLE XECORE57",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE58", "THREAD DISPATCH INPUT AVAILABLE XECORE58",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE59", "THREAD DISPATCH INPUT AVAILABLE XECORE59",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE60", "THREAD DISPATCH INPUT AVAILABLE XECORE60",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE61", "THREAD DISPATCH INPUT AVAILABLE XECORE61",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE62", "THREAD DISPATCH INPUT AVAILABLE XECORE62",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE63", "THREAD DISPATCH INPUT AVAILABLE XECORE63",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher89MetricSet::CThreadDispatcher89MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher89MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE0", "THREAD DISPATCH STALL XECORE0",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE1", "THREAD DISPATCH STALL XECORE1",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE2", "THREAD DISPATCH STALL XECORE2",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE3", "THREAD DISPATCH STALL XECORE3",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE4", "THREAD DISPATCH STALL XECORE4",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE5", "THREAD DISPATCH STALL XECORE5",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE6", "THREAD DISPATCH STALL XECORE6",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE7", "THREAD DISPATCH STALL XECORE7",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE8", "THREAD DISPATCH STALL XECORE8",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE9", "THREAD DISPATCH STALL XECORE9",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE10", "THREAD DISPATCH STALL XECORE10",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE11", "THREAD DISPATCH STALL XECORE11",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE12", "THREAD DISPATCH STALL XECORE12",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE13", "THREAD DISPATCH STALL XECORE13",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE14", "THREAD DISPATCH STALL XECORE14",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE15", "THREAD DISPATCH STALL XECORE15",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher90MetricSet::CThreadDispatcher90MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher90MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE16", "THREAD DISPATCH STALL XECORE16",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE17", "THREAD DISPATCH STALL XECORE17",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE18", "THREAD DISPATCH STALL XECORE18",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE19", "THREAD DISPATCH STALL XECORE19",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE20", "THREAD DISPATCH STALL XECORE20",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE21", "THREAD DISPATCH STALL XECORE21",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE22", "THREAD DISPATCH STALL XECORE22",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE23", "THREAD DISPATCH STALL XECORE23",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE24", "THREAD DISPATCH STALL XECORE24",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE25", "THREAD DISPATCH STALL XECORE25",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE26", "THREAD DISPATCH STALL XECORE26",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE27", "THREAD DISPATCH STALL XECORE27",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE28", "THREAD DISPATCH STALL XECORE28",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE29", "THREAD DISPATCH STALL XECORE29",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE30", "THREAD DISPATCH STALL XECORE30",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE31", "THREAD DISPATCH STALL XECORE31",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher91MetricSet::CThreadDispatcher91MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher91MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE32", "THREAD DISPATCH STALL XECORE32",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE33", "THREAD DISPATCH STALL XECORE33",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE34", "THREAD DISPATCH STALL XECORE34",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE35", "THREAD DISPATCH STALL XECORE35",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE36", "THREAD DISPATCH STALL XECORE36",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE37", "THREAD DISPATCH STALL XECORE37",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE38", "THREAD DISPATCH STALL XECORE38",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE39", "THREAD DISPATCH STALL XECORE39",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE40", "THREAD DISPATCH STALL XECORE40",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE41", "THREAD DISPATCH STALL XECORE41",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE42", "THREAD DISPATCH STALL XECORE42",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE43", "THREAD DISPATCH STALL XECORE43",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE44", "THREAD DISPATCH STALL XECORE44",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE45", "THREAD DISPATCH STALL XECORE45",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE46", "THREAD DISPATCH STALL XECORE46",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE47", "THREAD DISPATCH STALL XECORE47",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher92MetricSet::CThreadDispatcher92MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher92MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE48", "THREAD DISPATCH STALL XECORE48",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE49", "THREAD DISPATCH STALL XECORE49",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE50", "THREAD DISPATCH STALL XECORE50",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE51", "THREAD DISPATCH STALL XECORE51",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE52", "THREAD DISPATCH STALL XECORE52",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE53", "THREAD DISPATCH STALL XECORE53",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE54", "THREAD DISPATCH STALL XECORE54",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE55", "THREAD DISPATCH STALL XECORE55",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE56", "THREAD DISPATCH STALL XECORE56",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE57", "THREAD DISPATCH STALL XECORE57",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE58", "THREAD DISPATCH STALL XECORE58",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE59", "THREAD DISPATCH STALL XECORE59",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE60", "THREAD DISPATCH STALL XECORE60",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE61", "THREAD DISPATCH STALL XECORE61",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE62", "THREAD DISPATCH STALL XECORE62",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE63", "THREAD DISPATCH STALL XECORE63",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher93MetricSet::CThreadDispatcher93MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher93MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE0", "THREAD DISPATCH QUEUE0 ACTIVE XECORE0",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE1", "THREAD DISPATCH QUEUE0 ACTIVE XECORE1",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE2", "THREAD DISPATCH QUEUE0 ACTIVE XECORE2",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE3", "THREAD DISPATCH QUEUE0 ACTIVE XECORE3",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE4", "THREAD DISPATCH QUEUE0 ACTIVE XECORE4",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE5", "THREAD DISPATCH QUEUE0 ACTIVE XECORE5",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE6", "THREAD DISPATCH QUEUE0 ACTIVE XECORE6",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE7", "THREAD DISPATCH QUEUE0 ACTIVE XECORE7",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE8", "THREAD DISPATCH QUEUE0 ACTIVE XECORE8",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE9", "THREAD DISPATCH QUEUE0 ACTIVE XECORE9",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE10", "THREAD DISPATCH QUEUE0 ACTIVE XECORE10",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE11", "THREAD DISPATCH QUEUE0 ACTIVE XECORE11",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE12", "THREAD DISPATCH QUEUE0 ACTIVE XECORE12",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE13", "THREAD DISPATCH QUEUE0 ACTIVE XECORE13",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE14", "THREAD DISPATCH QUEUE0 ACTIVE XECORE14",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE15", "THREAD DISPATCH QUEUE0 ACTIVE XECORE15",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher94MetricSet::CThreadDispatcher94MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher94MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE16", "THREAD DISPATCH QUEUE0 ACTIVE XECORE16",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE17", "THREAD DISPATCH QUEUE0 ACTIVE XECORE17",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE18", "THREAD DISPATCH QUEUE0 ACTIVE XECORE18",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE19", "THREAD DISPATCH QUEUE0 ACTIVE XECORE19",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE20", "THREAD DISPATCH QUEUE0 ACTIVE XECORE20",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE21", "THREAD DISPATCH QUEUE0 ACTIVE XECORE21",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE22", "THREAD DISPATCH QUEUE0 ACTIVE XECORE22",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE23", "THREAD DISPATCH QUEUE0 ACTIVE XECORE23",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE24", "THREAD DISPATCH QUEUE0 ACTIVE XECORE24",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE25", "THREAD DISPATCH QUEUE0 ACTIVE XECORE25",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE26", "THREAD DISPATCH QUEUE0 ACTIVE XECORE26",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE27", "THREAD DISPATCH QUEUE0 ACTIVE XECORE27",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE28", "THREAD DISPATCH QUEUE0 ACTIVE XECORE28",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE29", "THREAD DISPATCH QUEUE0 ACTIVE XECORE29",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE30", "THREAD DISPATCH QUEUE0 ACTIVE XECORE30",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE31", "THREAD DISPATCH QUEUE0 ACTIVE XECORE31",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher95MetricSet::CThreadDispatcher95MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher95MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE32", "THREAD DISPATCH QUEUE0 ACTIVE XECORE32",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE33", "THREAD DISPATCH QUEUE0 ACTIVE XECORE33",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE34", "THREAD DISPATCH QUEUE0 ACTIVE XECORE34",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE35", "THREAD DISPATCH QUEUE0 ACTIVE XECORE35",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE36", "THREAD DISPATCH QUEUE0 ACTIVE XECORE36",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE37", "THREAD DISPATCH QUEUE0 ACTIVE XECORE37",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE38", "THREAD DISPATCH QUEUE0 ACTIVE XECORE38",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE39", "THREAD DISPATCH QUEUE0 ACTIVE XECORE39",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE40", "THREAD DISPATCH QUEUE0 ACTIVE XECORE40",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE41", "THREAD DISPATCH QUEUE0 ACTIVE XECORE41",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE42", "THREAD DISPATCH QUEUE0 ACTIVE XECORE42",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE43", "THREAD DISPATCH QUEUE0 ACTIVE XECORE43",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE44", "THREAD DISPATCH QUEUE0 ACTIVE XECORE44",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE45", "THREAD DISPATCH QUEUE0 ACTIVE XECORE45",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE46", "THREAD DISPATCH QUEUE0 ACTIVE XECORE46",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE47", "THREAD DISPATCH QUEUE0 ACTIVE XECORE47",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher96MetricSet::CThreadDispatcher96MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher96MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE48", "THREAD DISPATCH QUEUE0 ACTIVE XECORE48",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE49", "THREAD DISPATCH QUEUE0 ACTIVE XECORE49",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE50", "THREAD DISPATCH QUEUE0 ACTIVE XECORE50",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE51", "THREAD DISPATCH QUEUE0 ACTIVE XECORE51",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE52", "THREAD DISPATCH QUEUE0 ACTIVE XECORE52",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE53", "THREAD DISPATCH QUEUE0 ACTIVE XECORE53",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE54", "THREAD DISPATCH QUEUE0 ACTIVE XECORE54",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE55", "THREAD DISPATCH QUEUE0 ACTIVE XECORE55",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE56", "THREAD DISPATCH QUEUE0 ACTIVE XECORE56",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE57", "THREAD DISPATCH QUEUE0 ACTIVE XECORE57",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE58", "THREAD DISPATCH QUEUE0 ACTIVE XECORE58",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE59", "THREAD DISPATCH QUEUE0 ACTIVE XECORE59",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE60", "THREAD DISPATCH QUEUE0 ACTIVE XECORE60",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE61", "THREAD DISPATCH QUEUE0 ACTIVE XECORE61",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE62", "THREAD DISPATCH QUEUE0 ACTIVE XECORE62",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE63", "THREAD DISPATCH QUEUE0 ACTIVE XECORE63",
                          "Percentage of time in which GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher97MetricSet::CThreadDispatcher97MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher97MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE0", "THREAD DISPATCH QUEUE1 ACTIVE XECORE0",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE1", "THREAD DISPATCH QUEUE1 ACTIVE XECORE1",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE2", "THREAD DISPATCH QUEUE1 ACTIVE XECORE2",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE3", "THREAD DISPATCH QUEUE1 ACTIVE XECORE3",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE4", "THREAD DISPATCH QUEUE1 ACTIVE XECORE4",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE5", "THREAD DISPATCH QUEUE1 ACTIVE XECORE5",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE6", "THREAD DISPATCH QUEUE1 ACTIVE XECORE6",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE7", "THREAD DISPATCH QUEUE1 ACTIVE XECORE7",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE8", "THREAD DISPATCH QUEUE1 ACTIVE XECORE8",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE9", "THREAD DISPATCH QUEUE1 ACTIVE XECORE9",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE10", "THREAD DISPATCH QUEUE1 ACTIVE XECORE10",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE11", "THREAD DISPATCH QUEUE1 ACTIVE XECORE11",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE12", "THREAD DISPATCH QUEUE1 ACTIVE XECORE12",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE13", "THREAD DISPATCH QUEUE1 ACTIVE XECORE13",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE14", "THREAD DISPATCH QUEUE1 ACTIVE XECORE14",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE15", "THREAD DISPATCH QUEUE1 ACTIVE XECORE15",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher98MetricSet::CThreadDispatcher98MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher98MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE16", "THREAD DISPATCH QUEUE1 ACTIVE XECORE16",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE17", "THREAD DISPATCH QUEUE1 ACTIVE XECORE17",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE18", "THREAD DISPATCH QUEUE1 ACTIVE XECORE18",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE19", "THREAD DISPATCH QUEUE1 ACTIVE XECORE19",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE20", "THREAD DISPATCH QUEUE1 ACTIVE XECORE20",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE21", "THREAD DISPATCH QUEUE1 ACTIVE XECORE21",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE22", "THREAD DISPATCH QUEUE1 ACTIVE XECORE22",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE23", "THREAD DISPATCH QUEUE1 ACTIVE XECORE23",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE24", "THREAD DISPATCH QUEUE1 ACTIVE XECORE24",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE25", "THREAD DISPATCH QUEUE1 ACTIVE XECORE25",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE26", "THREAD DISPATCH QUEUE1 ACTIVE XECORE26",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE27", "THREAD DISPATCH QUEUE1 ACTIVE XECORE27",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE28", "THREAD DISPATCH QUEUE1 ACTIVE XECORE28",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE29", "THREAD DISPATCH QUEUE1 ACTIVE XECORE29",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE30", "THREAD DISPATCH QUEUE1 ACTIVE XECORE30",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE31", "THREAD DISPATCH QUEUE1 ACTIVE XECORE31",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher99MetricSet::CThreadDispatcher99MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher99MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE32", "THREAD DISPATCH QUEUE1 ACTIVE XECORE32",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE33", "THREAD DISPATCH QUEUE1 ACTIVE XECORE33",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE34", "THREAD DISPATCH QUEUE1 ACTIVE XECORE34",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE35", "THREAD DISPATCH QUEUE1 ACTIVE XECORE35",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE36", "THREAD DISPATCH QUEUE1 ACTIVE XECORE36",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE37", "THREAD DISPATCH QUEUE1 ACTIVE XECORE37",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE38", "THREAD DISPATCH QUEUE1 ACTIVE XECORE38",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE39", "THREAD DISPATCH QUEUE1 ACTIVE XECORE39",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE40", "THREAD DISPATCH QUEUE1 ACTIVE XECORE40",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE41", "THREAD DISPATCH QUEUE1 ACTIVE XECORE41",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE42", "THREAD DISPATCH QUEUE1 ACTIVE XECORE42",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE43", "THREAD DISPATCH QUEUE1 ACTIVE XECORE43",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE44", "THREAD DISPATCH QUEUE1 ACTIVE XECORE44",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE45", "THREAD DISPATCH QUEUE1 ACTIVE XECORE45",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE46", "THREAD DISPATCH QUEUE1 ACTIVE XECORE46",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE47", "THREAD DISPATCH QUEUE1 ACTIVE XECORE47",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher100MetricSet::CThreadDispatcher100MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher100MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE48", "THREAD DISPATCH QUEUE1 ACTIVE XECORE48",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE49", "THREAD DISPATCH QUEUE1 ACTIVE XECORE49",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE50", "THREAD DISPATCH QUEUE1 ACTIVE XECORE50",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE51", "THREAD DISPATCH QUEUE1 ACTIVE XECORE51",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE52", "THREAD DISPATCH QUEUE1 ACTIVE XECORE52",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE53", "THREAD DISPATCH QUEUE1 ACTIVE XECORE53",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE54", "THREAD DISPATCH QUEUE1 ACTIVE XECORE54",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE55", "THREAD DISPATCH QUEUE1 ACTIVE XECORE55",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE56", "THREAD DISPATCH QUEUE1 ACTIVE XECORE56",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE57", "THREAD DISPATCH QUEUE1 ACTIVE XECORE57",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE58", "THREAD DISPATCH QUEUE1 ACTIVE XECORE58",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE59", "THREAD DISPATCH QUEUE1 ACTIVE XECORE59",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE60", "THREAD DISPATCH QUEUE1 ACTIVE XECORE60",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE61", "THREAD DISPATCH QUEUE1 ACTIVE XECORE61",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE62", "THREAD DISPATCH QUEUE1 ACTIVE XECORE62",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE63", "THREAD DISPATCH QUEUE1 ACTIVE XECORE63",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093308c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher101MetricSet::CThreadDispatcher101MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher101MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE0", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE0",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE1", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE1",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE2", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE2",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE3", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE3",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE4", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE4",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE5", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE5",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE6", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE6",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE7", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE7",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE8", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE8",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE9", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE9",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE10", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE10",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE11", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE11",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE12", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE12",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE13", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE13",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE14", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE14",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE15", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE15",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher102MetricSet::CThreadDispatcher102MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher102MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE16", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE16",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE17", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE17",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE18", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE18",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE19", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE19",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE20", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE20",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE21", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE21",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE22", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE22",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE23", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE23",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE24", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE24",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE25", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE25",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE26", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE26",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE27", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE27",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE28", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE28",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE29", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE29",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE30", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE30",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE31", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE31",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher103MetricSet::CThreadDispatcher103MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher103MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE32", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE32",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE33", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE33",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE34", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE34",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE35", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE35",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE36", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE36",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE37", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE37",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE38", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE38",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE39", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE39",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE40", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE40",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE41", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE41",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE42", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE42",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE43", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE43",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE44", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE44",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE45", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE45",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE46", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE46",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE47", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE47",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher104MetricSet::CThreadDispatcher104MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher104MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE48", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE48",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE49", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE49",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE50", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE50",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE51", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE51",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE52", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE52",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE53", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE53",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE54", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE54",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE55", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE55",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE56", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE56",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE57", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE57",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE58", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE58",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE59", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE59",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE60", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE60",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE61", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE61",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE62", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE62",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE63", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE63",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher105MetricSet::CThreadDispatcher105MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher105MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE0", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE0",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE1", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE1",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE2", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE2",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE3", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE3",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE4", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE4",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE5", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE5",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE6", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE6",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE7", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE7",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE8", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE8",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE9", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE9",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE10", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE10",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE11", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE11",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE12", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE12",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE13", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE13",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE14", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE14",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE15", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE15",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher106MetricSet::CThreadDispatcher106MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher106MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE16", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE16",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE17", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE17",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE18", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE18",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE19", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE19",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE20", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE20",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE21", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE21",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE22", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE22",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE23", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE23",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE24", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE24",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE25", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE25",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE26", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE26",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE27", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE27",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE28", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE28",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE29", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE29",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE30", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE30",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE31", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE31",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher107MetricSet::CThreadDispatcher107MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher107MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE32", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE32",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE33", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE33",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE34", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE34",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE35", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE35",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE36", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE36",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE37", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE37",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE38", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE38",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE39", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE39",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE40", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE40",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE41", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE41",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE42", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE42",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE43", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE43",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE44", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE44",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE45", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE45",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE46", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE46",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE47", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE47",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher108MetricSet::CThreadDispatcher108MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher108MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE48", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE48",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE49", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE49",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE50", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE50",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE51", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE51",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE52", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE52",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE53", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE53",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE54", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE54",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE55", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE55",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE56", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE56",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE57", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE57",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE58", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE58",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE59", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE59",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE60", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE60",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE61", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE61",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE62", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE62",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE63", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE63",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e03001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e0b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e13001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e1b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e23001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e2b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e33001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e3b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f03001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f0b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f13001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f1b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f23001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f2b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f33001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f3b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher109MetricSet::CThreadDispatcher109MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher109MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE0", "GPGPU DISPATCH XECORE0",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE1", "GPGPU DISPATCH XECORE1",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE2", "GPGPU DISPATCH XECORE2",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE3", "GPGPU DISPATCH XECORE3",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE4", "GPGPU DISPATCH XECORE4",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE5", "GPGPU DISPATCH XECORE5",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE6", "GPGPU DISPATCH XECORE6",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE7", "GPGPU DISPATCH XECORE7",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE8", "GPGPU DISPATCH XECORE8",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE9", "GPGPU DISPATCH XECORE9",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE10", "GPGPU DISPATCH XECORE10",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE11", "GPGPU DISPATCH XECORE11",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE12", "GPGPU DISPATCH XECORE12",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE13", "GPGPU DISPATCH XECORE13",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE14", "GPGPU DISPATCH XECORE14",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE15", "GPGPU DISPATCH XECORE15",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher110MetricSet::CThreadDispatcher110MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher110MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE16", "GPGPU DISPATCH XECORE16",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE17", "GPGPU DISPATCH XECORE17",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE18", "GPGPU DISPATCH XECORE18",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE19", "GPGPU DISPATCH XECORE19",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE20", "GPGPU DISPATCH XECORE20",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE21", "GPGPU DISPATCH XECORE21",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE22", "GPGPU DISPATCH XECORE22",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE23", "GPGPU DISPATCH XECORE23",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE24", "GPGPU DISPATCH XECORE24",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE25", "GPGPU DISPATCH XECORE25",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE26", "GPGPU DISPATCH XECORE26",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE27", "GPGPU DISPATCH XECORE27",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE28", "GPGPU DISPATCH XECORE28",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE29", "GPGPU DISPATCH XECORE29",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE30", "GPGPU DISPATCH XECORE30",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE31", "GPGPU DISPATCH XECORE31",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher111MetricSet::CThreadDispatcher111MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher111MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE32", "GPGPU DISPATCH XECORE32",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE33", "GPGPU DISPATCH XECORE33",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE34", "GPGPU DISPATCH XECORE34",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE35", "GPGPU DISPATCH XECORE35",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE36", "GPGPU DISPATCH XECORE36",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE37", "GPGPU DISPATCH XECORE37",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE38", "GPGPU DISPATCH XECORE38",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE39", "GPGPU DISPATCH XECORE39",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE40", "GPGPU DISPATCH XECORE40",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE41", "GPGPU DISPATCH XECORE41",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE42", "GPGPU DISPATCH XECORE42",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE43", "GPGPU DISPATCH XECORE43",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE44", "GPGPU DISPATCH XECORE44",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE45", "GPGPU DISPATCH XECORE45",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE46", "GPGPU DISPATCH XECORE46",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE47", "GPGPU DISPATCH XECORE47",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CThreadDispatcher112MetricSet::CThreadDispatcher112MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CThreadDispatcher112MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE48", "GPGPU DISPATCH XECORE48",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE49", "GPGPU DISPATCH XECORE49",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE50", "GPGPU DISPATCH XECORE50",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE51", "GPGPU DISPATCH XECORE51",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE52", "GPGPU DISPATCH XECORE52",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE53", "GPGPU DISPATCH XECORE53",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE54", "GPGPU DISPATCH XECORE54",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE55", "GPGPU DISPATCH XECORE55",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE56", "GPGPU DISPATCH XECORE56",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE57", "GPGPU DISPATCH XECORE57",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE58", "GPGPU DISPATCH XECORE58",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE59", "GPGPU DISPATCH XECORE59",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE60", "GPGPU DISPATCH XECORE60",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE61", "GPGPU DISPATCH XECORE61",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE62", "GPGPU DISPATCH XECORE62",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE63", "GPGPU DISPATCH XECORE63",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x262b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x263b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x061b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x141b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12230980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x062b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10330980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x063b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x271b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x272b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x27330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x273b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07130006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x071b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d1b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07230006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b230980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07330006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330980, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x073b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0026, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine1MetricSet::CVectorEngine1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ICACHE_HIT_XECORE0", "ICACHE HIT _XECORE0",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ICACHE_HIT_XECORE1", "ICACHE HIT _XECORE1",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ICACHE_MISS_XECORE0", "ICACHE MISS XECORE0",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ICACHE_MISS_XECORE1", "ICACHE MISS XECORE1",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16012ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20036800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2203000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16092cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e01000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04037600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a09000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1209000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine2MetricSet::CVectorEngine2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ICACHE_HIT_XECORE2", "ICACHE HIT _XECORE2",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ICACHE_HIT_XECORE3", "ICACHE HIT _XECORE3",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ICACHE_MISS_XECORE2", "ICACHE MISS XECORE2",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ICACHE_MISS_XECORE3", "ICACHE MISS XECORE3",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16112ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20136800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2213000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16192cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x201b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x221b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c110006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e11000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04137600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1613001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08190006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a19000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1219000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine3MetricSet::CVectorEngine3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "ICACHE_HIT_XECORE4", "ICACHE HIT _XECORE4",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "ICACHE_HIT_XECORE5", "ICACHE HIT _XECORE5",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "ICACHE_MISS_XECORE4", "ICACHE MISS XECORE4",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "ICACHE_MISS_XECORE5", "ICACHE MISS XECORE5",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16212ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20236800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2223000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16292cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x202b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x222b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e21000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04237600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14230015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1623001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08290006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a29000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1229000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine4MetricSet::CVectorEngine4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "ICACHE_HIT_XECORE6", "ICACHE HIT _XECORE6",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "ICACHE_HIT_XECORE7", "ICACHE HIT _XECORE7",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "ICACHE_MISS_XECORE6", "ICACHE MISS XECORE6",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "ICACHE_MISS_XECORE7", "ICACHE MISS XECORE7",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16312ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20336800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16392cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x203b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x223b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c310006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e31000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04337600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c330016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14330015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1633001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08390006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a39000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1239000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x123b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine5MetricSet::CVectorEngine5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ICACHE_HIT_XECORE8", "ICACHE HIT _XECORE8",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ICACHE_HIT_XECORE9", "ICACHE HIT _XECORE9",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ICACHE_MISS_XECORE8", "ICACHE MISS XECORE8",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ICACHE_MISS_XECORE9", "ICACHE MISS XECORE9",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17012ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21036800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2303000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17092cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f01000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05037600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15030015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1703001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b09000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1309000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine6MetricSet::CVectorEngine6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ICACHE_HIT_XECORE10", "ICACHE HIT _XECORE10",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ICACHE_HIT_XECORE11", "ICACHE HIT _XECORE11",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ICACHE_MISS_XECORE10", "ICACHE MISS XECORE10",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ICACHE_MISS_XECORE11", "ICACHE MISS XECORE11",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17112ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21136800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2313000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17192cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x211b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x231b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f11000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05137600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1713001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09190006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b19000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1319000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine7MetricSet::CVectorEngine7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "ICACHE_HIT_XECORE12", "ICACHE HIT _XECORE12",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "ICACHE_HIT_XECORE13", "ICACHE HIT _XECORE13",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "ICACHE_MISS_XECORE12", "ICACHE MISS XECORE12",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "ICACHE_MISS_XECORE13", "ICACHE MISS XECORE13",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17212ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21236800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2323000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17292cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x212b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x232b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d210006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f21000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05237600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15230015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1723001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b29000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1329000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine8MetricSet::CVectorEngine8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "ICACHE_HIT_XECORE14", "ICACHE HIT _XECORE14",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "ICACHE_HIT_XECORE15", "ICACHE HIT _XECORE15",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "ICACHE_MISS_XECORE14", "ICACHE MISS XECORE14",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "ICACHE_MISS_XECORE15", "ICACHE MISS XECORE15",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17312ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21336800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2333000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17392cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x213b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x233b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d310006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f31000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05337600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d330016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15330015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1733001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09390006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b39000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1339000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x133b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine9MetricSet::CVectorEngine9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_HIT_XECORE16", "ICACHE HIT _XECORE16",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_HIT_XECORE17", "ICACHE HIT _XECORE17",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_MISS_XECORE16", "ICACHE MISS XECORE16",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_MISS_XECORE17", "ICACHE MISS XECORE17",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16012ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20036800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2203000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16092cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e01000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04037600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a09000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1209000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine10MetricSet::CVectorEngine10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_HIT_XECORE18", "ICACHE HIT _XECORE18",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_HIT_XECORE19", "ICACHE HIT _XECORE19",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_MISS_XECORE18", "ICACHE MISS XECORE18",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_MISS_XECORE19", "ICACHE MISS XECORE19",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16112ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20136800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2213000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16192cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x201b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x221b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c110006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e11000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04137600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1613001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08190006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a19000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1219000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine11MetricSet::CVectorEngine11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "ICACHE_HIT_XECORE20", "ICACHE HIT _XECORE20",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "ICACHE_HIT_XECORE21", "ICACHE HIT _XECORE21",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "ICACHE_MISS_XECORE20", "ICACHE MISS XECORE20",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "ICACHE_MISS_XECORE21", "ICACHE MISS XECORE21",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16212ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20236800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2223000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16292cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x202b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x222b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e21000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04237600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14230015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1623001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08290006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a29000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1229000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine12MetricSet::CVectorEngine12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "ICACHE_HIT_XECORE22", "ICACHE HIT _XECORE22",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "ICACHE_HIT_XECORE23", "ICACHE HIT _XECORE23",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "ICACHE_MISS_XECORE22", "ICACHE MISS XECORE22",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "ICACHE_MISS_XECORE23", "ICACHE MISS XECORE23",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16312ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20336800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16392cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x203b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x223b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c310006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e31000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04337600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c330016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14330015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1633001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08390006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a39000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1239000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x123b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine13MetricSet::CVectorEngine13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_HIT_XECORE24", "ICACHE HIT _XECORE24",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_HIT_XECORE25", "ICACHE HIT _XECORE25",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_MISS_XECORE24", "ICACHE MISS XECORE24",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_MISS_XECORE25", "ICACHE MISS XECORE25",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17012ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21036800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2303000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17092cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f01000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05037600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15030015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1703001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b09000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1309000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine14MetricSet::CVectorEngine14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_HIT_XECORE26", "ICACHE HIT _XECORE26",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_HIT_XECORE27", "ICACHE HIT _XECORE27",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_MISS_XECORE26", "ICACHE MISS XECORE26",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_MISS_XECORE27", "ICACHE MISS XECORE27",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17112ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21136800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2313000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17192cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x211b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x231b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f11000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05137600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1713001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09190006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b19000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1319000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine15MetricSet::CVectorEngine15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "ICACHE_HIT_XECORE28", "ICACHE HIT _XECORE28",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "ICACHE_HIT_XECORE29", "ICACHE HIT _XECORE29",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "ICACHE_MISS_XECORE28", "ICACHE MISS XECORE28",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "ICACHE_MISS_XECORE29", "ICACHE MISS XECORE29",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17212ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21236800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2323000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17292cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x212b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x232b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d210006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f21000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05237600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15230015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1723001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b29000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1329000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine16MetricSet::CVectorEngine16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "ICACHE_HIT_XECORE30", "ICACHE HIT _XECORE30",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "ICACHE_HIT_XECORE31", "ICACHE HIT _XECORE31",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "ICACHE_MISS_XECORE30", "ICACHE MISS XECORE30",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "ICACHE_MISS_XECORE31", "ICACHE MISS XECORE31",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17312ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21336800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2333000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17392cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x213b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x233b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d310006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f31000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05337600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d330016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15330015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1733001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09390006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b39000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1339000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x133b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine17MetricSet::CVectorEngine17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_HIT_XECORE32", "ICACHE HIT _XECORE32",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_HIT_XECORE33", "ICACHE HIT _XECORE33",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_MISS_XECORE32", "ICACHE MISS XECORE32",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_MISS_XECORE33", "ICACHE MISS XECORE33",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16012ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20036800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2203000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16092cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e01000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04037600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a09000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1209000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine18MetricSet::CVectorEngine18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_HIT_XECORE34", "ICACHE HIT _XECORE34",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_HIT_XECORE35", "ICACHE HIT _XECORE35",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_MISS_XECORE34", "ICACHE MISS XECORE34",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_MISS_XECORE35", "ICACHE MISS XECORE35",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16112ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20136800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2213000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16192cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x201b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x221b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c110006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e11000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04137600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1613001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08190006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a19000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1219000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine19MetricSet::CVectorEngine19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "ICACHE_HIT_XECORE36", "ICACHE HIT _XECORE36",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "ICACHE_HIT_XECORE37", "ICACHE HIT _XECORE37",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "ICACHE_MISS_XECORE36", "ICACHE MISS XECORE36",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "ICACHE_MISS_XECORE37", "ICACHE MISS XECORE37",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16212ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20236800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2223000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16292cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x202b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x222b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e21000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04237600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14230015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1623001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08290006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a29000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1229000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine20MetricSet::CVectorEngine20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "ICACHE_HIT_XECORE38", "ICACHE HIT _XECORE38",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "ICACHE_HIT_XECORE39", "ICACHE HIT _XECORE39",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "ICACHE_MISS_XECORE38", "ICACHE MISS XECORE38",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "ICACHE_MISS_XECORE39", "ICACHE MISS XECORE39",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16312ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20336800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16392cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x203b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x223b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c310006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e31000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04337600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c330016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14330015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1633001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08390006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a39000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1239000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x123b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine21MetricSet::CVectorEngine21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_HIT_XECORE40", "ICACHE HIT _XECORE40",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_HIT_XECORE41", "ICACHE HIT _XECORE41",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_MISS_XECORE40", "ICACHE MISS XECORE40",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_MISS_XECORE41", "ICACHE MISS XECORE41",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17012ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21036800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2303000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17092cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f01000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05037600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15030015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1703001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b09000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1309000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine22MetricSet::CVectorEngine22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_HIT_XECORE42", "ICACHE HIT _XECORE42",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_HIT_XECORE43", "ICACHE HIT _XECORE43",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_MISS_XECORE42", "ICACHE MISS XECORE42",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_MISS_XECORE43", "ICACHE MISS XECORE43",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17112ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21136800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2313000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17192cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x211b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x231b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f11000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05137600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1713001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09190006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b19000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1319000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine23MetricSet::CVectorEngine23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "ICACHE_HIT_XECORE44", "ICACHE HIT _XECORE44",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "ICACHE_HIT_XECORE45", "ICACHE HIT _XECORE45",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "ICACHE_MISS_XECORE44", "ICACHE MISS XECORE44",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "ICACHE_MISS_XECORE45", "ICACHE MISS XECORE45",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17212ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21236800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2323000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17292cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x212b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x232b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d210006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f21000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05237600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15230015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1723001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b29000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1329000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine24MetricSet::CVectorEngine24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "ICACHE_HIT_XECORE46", "ICACHE HIT _XECORE46",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "ICACHE_HIT_XECORE47", "ICACHE HIT _XECORE47",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "ICACHE_MISS_XECORE46", "ICACHE MISS XECORE46",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "ICACHE_MISS_XECORE47", "ICACHE MISS XECORE47",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17312ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21336800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2333000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17392cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x213b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x233b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d310006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f31000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05337600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d330016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15330015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1733001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09390006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b39000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1339000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x133b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine25MetricSet::CVectorEngine25MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine25MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ICACHE_HIT_XECORE48", "ICACHE HIT _XECORE48",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ICACHE_HIT_XECORE49", "ICACHE HIT _XECORE49",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ICACHE_MISS_XECORE48", "ICACHE MISS XECORE48",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ICACHE_MISS_XECORE49", "ICACHE MISS XECORE49",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16012ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20036800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2203000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16092cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e01000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04037600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a09000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1209000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine26MetricSet::CVectorEngine26MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine26MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ICACHE_HIT_XECORE50", "ICACHE HIT _XECORE50",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ICACHE_HIT_XECORE51", "ICACHE HIT _XECORE51",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ICACHE_MISS_XECORE50", "ICACHE MISS XECORE50",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ICACHE_MISS_XECORE51", "ICACHE MISS XECORE51",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16112ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20136800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2213000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16192cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x201b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x221b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04110008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c110006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e11000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04137600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c130016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14130015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1613001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04190008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08190006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a19000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1219000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x041b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x081b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x121b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine27MetricSet::CVectorEngine27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "ICACHE_HIT_XECORE52", "ICACHE HIT _XECORE52",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "ICACHE_HIT_XECORE53", "ICACHE HIT _XECORE53",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "ICACHE_MISS_XECORE52", "ICACHE MISS XECORE52",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "ICACHE_MISS_XECORE53", "ICACHE MISS XECORE53",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16212ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20236800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2223000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16292cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x202b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x222b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04210008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e21000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04237600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c230016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14230015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1623001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04290008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08290006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a29000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1229000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x042b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x082b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x102b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x122b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine28MetricSet::CVectorEngine28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "ICACHE_HIT_XECORE54", "ICACHE HIT _XECORE54",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "ICACHE_HIT_XECORE55", "ICACHE HIT _XECORE55",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "ICACHE_MISS_XECORE54", "ICACHE MISS XECORE54",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "ICACHE_MISS_XECORE55", "ICACHE MISS XECORE55",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16312ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20336800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16392cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x203b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x223b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04310008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c310006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e31000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04337600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c330016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14330015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1633001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04390008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08390006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a39000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1239000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x043b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x083b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x103b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x123b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine29MetricSet::CVectorEngine29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ICACHE_HIT_XECORE56", "ICACHE HIT _XECORE56",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ICACHE_HIT_XECORE57", "ICACHE HIT _XECORE57",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ICACHE_MISS_XECORE56", "ICACHE MISS XECORE56",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ICACHE_MISS_XECORE57", "ICACHE MISS XECORE57",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17012ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21036800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2303000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17092cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f01000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05037600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f03001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15030015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1703001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b09000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1309000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c055aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine30MetricSet::CVectorEngine30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ICACHE_HIT_XECORE58", "ICACHE HIT _XECORE58",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ICACHE_HIT_XECORE59", "ICACHE HIT _XECORE59",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ICACHE_MISS_XECORE58", "ICACHE MISS XECORE58",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ICACHE_MISS_XECORE59", "ICACHE MISS XECORE59",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17112ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21136800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2313000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17192cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x211b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x231b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05110008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d110006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f11000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15110005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03110000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05137600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d130016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f13001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15130015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1713001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05190008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09190006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b19000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11190005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1319000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03190000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x051b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x091b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b1b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x111b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x131b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c155aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine31MetricSet::CVectorEngine31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "ICACHE_HIT_XECORE60", "ICACHE HIT _XECORE60",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "ICACHE_HIT_XECORE61", "ICACHE HIT _XECORE61",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "ICACHE_MISS_XECORE60", "ICACHE MISS XECORE60",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "ICACHE_MISS_XECORE61", "ICACHE MISS XECORE61",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17212ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21236800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2323000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17292cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x212b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x232b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05210008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d210006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f21000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15210005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05237600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d230016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f23001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15230015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1723001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09230000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05290008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09290006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b29000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11290005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1329000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03290000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine32MetricSet::CVectorEngine32MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine32MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "ICACHE_HIT_XECORE62", "ICACHE HIT _XECORE62",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "ICACHE_HIT_XECORE63", "ICACHE HIT _XECORE63",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "ICACHE_MISS_XECORE62", "ICACHE MISS XECORE62",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "ICACHE_MISS_XECORE63", "ICACHE MISS XECORE63",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD 2 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e501000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17312ccd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21336800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2333000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17392cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x213b6800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x233b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05310008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d310006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f31000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15310005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03310000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05337600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d330016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f33001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15330015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1733001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09330000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333cc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f54400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05390008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09390006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b39000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11390005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1339000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03390000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x053b7600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x093b0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b3b001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x113b0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x133b001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b00cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd0044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0a0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine33MetricSet::CVectorEngine33MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine33MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE0_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE0 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE0_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE0 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE0_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE0 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE0_XVE0_THREAD0", "XVE_STALL_OTHER XECORE0 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE0_XVE0_THREAD0", "XVE_STALL_SBID XECORE0 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE0_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE0 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE0_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE0 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE0_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE0 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c404a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e40016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04404e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06400717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08402928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a400851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine34MetricSet::CVectorEngine34MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine34MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE1_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE1 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE1_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE1 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE1_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE1 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE1_XVE0_THREAD0", "XVE_STALL_OTHER XECORE1 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE1_XVE0_THREAD0", "XVE_STALL_SBID XECORE1 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE1_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE1 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE1_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE1 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE1_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE1 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c484a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e48016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04484e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08482928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine35MetricSet::CVectorEngine35MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine35MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE2_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE2 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE2_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE2 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE2_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE2 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE2_XVE0_THREAD0", "XVE_STALL_OTHER XECORE2 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE2_XVE0_THREAD0", "XVE_STALL_SBID XECORE2 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE2_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE2 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE2_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE2 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE2_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE2 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c504a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e50016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x025042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04504e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06500717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08502928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a500851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine36MetricSet::CVectorEngine36MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine36MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE3_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE3 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE3_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE3 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE3_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE3 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE3_XVE0_THREAD0", "XVE_STALL_OTHER XECORE3 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE3_XVE0_THREAD0", "XVE_STALL_SBID XECORE3 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE3_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE3 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE3_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE3 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE3_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE3 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c584a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e58016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x025842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04584e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06580717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08582928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a580851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine37MetricSet::CVectorEngine37MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine37MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE4_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE4 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE4_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE4 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE4_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE4 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE4_XVE0_THREAD0", "XVE_STALL_OTHER XECORE4 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE4_XVE0_THREAD0", "XVE_STALL_SBID XECORE4 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE4_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE4 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE4_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE4 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE4_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE4 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c604a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e60016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04604e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06600717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08602928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a600851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine38MetricSet::CVectorEngine38MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine38MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE5_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE5 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE5_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE5 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE5_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE5 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE5_XVE0_THREAD0", "XVE_STALL_OTHER XECORE5 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE5_XVE0_THREAD0", "XVE_STALL_SBID XECORE5 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE5_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE5 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE5_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE5 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE5_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE5 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c684a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e68016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04684e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06680717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08682928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a680851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine39MetricSet::CVectorEngine39MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine39MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE6_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE6 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE6_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE6 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE6_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE6 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE6_XVE0_THREAD0", "XVE_STALL_OTHER XECORE6 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE6_XVE0_THREAD0", "XVE_STALL_SBID XECORE6 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE6_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE6 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE6_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE6 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE6_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE6 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c704a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e70016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x027042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04704e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06700717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08702928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a700851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine40MetricSet::CVectorEngine40MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine40MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE7_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE7 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE7_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE7 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE7_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE7 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE7_XVE0_THREAD0", "XVE_STALL_OTHER XECORE7 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE7_XVE0_THREAD0", "XVE_STALL_SBID XECORE7 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE7_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE7 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE7_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE7 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE7_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE7 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c784a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e78016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x027842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04784e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06780717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08782928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a780851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine41MetricSet::CVectorEngine41MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine41MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE8_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE8 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE8_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE8 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE8_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE8 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE8_XVE0_THREAD0", "XVE_STALL_OTHER XECORE8 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE8_XVE0_THREAD0", "XVE_STALL_SBID XECORE8 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE8_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE8 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE8_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE8 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE8_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE8 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d404a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f40016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05404e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07400717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09402928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b400851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine42MetricSet::CVectorEngine42MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine42MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE9_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE9 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE9_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE9 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE9_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE9 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE9_XVE0_THREAD0", "XVE_STALL_OTHER XECORE9 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE9_XVE0_THREAD0", "XVE_STALL_SBID XECORE9 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE9_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE9 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE9_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE9 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE9_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE9 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d484a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f48016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05484e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07480717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09482928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b480851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine43MetricSet::CVectorEngine43MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine43MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE10_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE10 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE10_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE10 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE10_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE10 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE10_XVE0_THREAD0", "XVE_STALL_OTHER XECORE10 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE10_XVE0_THREAD0", "XVE_STALL_SBID XECORE10 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE10_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE10 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE10_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE10 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE10_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE10 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d504a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x035042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05504e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07500717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09502928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b500851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine44MetricSet::CVectorEngine44MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine44MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE11_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE11 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE11_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE11 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE11_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE11 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE11_XVE0_THREAD0", "XVE_STALL_OTHER XECORE11 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE11_XVE0_THREAD0", "XVE_STALL_SBID XECORE11 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE11_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE11 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE11_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE11 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE11_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE11 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d584a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f58016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x035842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05584e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07580717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09582928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b580851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine45MetricSet::CVectorEngine45MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine45MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE12_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE12 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE12_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE12 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE12_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE12 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE12_XVE0_THREAD0", "XVE_STALL_OTHER XECORE12 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE12_XVE0_THREAD0", "XVE_STALL_SBID XECORE12 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE12_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE12 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE12_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE12 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE12_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE12 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d604a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f60016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05604e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07600717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09602928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b600851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine46MetricSet::CVectorEngine46MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine46MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE13_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE13 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE13_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE13 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE13_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE13 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE13_XVE0_THREAD0", "XVE_STALL_OTHER XECORE13 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE13_XVE0_THREAD0", "XVE_STALL_SBID XECORE13 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE13_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE13 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE13_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE13 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE13_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE13 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d684a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f68016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05684e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07680717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09682928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b680851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine47MetricSet::CVectorEngine47MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine47MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE14_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE14 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE14_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE14 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE14_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE14 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE14_XVE0_THREAD0", "XVE_STALL_OTHER XECORE14 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE14_XVE0_THREAD0", "XVE_STALL_SBID XECORE14 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE14_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE14 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE14_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE14 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE14_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE14 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d704a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f70016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05704e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07700717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09702928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b700851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine48MetricSet::CVectorEngine48MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine48MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE15_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE15 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE15_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE15 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE15_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE15 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE15_XVE0_THREAD0", "XVE_STALL_OTHER XECORE15 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE15_XVE0_THREAD0", "XVE_STALL_SBID XECORE15 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE15_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE15 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE15_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE15 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE15_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE15 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d784a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f78016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05784e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07780717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09782928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b780851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine49MetricSet::CVectorEngine49MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine49MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE16_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE16 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE16_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE16 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE16_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE16 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE16_XVE0_THREAD0", "XVE_STALL_OTHER XECORE16 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE16_XVE0_THREAD0", "XVE_STALL_SBID XECORE16 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE16_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE16 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE16_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE16 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE16_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE16 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c404a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e40016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04404e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06400717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08402928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a400851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine50MetricSet::CVectorEngine50MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine50MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE17_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE17 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE17_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE17 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE17_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE17 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE17_XVE0_THREAD0", "XVE_STALL_OTHER XECORE17 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE17_XVE0_THREAD0", "XVE_STALL_SBID XECORE17 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE17_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE17 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE17_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE17 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE17_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE17 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c484a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e48016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04484e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08482928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine51MetricSet::CVectorEngine51MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine51MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE18_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE18 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE18_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE18 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE18_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE18 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE18_XVE0_THREAD0", "XVE_STALL_OTHER XECORE18 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE18_XVE0_THREAD0", "XVE_STALL_SBID XECORE18 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE18_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE18 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE18_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE18 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE18_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE18 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c504a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e50016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x025042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04504e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06500717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08502928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a500851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine52MetricSet::CVectorEngine52MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine52MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE19_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE19 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE19_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE19 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE19_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE19 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE19_XVE0_THREAD0", "XVE_STALL_OTHER XECORE19 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE19_XVE0_THREAD0", "XVE_STALL_SBID XECORE19 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE19_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE19 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE19_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE19 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE19_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE19 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c584a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e58016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x025842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04584e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06580717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08582928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a580851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine53MetricSet::CVectorEngine53MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine53MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE20_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE20 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE20_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE20 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE20_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE20 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE20_XVE0_THREAD0", "XVE_STALL_OTHER XECORE20 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE20_XVE0_THREAD0", "XVE_STALL_SBID XECORE20 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE20_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE20 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE20_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE20 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE20_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE20 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c604a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e60016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04604e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06600717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08602928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a600851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine54MetricSet::CVectorEngine54MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine54MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE21_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE21 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE21_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE21 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE21_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE21 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE21_XVE0_THREAD0", "XVE_STALL_OTHER XECORE21 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE21_XVE0_THREAD0", "XVE_STALL_SBID XECORE21 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE21_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE21 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE21_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE21 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE21_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE21 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c684a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e68016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04684e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06680717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08682928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a680851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine55MetricSet::CVectorEngine55MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine55MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE22_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE22 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE22_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE22 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE22_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE22 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE22_XVE0_THREAD0", "XVE_STALL_OTHER XECORE22 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE22_XVE0_THREAD0", "XVE_STALL_SBID XECORE22 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE22_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE22 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE22_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE22 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE22_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE22 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c704a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e70016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x027042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04704e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06700717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08702928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a700851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine56MetricSet::CVectorEngine56MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine56MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE23_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE23 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE23_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE23 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE23_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE23 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE23_XVE0_THREAD0", "XVE_STALL_OTHER XECORE23 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE23_XVE0_THREAD0", "XVE_STALL_SBID XECORE23 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE23_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE23 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE23_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE23 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE23_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE23 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c784a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e78016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x027842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04784e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06780717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08782928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a780851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine57MetricSet::CVectorEngine57MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine57MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE24_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE24 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE24_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE24 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE24_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE24 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE24_XVE0_THREAD0", "XVE_STALL_OTHER XECORE24 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE24_XVE0_THREAD0", "XVE_STALL_SBID XECORE24 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE24_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE24 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE24_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE24 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE24_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE24 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d404a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f40016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05404e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07400717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09402928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b400851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine58MetricSet::CVectorEngine58MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine58MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE25_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE25 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE25_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE25 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE25_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE25 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE25_XVE0_THREAD0", "XVE_STALL_OTHER XECORE25 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE25_XVE0_THREAD0", "XVE_STALL_SBID XECORE25 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE25_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE25 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE25_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE25 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE25_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE25 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d484a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f48016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05484e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07480717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09482928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b480851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine59MetricSet::CVectorEngine59MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine59MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE26_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE26 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE26_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE26 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE26_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE26 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE26_XVE0_THREAD0", "XVE_STALL_OTHER XECORE26 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE26_XVE0_THREAD0", "XVE_STALL_SBID XECORE26 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE26_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE26 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE26_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE26 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE26_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE26 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d504a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x035042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05504e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07500717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09502928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b500851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine60MetricSet::CVectorEngine60MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine60MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE27_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE27 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE27_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE27 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE27_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE27 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE27_XVE0_THREAD0", "XVE_STALL_OTHER XECORE27 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE27_XVE0_THREAD0", "XVE_STALL_SBID XECORE27 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE27_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE27 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE27_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE27 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE27_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE27 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d584a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f58016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x035842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05584e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07580717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09582928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b580851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine61MetricSet::CVectorEngine61MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine61MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE28_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE28 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE28_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE28 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE28_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE28 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE28_XVE0_THREAD0", "XVE_STALL_OTHER XECORE28 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE28_XVE0_THREAD0", "XVE_STALL_SBID XECORE28 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE28_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE28 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE28_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE28 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE28_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE28 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d604a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f60016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05604e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07600717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09602928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b600851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine62MetricSet::CVectorEngine62MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine62MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE29_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE29 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE29_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE29 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE29_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE29 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE29_XVE0_THREAD0", "XVE_STALL_OTHER XECORE29 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE29_XVE0_THREAD0", "XVE_STALL_SBID XECORE29 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE29_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE29 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE29_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE29 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE29_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE29 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d684a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f68016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05684e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07680717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09682928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b680851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine63MetricSet::CVectorEngine63MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine63MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE30_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE30 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE30_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE30 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE30_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE30 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE30_XVE0_THREAD0", "XVE_STALL_OTHER XECORE30 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE30_XVE0_THREAD0", "XVE_STALL_SBID XECORE30 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE30_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE30 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE30_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE30 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE30_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE30 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d704a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f70016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05704e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07700717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09702928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b700851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine64MetricSet::CVectorEngine64MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine64MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE31_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE31 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE31_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE31 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE31_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE31 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE31_XVE0_THREAD0", "XVE_STALL_OTHER XECORE31 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE31_XVE0_THREAD0", "XVE_STALL_SBID XECORE31 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE31_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE31 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE31_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE31 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE31_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE31 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d784a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f78016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05784e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07780717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09782928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b780851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine65MetricSet::CVectorEngine65MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine65MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE32_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE32 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE32_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE32 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE32_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE32 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE32_XVE0_THREAD0", "XVE_STALL_OTHER XECORE32 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE32_XVE0_THREAD0", "XVE_STALL_SBID XECORE32 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE32_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE32 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE32_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE32 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE32_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE32 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c404a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e40016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04404e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06400717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08402928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a400851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine66MetricSet::CVectorEngine66MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine66MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE33_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE33 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE33_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE33 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE33_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE33 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE33_XVE0_THREAD0", "XVE_STALL_OTHER XECORE33 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE33_XVE0_THREAD0", "XVE_STALL_SBID XECORE33 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE33_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE33 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE33_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE33 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE33_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE33 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c484a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e48016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04484e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08482928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine67MetricSet::CVectorEngine67MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine67MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE34_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE34 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE34_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE34 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE34_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE34 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE34_XVE0_THREAD0", "XVE_STALL_OTHER XECORE34 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE34_XVE0_THREAD0", "XVE_STALL_SBID XECORE34 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE34_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE34 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE34_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE34 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE34_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE34 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c504a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e50016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x025042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04504e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06500717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08502928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a500851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine68MetricSet::CVectorEngine68MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine68MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE35_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE35 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE35_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE35 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE35_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE35 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE35_XVE0_THREAD0", "XVE_STALL_OTHER XECORE35 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE35_XVE0_THREAD0", "XVE_STALL_SBID XECORE35 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE35_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE35 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE35_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE35 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE35_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE35 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c584a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e58016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x025842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04584e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06580717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08582928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a580851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine69MetricSet::CVectorEngine69MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine69MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE36_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE36 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE36_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE36 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE36_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE36 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE36_XVE0_THREAD0", "XVE_STALL_OTHER XECORE36 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE36_XVE0_THREAD0", "XVE_STALL_SBID XECORE36 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE36_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE36 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE36_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE36 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE36_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE36 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c604a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e60016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04604e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06600717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08602928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a600851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine70MetricSet::CVectorEngine70MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine70MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE37_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE37 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE37_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE37 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE37_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE37 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE37_XVE0_THREAD0", "XVE_STALL_OTHER XECORE37 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE37_XVE0_THREAD0", "XVE_STALL_SBID XECORE37 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE37_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE37 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE37_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE37 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE37_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE37 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c684a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e68016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04684e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06680717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08682928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a680851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine71MetricSet::CVectorEngine71MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine71MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE38_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE38 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE38_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE38 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE38_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE38 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE38_XVE0_THREAD0", "XVE_STALL_OTHER XECORE38 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE38_XVE0_THREAD0", "XVE_STALL_SBID XECORE38 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE38_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE38 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE38_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE38 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE38_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE38 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c704a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e70016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x027042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04704e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06700717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08702928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a700851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine72MetricSet::CVectorEngine72MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine72MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE39_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE39 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE39_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE39 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE39_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE39 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE39_XVE0_THREAD0", "XVE_STALL_OTHER XECORE39 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE39_XVE0_THREAD0", "XVE_STALL_SBID XECORE39 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE39_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE39 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE39_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE39 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE39_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE39 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c784a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e78016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x027842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04784e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06780717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08782928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a780851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine73MetricSet::CVectorEngine73MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine73MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE40_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE40 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE40_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE40 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE40_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE40 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE40_XVE0_THREAD0", "XVE_STALL_OTHER XECORE40 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE40_XVE0_THREAD0", "XVE_STALL_SBID XECORE40 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE40_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE40 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE40_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE40 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE40_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE40 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d404a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f40016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05404e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07400717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09402928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b400851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine74MetricSet::CVectorEngine74MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine74MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE41_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE41 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE41_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE41 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE41_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE41 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE41_XVE0_THREAD0", "XVE_STALL_OTHER XECORE41 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE41_XVE0_THREAD0", "XVE_STALL_SBID XECORE41 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE41_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE41 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE41_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE41 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE41_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE41 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d484a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f48016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05484e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07480717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09482928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b480851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine75MetricSet::CVectorEngine75MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine75MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE42_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE42 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE42_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE42 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE42_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE42 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE42_XVE0_THREAD0", "XVE_STALL_OTHER XECORE42 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE42_XVE0_THREAD0", "XVE_STALL_SBID XECORE42 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE42_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE42 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE42_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE42 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE42_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE42 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d504a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x035042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05504e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07500717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09502928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b500851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine76MetricSet::CVectorEngine76MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine76MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE43_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE43 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE43_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE43 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE43_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE43 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE43_XVE0_THREAD0", "XVE_STALL_OTHER XECORE43 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE43_XVE0_THREAD0", "XVE_STALL_SBID XECORE43 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE43_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE43 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE43_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE43 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE43_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE43 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d584a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f58016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x035842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05584e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07580717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09582928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b580851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine77MetricSet::CVectorEngine77MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine77MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE44_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE44 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE44_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE44 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE44_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE44 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE44_XVE0_THREAD0", "XVE_STALL_OTHER XECORE44 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE44_XVE0_THREAD0", "XVE_STALL_SBID XECORE44 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE44_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE44 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE44_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE44 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE44_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE44 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d604a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f60016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05604e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07600717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09602928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b600851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine78MetricSet::CVectorEngine78MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine78MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE45_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE45 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE45_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE45 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE45_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE45 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE45_XVE0_THREAD0", "XVE_STALL_OTHER XECORE45 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE45_XVE0_THREAD0", "XVE_STALL_SBID XECORE45 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE45_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE45 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE45_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE45 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE45_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE45 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d684a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f68016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05684e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07680717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09682928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b680851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine79MetricSet::CVectorEngine79MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine79MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE46_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE46 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE46_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE46 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE46_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE46 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE46_XVE0_THREAD0", "XVE_STALL_OTHER XECORE46 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE46_XVE0_THREAD0", "XVE_STALL_SBID XECORE46 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE46_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE46 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE46_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE46 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE46_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE46 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d704a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f70016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05704e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07700717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09702928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b700851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine80MetricSet::CVectorEngine80MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine80MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE47_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE47 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE47_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE47 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE47_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE47 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE47_XVE0_THREAD0", "XVE_STALL_OTHER XECORE47 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE47_XVE0_THREAD0", "XVE_STALL_SBID XECORE47 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE47_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE47 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE47_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE47 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE47_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE47 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d784a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f78016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05784e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07780717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09782928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b780851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine81MetricSet::CVectorEngine81MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine81MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE48_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE48 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE48_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE48 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE48_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE48 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE48_XVE0_THREAD0", "XVE_STALL_OTHER XECORE48 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE48_XVE0_THREAD0", "XVE_STALL_SBID XECORE48 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE48_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE48 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE48_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE48 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE48_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE48 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c404a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e40016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04404e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06400717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08402928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a400851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine82MetricSet::CVectorEngine82MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine82MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE49_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE49 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE49_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE49 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE49_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE49 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE49_XVE0_THREAD0", "XVE_STALL_OTHER XECORE49 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE49_XVE0_THREAD0", "XVE_STALL_SBID XECORE49 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE49_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE49 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE49_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE49 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE49_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE49 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c484a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e48016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04484e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06480717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08482928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a480851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine83MetricSet::CVectorEngine83MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine83MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE50_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE50 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE50_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE50 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE50_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE50 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE50_XVE0_THREAD0", "XVE_STALL_OTHER XECORE50 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE50_XVE0_THREAD0", "XVE_STALL_SBID XECORE50 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE50_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE50 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE50_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE50 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE50_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE50 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c504a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e50016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x025042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04504e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06500717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08502928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a500851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine84MetricSet::CVectorEngine84MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine84MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE51_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE51 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE51_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE51 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE51_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE51 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE51_XVE0_THREAD0", "XVE_STALL_OTHER XECORE51 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE51_XVE0_THREAD0", "XVE_STALL_SBID XECORE51 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE51_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE51 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE51_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE51 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE51_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE51 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c584a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e58016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x025842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04584e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06580717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08582928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a580851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine85MetricSet::CVectorEngine85MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine85MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE52_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE52 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE52_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE52 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE52_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE52 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE52_XVE0_THREAD0", "XVE_STALL_OTHER XECORE52 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE52_XVE0_THREAD0", "XVE_STALL_SBID XECORE52 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE52_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE52 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE52_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE52 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE52_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE52 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c604a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e60016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04604e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06600717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08602928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a600851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine86MetricSet::CVectorEngine86MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine86MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE53_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE53 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE53_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE53 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE53_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE53 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE53_XVE0_THREAD0", "XVE_STALL_OTHER XECORE53 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE53_XVE0_THREAD0", "XVE_STALL_SBID XECORE53 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE53_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE53 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE53_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE53 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE53_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE53 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c684a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e68016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04684e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06680717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08682928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a680851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine87MetricSet::CVectorEngine87MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine87MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE54_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE54 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE54_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE54 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE54_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE54 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE54_XVE0_THREAD0", "XVE_STALL_OTHER XECORE54 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE54_XVE0_THREAD0", "XVE_STALL_SBID XECORE54 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE54_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE54 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE54_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE54 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE54_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE54 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c704a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e70016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x027042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04704e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06700717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08702928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a700851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine88MetricSet::CVectorEngine88MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine88MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE55_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE55 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE55_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE55 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE55_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE55 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE55_XVE0_THREAD0", "XVE_STALL_OTHER XECORE55 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE55_XVE0_THREAD0", "XVE_STALL_SBID XECORE55 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE55_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE55 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE55_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE55 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE55_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE55 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c784a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e78016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x027842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04784e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06780717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08782928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a780851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine89MetricSet::CVectorEngine89MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine89MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE56_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE56 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE56_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE56 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE56_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE56 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE56_XVE0_THREAD0", "XVE_STALL_OTHER XECORE56 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE56_XVE0_THREAD0", "XVE_STALL_SBID XECORE56 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE56_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE56 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE56_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE56 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE56_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE56 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d404a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f40016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05404e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07400717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09402928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b400851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03015555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c05555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine90MetricSet::CVectorEngine90MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine90MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE57_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE57 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE57_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE57 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE57_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE57 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE57_XVE0_THREAD0", "XVE_STALL_OTHER XECORE57 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE57_XVE0_THREAD0", "XVE_STALL_SBID XECORE57 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE57_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE57 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE57_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE57 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE57_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE57 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d484a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f48016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05484e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07480717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09482928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b480851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03095555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ccffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ceffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c0aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine91MetricSet::CVectorEngine91MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine91MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE58_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE58 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE58_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE58 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE58_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE58 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE58_XVE0_THREAD0", "XVE_STALL_OTHER XECORE58 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE58_XVE0_THREAD0", "XVE_STALL_SBID XECORE58 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE58_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE58 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE58_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE58 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE58_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE58 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d504a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x035042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05504e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07500717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09502928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b500851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03115555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine92MetricSet::CVectorEngine92MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine92MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE59_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE59 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE59_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE59 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE59_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE59 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE59_XVE0_THREAD0", "XVE_STALL_OTHER XECORE59 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE59_XVE0_THREAD0", "XVE_STALL_SBID XECORE59 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE59_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE59 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE59_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE59 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE59_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE59 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d584a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f58016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x035842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05584e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07580717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09582928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b580851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03195555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01deffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine93MetricSet::CVectorEngine93MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine93MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE60_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE60 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE60_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE60 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE60_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE60 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE60_XVE0_THREAD0", "XVE_STALL_OTHER XECORE60 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE60_XVE0_THREAD0", "XVE_STALL_SBID XECORE60 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE60_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE60 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE60_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE60 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE60_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE60 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d604a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f60016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05604e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07600717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09602928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b600851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03215555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c25555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine94MetricSet::CVectorEngine94MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine94MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE61_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE61 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE61_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE61 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE61_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE61 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE61_XVE0_THREAD0", "XVE_STALL_OTHER XECORE61 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE61_XVE0_THREAD0", "XVE_STALL_SBID XECORE61 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE61_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE61 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE61_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE61 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE61_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE61 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d684a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f68016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05684e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07680717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09682928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b680851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03295555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ecffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01eeffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine95MetricSet::CVectorEngine95MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine95MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE62_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE62 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE62_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE62 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE62_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE62 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE62_XVE0_THREAD0", "XVE_STALL_OTHER XECORE62 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE62_XVE0_THREAD0", "XVE_STALL_SBID XECORE62 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE62_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE62 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE62_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE62 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE62_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE62 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d704a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f70016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05704e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07700717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09702928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b700851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03315555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f55555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c31249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine96MetricSet::CVectorEngine96MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine96MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE63_XVE0_THREAD0", "XVE_STALL_ALUWR XECORE63 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE63_XVE0_THREAD0", "XVE_STALL_BARRIER XECORE63 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE63_XVE0_THREAD0", "XVE_STALL_INSTFETCH XECORE63 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE63_XVE0_THREAD0", "XVE_STALL_OTHER XECORE63 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one thread is waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE63_XVE0_THREAD0", "XVE_STALL_SBID XECORE63 XVE0 THREAD0",
                          "Percentage of time WFWN XVE is stalled with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE63_XVE0_THREAD0", "XVE_STALL_SENDWR XECORE63 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled and at least one  thread is waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_STALL_CONTROL_XECORE63_XVE0_THREAD0", "XVE_STALL_CONTROL XECORE63 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread waiting for JEU to complete branch instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_STALL_PIPESTALL_XECORE63_XVE0_THREAD0", "XVE_STALL_PIPESTALL XECORE63 XVE0 THREAD0",
                          "Percentage of time when XVE is stalled, with at least one thread ready to be scheduled (Grf conf/send holds etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d784a36, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f78016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037842b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05784e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07780717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09782928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b780851, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03395555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033bffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fcffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01feffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine97MetricSet::CVectorEngine97MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine97MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE0", "XVE INST EXECUTED BITCONV XECORE0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE1", "XVE INST EXECUTED BITCONV XECORE1",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE0", "XVE INST EXECUTED XMX INT2 XECORE0",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE1", "XVE INST EXECUTED XMX INT2 XECORE1",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE0", "XVE MULTIPLE PIPE ACTIVE XECORE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE1", "XVE MULTIPLE PIPE ACTIVE XECORE1",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE0_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE0 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE1_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE1 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE0_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE0 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE1_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE1 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE0_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE1_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c403e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e40000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c483e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e48000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08402411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a400180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02014444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02481800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06484415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08480120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a48200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00091050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02091111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c060a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine98MetricSet::CVectorEngine98MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine98MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE2", "XVE INST EXECUTED BITCONV XECORE2",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE3", "XVE INST EXECUTED BITCONV XECORE3",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE2", "XVE INST EXECUTED XMX INT2 XECORE2",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE3", "XVE INST EXECUTED XMX INT2 XECORE3",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE2", "XVE MULTIPLE PIPE ACTIVE XECORE2",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE3", "XVE MULTIPLE PIPE ACTIVE XECORE3",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE2_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE2 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE3_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE3 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE2_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE2 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE3_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE3 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE2_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE3_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c503e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e50000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c583e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e58000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x025000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x065002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08502411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a500180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00114005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02114444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02581800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04580007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06584415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08580120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a58200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00191050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02191111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c160a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c16666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine99MetricSet::CVectorEngine99MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine99MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE4", "XVE INST EXECUTED BITCONV XECORE4",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE5", "XVE INST EXECUTED BITCONV XECORE5",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE4", "XVE INST EXECUTED XMX INT2 XECORE4",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE5", "XVE INST EXECUTED XMX INT2 XECORE5",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE4", "XVE MULTIPLE PIPE ACTIVE XECORE4",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE5", "XVE MULTIPLE PIPE ACTIVE XECORE5",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE4_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE4 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE5_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE5 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE4_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE4 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE5_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE5 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE4_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE5_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c603e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e60000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c683e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e68000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08602411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a600180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00214005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02214444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02681800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04680007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06684415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08680120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a68200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00291050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02291111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c260a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c26666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine100MetricSet::CVectorEngine100MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine100MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE6", "XVE INST EXECUTED BITCONV XECORE6",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE7", "XVE INST EXECUTED BITCONV XECORE7",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE6", "XVE INST EXECUTED XMX INT2 XECORE6",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE7", "XVE INST EXECUTED XMX INT2 XECORE7",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE6", "XVE MULTIPLE PIPE ACTIVE XECORE6",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE7", "XVE MULTIPLE PIPE ACTIVE XECORE7",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE6_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE6 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE7_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE7 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE6_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE6 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE7_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE7 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE6_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE7_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c703e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e70000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c783e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e78000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x027000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x067002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08702411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a700180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00314005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02314444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02781800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04780007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06784415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08780120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a78200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00391050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02391111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine101MetricSet::CVectorEngine101MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine101MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE8", "XVE INST EXECUTED BITCONV XECORE8",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE9", "XVE INST EXECUTED BITCONV XECORE9",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE8", "XVE INST EXECUTED XMX INT2 XECORE8",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE9", "XVE INST EXECUTED XMX INT2 XECORE9",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE8", "XVE MULTIPLE PIPE ACTIVE XECORE8",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE9", "XVE MULTIPLE PIPE ACTIVE XECORE9",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE8_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE8 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE9_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE9 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE8_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE8 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE9_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE9 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE8_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE9_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d403e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f40000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d483e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f48000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09402411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b400180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01014005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03014444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03481800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07484415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09480120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b48200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03091111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c060a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine102MetricSet::CVectorEngine102MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine102MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE10", "XVE INST EXECUTED BITCONV XECORE10",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE11", "XVE INST EXECUTED BITCONV XECORE11",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE10", "XVE INST EXECUTED XMX INT2 XECORE10",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE11", "XVE INST EXECUTED XMX INT2 XECORE11",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE10", "XVE MULTIPLE PIPE ACTIVE XECORE10",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE11", "XVE MULTIPLE PIPE ACTIVE XECORE11",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE10_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE10 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE11_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE11 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE10_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE10 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE11_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE11 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE10_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE11_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d503e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d583e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f58000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x035000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x075002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09502411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b500180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01114005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03114444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03581800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05580007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07584415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09580120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b58200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01191050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03191111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c160a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c16666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine103MetricSet::CVectorEngine103MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine103MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE12", "XVE INST EXECUTED BITCONV XECORE12",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE13", "XVE INST EXECUTED BITCONV XECORE13",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE12", "XVE INST EXECUTED XMX INT2 XECORE12",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE13", "XVE INST EXECUTED XMX INT2 XECORE13",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE12", "XVE MULTIPLE PIPE ACTIVE XECORE12",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE13", "XVE MULTIPLE PIPE ACTIVE XECORE13",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE12_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE12 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE13_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE13 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE12_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE12 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE13_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE13 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE12_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE13_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d603e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f60000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d683e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f68000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x076002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09602411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b600180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01214005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03214444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03681800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05680007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07684415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09680120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b68200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01291050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03291111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c260a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c26666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine104MetricSet::CVectorEngine104MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine104MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE14", "XVE INST EXECUTED BITCONV XECORE14",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE15", "XVE INST EXECUTED BITCONV XECORE15",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE14", "XVE INST EXECUTED XMX INT2 XECORE14",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE15", "XVE INST EXECUTED XMX INT2 XECORE15",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE14", "XVE MULTIPLE PIPE ACTIVE XECORE14",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE15", "XVE MULTIPLE PIPE ACTIVE XECORE15",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE14_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE14 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE15_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE15 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE14_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE14 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE15_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE15 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE14_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE15_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d703e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f70000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d783e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f78000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x077002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09702411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b700180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01314005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03314444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03781800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05780007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07784415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09780120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b78200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01391050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03391111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine105MetricSet::CVectorEngine105MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine105MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE16", "XVE INST EXECUTED BITCONV XECORE16",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE17", "XVE INST EXECUTED BITCONV XECORE17",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE16", "XVE INST EXECUTED XMX INT2 XECORE16",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE17", "XVE INST EXECUTED XMX INT2 XECORE17",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE16", "XVE MULTIPLE PIPE ACTIVE XECORE16",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE17", "XVE MULTIPLE PIPE ACTIVE XECORE17",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE16_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE16 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE17_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE17 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE16_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE16 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE17_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE17 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE16_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE16 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE17_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE17 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c403e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e40000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c483e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e48000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08402411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a400180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02014444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02481800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06484415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08480120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a48200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00091050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02091111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c060a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine106MetricSet::CVectorEngine106MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine106MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE18", "XVE INST EXECUTED BITCONV XECORE18",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE19", "XVE INST EXECUTED BITCONV XECORE19",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE18", "XVE INST EXECUTED XMX INT2 XECORE18",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE19", "XVE INST EXECUTED XMX INT2 XECORE19",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE18", "XVE MULTIPLE PIPE ACTIVE XECORE18",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE19", "XVE MULTIPLE PIPE ACTIVE XECORE19",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE18_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE18 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE19_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE19 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE18_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE18 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE19_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE19 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE18_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE18 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE19_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE19 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c503e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e50000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c583e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e58000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x025000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x065002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08502411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a500180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00114005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02114444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02581800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04580007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06584415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08580120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a58200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00191050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02191111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c160a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c16666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine107MetricSet::CVectorEngine107MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine107MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE20", "XVE INST EXECUTED BITCONV XECORE20",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE21", "XVE INST EXECUTED BITCONV XECORE21",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE20", "XVE INST EXECUTED XMX INT2 XECORE20",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE21", "XVE INST EXECUTED XMX INT2 XECORE21",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE20", "XVE MULTIPLE PIPE ACTIVE XECORE20",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE21", "XVE MULTIPLE PIPE ACTIVE XECORE21",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE20_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE20 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE21_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE21 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE20_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE20 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE21_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE21 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE20_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE20 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE21_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE21 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c603e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e60000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c683e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e68000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08602411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a600180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00214005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02214444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02681800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04680007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06684415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08680120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a68200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00291050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02291111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c260a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c26666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine108MetricSet::CVectorEngine108MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine108MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE22", "XVE INST EXECUTED BITCONV XECORE22",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE23", "XVE INST EXECUTED BITCONV XECORE23",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE22", "XVE INST EXECUTED XMX INT2 XECORE22",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE23", "XVE INST EXECUTED XMX INT2 XECORE23",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE22", "XVE MULTIPLE PIPE ACTIVE XECORE22",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE23", "XVE MULTIPLE PIPE ACTIVE XECORE23",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE22_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE22 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE23_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE23 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE22_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE22 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE23_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE23 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE22_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE22 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE23_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE23 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c703e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e70000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c783e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e78000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x027000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x067002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08702411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a700180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00314005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02314444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02781800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04780007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06784415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08780120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a78200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00391050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02391111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine109MetricSet::CVectorEngine109MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine109MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE24", "XVE INST EXECUTED BITCONV XECORE24",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE25", "XVE INST EXECUTED BITCONV XECORE25",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE24", "XVE INST EXECUTED XMX INT2 XECORE24",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE25", "XVE INST EXECUTED XMX INT2 XECORE25",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE24", "XVE MULTIPLE PIPE ACTIVE XECORE24",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE25", "XVE MULTIPLE PIPE ACTIVE XECORE25",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE24_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE24 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE25_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE25 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE24_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE24 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE25_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE25 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE24_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE24 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE25_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE25 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d403e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f40000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d483e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f48000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09402411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b400180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01014005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03014444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03481800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07484415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09480120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b48200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03091111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c060a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine110MetricSet::CVectorEngine110MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine110MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE26", "XVE INST EXECUTED BITCONV XECORE26",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE27", "XVE INST EXECUTED BITCONV XECORE27",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE26", "XVE INST EXECUTED XMX INT2 XECORE26",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE27", "XVE INST EXECUTED XMX INT2 XECORE27",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE26", "XVE MULTIPLE PIPE ACTIVE XECORE26",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE27", "XVE MULTIPLE PIPE ACTIVE XECORE27",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE26_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE26 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE27_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE27 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE26_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE26 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE27_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE27 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE26_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE26 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE27_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE27 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d503e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d583e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f58000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x035000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x075002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09502411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b500180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01114005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03114444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03581800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05580007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07584415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09580120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b58200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01191050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03191111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c160a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c16666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine111MetricSet::CVectorEngine111MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine111MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE28", "XVE INST EXECUTED BITCONV XECORE28",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE29", "XVE INST EXECUTED BITCONV XECORE29",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE28", "XVE INST EXECUTED XMX INT2 XECORE28",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE29", "XVE INST EXECUTED XMX INT2 XECORE29",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE28", "XVE MULTIPLE PIPE ACTIVE XECORE28",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE29", "XVE MULTIPLE PIPE ACTIVE XECORE29",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE28_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE28 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE29_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE29 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE28_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE28 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE29_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE29 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE28_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE28 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE29_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE29 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d603e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f60000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d683e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f68000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x076002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09602411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b600180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01214005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03214444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03681800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05680007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07684415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09680120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b68200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01291050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03291111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c260a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c26666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine112MetricSet::CVectorEngine112MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine112MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE30", "XVE INST EXECUTED BITCONV XECORE30",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE31", "XVE INST EXECUTED BITCONV XECORE31",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE30", "XVE INST EXECUTED XMX INT2 XECORE30",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE31", "XVE INST EXECUTED XMX INT2 XECORE31",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE30", "XVE MULTIPLE PIPE ACTIVE XECORE30",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE31", "XVE MULTIPLE PIPE ACTIVE XECORE31",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE30_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE30 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE31_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE31 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE30_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE30 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE31_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE31 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE30_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE30 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE31_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE31 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d703e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f70000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d783e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f78000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x077002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09702411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b700180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01314005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03314444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03781800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05780007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07784415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09780120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b78200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01391050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03391111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine113MetricSet::CVectorEngine113MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine113MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE32", "XVE INST EXECUTED BITCONV XECORE32",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE33", "XVE INST EXECUTED BITCONV XECORE33",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE32", "XVE INST EXECUTED XMX INT2 XECORE32",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE33", "XVE INST EXECUTED XMX INT2 XECORE33",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE32", "XVE MULTIPLE PIPE ACTIVE XECORE32",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE33", "XVE MULTIPLE PIPE ACTIVE XECORE33",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE32_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE32 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE33_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE33 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE32_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE32 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE33_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE33 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE32_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE32 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE33_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE33 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c403e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e40000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c483e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e48000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08402411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a400180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02014444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02481800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06484415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08480120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a48200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00091050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02091111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c060a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine114MetricSet::CVectorEngine114MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine114MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE34", "XVE INST EXECUTED BITCONV XECORE34",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE35", "XVE INST EXECUTED BITCONV XECORE35",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE34", "XVE INST EXECUTED XMX INT2 XECORE34",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE35", "XVE INST EXECUTED XMX INT2 XECORE35",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE34", "XVE MULTIPLE PIPE ACTIVE XECORE34",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE35", "XVE MULTIPLE PIPE ACTIVE XECORE35",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE34_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE34 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE35_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE35 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE34_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE34 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE35_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE35 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE34_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE34 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE35_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE35 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c503e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e50000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c583e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e58000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x025000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x065002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08502411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a500180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00114005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02114444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02581800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04580007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06584415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08580120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a58200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00191050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02191111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c160a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c16666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine115MetricSet::CVectorEngine115MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine115MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE36", "XVE INST EXECUTED BITCONV XECORE36",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE37", "XVE INST EXECUTED BITCONV XECORE37",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE36", "XVE INST EXECUTED XMX INT2 XECORE36",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE37", "XVE INST EXECUTED XMX INT2 XECORE37",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE36", "XVE MULTIPLE PIPE ACTIVE XECORE36",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE37", "XVE MULTIPLE PIPE ACTIVE XECORE37",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE36_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE36 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE37_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE37 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE36_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE36 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE37_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE37 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE36_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE36 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE37_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE37 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c603e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e60000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c683e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e68000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08602411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a600180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00214005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02214444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02681800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04680007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06684415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08680120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a68200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00291050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02291111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c260a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c26666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine116MetricSet::CVectorEngine116MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine116MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE38", "XVE INST EXECUTED BITCONV XECORE38",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE39", "XVE INST EXECUTED BITCONV XECORE39",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE38", "XVE INST EXECUTED XMX INT2 XECORE38",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE39", "XVE INST EXECUTED XMX INT2 XECORE39",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE38", "XVE MULTIPLE PIPE ACTIVE XECORE38",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE39", "XVE MULTIPLE PIPE ACTIVE XECORE39",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE38_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE38 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE39_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE39 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE38_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE38 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE39_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE39 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE38_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE38 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE39_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE39 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c703e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e70000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c783e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e78000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x027000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x067002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08702411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a700180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00314005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02314444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02781800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04780007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06784415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08780120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a78200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00391050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02391111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine117MetricSet::CVectorEngine117MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine117MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE40", "XVE INST EXECUTED BITCONV XECORE40",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE41", "XVE INST EXECUTED BITCONV XECORE41",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE40", "XVE INST EXECUTED XMX INT2 XECORE40",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE41", "XVE INST EXECUTED XMX INT2 XECORE41",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE40", "XVE MULTIPLE PIPE ACTIVE XECORE40",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE41", "XVE MULTIPLE PIPE ACTIVE XECORE41",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE40_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE40 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE41_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE41 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE40_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE40 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE41_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE41 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE40_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE40 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE41_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE41 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d403e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f40000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d483e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f48000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09402411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b400180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01014005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03014444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03481800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07484415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09480120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b48200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03091111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c060a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine118MetricSet::CVectorEngine118MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine118MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE42", "XVE INST EXECUTED BITCONV XECORE42",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE43", "XVE INST EXECUTED BITCONV XECORE43",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE42", "XVE INST EXECUTED XMX INT2 XECORE42",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE43", "XVE INST EXECUTED XMX INT2 XECORE43",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE42", "XVE MULTIPLE PIPE ACTIVE XECORE42",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE43", "XVE MULTIPLE PIPE ACTIVE XECORE43",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE42_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE42 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE43_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE43 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE42_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE42 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE43_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE43 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE42_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE42 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE43_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE43 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d503e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d583e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f58000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x035000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x075002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09502411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b500180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01114005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03114444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03581800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05580007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07584415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09580120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b58200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01191050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03191111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c160a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c16666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine119MetricSet::CVectorEngine119MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine119MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE44", "XVE INST EXECUTED BITCONV XECORE44",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE45", "XVE INST EXECUTED BITCONV XECORE45",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE44", "XVE INST EXECUTED XMX INT2 XECORE44",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE45", "XVE INST EXECUTED XMX INT2 XECORE45",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE44", "XVE MULTIPLE PIPE ACTIVE XECORE44",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE45", "XVE MULTIPLE PIPE ACTIVE XECORE45",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE44_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE44 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE45_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE45 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE44_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE44 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE45_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE45 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE44_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE44 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE45_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE45 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d603e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f60000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d683e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f68000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x076002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09602411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b600180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01214005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03214444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03681800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05680007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07684415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09680120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b68200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01291050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03291111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c260a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c26666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine120MetricSet::CVectorEngine120MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine120MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE46", "XVE INST EXECUTED BITCONV XECORE46",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE47", "XVE INST EXECUTED BITCONV XECORE47",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE46", "XVE INST EXECUTED XMX INT2 XECORE46",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE47", "XVE INST EXECUTED XMX INT2 XECORE47",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE46", "XVE MULTIPLE PIPE ACTIVE XECORE46",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE47", "XVE MULTIPLE PIPE ACTIVE XECORE47",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE46_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE46 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE47_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE47 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE46_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE46 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE47_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE47 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE46_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE46 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE47_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE47 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d703e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f70000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d783e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f78000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x077002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09702411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b700180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01314005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03314444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03781800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05780007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07784415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09780120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b78200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01391050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03391111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine121MetricSet::CVectorEngine121MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine121MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE48", "XVE INST EXECUTED BITCONV XECORE48",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE49", "XVE INST EXECUTED BITCONV XECORE49",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE48", "XVE INST EXECUTED XMX INT2 XECORE48",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE49", "XVE INST EXECUTED XMX INT2 XECORE49",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE48", "XVE MULTIPLE PIPE ACTIVE XECORE48",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE49", "XVE MULTIPLE PIPE ACTIVE XECORE49",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE48_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE48 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE49_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE49 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE48_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE48 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE49_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE49 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE48_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE48 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE49_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE49 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c403e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e40000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c483e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e48000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x064002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08402411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a400180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02014444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02481800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06484415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08480120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a48200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00091050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02091111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c060a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine122MetricSet::CVectorEngine122MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine122MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE50", "XVE INST EXECUTED BITCONV XECORE50",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE51", "XVE INST EXECUTED BITCONV XECORE51",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE50", "XVE INST EXECUTED XMX INT2 XECORE50",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE51", "XVE INST EXECUTED XMX INT2 XECORE51",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE50", "XVE MULTIPLE PIPE ACTIVE XECORE50",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE51", "XVE MULTIPLE PIPE ACTIVE XECORE51",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE50_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE50 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE51_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE51 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE50_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE50 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE51_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE51 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE50_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE50 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE51_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE51 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c503e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e50000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c583e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e58000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x025000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x065002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08502411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a500180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00114005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02114444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0013c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0213cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02581800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04580007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06584415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08580120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a58200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00191050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02191111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x001b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c160a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c16666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine123MetricSet::CVectorEngine123MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine123MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE52", "XVE INST EXECUTED BITCONV XECORE52",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE53", "XVE INST EXECUTED BITCONV XECORE53",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE52", "XVE INST EXECUTED XMX INT2 XECORE52",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE53", "XVE INST EXECUTED XMX INT2 XECORE53",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE52", "XVE MULTIPLE PIPE ACTIVE XECORE52",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE53", "XVE MULTIPLE PIPE ACTIVE XECORE53",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE52_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE52 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE53_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE53 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE52_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE52 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE53_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE53 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE52_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE52 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE53_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE53 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c603e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e60000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c683e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e68000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x066002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08602411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a600180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00214005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02214444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0023c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0223cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02681800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04680007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06684415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08680120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a68200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00291050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02291111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x002b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ed1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c260a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c26666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine124MetricSet::CVectorEngine124MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine124MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE54", "XVE INST EXECUTED BITCONV XECORE54",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE55", "XVE INST EXECUTED BITCONV XECORE55",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE54", "XVE INST EXECUTED XMX INT2 XECORE54",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE55", "XVE INST EXECUTED XMX INT2 XECORE55",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE54", "XVE MULTIPLE PIPE ACTIVE XECORE54",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE55", "XVE MULTIPLE PIPE ACTIVE XECORE55",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE54_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE54 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE55_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE55 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE54_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE54 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE55_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE55 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE54_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE54 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE55_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE55 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f15055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f30492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f32490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22d306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c703e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e70000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c783e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e78000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x027000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x067002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08702411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a700180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00314005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02314444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0033c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02781800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04780007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06784415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08780120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a78200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00391050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02391111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x003b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine125MetricSet::CVectorEngine125MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine125MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE56", "XVE INST EXECUTED BITCONV XECORE56",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE57", "XVE INST EXECUTED BITCONV XECORE57",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE56", "XVE INST EXECUTED XMX INT2 XECORE56",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE57", "XVE INST EXECUTED XMX INT2 XECORE57",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE56", "XVE MULTIPLE PIPE ACTIVE XECORE56",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE57", "XVE MULTIPLE PIPE ACTIVE XECORE57",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE56_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE56 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE57_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE57 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE56_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE56 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE57_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE57 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE56_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE56 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE57_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE57 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d403e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f40000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d483e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f48000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09402411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b400180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01014005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03014444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0303cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03481800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07484415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09480120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b48200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03091111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03cd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c060a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c06666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c1ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine126MetricSet::CVectorEngine126MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine126MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE58", "XVE INST EXECUTED BITCONV XECORE58",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE59", "XVE INST EXECUTED BITCONV XECORE59",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE58", "XVE INST EXECUTED XMX INT2 XECORE58",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE59", "XVE INST EXECUTED XMX INT2 XECORE59",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE58", "XVE MULTIPLE PIPE ACTIVE XECORE58",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE59", "XVE MULTIPLE PIPE ACTIVE XECORE59",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE58_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE58 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE59_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE59 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE58_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE58 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE59_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE59 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE58_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE58 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE59_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE59 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d503e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d583e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f58000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x035000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x075002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09502411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b500180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01114005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03114444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0113c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0313cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03581800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05580007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07584415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09580120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b58200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01191050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03191111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x031b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03dd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c160a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c16666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c2ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine127MetricSet::CVectorEngine127MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine127MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE60", "XVE INST EXECUTED BITCONV XECORE60",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE61", "XVE INST EXECUTED BITCONV XECORE61",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE60", "XVE INST EXECUTED XMX INT2 XECORE60",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE61", "XVE INST EXECUTED XMX INT2 XECORE61",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE60", "XVE MULTIPLE PIPE ACTIVE XECORE60",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE61", "XVE MULTIPLE PIPE ACTIVE XECORE61",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE60_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE60 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE61_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE61 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE60_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE60 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE61_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE61 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE60_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE60 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE61_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE61 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d603e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f60000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d683e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f68000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x076002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09602411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b600180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01214005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03214444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0123c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0323cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03681800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05680007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07684415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09680120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b68200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01291050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03291111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03ed1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c260a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c26666, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine128MetricSet::CVectorEngine128MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine128MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE62", "XVE INST EXECUTED BITCONV XECORE62",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BITCONV_XECORE63", "XVE INST EXECUTED BITCONV XECORE63",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE62", "XVE INST EXECUTED XMX INT2 XECORE62",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT2_XECORE63", "XVE INST EXECUTED XMX INT2 XECORE63",
                          "Number of execution slots taken by INT2 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE62", "XVE MULTIPLE PIPE ACTIVE XECORE62",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE63", "XVE MULTIPLE PIPE ACTIVE XECORE63",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE62_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE62 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_BARRIER_XECORE63_XVE0_THREAD0", "XVE INST EXECUTED BARRIER XECORE63 XVE0 THREAD0",
                          "Number of execution slots taken by bit manipulation instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE62_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE62 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_INST_EXECUTED_DIVERGENT_XECORE63_XVE0_THREAD0", "XVE INST EXECUTED_DIVERGENT XECORE63 XVE0 THREAD0",
                          "Number of execution slots taken by divergent instructions executed",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE62_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE62 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE63_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE63 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104a0aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffcf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f306db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f336d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d703e28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f70000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d783e20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f78000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x077002a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09702411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b700180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01314005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03314444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0333cccc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f4aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f54005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f54444, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f6aa83, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03781800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05780007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07784415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09780120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b78200c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01391050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03391111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b30f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x033b3333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd1050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03fd1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe554c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c31450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c3228a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine129MetricSet::CVectorEngine129MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine129MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE0_XVE0", "XVE INST ISSUED ALL XECORE0 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE1_XVE0", "XVE INST ISSUED ALL XECORE1 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE2_XVE0", "XVE INST ISSUED ALL XECORE2 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE3_XVE0", "XVE INST ISSUED ALL XECORE3 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore4";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE4_XVE0", "XVE INST ISSUED ALL XECORE4 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore5";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE5_XVE0", "XVE INST ISSUED ALL XECORE5 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore6";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE6_XVE0", "XVE INST ISSUED ALL XECORE6 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore7";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE7_XVE0", "XVE INST ISSUED ALL XECORE7 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE8_XVE0", "XVE INST ISSUED ALL XECORE8 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE9_XVE0", "XVE INST ISSUED ALL XECORE9 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE10_XVE0", "XVE INST ISSUED ALL XECORE10 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE11_XVE0", "XVE INST ISSUED ALL XECORE11 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore4";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE12_XVE0", "XVE INST ISSUED ALL XECORE12 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore5";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE13_XVE0", "XVE INST ISSUED ALL XECORE13 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore6";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE14_XVE0", "XVE INST ISSUED ALL XECORE14 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore7";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE15_XVE0", "XVE INST ISSUED ALL XECORE15 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4002e7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c5002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c5802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c7002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c7802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02014000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a481c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a5000e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a580007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08601c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08700007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06781c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d5002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d5802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d7002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d7802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074000e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01014000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x055800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05600007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03681c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037000e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03780007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine130MetricSet::CVectorEngine130MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine130MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE16_XVE0", "XVE INST ISSUED ALL XECORE16 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE17_XVE0", "XVE INST ISSUED ALL XECORE17 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE18_XVE0", "XVE INST ISSUED ALL XECORE18 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE19_XVE0", "XVE INST ISSUED ALL XECORE19 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore4";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE20_XVE0", "XVE INST ISSUED ALL XECORE20 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore5";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE21_XVE0", "XVE INST ISSUED ALL XECORE21 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore6";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE22_XVE0", "XVE INST ISSUED ALL XECORE22 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore7";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE23_XVE0", "XVE INST ISSUED ALL XECORE23 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE24_XVE0", "XVE INST ISSUED ALL XECORE24 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE25_XVE0", "XVE INST ISSUED ALL XECORE25 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE26_XVE0", "XVE INST ISSUED ALL XECORE26 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE27_XVE0", "XVE INST ISSUED ALL XECORE27 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore4";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE28_XVE0", "XVE INST ISSUED ALL XECORE28 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore5";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE29_XVE0", "XVE INST ISSUED ALL XECORE29 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore6";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE30_XVE0", "XVE INST ISSUED ALL XECORE30 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore7";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE31_XVE0", "XVE INST ISSUED ALL XECORE31 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4002e7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c5002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c5802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c7002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c7802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02014000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a481c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a5000e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a580007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08601c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08700007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06781c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d5002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d5802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d7002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d7802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074000e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01014000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x055800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05600007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03681c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037000e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03780007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine131MetricSet::CVectorEngine131MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine131MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE32_XVE0", "XVE INST ISSUED ALL XECORE32 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE33_XVE0", "XVE INST ISSUED ALL XECORE33 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE34_XVE0", "XVE INST ISSUED ALL XECORE34 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE35_XVE0", "XVE INST ISSUED ALL XECORE35 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore4";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE36_XVE0", "XVE INST ISSUED ALL XECORE36 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore5";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE37_XVE0", "XVE INST ISSUED ALL XECORE37 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore6";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE38_XVE0", "XVE INST ISSUED ALL XECORE38 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore7";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE39_XVE0", "XVE INST ISSUED ALL XECORE39 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE40_XVE0", "XVE INST ISSUED ALL XECORE40 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE41_XVE0", "XVE INST ISSUED ALL XECORE41 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE42_XVE0", "XVE INST ISSUED ALL XECORE42 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE43_XVE0", "XVE INST ISSUED ALL XECORE43 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore4";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE44_XVE0", "XVE INST ISSUED ALL XECORE44 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore5";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE45_XVE0", "XVE INST ISSUED ALL XECORE45 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore6";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE46_XVE0", "XVE INST ISSUED ALL XECORE46 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore7";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE47_XVE0", "XVE INST ISSUED ALL XECORE47 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0140ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3340ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4002e7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c5002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c5802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c7002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c7802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02014000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a481c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a5000e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a580007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08601c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08700007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06781c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d5002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d5802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d7002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d7802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074000e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01014000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x055800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05600007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03681c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037000e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03780007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine132MetricSet::CVectorEngine132MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine132MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE48_XVE0", "XVE INST ISSUED ALL XECORE48 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE49_XVE0", "XVE INST ISSUED ALL XECORE49 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE50_XVE0", "XVE INST ISSUED ALL XECORE50 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE51_XVE0", "XVE INST ISSUED ALL XECORE51 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore4";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE52_XVE0", "XVE INST ISSUED ALL XECORE52 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore5";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE53_XVE0", "XVE INST ISSUED ALL XECORE53 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore6";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE54_XVE0", "XVE INST ISSUED ALL XECORE54 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore7";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE55_XVE0", "XVE INST ISSUED ALL XECORE55 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE56_XVE0", "XVE INST ISSUED ALL XECORE56 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE57_XVE0", "XVE INST ISSUED ALL XECORE57 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE58_XVE0", "XVE INST ISSUED ALL XECORE58 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE59_XVE0", "XVE INST ISSUED ALL XECORE59 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore4";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE60_XVE0", "XVE INST ISSUED ALL XECORE60 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore5";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE61_XVE0", "XVE INST ISSUED ALL XECORE61 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore6";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE62_XVE0", "XVE INST ISSUED ALL XECORE62 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore7";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE63_XVE0", "XVE INST ISSUED ALL XECORE63 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x33405555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0141ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4f41ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03035555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0104aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0304aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0050ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e502400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28500090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a501008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c500070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e500c07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30500060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32500603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20500020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22500202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24500010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f50ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f0ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f2ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22f336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24f324db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26f32492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28f30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f4aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24d33600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26d336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28d30003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4002e7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c4802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c5002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c5802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c6802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c7002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c7802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02014000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0203c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c48000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c68000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a481c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00cc4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ce4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a5000e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02110400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d62000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a580007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02190100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00dc1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00de1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08601c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x086800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02290010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ec0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00ee0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08700007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02310004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0233000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f60200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06781c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02390001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x023b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fc0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00fe0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c31400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c336db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d5002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d5802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d7002e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d7802e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074000e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01400000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01014000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0103c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c54000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07480007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01480000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cc0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01cd1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ce0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05501c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01500000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01110400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01130c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d50400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d60020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x055800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01580000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01190100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x011b0300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dc0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01dd0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01de0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05600007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01600000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01210040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03681c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01680000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01290010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ec0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ed0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01ee0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x037000e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01700000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01310004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0133000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f60002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03780007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01780000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01390001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x013b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fc0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fd0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01fe0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c06000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c1f600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c2ff60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c336ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine133MetricSet::CVectorEngine133MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine133MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_ALU1_ACTIVE", "XVE PIPE ALU0 AND ALU1 ACTIVE",
                          "Percentage of time in which ALU0 and ALU1 pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_ALU2_ACTIVE", "XVE PIPE ALU0 AND ALU2 ACTIVE",
                          "Percentage of time in which ALU0 and ALU2 pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL", "XVE INST EXECUTED ALU0 ALL",
                          "Number of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL", "XVE INST EXECUTED ALU1 ALL",
                          "Number of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU2_ALL", "XVE INST EXECUTED ALU2 ALL",
                          "Number of execution slots taken by instructions executed on ALU2 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_CONTROL_ALL", "XVE INST EXECUTED CONTROL ALL",
                          "Number of instructions executed on Jump Pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL", "XVE INST EXECUTED SEND ALL",
                          "Number of instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE_CYCLES", "XVE ACTIVE CYCLES",
                          "Number of cycles at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES", "XVE STALL CYCLES",
                          "Number of cycles any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_CYCLES_ALL", "XVE THREADS OCCUPANCY CYCLES ALL",
                          "Number of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "8 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount $VectorEngineThreadsCount UMUL UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL_UTILIZATION", "XVE INST EXECUTED ALU0 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL_UTILIZATION", "XVE INST EXECUTED ALU1 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU2_ALL_UTILIZATION", "XVE INST EXECUTED ALU2 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU2 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_CONTROL_ALL_UTILIZATION", "XVE INST EXECUTED CONTROL ALL UTILIZATION",
                          "Percentage of time taken by instructions executed on Jump pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL_UTILIZATION", "XVE INST EXECUTED SEND ALL UTILIZATION",
                          "Percentage of time taken by instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_ALU2_ACTIVE_CYCLES", "XVE PIPE ALU0 AND ALU2 ACTIVE CYCLES",
                          "Number of cycles in ALU0 and ALU2 pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_PIPE_ALU0_AND_ALU2_ACTIVE" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_ALU1_ACTIVE_CYCLES", "XVE PIPE ALU0 AND ALU1 ACTIVE CYCLES",
                          "Number of cycles in ALU0 and ALU1 pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_PIPE_ALU0_AND_ALU1_ACTIVE" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x0000a003, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00009001, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x01002001, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x00005004, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CVectorEngine134MetricSet::CVectorEngine134MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CVectorEngine134MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL", "XVE INST EXECUTED ALU0 ALL",
                          "Number of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP16", "XVE INST EXECUTED FP16",
                          "Number of execution slots taken by FP16 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP32", "XVE INST EXECUTED FP32",
                          "Number of execution slots taken by FP32 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP64", "XVE INST EXECUTED FP64",
                          "Number of execution slots taken by FP64 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL", "XVE INST EXECUTED ALU1 ALL",
                          "Number of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_INT16", "XVE INST EXECUTED INT16",
                          "Number of execution slots taken by INT16 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_INT32", "XVE INST EXECUTED INT32",
                          "Number of execution slots taken by INT32 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_MATH", "XVE INST EXECUTED MATH",
                          "Number of execution slots taken by extended math instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU2_ALL", "XVE INST EXECUTED ALU2 ALL",
                          "Number of execution slots taken by instructions executed on ALU2 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT4", "XVE INST EXECUTED XMX INT4",
                          "Number of execution slots taken by INT4 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT8", "XVE INST EXECUTED XMX INT8",
                          "Number of execution slots taken by INT8 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x54:0xb1" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_FP16", "XVE INST EXECUTED XMX FP16",
                          "Number of execution slots taken by FP16 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_BF16", "XVE INST EXECUTED XMX BF16",
                          "Number of execution slots taken by BF16 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x5c:0xb3" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL_UTILIZATION", "XVE INST EXECUTED ALU0 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP16_UTILIZATION", "XVE INST EXECUTED FP16 UTILIZATION",
                          "Percentage of execution slots taken by FP16 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP32_UTILIZATION", "XVE INST EXECUTED FP32 UTILIZATION",
                          "Percentage of execution slots taken by FP32 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP64_UTILIZATION", "XVE INST EXECUTED FP64 UTILIZATION",
                          "Percentage of execution slots taken by FP64 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL_UTILIZATION", "XVE INST EXECUTED ALU1 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_INT16_UTILIZATION", "XVE INST EXECUTED INT16 UTILIZATION",
                          "Percentage of execution slots taken by INT16 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_INT32_UTILIZATION", "XVE INST EXECUTED INT32 UTILIZATION",
                          "Percentage of execution slots taken by INT32 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_MATH_UTILIZATION", "XVE INST EXECUTED MATH UTILIZATION",
                          "Percentage of execution slots taken by extended math instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 23 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU2_ALL_UTILIZATION", "XVE INST EXECUTED ALU2 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU2 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 24 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT4_UTILIZATION", "XVE INST EXECUTED XMX INT4 UTILIZATION",
                          "Percentage of execution slots taken by INT4 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 25 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT8_UTILIZATION", "XVE INST EXECUTED XMX INT8 UTILIZATION",
                          "Percentage of execution slots taken by INT8 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 26 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x54:0xb1" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_FP16_UTILIZATION", "XVE INST EXECUTED XMX FP16 UTILIZATION",
                          "Percentage of execution slots taken by FP16 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 27 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_BF16_UTILIZATION", "XVE INST EXECUTED XMX BF16 UTILIZATION",
                          "Percentage of execution slots taken by BF16 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 28 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x5c:0xb3" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00006000, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x0000b007, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x0000c001, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x0200000d, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x02003009, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe55c, 0x0200200f, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe65c, 0x0000000e, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
} // namespace MetricsDiscoveryInternal::MetricSets_PVC_GT2_OA

#endif
